var cH=Object.defineProperty;var dH=(e,t,n)=>t in e?cH(e,t,{enumerable:!0,configurable:!0,writable:!0,value:n}):e[t]=n;var Ea=(e,t,n)=>dH(e,typeof t!="symbol"?t+"":t,n);function fH(e,t){for(var n=0;n<t.length;n++){const r=t[n];if(typeof r!="string"&&!Array.isArray(r)){for(const a in r)if(a!=="default"&&!(a in e)){const i=Object.getOwnPropertyDescriptor(r,a);i&&Object.defineProperty(e,a,i.get?i:{enumerable:!0,get:()=>r[a]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}(function(){const t=document.createElement("link").relList;if(t&&t.supports&&t.supports("modulepreload"))return;for(const a of document.querySelectorAll('link[rel="modulepreload"]'))r(a);new MutationObserver(a=>{for(const i of a)if(i.type==="childList")for(const l of i.addedNodes)l.tagName==="LINK"&&l.rel==="modulepreload"&&r(l)}).observe(document,{childList:!0,subtree:!0});function n(a){const i={};return a.integrity&&(i.integrity=a.integrity),a.referrerPolicy&&(i.referrerPolicy=a.referrerPolicy),a.crossOrigin==="use-credentials"?i.credentials="include":a.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function r(a){if(a.ep)return;a.ep=!0;const i=n(a);fetch(a.href,i)}})();var Cd=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function an(e){return e&&e.__esModule&&Object.prototype.hasOwnProperty.call(e,"default")?e.default:e}function pH(e){if(e.__esModule)return e;var t=e.default;if(typeof t=="function"){var n=function r(){return this instanceof r?Reflect.construct(t,arguments,this.constructor):t.apply(this,arguments)};n.prototype=t.prototype}else n={};return Object.defineProperty(n,"__esModule",{value:!0}),Object.keys(e).forEach(function(r){var a=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(n,r,a.get?a:{enumerable:!0,get:function(){return e[r]}})}),n}var eh={exports:{}},Is={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var q1;function gH(){if(q1)return Is;q1=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.fragment");function n(r,a,i){var l=null;if(i!==void 0&&(l=""+i),a.key!==void 0&&(l=""+a.key),"key"in a){i={};for(var u in a)u!=="key"&&(i[u]=a[u])}else i=a;return a=i.ref,{$$typeof:e,type:r,key:l,ref:a!==void 0?a:null,props:i}}return Is.Fragment=t,Is.jsx=n,Is.jsxs=n,Is}var V1;function hH(){return V1||(V1=1,eh.exports=gH()),eh.exports}var w=hH(),th={exports:{}},at={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var W1;function mH(){if(W1)return at;W1=1;var e=Symbol.for("react.transitional.element"),t=Symbol.for("react.portal"),n=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),a=Symbol.for("react.profiler"),i=Symbol.for("react.consumer"),l=Symbol.for("react.context"),u=Symbol.for("react.forward_ref"),c=Symbol.for("react.suspense"),f=Symbol.for("react.memo"),p=Symbol.for("react.lazy"),g=Symbol.iterator;function b(D){return D===null||typeof D!="object"?null:(D=g&&D[g]||D["@@iterator"],typeof D=="function"?D:null)}var m={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},S=Object.assign,v={};function A(D,V,U){this.props=D,this.context=V,this.refs=v,this.updater=U||m}A.prototype.isReactComponent={},A.prototype.setState=function(D,V){if(typeof D!="object"&&typeof D!="function"&&D!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,D,V,"setState")},A.prototype.forceUpdate=function(D){this.updater.enqueueForceUpdate(this,D,"forceUpdate")};function R(){}R.prototype=A.prototype;function x(D,V,U){this.props=D,this.context=V,this.refs=v,this.updater=U||m}var T=x.prototype=new R;T.constructor=x,S(T,A.prototype),T.isPureReactComponent=!0;var C=Array.isArray,N={H:null,A:null,T:null,S:null},_=Object.prototype.hasOwnProperty;function O(D,V,U,L,Y,Q){return U=Q.ref,{$$typeof:e,type:D,key:V,ref:U!==void 0?U:null,props:Q}}function z(D,V){return O(D.type,V,void 0,void 0,void 0,D.props)}function I(D){return typeof D=="object"&&D!==null&&D.$$typeof===e}function M(D){var V={"=":"=0",":":"=2"};return"$"+D.replace(/[=:]/g,function(U){return V[U]})}var H=/\/+/g;function q(D,V){return typeof D=="object"&&D!==null&&D.key!=null?M(""+D.key):V.toString(36)}function P(){}function W(D){switch(D.status){case"fulfilled":return D.value;case"rejected":throw D.reason;default:switch(typeof D.status=="string"?D.then(P,P):(D.status="pending",D.then(function(V){D.status==="pending"&&(D.status="fulfilled",D.value=V)},function(V){D.status==="pending"&&(D.status="rejected",D.reason=V)})),D.status){case"fulfilled":return D.value;case"rejected":throw D.reason}}throw D}function Z(D,V,U,L,Y){var Q=typeof D;(Q==="undefined"||Q==="boolean")&&(D=null);var se=!1;if(D===null)se=!0;else switch(Q){case"bigint":case"string":case"number":se=!0;break;case"object":switch(D.$$typeof){case e:case t:se=!0;break;case p:return se=D._init,Z(se(D._payload),V,U,L,Y)}}if(se)return Y=Y(D),se=L===""?"."+q(D,0):L,C(Y)?(U="",se!=null&&(U=se.replace(H,"$&/")+"/"),Z(Y,V,U,"",function(Ae){return Ae})):Y!=null&&(I(Y)&&(Y=z(Y,U+(Y.key==null||D&&D.key===Y.key?"":(""+Y.key).replace(H,"$&/")+"/")+se)),V.push(Y)),1;se=0;var re=L===""?".":L+":";if(C(D))for(var le=0;le<D.length;le++)L=D[le],Q=re+q(L,le),se+=Z(L,V,U,Q,Y);else if(le=b(D),typeof le=="function")for(D=le.call(D),le=0;!(L=D.next()).done;)L=L.value,Q=re+q(L,le++),se+=Z(L,V,U,Q,Y);else if(Q==="object"){if(typeof D.then=="function")return Z(W(D),V,U,L,Y);throw V=String(D),Error("Objects are not valid as a React child (found: "+(V==="[object Object]"?"object with keys {"+Object.keys(D).join(", ")+"}":V)+"). If you meant to render a collection of children, use an array instead.")}return se}function j(D,V,U){if(D==null)return D;var L=[],Y=0;return Z(D,L,"","",function(Q){return V.call(U,Q,Y++)}),L}function G(D){if(D._status===-1){var V=D._result;V=V(),V.then(function(U){(D._status===0||D._status===-1)&&(D._status=1,D._result=U)},function(U){(D._status===0||D._status===-1)&&(D._status=2,D._result=U)}),D._status===-1&&(D._status=0,D._result=V)}if(D._status===1)return D._result.default;throw D._result}var B=typeof reportError=="function"?reportError:function(D){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var V=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof D=="object"&&D!==null&&typeof D.message=="string"?String(D.message):String(D),error:D});if(!window.dispatchEvent(V))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",D);return}console.error(D)};function X(){}return at.Children={map:j,forEach:function(D,V,U){j(D,function(){V.apply(this,arguments)},U)},count:function(D){var V=0;return j(D,function(){V++}),V},toArray:function(D){return j(D,function(V){return V})||[]},only:function(D){if(!I(D))throw Error("React.Children.only expected to receive a single React element child.");return D}},at.Component=A,at.Fragment=n,at.Profiler=a,at.PureComponent=x,at.StrictMode=r,at.Suspense=c,at.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=N,at.act=function(){throw Error("act(...) is not supported in production builds of React.")},at.cache=function(D){return function(){return D.apply(null,arguments)}},at.cloneElement=function(D,V,U){if(D==null)throw Error("The argument must be a React element, but you passed "+D+".");var L=S({},D.props),Y=D.key,Q=void 0;if(V!=null)for(se in V.ref!==void 0&&(Q=void 0),V.key!==void 0&&(Y=""+V.key),V)!_.call(V,se)||se==="key"||se==="__self"||se==="__source"||se==="ref"&&V.ref===void 0||(L[se]=V[se]);var se=arguments.length-2;if(se===1)L.children=U;else if(1<se){for(var re=Array(se),le=0;le<se;le++)re[le]=arguments[le+2];L.children=re}return O(D.type,Y,void 0,void 0,Q,L)},at.createContext=function(D){return D={$$typeof:l,_currentValue:D,_currentValue2:D,_threadCount:0,Provider:null,Consumer:null},D.Provider=D,D.Consumer={$$typeof:i,_context:D},D},at.createElement=function(D,V,U){var L,Y={},Q=null;if(V!=null)for(L in V.key!==void 0&&(Q=""+V.key),V)_.call(V,L)&&L!=="key"&&L!=="__self"&&L!=="__source"&&(Y[L]=V[L]);var se=arguments.length-2;if(se===1)Y.children=U;else if(1<se){for(var re=Array(se),le=0;le<se;le++)re[le]=arguments[le+2];Y.children=re}if(D&&D.defaultProps)for(L in se=D.defaultProps,se)Y[L]===void 0&&(Y[L]=se[L]);return O(D,Q,void 0,void 0,null,Y)},at.createRef=function(){return{current:null}},at.forwardRef=function(D){return{$$typeof:u,render:D}},at.isValidElement=I,at.lazy=function(D){return{$$typeof:p,_payload:{_status:-1,_result:D},_init:G}},at.memo=function(D,V){return{$$typeof:f,type:D,compare:V===void 0?null:V}},at.startTransition=function(D){var V=N.T,U={};N.T=U;try{var L=D(),Y=N.S;Y!==null&&Y(U,L),typeof L=="object"&&L!==null&&typeof L.then=="function"&&L.then(X,B)}catch(Q){B(Q)}finally{N.T=V}},at.unstable_useCacheRefresh=function(){return N.H.useCacheRefresh()},at.use=function(D){return N.H.use(D)},at.useActionState=function(D,V,U){return N.H.useActionState(D,V,U)},at.useCallback=function(D,V){return N.H.useCallback(D,V)},at.useContext=function(D){return N.H.useContext(D)},at.useDebugValue=function(){},at.useDeferredValue=function(D,V){return N.H.useDeferredValue(D,V)},at.useEffect=function(D,V){return N.H.useEffect(D,V)},at.useId=function(){return N.H.useId()},at.useImperativeHandle=function(D,V,U){return N.H.useImperativeHandle(D,V,U)},at.useInsertionEffect=function(D,V){return N.H.useInsertionEffect(D,V)},at.useLayoutEffect=function(D,V){return N.H.useLayoutEffect(D,V)},at.useMemo=function(D,V){return N.H.useMemo(D,V)},at.useOptimistic=function(D,V){return N.H.useOptimistic(D,V)},at.useReducer=function(D,V,U){return N.H.useReducer(D,V,U)},at.useRef=function(D){return N.H.useRef(D)},at.useState=function(D){return N.H.useState(D)},at.useSyncExternalStore=function(D,V,U){return N.H.useSyncExternalStore(D,V,U)},at.useTransition=function(){return N.H.useTransition()},at.version="19.0.0",at}var Y1;function nf(){return Y1||(Y1=1,th.exports=mH()),th.exports}var k=nf();const ye=an(k),bH=fH({__proto__:null,default:ye},[k]);var nh={exports:{}},Ls={},rh={exports:{}},ah={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var K1;function yH(){return K1||(K1=1,function(e){function t(j,G){var B=j.length;j.push(G);e:for(;0<B;){var X=B-1>>>1,D=j[X];if(0<a(D,G))j[X]=G,j[B]=D,B=X;else break e}}function n(j){return j.length===0?null:j[0]}function r(j){if(j.length===0)return null;var G=j[0],B=j.pop();if(B!==G){j[0]=B;e:for(var X=0,D=j.length,V=D>>>1;X<V;){var U=2*(X+1)-1,L=j[U],Y=U+1,Q=j[Y];if(0>a(L,B))Y<D&&0>a(Q,L)?(j[X]=Q,j[Y]=B,X=Y):(j[X]=L,j[U]=B,X=U);else if(Y<D&&0>a(Q,B))j[X]=Q,j[Y]=B,X=Y;else break e}}return G}function a(j,G){var B=j.sortIndex-G.sortIndex;return B!==0?B:j.id-G.id}if(e.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var i=performance;e.unstable_now=function(){return i.now()}}else{var l=Date,u=l.now();e.unstable_now=function(){return l.now()-u}}var c=[],f=[],p=1,g=null,b=3,m=!1,S=!1,v=!1,A=typeof setTimeout=="function"?setTimeout:null,R=typeof clearTimeout=="function"?clearTimeout:null,x=typeof setImmediate<"u"?setImmediate:null;function T(j){for(var G=n(f);G!==null;){if(G.callback===null)r(f);else if(G.startTime<=j)r(f),G.sortIndex=G.expirationTime,t(c,G);else break;G=n(f)}}function C(j){if(v=!1,T(j),!S)if(n(c)!==null)S=!0,W();else{var G=n(f);G!==null&&Z(C,G.startTime-j)}}var N=!1,_=-1,O=5,z=-1;function I(){return!(e.unstable_now()-z<O)}function M(){if(N){var j=e.unstable_now();z=j;var G=!0;try{e:{S=!1,v&&(v=!1,R(_),_=-1),m=!0;var B=b;try{t:{for(T(j),g=n(c);g!==null&&!(g.expirationTime>j&&I());){var X=g.callback;if(typeof X=="function"){g.callback=null,b=g.priorityLevel;var D=X(g.expirationTime<=j);if(j=e.unstable_now(),typeof D=="function"){g.callback=D,T(j),G=!0;break t}g===n(c)&&r(c),T(j)}else r(c);g=n(c)}if(g!==null)G=!0;else{var V=n(f);V!==null&&Z(C,V.startTime-j),G=!1}}break e}finally{g=null,b=B,m=!1}G=void 0}}finally{G?H():N=!1}}}var H;if(typeof x=="function")H=function(){x(M)};else if(typeof MessageChannel<"u"){var q=new MessageChannel,P=q.port2;q.port1.onmessage=M,H=function(){P.postMessage(null)}}else H=function(){A(M,0)};function W(){N||(N=!0,H())}function Z(j,G){_=A(function(){j(e.unstable_now())},G)}e.unstable_IdlePriority=5,e.unstable_ImmediatePriority=1,e.unstable_LowPriority=4,e.unstable_NormalPriority=3,e.unstable_Profiling=null,e.unstable_UserBlockingPriority=2,e.unstable_cancelCallback=function(j){j.callback=null},e.unstable_continueExecution=function(){S||m||(S=!0,W())},e.unstable_forceFrameRate=function(j){0>j||125<j?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):O=0<j?Math.floor(1e3/j):5},e.unstable_getCurrentPriorityLevel=function(){return b},e.unstable_getFirstCallbackNode=function(){return n(c)},e.unstable_next=function(j){switch(b){case 1:case 2:case 3:var G=3;break;default:G=b}var B=b;b=G;try{return j()}finally{b=B}},e.unstable_pauseExecution=function(){},e.unstable_requestPaint=function(){},e.unstable_runWithPriority=function(j,G){switch(j){case 1:case 2:case 3:case 4:case 5:break;default:j=3}var B=b;b=j;try{return G()}finally{b=B}},e.unstable_scheduleCallback=function(j,G,B){var X=e.unstable_now();switch(typeof B=="object"&&B!==null?(B=B.delay,B=typeof B=="number"&&0<B?X+B:X):B=X,j){case 1:var D=-1;break;case 2:D=250;break;case 5:D=1073741823;break;case 4:D=1e4;break;default:D=5e3}return D=B+D,j={id:p++,callback:G,priorityLevel:j,startTime:B,expirationTime:D,sortIndex:-1},B>X?(j.sortIndex=B,t(f,j),n(c)===null&&j===n(f)&&(v?(R(_),_=-1):v=!0,Z(C,B-X))):(j.sortIndex=D,t(c,j),S||m||(S=!0,W())),j},e.unstable_shouldYield=I,e.unstable_wrapCallback=function(j){var G=b;return function(){var B=b;b=G;try{return j.apply(this,arguments)}finally{b=B}}}}(ah)),ah}var X1;function vH(){return X1||(X1=1,rh.exports=yH()),rh.exports}var oh={exports:{}},bn={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var Z1;function SH(){if(Z1)return bn;Z1=1;var e=nf();function t(c){var f="https://react.dev/errors/"+c;if(1<arguments.length){f+="?args[]="+encodeURIComponent(arguments[1]);for(var p=2;p<arguments.length;p++)f+="&args[]="+encodeURIComponent(arguments[p])}return"Minified React error #"+c+"; visit "+f+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function n(){}var r={d:{f:n,r:function(){throw Error(t(522))},D:n,C:n,L:n,m:n,X:n,S:n,M:n},p:0,findDOMNode:null},a=Symbol.for("react.portal");function i(c,f,p){var g=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:a,key:g==null?null:""+g,children:c,containerInfo:f,implementation:p}}var l=e.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function u(c,f){if(c==="font")return"";if(typeof f=="string")return f==="use-credentials"?f:""}return bn.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,bn.createPortal=function(c,f){var p=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!f||f.nodeType!==1&&f.nodeType!==9&&f.nodeType!==11)throw Error(t(299));return i(c,f,null,p)},bn.flushSync=function(c){var f=l.T,p=r.p;try{if(l.T=null,r.p=2,c)return c()}finally{l.T=f,r.p=p,r.d.f()}},bn.preconnect=function(c,f){typeof c=="string"&&(f?(f=f.crossOrigin,f=typeof f=="string"?f==="use-credentials"?f:"":void 0):f=null,r.d.C(c,f))},bn.prefetchDNS=function(c){typeof c=="string"&&r.d.D(c)},bn.preinit=function(c,f){if(typeof c=="string"&&f&&typeof f.as=="string"){var p=f.as,g=u(p,f.crossOrigin),b=typeof f.integrity=="string"?f.integrity:void 0,m=typeof f.fetchPriority=="string"?f.fetchPriority:void 0;p==="style"?r.d.S(c,typeof f.precedence=="string"?f.precedence:void 0,{crossOrigin:g,integrity:b,fetchPriority:m}):p==="script"&&r.d.X(c,{crossOrigin:g,integrity:b,fetchPriority:m,nonce:typeof f.nonce=="string"?f.nonce:void 0})}},bn.preinitModule=function(c,f){if(typeof c=="string")if(typeof f=="object"&&f!==null){if(f.as==null||f.as==="script"){var p=u(f.as,f.crossOrigin);r.d.M(c,{crossOrigin:p,integrity:typeof f.integrity=="string"?f.integrity:void 0,nonce:typeof f.nonce=="string"?f.nonce:void 0})}}else f==null&&r.d.M(c)},bn.preload=function(c,f){if(typeof c=="string"&&typeof f=="object"&&f!==null&&typeof f.as=="string"){var p=f.as,g=u(p,f.crossOrigin);r.d.L(c,p,{crossOrigin:g,integrity:typeof f.integrity=="string"?f.integrity:void 0,nonce:typeof f.nonce=="string"?f.nonce:void 0,type:typeof f.type=="string"?f.type:void 0,fetchPriority:typeof f.fetchPriority=="string"?f.fetchPriority:void 0,referrerPolicy:typeof f.referrerPolicy=="string"?f.referrerPolicy:void 0,imageSrcSet:typeof f.imageSrcSet=="string"?f.imageSrcSet:void 0,imageSizes:typeof f.imageSizes=="string"?f.imageSizes:void 0,media:typeof f.media=="string"?f.media:void 0})}},bn.preloadModule=function(c,f){if(typeof c=="string")if(f){var p=u(f.as,f.crossOrigin);r.d.m(c,{as:typeof f.as=="string"&&f.as!=="script"?f.as:void 0,crossOrigin:p,integrity:typeof f.integrity=="string"?f.integrity:void 0})}else r.d.m(c)},bn.requestFormReset=function(c){r.d.r(c)},bn.unstable_batchedUpdates=function(c,f){return c(f)},bn.useFormState=function(c,f,p){return l.H.useFormState(c,f,p)},bn.useFormStatus=function(){return l.H.useHostTransitionStatus()},bn.version="19.0.0",bn}var Q1;function mz(){if(Q1)return oh.exports;Q1=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),oh.exports=SH(),oh.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var J1;function EH(){if(J1)return Ls;J1=1;var e=vH(),t=nf(),n=mz();function r(o){var s="https://react.dev/errors/"+o;if(1<arguments.length){s+="?args[]="+encodeURIComponent(arguments[1]);for(var d=2;d<arguments.length;d++)s+="&args[]="+encodeURIComponent(arguments[d])}return"Minified React error #"+o+"; visit "+s+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function a(o){return!(!o||o.nodeType!==1&&o.nodeType!==9&&o.nodeType!==11)}var i=Symbol.for("react.element"),l=Symbol.for("react.transitional.element"),u=Symbol.for("react.portal"),c=Symbol.for("react.fragment"),f=Symbol.for("react.strict_mode"),p=Symbol.for("react.profiler"),g=Symbol.for("react.provider"),b=Symbol.for("react.consumer"),m=Symbol.for("react.context"),S=Symbol.for("react.forward_ref"),v=Symbol.for("react.suspense"),A=Symbol.for("react.suspense_list"),R=Symbol.for("react.memo"),x=Symbol.for("react.lazy"),T=Symbol.for("react.offscreen"),C=Symbol.for("react.memo_cache_sentinel"),N=Symbol.iterator;function _(o){return o===null||typeof o!="object"?null:(o=N&&o[N]||o["@@iterator"],typeof o=="function"?o:null)}var O=Symbol.for("react.client.reference");function z(o){if(o==null)return null;if(typeof o=="function")return o.$$typeof===O?null:o.displayName||o.name||null;if(typeof o=="string")return o;switch(o){case c:return"Fragment";case u:return"Portal";case p:return"Profiler";case f:return"StrictMode";case v:return"Suspense";case A:return"SuspenseList"}if(typeof o=="object")switch(o.$$typeof){case m:return(o.displayName||"Context")+".Provider";case b:return(o._context.displayName||"Context")+".Consumer";case S:var s=o.render;return o=o.displayName,o||(o=s.displayName||s.name||"",o=o!==""?"ForwardRef("+o+")":"ForwardRef"),o;case R:return s=o.displayName||null,s!==null?s:z(o.type)||"Memo";case x:s=o._payload,o=o._init;try{return z(o(s))}catch{}}return null}var I=t.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,M=Object.assign,H,q;function P(o){if(H===void 0)try{throw Error()}catch(d){var s=d.stack.trim().match(/\n( *(at )?)/);H=s&&s[1]||"",q=-1<d.stack.indexOf(`
    at`)?" (<anonymous>)":-1<d.stack.indexOf("@")?"@unknown:0:0":""}return`
`+H+o+q}var W=!1;function Z(o,s){if(!o||W)return"";W=!0;var d=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var h={DetermineComponentFrameRoot:function(){try{if(s){var Te=function(){throw Error()};if(Object.defineProperty(Te.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Te,[])}catch(ge){var de=ge}Reflect.construct(o,[],Te)}else{try{Te.call()}catch(ge){de=ge}o.call(Te.prototype)}}else{try{throw Error()}catch(ge){de=ge}(Te=o())&&typeof Te.catch=="function"&&Te.catch(function(){})}}catch(ge){if(ge&&de&&typeof ge.stack=="string")return[ge.stack,de.stack]}return[null,null]}};h.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var y=Object.getOwnPropertyDescriptor(h.DetermineComponentFrameRoot,"name");y&&y.configurable&&Object.defineProperty(h.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var E=h.DetermineComponentFrameRoot(),F=E[0],$=E[1];if(F&&$){var K=F.split(`
`),ne=$.split(`
`);for(y=h=0;h<K.length&&!K[h].includes("DetermineComponentFrameRoot");)h++;for(;y<ne.length&&!ne[y].includes("DetermineComponentFrameRoot");)y++;if(h===K.length||y===ne.length)for(h=K.length-1,y=ne.length-1;1<=h&&0<=y&&K[h]!==ne[y];)y--;for(;1<=h&&0<=y;h--,y--)if(K[h]!==ne[y]){if(h!==1||y!==1)do if(h--,y--,0>y||K[h]!==ne[y]){var be=`
`+K[h].replace(" at new "," at ");return o.displayName&&be.includes("<anonymous>")&&(be=be.replace("<anonymous>",o.displayName)),be}while(1<=h&&0<=y);break}}}finally{W=!1,Error.prepareStackTrace=d}return(d=o?o.displayName||o.name:"")?P(d):""}function j(o){switch(o.tag){case 26:case 27:case 5:return P(o.type);case 16:return P("Lazy");case 13:return P("Suspense");case 19:return P("SuspenseList");case 0:case 15:return o=Z(o.type,!1),o;case 11:return o=Z(o.type.render,!1),o;case 1:return o=Z(o.type,!0),o;default:return""}}function G(o){try{var s="";do s+=j(o),o=o.return;while(o);return s}catch(d){return`
Error generating stack: `+d.message+`
`+d.stack}}function B(o){var s=o,d=o;if(o.alternate)for(;s.return;)s=s.return;else{o=s;do s=o,s.flags&4098&&(d=s.return),o=s.return;while(o)}return s.tag===3?d:null}function X(o){if(o.tag===13){var s=o.memoizedState;if(s===null&&(o=o.alternate,o!==null&&(s=o.memoizedState)),s!==null)return s.dehydrated}return null}function D(o){if(B(o)!==o)throw Error(r(188))}function V(o){var s=o.alternate;if(!s){if(s=B(o),s===null)throw Error(r(188));return s!==o?null:o}for(var d=o,h=s;;){var y=d.return;if(y===null)break;var E=y.alternate;if(E===null){if(h=y.return,h!==null){d=h;continue}break}if(y.child===E.child){for(E=y.child;E;){if(E===d)return D(y),o;if(E===h)return D(y),s;E=E.sibling}throw Error(r(188))}if(d.return!==h.return)d=y,h=E;else{for(var F=!1,$=y.child;$;){if($===d){F=!0,d=y,h=E;break}if($===h){F=!0,h=y,d=E;break}$=$.sibling}if(!F){for($=E.child;$;){if($===d){F=!0,d=E,h=y;break}if($===h){F=!0,h=E,d=y;break}$=$.sibling}if(!F)throw Error(r(189))}}if(d.alternate!==h)throw Error(r(190))}if(d.tag!==3)throw Error(r(188));return d.stateNode.current===d?o:s}function U(o){var s=o.tag;if(s===5||s===26||s===27||s===6)return o;for(o=o.child;o!==null;){if(s=U(o),s!==null)return s;o=o.sibling}return null}var L=Array.isArray,Y=n.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,Q={pending:!1,data:null,method:null,action:null},se=[],re=-1;function le(o){return{current:o}}function Ae(o){0>re||(o.current=se[re],se[re]=null,re--)}function ae(o,s){re++,se[re]=o.current,o.current=s}var we=le(null),xe=le(null),Ie=le(null),Ce=le(null);function Ee(o,s){switch(ae(Ie,s),ae(xe,o),ae(we,null),o=s.nodeType,o){case 9:case 11:s=(s=s.documentElement)&&(s=s.namespaceURI)?S1(s):0;break;default:if(o=o===8?s.parentNode:s,s=o.tagName,o=o.namespaceURI)o=S1(o),s=E1(o,s);else switch(s){case"svg":s=1;break;case"math":s=2;break;default:s=0}}Ae(we),ae(we,s)}function J(){Ae(we),Ae(xe),Ae(Ie)}function fe(o){o.memoizedState!==null&&ae(Ce,o);var s=we.current,d=E1(s,o.type);s!==d&&(ae(xe,o),ae(we,d))}function ke(o){xe.current===o&&(Ae(we),Ae(xe)),Ce.current===o&&(Ae(Ce),Rs._currentValue=Q)}var me=Object.prototype.hasOwnProperty,ve=e.unstable_scheduleCallback,ie=e.unstable_cancelCallback,ze=e.unstable_shouldYield,Pe=e.unstable_requestPaint,he=e.unstable_now,Ne=e.unstable_getCurrentPriorityLevel,ee=e.unstable_ImmediatePriority,ce=e.unstable_UserBlockingPriority,Re=e.unstable_NormalPriority,Fe=e.unstable_LowPriority,qe=e.unstable_IdlePriority,mt=e.log,St=e.unstable_setDisableYieldValue,pt=null,Je=null;function wt(o){if(Je&&typeof Je.onCommitFiberRoot=="function")try{Je.onCommitFiberRoot(pt,o,void 0,(o.current.flags&128)===128)}catch{}}function rt(o){if(typeof mt=="function"&&St(o),Je&&typeof Je.setStrictMode=="function")try{Je.setStrictMode(pt,o)}catch{}}var bt=Math.clz32?Math.clz32:Mt,Bt=Math.log,sn=Math.LN2;function Mt(o){return o>>>=0,o===0?32:31-(Bt(o)/sn|0)|0}var er=128,zr=4194304;function Kt(o){var s=o&42;if(s!==0)return s;switch(o&-o){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return o&4194176;case 4194304:case 8388608:case 16777216:case 33554432:return o&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return o}}function na(o,s){var d=o.pendingLanes;if(d===0)return 0;var h=0,y=o.suspendedLanes,E=o.pingedLanes,F=o.warmLanes;o=o.finishedLanes!==0;var $=d&134217727;return $!==0?(d=$&~y,d!==0?h=Kt(d):(E&=$,E!==0?h=Kt(E):o||(F=$&~F,F!==0&&(h=Kt(F))))):($=d&~y,$!==0?h=Kt($):E!==0?h=Kt(E):o||(F=d&~F,F!==0&&(h=Kt(F)))),h===0?0:s!==0&&s!==h&&!(s&y)&&(y=h&-h,F=s&-s,y>=F||y===32&&(F&4194176)!==0)?s:h}function Ke(o,s){return(o.pendingLanes&~(o.suspendedLanes&~o.pingedLanes)&s)===0}function gt(o,s){switch(o){case 1:case 2:case 4:case 8:return s+250;case 16:case 32:case 64:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return s+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function _t(){var o=er;return er<<=1,!(er&4194176)&&(er=128),o}function Rn(){var o=zr;return zr<<=1,!(zr&62914560)&&(zr=4194304),o}function kn(o){for(var s=[],d=0;31>d;d++)s.push(o);return s}function Cn(o,s){o.pendingLanes|=s,s!==268435456&&(o.suspendedLanes=0,o.pingedLanes=0,o.warmLanes=0)}function ra(o,s,d,h,y,E){var F=o.pendingLanes;o.pendingLanes=d,o.suspendedLanes=0,o.pingedLanes=0,o.warmLanes=0,o.expiredLanes&=d,o.entangledLanes&=d,o.errorRecoveryDisabledLanes&=d,o.shellSuspendCounter=0;var $=o.entanglements,K=o.expirationTimes,ne=o.hiddenUpdates;for(d=F&~d;0<d;){var be=31-bt(d),Te=1<<be;$[be]=0,K[be]=-1;var de=ne[be];if(de!==null)for(ne[be]=null,be=0;be<de.length;be++){var ge=de[be];ge!==null&&(ge.lane&=-536870913)}d&=~Te}h!==0&&Nn(o,h,0),E!==0&&y===0&&o.tag!==0&&(o.suspendedLanes|=E&~(F&~s))}function Nn(o,s,d){o.pendingLanes|=s,o.suspendedLanes&=~s;var h=31-bt(s);o.entangledLanes|=s,o.entanglements[h]=o.entanglements[h]|1073741824|d&4194218}function Sr(o,s){var d=o.entangledLanes|=s;for(o=o.entanglements;d;){var h=31-bt(d),y=1<<h;y&s|o[h]&s&&(o[h]|=s),d&=~y}}function mA(o){return o&=-o,2<o?8<o?o&134217727?32:268435456:8:2}function bA(){var o=Y.p;return o!==0?o:(o=window.event,o===void 0?32:B1(o.type))}function eG(o,s){var d=Y.p;try{return Y.p=o,s()}finally{Y.p=d}}var za=Math.random().toString(36).slice(2),hn="__reactFiber$"+za,On="__reactProps$"+za,pi="__reactContainer$"+za,Xf="__reactEvents$"+za,tG="__reactListeners$"+za,nG="__reactHandles$"+za,yA="__reactResources$"+za,Ul="__reactMarker$"+za;function Zf(o){delete o[hn],delete o[On],delete o[Xf],delete o[tG],delete o[nG]}function To(o){var s=o[hn];if(s)return s;for(var d=o.parentNode;d;){if(s=d[pi]||d[hn]){if(d=s.alternate,s.child!==null||d!==null&&d.child!==null)for(o=k1(o);o!==null;){if(d=o[hn])return d;o=k1(o)}return s}o=d,d=o.parentNode}return null}function gi(o){if(o=o[hn]||o[pi]){var s=o.tag;if(s===5||s===6||s===13||s===26||s===27||s===3)return o}return null}function jl(o){var s=o.tag;if(s===5||s===26||s===27||s===6)return o.stateNode;throw Error(r(33))}function hi(o){var s=o[yA];return s||(s=o[yA]={hoistableStyles:new Map,hoistableScripts:new Map}),s}function Jt(o){o[Ul]=!0}var vA=new Set,SA={};function _o(o,s){mi(o,s),mi(o+"Capture",s)}function mi(o,s){for(SA[o]=s,o=0;o<s.length;o++)vA.add(s[o])}var aa=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),rG=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),EA={},wA={};function aG(o){return me.call(wA,o)?!0:me.call(EA,o)?!1:rG.test(o)?wA[o]=!0:(EA[o]=!0,!1)}function Nu(o,s,d){if(aG(s))if(d===null)o.removeAttribute(s);else{switch(typeof d){case"undefined":case"function":case"symbol":o.removeAttribute(s);return;case"boolean":var h=s.toLowerCase().slice(0,5);if(h!=="data-"&&h!=="aria-"){o.removeAttribute(s);return}}o.setAttribute(s,""+d)}}function Ou(o,s,d){if(d===null)o.removeAttribute(s);else{switch(typeof d){case"undefined":case"function":case"symbol":case"boolean":o.removeAttribute(s);return}o.setAttribute(s,""+d)}}function oa(o,s,d,h){if(h===null)o.removeAttribute(d);else{switch(typeof h){case"undefined":case"function":case"symbol":case"boolean":o.removeAttribute(d);return}o.setAttributeNS(s,d,""+h)}}function tr(o){switch(typeof o){case"bigint":case"boolean":case"number":case"string":case"undefined":return o;case"object":return o;default:return""}}function xA(o){var s=o.type;return(o=o.nodeName)&&o.toLowerCase()==="input"&&(s==="checkbox"||s==="radio")}function oG(o){var s=xA(o)?"checked":"value",d=Object.getOwnPropertyDescriptor(o.constructor.prototype,s),h=""+o[s];if(!o.hasOwnProperty(s)&&typeof d<"u"&&typeof d.get=="function"&&typeof d.set=="function"){var y=d.get,E=d.set;return Object.defineProperty(o,s,{configurable:!0,get:function(){return y.call(this)},set:function(F){h=""+F,E.call(this,F)}}),Object.defineProperty(o,s,{enumerable:d.enumerable}),{getValue:function(){return h},setValue:function(F){h=""+F},stopTracking:function(){o._valueTracker=null,delete o[s]}}}}function Du(o){o._valueTracker||(o._valueTracker=oG(o))}function kA(o){if(!o)return!1;var s=o._valueTracker;if(!s)return!0;var d=s.getValue(),h="";return o&&(h=xA(o)?o.checked?"true":"false":o.value),o=h,o!==d?(s.setValue(o),!0):!1}function Iu(o){if(o=o||(typeof document<"u"?document:void 0),typeof o>"u")return null;try{return o.activeElement||o.body}catch{return o.body}}var iG=/[\n"\\]/g;function nr(o){return o.replace(iG,function(s){return"\\"+s.charCodeAt(0).toString(16)+" "})}function Qf(o,s,d,h,y,E,F,$){o.name="",F!=null&&typeof F!="function"&&typeof F!="symbol"&&typeof F!="boolean"?o.type=F:o.removeAttribute("type"),s!=null?F==="number"?(s===0&&o.value===""||o.value!=s)&&(o.value=""+tr(s)):o.value!==""+tr(s)&&(o.value=""+tr(s)):F!=="submit"&&F!=="reset"||o.removeAttribute("value"),s!=null?Jf(o,F,tr(s)):d!=null?Jf(o,F,tr(d)):h!=null&&o.removeAttribute("value"),y==null&&E!=null&&(o.defaultChecked=!!E),y!=null&&(o.checked=y&&typeof y!="function"&&typeof y!="symbol"),$!=null&&typeof $!="function"&&typeof $!="symbol"&&typeof $!="boolean"?o.name=""+tr($):o.removeAttribute("name")}function AA(o,s,d,h,y,E,F,$){if(E!=null&&typeof E!="function"&&typeof E!="symbol"&&typeof E!="boolean"&&(o.type=E),s!=null||d!=null){if(!(E!=="submit"&&E!=="reset"||s!=null))return;d=d!=null?""+tr(d):"",s=s!=null?""+tr(s):d,$||s===o.value||(o.value=s),o.defaultValue=s}h=h??y,h=typeof h!="function"&&typeof h!="symbol"&&!!h,o.checked=$?o.checked:!!h,o.defaultChecked=!!h,F!=null&&typeof F!="function"&&typeof F!="symbol"&&typeof F!="boolean"&&(o.name=F)}function Jf(o,s,d){s==="number"&&Iu(o.ownerDocument)===o||o.defaultValue===""+d||(o.defaultValue=""+d)}function bi(o,s,d,h){if(o=o.options,s){s={};for(var y=0;y<d.length;y++)s["$"+d[y]]=!0;for(d=0;d<o.length;d++)y=s.hasOwnProperty("$"+o[d].value),o[d].selected!==y&&(o[d].selected=y),y&&h&&(o[d].defaultSelected=!0)}else{for(d=""+tr(d),s=null,y=0;y<o.length;y++){if(o[y].value===d){o[y].selected=!0,h&&(o[y].defaultSelected=!0);return}s!==null||o[y].disabled||(s=o[y])}s!==null&&(s.selected=!0)}}function TA(o,s,d){if(s!=null&&(s=""+tr(s),s!==o.value&&(o.value=s),d==null)){o.defaultValue!==s&&(o.defaultValue=s);return}o.defaultValue=d!=null?""+tr(d):""}function _A(o,s,d,h){if(s==null){if(h!=null){if(d!=null)throw Error(r(92));if(L(h)){if(1<h.length)throw Error(r(93));h=h[0]}d=h}d==null&&(d=""),s=d}d=tr(s),o.defaultValue=d,h=o.textContent,h===d&&h!==""&&h!==null&&(o.value=h)}function yi(o,s){if(s){var d=o.firstChild;if(d&&d===o.lastChild&&d.nodeType===3){d.nodeValue=s;return}}o.textContent=s}var lG=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function RA(o,s,d){var h=s.indexOf("--")===0;d==null||typeof d=="boolean"||d===""?h?o.setProperty(s,""):s==="float"?o.cssFloat="":o[s]="":h?o.setProperty(s,d):typeof d!="number"||d===0||lG.has(s)?s==="float"?o.cssFloat=d:o[s]=(""+d).trim():o[s]=d+"px"}function CA(o,s,d){if(s!=null&&typeof s!="object")throw Error(r(62));if(o=o.style,d!=null){for(var h in d)!d.hasOwnProperty(h)||s!=null&&s.hasOwnProperty(h)||(h.indexOf("--")===0?o.setProperty(h,""):h==="float"?o.cssFloat="":o[h]="");for(var y in s)h=s[y],s.hasOwnProperty(y)&&d[y]!==h&&RA(o,y,h)}else for(var E in s)s.hasOwnProperty(E)&&RA(o,E,s[E])}function ep(o){if(o.indexOf("-")===-1)return!1;switch(o){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var sG=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),uG=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function Lu(o){return uG.test(""+o)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":o}var tp=null;function np(o){return o=o.target||o.srcElement||window,o.correspondingUseElement&&(o=o.correspondingUseElement),o.nodeType===3?o.parentNode:o}var vi=null,Si=null;function NA(o){var s=gi(o);if(s&&(o=s.stateNode)){var d=o[On]||null;e:switch(o=s.stateNode,s.type){case"input":if(Qf(o,d.value,d.defaultValue,d.defaultValue,d.checked,d.defaultChecked,d.type,d.name),s=d.name,d.type==="radio"&&s!=null){for(d=o;d.parentNode;)d=d.parentNode;for(d=d.querySelectorAll('input[name="'+nr(""+s)+'"][type="radio"]'),s=0;s<d.length;s++){var h=d[s];if(h!==o&&h.form===o.form){var y=h[On]||null;if(!y)throw Error(r(90));Qf(h,y.value,y.defaultValue,y.defaultValue,y.checked,y.defaultChecked,y.type,y.name)}}for(s=0;s<d.length;s++)h=d[s],h.form===o.form&&kA(h)}break e;case"textarea":TA(o,d.value,d.defaultValue);break e;case"select":s=d.value,s!=null&&bi(o,!!d.multiple,s,!1)}}}var rp=!1;function OA(o,s,d){if(rp)return o(s,d);rp=!0;try{var h=o(s);return h}finally{if(rp=!1,(vi!==null||Si!==null)&&(bc(),vi&&(s=vi,o=Si,Si=vi=null,NA(s),o)))for(s=0;s<o.length;s++)NA(o[s])}}function Gl(o,s){var d=o.stateNode;if(d===null)return null;var h=d[On]||null;if(h===null)return null;d=h[s];e:switch(s){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(h=!h.disabled)||(o=o.type,h=!(o==="button"||o==="input"||o==="select"||o==="textarea")),o=!h;break e;default:o=!1}if(o)return null;if(d&&typeof d!="function")throw Error(r(231,s,typeof d));return d}var ap=!1;if(aa)try{var Hl={};Object.defineProperty(Hl,"passive",{get:function(){ap=!0}}),window.addEventListener("test",Hl,Hl),window.removeEventListener("test",Hl,Hl)}catch{ap=!1}var Pa=null,op=null,Mu=null;function DA(){if(Mu)return Mu;var o,s=op,d=s.length,h,y="value"in Pa?Pa.value:Pa.textContent,E=y.length;for(o=0;o<d&&s[o]===y[o];o++);var F=d-o;for(h=1;h<=F&&s[d-h]===y[E-h];h++);return Mu=y.slice(o,1<h?1-h:void 0)}function Fu(o){var s=o.keyCode;return"charCode"in o?(o=o.charCode,o===0&&s===13&&(o=13)):o=s,o===10&&(o=13),32<=o||o===13?o:0}function zu(){return!0}function IA(){return!1}function Dn(o){function s(d,h,y,E,F){this._reactName=d,this._targetInst=y,this.type=h,this.nativeEvent=E,this.target=F,this.currentTarget=null;for(var $ in o)o.hasOwnProperty($)&&(d=o[$],this[$]=d?d(E):E[$]);return this.isDefaultPrevented=(E.defaultPrevented!=null?E.defaultPrevented:E.returnValue===!1)?zu:IA,this.isPropagationStopped=IA,this}return M(s.prototype,{preventDefault:function(){this.defaultPrevented=!0;var d=this.nativeEvent;d&&(d.preventDefault?d.preventDefault():typeof d.returnValue!="unknown"&&(d.returnValue=!1),this.isDefaultPrevented=zu)},stopPropagation:function(){var d=this.nativeEvent;d&&(d.stopPropagation?d.stopPropagation():typeof d.cancelBubble!="unknown"&&(d.cancelBubble=!0),this.isPropagationStopped=zu)},persist:function(){},isPersistent:zu}),s}var Ro={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(o){return o.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},Pu=Dn(Ro),$l=M({},Ro,{view:0,detail:0}),cG=Dn($l),ip,lp,ql,Bu=M({},$l,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:up,button:0,buttons:0,relatedTarget:function(o){return o.relatedTarget===void 0?o.fromElement===o.srcElement?o.toElement:o.fromElement:o.relatedTarget},movementX:function(o){return"movementX"in o?o.movementX:(o!==ql&&(ql&&o.type==="mousemove"?(ip=o.screenX-ql.screenX,lp=o.screenY-ql.screenY):lp=ip=0,ql=o),ip)},movementY:function(o){return"movementY"in o?o.movementY:lp}}),LA=Dn(Bu),dG=M({},Bu,{dataTransfer:0}),fG=Dn(dG),pG=M({},$l,{relatedTarget:0}),sp=Dn(pG),gG=M({},Ro,{animationName:0,elapsedTime:0,pseudoElement:0}),hG=Dn(gG),mG=M({},Ro,{clipboardData:function(o){return"clipboardData"in o?o.clipboardData:window.clipboardData}}),bG=Dn(mG),yG=M({},Ro,{data:0}),MA=Dn(yG),vG={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},SG={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},EG={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function wG(o){var s=this.nativeEvent;return s.getModifierState?s.getModifierState(o):(o=EG[o])?!!s[o]:!1}function up(){return wG}var xG=M({},$l,{key:function(o){if(o.key){var s=vG[o.key]||o.key;if(s!=="Unidentified")return s}return o.type==="keypress"?(o=Fu(o),o===13?"Enter":String.fromCharCode(o)):o.type==="keydown"||o.type==="keyup"?SG[o.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:up,charCode:function(o){return o.type==="keypress"?Fu(o):0},keyCode:function(o){return o.type==="keydown"||o.type==="keyup"?o.keyCode:0},which:function(o){return o.type==="keypress"?Fu(o):o.type==="keydown"||o.type==="keyup"?o.keyCode:0}}),kG=Dn(xG),AG=M({},Bu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),FA=Dn(AG),TG=M({},$l,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:up}),_G=Dn(TG),RG=M({},Ro,{propertyName:0,elapsedTime:0,pseudoElement:0}),CG=Dn(RG),NG=M({},Bu,{deltaX:function(o){return"deltaX"in o?o.deltaX:"wheelDeltaX"in o?-o.wheelDeltaX:0},deltaY:function(o){return"deltaY"in o?o.deltaY:"wheelDeltaY"in o?-o.wheelDeltaY:"wheelDelta"in o?-o.wheelDelta:0},deltaZ:0,deltaMode:0}),OG=Dn(NG),DG=M({},Ro,{newState:0,oldState:0}),IG=Dn(DG),LG=[9,13,27,32],cp=aa&&"CompositionEvent"in window,Vl=null;aa&&"documentMode"in document&&(Vl=document.documentMode);var MG=aa&&"TextEvent"in window&&!Vl,zA=aa&&(!cp||Vl&&8<Vl&&11>=Vl),PA=" ",BA=!1;function UA(o,s){switch(o){case"keyup":return LG.indexOf(s.keyCode)!==-1;case"keydown":return s.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function jA(o){return o=o.detail,typeof o=="object"&&"data"in o?o.data:null}var Ei=!1;function FG(o,s){switch(o){case"compositionend":return jA(s);case"keypress":return s.which!==32?null:(BA=!0,PA);case"textInput":return o=s.data,o===PA&&BA?null:o;default:return null}}function zG(o,s){if(Ei)return o==="compositionend"||!cp&&UA(o,s)?(o=DA(),Mu=op=Pa=null,Ei=!1,o):null;switch(o){case"paste":return null;case"keypress":if(!(s.ctrlKey||s.altKey||s.metaKey)||s.ctrlKey&&s.altKey){if(s.char&&1<s.char.length)return s.char;if(s.which)return String.fromCharCode(s.which)}return null;case"compositionend":return zA&&s.locale!=="ko"?null:s.data;default:return null}}var PG={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function GA(o){var s=o&&o.nodeName&&o.nodeName.toLowerCase();return s==="input"?!!PG[o.type]:s==="textarea"}function HA(o,s,d,h){vi?Si?Si.push(h):Si=[h]:vi=h,s=wc(s,"onChange"),0<s.length&&(d=new Pu("onChange","change",null,d,h),o.push({event:d,listeners:s}))}var Wl=null,Yl=null;function BG(o){h1(o,0)}function Uu(o){var s=jl(o);if(kA(s))return o}function $A(o,s){if(o==="change")return s}var qA=!1;if(aa){var dp;if(aa){var fp="oninput"in document;if(!fp){var VA=document.createElement("div");VA.setAttribute("oninput","return;"),fp=typeof VA.oninput=="function"}dp=fp}else dp=!1;qA=dp&&(!document.documentMode||9<document.documentMode)}function WA(){Wl&&(Wl.detachEvent("onpropertychange",YA),Yl=Wl=null)}function YA(o){if(o.propertyName==="value"&&Uu(Yl)){var s=[];HA(s,Yl,o,np(o)),OA(BG,s)}}function UG(o,s,d){o==="focusin"?(WA(),Wl=s,Yl=d,Wl.attachEvent("onpropertychange",YA)):o==="focusout"&&WA()}function jG(o){if(o==="selectionchange"||o==="keyup"||o==="keydown")return Uu(Yl)}function GG(o,s){if(o==="click")return Uu(s)}function HG(o,s){if(o==="input"||o==="change")return Uu(s)}function $G(o,s){return o===s&&(o!==0||1/o===1/s)||o!==o&&s!==s}var Hn=typeof Object.is=="function"?Object.is:$G;function Kl(o,s){if(Hn(o,s))return!0;if(typeof o!="object"||o===null||typeof s!="object"||s===null)return!1;var d=Object.keys(o),h=Object.keys(s);if(d.length!==h.length)return!1;for(h=0;h<d.length;h++){var y=d[h];if(!me.call(s,y)||!Hn(o[y],s[y]))return!1}return!0}function KA(o){for(;o&&o.firstChild;)o=o.firstChild;return o}function XA(o,s){var d=KA(o);o=0;for(var h;d;){if(d.nodeType===3){if(h=o+d.textContent.length,o<=s&&h>=s)return{node:d,offset:s-o};o=h}e:{for(;d;){if(d.nextSibling){d=d.nextSibling;break e}d=d.parentNode}d=void 0}d=KA(d)}}function ZA(o,s){return o&&s?o===s?!0:o&&o.nodeType===3?!1:s&&s.nodeType===3?ZA(o,s.parentNode):"contains"in o?o.contains(s):o.compareDocumentPosition?!!(o.compareDocumentPosition(s)&16):!1:!1}function QA(o){o=o!=null&&o.ownerDocument!=null&&o.ownerDocument.defaultView!=null?o.ownerDocument.defaultView:window;for(var s=Iu(o.document);s instanceof o.HTMLIFrameElement;){try{var d=typeof s.contentWindow.location.href=="string"}catch{d=!1}if(d)o=s.contentWindow;else break;s=Iu(o.document)}return s}function pp(o){var s=o&&o.nodeName&&o.nodeName.toLowerCase();return s&&(s==="input"&&(o.type==="text"||o.type==="search"||o.type==="tel"||o.type==="url"||o.type==="password")||s==="textarea"||o.contentEditable==="true")}function qG(o,s){var d=QA(s);s=o.focusedElem;var h=o.selectionRange;if(d!==s&&s&&s.ownerDocument&&ZA(s.ownerDocument.documentElement,s)){if(h!==null&&pp(s)){if(o=h.start,d=h.end,d===void 0&&(d=o),"selectionStart"in s)s.selectionStart=o,s.selectionEnd=Math.min(d,s.value.length);else if(d=(o=s.ownerDocument||document)&&o.defaultView||window,d.getSelection){d=d.getSelection();var y=s.textContent.length,E=Math.min(h.start,y);h=h.end===void 0?E:Math.min(h.end,y),!d.extend&&E>h&&(y=h,h=E,E=y),y=XA(s,E);var F=XA(s,h);y&&F&&(d.rangeCount!==1||d.anchorNode!==y.node||d.anchorOffset!==y.offset||d.focusNode!==F.node||d.focusOffset!==F.offset)&&(o=o.createRange(),o.setStart(y.node,y.offset),d.removeAllRanges(),E>h?(d.addRange(o),d.extend(F.node,F.offset)):(o.setEnd(F.node,F.offset),d.addRange(o)))}}for(o=[],d=s;d=d.parentNode;)d.nodeType===1&&o.push({element:d,left:d.scrollLeft,top:d.scrollTop});for(typeof s.focus=="function"&&s.focus(),s=0;s<o.length;s++)d=o[s],d.element.scrollLeft=d.left,d.element.scrollTop=d.top}}var VG=aa&&"documentMode"in document&&11>=document.documentMode,wi=null,gp=null,Xl=null,hp=!1;function JA(o,s,d){var h=d.window===d?d.document:d.nodeType===9?d:d.ownerDocument;hp||wi==null||wi!==Iu(h)||(h=wi,"selectionStart"in h&&pp(h)?h={start:h.selectionStart,end:h.selectionEnd}:(h=(h.ownerDocument&&h.ownerDocument.defaultView||window).getSelection(),h={anchorNode:h.anchorNode,anchorOffset:h.anchorOffset,focusNode:h.focusNode,focusOffset:h.focusOffset}),Xl&&Kl(Xl,h)||(Xl=h,h=wc(gp,"onSelect"),0<h.length&&(s=new Pu("onSelect","select",null,s,d),o.push({event:s,listeners:h}),s.target=wi)))}function Co(o,s){var d={};return d[o.toLowerCase()]=s.toLowerCase(),d["Webkit"+o]="webkit"+s,d["Moz"+o]="moz"+s,d}var xi={animationend:Co("Animation","AnimationEnd"),animationiteration:Co("Animation","AnimationIteration"),animationstart:Co("Animation","AnimationStart"),transitionrun:Co("Transition","TransitionRun"),transitionstart:Co("Transition","TransitionStart"),transitioncancel:Co("Transition","TransitionCancel"),transitionend:Co("Transition","TransitionEnd")},mp={},eT={};aa&&(eT=document.createElement("div").style,"AnimationEvent"in window||(delete xi.animationend.animation,delete xi.animationiteration.animation,delete xi.animationstart.animation),"TransitionEvent"in window||delete xi.transitionend.transition);function No(o){if(mp[o])return mp[o];if(!xi[o])return o;var s=xi[o],d;for(d in s)if(s.hasOwnProperty(d)&&d in eT)return mp[o]=s[d];return o}var tT=No("animationend"),nT=No("animationiteration"),rT=No("animationstart"),WG=No("transitionrun"),YG=No("transitionstart"),KG=No("transitioncancel"),aT=No("transitionend"),oT=new Map,iT="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll scrollEnd toggle touchMove waiting wheel".split(" ");function Er(o,s){oT.set(o,s),_o(s,[o])}var rr=[],ki=0,bp=0;function ju(){for(var o=ki,s=bp=ki=0;s<o;){var d=rr[s];rr[s++]=null;var h=rr[s];rr[s++]=null;var y=rr[s];rr[s++]=null;var E=rr[s];if(rr[s++]=null,h!==null&&y!==null){var F=h.pending;F===null?y.next=y:(y.next=F.next,F.next=y),h.pending=y}E!==0&&lT(d,y,E)}}function Gu(o,s,d,h){rr[ki++]=o,rr[ki++]=s,rr[ki++]=d,rr[ki++]=h,bp|=h,o.lanes|=h,o=o.alternate,o!==null&&(o.lanes|=h)}function yp(o,s,d,h){return Gu(o,s,d,h),Hu(o)}function Ba(o,s){return Gu(o,null,null,s),Hu(o)}function lT(o,s,d){o.lanes|=d;var h=o.alternate;h!==null&&(h.lanes|=d);for(var y=!1,E=o.return;E!==null;)E.childLanes|=d,h=E.alternate,h!==null&&(h.childLanes|=d),E.tag===22&&(o=E.stateNode,o===null||o._visibility&1||(y=!0)),o=E,E=E.return;y&&s!==null&&o.tag===3&&(E=o.stateNode,y=31-bt(d),E=E.hiddenUpdates,o=E[y],o===null?E[y]=[s]:o.push(s),s.lane=d|536870912)}function Hu(o){if(50<Es)throw Es=0,kg=null,Error(r(185));for(var s=o.return;s!==null;)o=s,s=o.return;return o.tag===3?o.stateNode:null}var Ai={},sT=new WeakMap;function ar(o,s){if(typeof o=="object"&&o!==null){var d=sT.get(o);return d!==void 0?d:(s={value:o,source:s,stack:G(s)},sT.set(o,s),s)}return{value:o,source:s,stack:G(s)}}var Ti=[],_i=0,$u=null,qu=0,or=[],ir=0,Oo=null,ia=1,la="";function Do(o,s){Ti[_i++]=qu,Ti[_i++]=$u,$u=o,qu=s}function uT(o,s,d){or[ir++]=ia,or[ir++]=la,or[ir++]=Oo,Oo=o;var h=ia;o=la;var y=32-bt(h)-1;h&=~(1<<y),d+=1;var E=32-bt(s)+y;if(30<E){var F=y-y%5;E=(h&(1<<F)-1).toString(32),h>>=F,y-=F,ia=1<<32-bt(s)+y|d<<y|h,la=E+o}else ia=1<<E|d<<y|h,la=o}function vp(o){o.return!==null&&(Do(o,1),uT(o,1,0))}function Sp(o){for(;o===$u;)$u=Ti[--_i],Ti[_i]=null,qu=Ti[--_i],Ti[_i]=null;for(;o===Oo;)Oo=or[--ir],or[ir]=null,la=or[--ir],or[ir]=null,ia=or[--ir],or[ir]=null}var An=null,un=null,yt=!1,wr=null,Pr=!1,Ep=Error(r(519));function Io(o){var s=Error(r(418,""));throw Jl(ar(s,o)),Ep}function cT(o){var s=o.stateNode,d=o.type,h=o.memoizedProps;switch(s[hn]=o,s[On]=h,d){case"dialog":dt("cancel",s),dt("close",s);break;case"iframe":case"object":case"embed":dt("load",s);break;case"video":case"audio":for(d=0;d<xs.length;d++)dt(xs[d],s);break;case"source":dt("error",s);break;case"img":case"image":case"link":dt("error",s),dt("load",s);break;case"details":dt("toggle",s);break;case"input":dt("invalid",s),AA(s,h.value,h.defaultValue,h.checked,h.defaultChecked,h.type,h.name,!0),Du(s);break;case"select":dt("invalid",s);break;case"textarea":dt("invalid",s),_A(s,h.value,h.defaultValue,h.children),Du(s)}d=h.children,typeof d!="string"&&typeof d!="number"&&typeof d!="bigint"||s.textContent===""+d||h.suppressHydrationWarning===!0||v1(s.textContent,d)?(h.popover!=null&&(dt("beforetoggle",s),dt("toggle",s)),h.onScroll!=null&&dt("scroll",s),h.onScrollEnd!=null&&dt("scrollend",s),h.onClick!=null&&(s.onclick=xc),s=!0):s=!1,s||Io(o)}function dT(o){for(An=o.return;An;)switch(An.tag){case 3:case 27:Pr=!0;return;case 5:case 13:Pr=!1;return;default:An=An.return}}function Zl(o){if(o!==An)return!1;if(!yt)return dT(o),yt=!0,!1;var s=!1,d;if((d=o.tag!==3&&o.tag!==27)&&((d=o.tag===5)&&(d=o.type,d=!(d!=="form"&&d!=="button")||jg(o.type,o.memoizedProps)),d=!d),d&&(s=!0),s&&un&&Io(o),dT(o),o.tag===13){if(o=o.memoizedState,o=o!==null?o.dehydrated:null,!o)throw Error(r(317));e:{for(o=o.nextSibling,s=0;o;){if(o.nodeType===8)if(d=o.data,d==="/$"){if(s===0){un=kr(o.nextSibling);break e}s--}else d!=="$"&&d!=="$!"&&d!=="$?"||s++;o=o.nextSibling}un=null}}else un=An?kr(o.stateNode.nextSibling):null;return!0}function Ql(){un=An=null,yt=!1}function Jl(o){wr===null?wr=[o]:wr.push(o)}var es=Error(r(460)),fT=Error(r(474)),wp={then:function(){}};function pT(o){return o=o.status,o==="fulfilled"||o==="rejected"}function Vu(){}function gT(o,s,d){switch(d=o[d],d===void 0?o.push(s):d!==s&&(s.then(Vu,Vu),s=d),s.status){case"fulfilled":return s.value;case"rejected":throw o=s.reason,o===es?Error(r(483)):o;default:if(typeof s.status=="string")s.then(Vu,Vu);else{if(o=Ot,o!==null&&100<o.shellSuspendCounter)throw Error(r(482));o=s,o.status="pending",o.then(function(h){if(s.status==="pending"){var y=s;y.status="fulfilled",y.value=h}},function(h){if(s.status==="pending"){var y=s;y.status="rejected",y.reason=h}})}switch(s.status){case"fulfilled":return s.value;case"rejected":throw o=s.reason,o===es?Error(r(483)):o}throw ts=s,es}}var ts=null;function hT(){if(ts===null)throw Error(r(459));var o=ts;return ts=null,o}var Ri=null,ns=0;function Wu(o){var s=ns;return ns+=1,Ri===null&&(Ri=[]),gT(Ri,o,s)}function rs(o,s){s=s.props.ref,o.ref=s!==void 0?s:null}function Yu(o,s){throw s.$$typeof===i?Error(r(525)):(o=Object.prototype.toString.call(s),Error(r(31,o==="[object Object]"?"object with keys {"+Object.keys(s).join(", ")+"}":o)))}function mT(o){var s=o._init;return s(o._payload)}function bT(o){function s(oe,te){if(o){var ue=oe.deletions;ue===null?(oe.deletions=[te],oe.flags|=16):ue.push(te)}}function d(oe,te){if(!o)return null;for(;te!==null;)s(oe,te),te=te.sibling;return null}function h(oe){for(var te=new Map;oe!==null;)oe.key!==null?te.set(oe.key,oe):te.set(oe.index,oe),oe=oe.sibling;return te}function y(oe,te){return oe=Za(oe,te),oe.index=0,oe.sibling=null,oe}function E(oe,te,ue){return oe.index=ue,o?(ue=oe.alternate,ue!==null?(ue=ue.index,ue<te?(oe.flags|=33554434,te):ue):(oe.flags|=33554434,te)):(oe.flags|=1048576,te)}function F(oe){return o&&oe.alternate===null&&(oe.flags|=33554434),oe}function $(oe,te,ue,Se){return te===null||te.tag!==6?(te=mg(ue,oe.mode,Se),te.return=oe,te):(te=y(te,ue),te.return=oe,te)}function K(oe,te,ue,Se){var Ue=ue.type;return Ue===c?be(oe,te,ue.props.children,Se,ue.key):te!==null&&(te.elementType===Ue||typeof Ue=="object"&&Ue!==null&&Ue.$$typeof===x&&mT(Ue)===te.type)?(te=y(te,ue.props),rs(te,ue),te.return=oe,te):(te=fc(ue.type,ue.key,ue.props,null,oe.mode,Se),rs(te,ue),te.return=oe,te)}function ne(oe,te,ue,Se){return te===null||te.tag!==4||te.stateNode.containerInfo!==ue.containerInfo||te.stateNode.implementation!==ue.implementation?(te=bg(ue,oe.mode,Se),te.return=oe,te):(te=y(te,ue.children||[]),te.return=oe,te)}function be(oe,te,ue,Se,Ue){return te===null||te.tag!==7?(te=Ho(ue,oe.mode,Se,Ue),te.return=oe,te):(te=y(te,ue),te.return=oe,te)}function Te(oe,te,ue){if(typeof te=="string"&&te!==""||typeof te=="number"||typeof te=="bigint")return te=mg(""+te,oe.mode,ue),te.return=oe,te;if(typeof te=="object"&&te!==null){switch(te.$$typeof){case l:return ue=fc(te.type,te.key,te.props,null,oe.mode,ue),rs(ue,te),ue.return=oe,ue;case u:return te=bg(te,oe.mode,ue),te.return=oe,te;case x:var Se=te._init;return te=Se(te._payload),Te(oe,te,ue)}if(L(te)||_(te))return te=Ho(te,oe.mode,ue,null),te.return=oe,te;if(typeof te.then=="function")return Te(oe,Wu(te),ue);if(te.$$typeof===m)return Te(oe,uc(oe,te),ue);Yu(oe,te)}return null}function de(oe,te,ue,Se){var Ue=te!==null?te.key:null;if(typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint")return Ue!==null?null:$(oe,te,""+ue,Se);if(typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case l:return ue.key===Ue?K(oe,te,ue,Se):null;case u:return ue.key===Ue?ne(oe,te,ue,Se):null;case x:return Ue=ue._init,ue=Ue(ue._payload),de(oe,te,ue,Se)}if(L(ue)||_(ue))return Ue!==null?null:be(oe,te,ue,Se,null);if(typeof ue.then=="function")return de(oe,te,Wu(ue),Se);if(ue.$$typeof===m)return de(oe,te,uc(oe,ue),Se);Yu(oe,ue)}return null}function ge(oe,te,ue,Se,Ue){if(typeof Se=="string"&&Se!==""||typeof Se=="number"||typeof Se=="bigint")return oe=oe.get(ue)||null,$(te,oe,""+Se,Ue);if(typeof Se=="object"&&Se!==null){switch(Se.$$typeof){case l:return oe=oe.get(Se.key===null?ue:Se.key)||null,K(te,oe,Se,Ue);case u:return oe=oe.get(Se.key===null?ue:Se.key)||null,ne(te,oe,Se,Ue);case x:var it=Se._init;return Se=it(Se._payload),ge(oe,te,ue,Se,Ue)}if(L(Se)||_(Se))return oe=oe.get(ue)||null,be(te,oe,Se,Ue,null);if(typeof Se.then=="function")return ge(oe,te,ue,Wu(Se),Ue);if(Se.$$typeof===m)return ge(oe,te,ue,uc(te,Se),Ue);Yu(te,Se)}return null}function He(oe,te,ue,Se){for(var Ue=null,it=null,Ve=te,Qe=te=0,nn=null;Ve!==null&&Qe<ue.length;Qe++){Ve.index>Qe?(nn=Ve,Ve=null):nn=Ve.sibling;var vt=de(oe,Ve,ue[Qe],Se);if(vt===null){Ve===null&&(Ve=nn);break}o&&Ve&&vt.alternate===null&&s(oe,Ve),te=E(vt,te,Qe),it===null?Ue=vt:it.sibling=vt,it=vt,Ve=nn}if(Qe===ue.length)return d(oe,Ve),yt&&Do(oe,Qe),Ue;if(Ve===null){for(;Qe<ue.length;Qe++)Ve=Te(oe,ue[Qe],Se),Ve!==null&&(te=E(Ve,te,Qe),it===null?Ue=Ve:it.sibling=Ve,it=Ve);return yt&&Do(oe,Qe),Ue}for(Ve=h(Ve);Qe<ue.length;Qe++)nn=ge(Ve,oe,Qe,ue[Qe],Se),nn!==null&&(o&&nn.alternate!==null&&Ve.delete(nn.key===null?Qe:nn.key),te=E(nn,te,Qe),it===null?Ue=nn:it.sibling=nn,it=nn);return o&&Ve.forEach(function(ao){return s(oe,ao)}),yt&&Do(oe,Qe),Ue}function et(oe,te,ue,Se){if(ue==null)throw Error(r(151));for(var Ue=null,it=null,Ve=te,Qe=te=0,nn=null,vt=ue.next();Ve!==null&&!vt.done;Qe++,vt=ue.next()){Ve.index>Qe?(nn=Ve,Ve=null):nn=Ve.sibling;var ao=de(oe,Ve,vt.value,Se);if(ao===null){Ve===null&&(Ve=nn);break}o&&Ve&&ao.alternate===null&&s(oe,Ve),te=E(ao,te,Qe),it===null?Ue=ao:it.sibling=ao,it=ao,Ve=nn}if(vt.done)return d(oe,Ve),yt&&Do(oe,Qe),Ue;if(Ve===null){for(;!vt.done;Qe++,vt=ue.next())vt=Te(oe,vt.value,Se),vt!==null&&(te=E(vt,te,Qe),it===null?Ue=vt:it.sibling=vt,it=vt);return yt&&Do(oe,Qe),Ue}for(Ve=h(Ve);!vt.done;Qe++,vt=ue.next())vt=ge(Ve,oe,Qe,vt.value,Se),vt!==null&&(o&&vt.alternate!==null&&Ve.delete(vt.key===null?Qe:vt.key),te=E(vt,te,Qe),it===null?Ue=vt:it.sibling=vt,it=vt);return o&&Ve.forEach(function(uH){return s(oe,uH)}),yt&&Do(oe,Qe),Ue}function Gt(oe,te,ue,Se){if(typeof ue=="object"&&ue!==null&&ue.type===c&&ue.key===null&&(ue=ue.props.children),typeof ue=="object"&&ue!==null){switch(ue.$$typeof){case l:e:{for(var Ue=ue.key;te!==null;){if(te.key===Ue){if(Ue=ue.type,Ue===c){if(te.tag===7){d(oe,te.sibling),Se=y(te,ue.props.children),Se.return=oe,oe=Se;break e}}else if(te.elementType===Ue||typeof Ue=="object"&&Ue!==null&&Ue.$$typeof===x&&mT(Ue)===te.type){d(oe,te.sibling),Se=y(te,ue.props),rs(Se,ue),Se.return=oe,oe=Se;break e}d(oe,te);break}else s(oe,te);te=te.sibling}ue.type===c?(Se=Ho(ue.props.children,oe.mode,Se,ue.key),Se.return=oe,oe=Se):(Se=fc(ue.type,ue.key,ue.props,null,oe.mode,Se),rs(Se,ue),Se.return=oe,oe=Se)}return F(oe);case u:e:{for(Ue=ue.key;te!==null;){if(te.key===Ue)if(te.tag===4&&te.stateNode.containerInfo===ue.containerInfo&&te.stateNode.implementation===ue.implementation){d(oe,te.sibling),Se=y(te,ue.children||[]),Se.return=oe,oe=Se;break e}else{d(oe,te);break}else s(oe,te);te=te.sibling}Se=bg(ue,oe.mode,Se),Se.return=oe,oe=Se}return F(oe);case x:return Ue=ue._init,ue=Ue(ue._payload),Gt(oe,te,ue,Se)}if(L(ue))return He(oe,te,ue,Se);if(_(ue)){if(Ue=_(ue),typeof Ue!="function")throw Error(r(150));return ue=Ue.call(ue),et(oe,te,ue,Se)}if(typeof ue.then=="function")return Gt(oe,te,Wu(ue),Se);if(ue.$$typeof===m)return Gt(oe,te,uc(oe,ue),Se);Yu(oe,ue)}return typeof ue=="string"&&ue!==""||typeof ue=="number"||typeof ue=="bigint"?(ue=""+ue,te!==null&&te.tag===6?(d(oe,te.sibling),Se=y(te,ue),Se.return=oe,oe=Se):(d(oe,te),Se=mg(ue,oe.mode,Se),Se.return=oe,oe=Se),F(oe)):d(oe,te)}return function(oe,te,ue,Se){try{ns=0;var Ue=Gt(oe,te,ue,Se);return Ri=null,Ue}catch(Ve){if(Ve===es)throw Ve;var it=cr(29,Ve,null,oe.mode);return it.lanes=Se,it.return=oe,it}finally{}}}var Lo=bT(!0),yT=bT(!1),Ci=le(null),Ku=le(0);function vT(o,s){o=ya,ae(Ku,o),ae(Ci,s),ya=o|s.baseLanes}function xp(){ae(Ku,ya),ae(Ci,Ci.current)}function kp(){ya=Ku.current,Ae(Ci),Ae(Ku)}var lr=le(null),Br=null;function Ua(o){var s=o.alternate;ae(Xt,Xt.current&1),ae(lr,o),Br===null&&(s===null||Ci.current!==null||s.memoizedState!==null)&&(Br=o)}function ST(o){if(o.tag===22){if(ae(Xt,Xt.current),ae(lr,o),Br===null){var s=o.alternate;s!==null&&s.memoizedState!==null&&(Br=o)}}else ja()}function ja(){ae(Xt,Xt.current),ae(lr,lr.current)}function sa(o){Ae(lr),Br===o&&(Br=null),Ae(Xt)}var Xt=le(0);function Xu(o){for(var s=o;s!==null;){if(s.tag===13){var d=s.memoizedState;if(d!==null&&(d=d.dehydrated,d===null||d.data==="$?"||d.data==="$!"))return s}else if(s.tag===19&&s.memoizedProps.revealOrder!==void 0){if(s.flags&128)return s}else if(s.child!==null){s.child.return=s,s=s.child;continue}if(s===o)break;for(;s.sibling===null;){if(s.return===null||s.return===o)return null;s=s.return}s.sibling.return=s.return,s=s.sibling}return null}var XG=typeof AbortController<"u"?AbortController:function(){var o=[],s=this.signal={aborted:!1,addEventListener:function(d,h){o.push(h)}};this.abort=function(){s.aborted=!0,o.forEach(function(d){return d()})}},ZG=e.unstable_scheduleCallback,QG=e.unstable_NormalPriority,Zt={$$typeof:m,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function Ap(){return{controller:new XG,data:new Map,refCount:0}}function as(o){o.refCount--,o.refCount===0&&ZG(QG,function(){o.controller.abort()})}var os=null,Tp=0,Ni=0,Oi=null;function JG(o,s){if(os===null){var d=os=[];Tp=0,Ni=Dg(),Oi={status:"pending",value:void 0,then:function(h){d.push(h)}}}return Tp++,s.then(ET,ET),s}function ET(){if(--Tp===0&&os!==null){Oi!==null&&(Oi.status="fulfilled");var o=os;os=null,Ni=0,Oi=null;for(var s=0;s<o.length;s++)(0,o[s])()}}function e6(o,s){var d=[],h={status:"pending",value:null,reason:null,then:function(y){d.push(y)}};return o.then(function(){h.status="fulfilled",h.value=s;for(var y=0;y<d.length;y++)(0,d[y])(s)},function(y){for(h.status="rejected",h.reason=y,y=0;y<d.length;y++)(0,d[y])(void 0)}),h}var wT=I.S;I.S=function(o,s){typeof s=="object"&&s!==null&&typeof s.then=="function"&&JG(o,s),wT!==null&&wT(o,s)};var Mo=le(null);function _p(){var o=Mo.current;return o!==null?o:Ot.pooledCache}function Zu(o,s){s===null?ae(Mo,Mo.current):ae(Mo,s.pool)}function xT(){var o=_p();return o===null?null:{parent:Zt._currentValue,pool:o}}var Ga=0,ot=null,kt=null,qt=null,Qu=!1,Di=!1,Fo=!1,Ju=0,is=0,Ii=null,t6=0;function Ht(){throw Error(r(321))}function Rp(o,s){if(s===null)return!1;for(var d=0;d<s.length&&d<o.length;d++)if(!Hn(o[d],s[d]))return!1;return!0}function Cp(o,s,d,h,y,E){return Ga=E,ot=s,s.memoizedState=null,s.updateQueue=null,s.lanes=0,I.H=o===null||o.memoizedState===null?zo:Ha,Fo=!1,E=d(h,y),Fo=!1,Di&&(E=AT(s,d,h,y)),kT(o),E}function kT(o){I.H=Ur;var s=kt!==null&&kt.next!==null;if(Ga=0,qt=kt=ot=null,Qu=!1,is=0,Ii=null,s)throw Error(r(300));o===null||en||(o=o.dependencies,o!==null&&sc(o)&&(en=!0))}function AT(o,s,d,h){ot=o;var y=0;do{if(Di&&(Ii=null),is=0,Di=!1,25<=y)throw Error(r(301));if(y+=1,qt=kt=null,o.updateQueue!=null){var E=o.updateQueue;E.lastEffect=null,E.events=null,E.stores=null,E.memoCache!=null&&(E.memoCache.index=0)}I.H=Po,E=s(d,h)}while(Di);return E}function n6(){var o=I.H,s=o.useState()[0];return s=typeof s.then=="function"?ls(s):s,o=o.useState()[0],(kt!==null?kt.memoizedState:null)!==o&&(ot.flags|=1024),s}function Np(){var o=Ju!==0;return Ju=0,o}function Op(o,s,d){s.updateQueue=o.updateQueue,s.flags&=-2053,o.lanes&=~d}function Dp(o){if(Qu){for(o=o.memoizedState;o!==null;){var s=o.queue;s!==null&&(s.pending=null),o=o.next}Qu=!1}Ga=0,qt=kt=ot=null,Di=!1,is=Ju=0,Ii=null}function In(){var o={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return qt===null?ot.memoizedState=qt=o:qt=qt.next=o,qt}function Vt(){if(kt===null){var o=ot.alternate;o=o!==null?o.memoizedState:null}else o=kt.next;var s=qt===null?ot.memoizedState:qt.next;if(s!==null)qt=s,kt=o;else{if(o===null)throw ot.alternate===null?Error(r(467)):Error(r(310));kt=o,o={memoizedState:kt.memoizedState,baseState:kt.baseState,baseQueue:kt.baseQueue,queue:kt.queue,next:null},qt===null?ot.memoizedState=qt=o:qt=qt.next=o}return qt}var ec;ec=function(){return{lastEffect:null,events:null,stores:null,memoCache:null}};function ls(o){var s=is;return is+=1,Ii===null&&(Ii=[]),o=gT(Ii,o,s),s=ot,(qt===null?s.memoizedState:qt.next)===null&&(s=s.alternate,I.H=s===null||s.memoizedState===null?zo:Ha),o}function tc(o){if(o!==null&&typeof o=="object"){if(typeof o.then=="function")return ls(o);if(o.$$typeof===m)return mn(o)}throw Error(r(438,String(o)))}function Ip(o){var s=null,d=ot.updateQueue;if(d!==null&&(s=d.memoCache),s==null){var h=ot.alternate;h!==null&&(h=h.updateQueue,h!==null&&(h=h.memoCache,h!=null&&(s={data:h.data.map(function(y){return y.slice()}),index:0})))}if(s==null&&(s={data:[],index:0}),d===null&&(d=ec(),ot.updateQueue=d),d.memoCache=s,d=s.data[s.index],d===void 0)for(d=s.data[s.index]=Array(o),h=0;h<o;h++)d[h]=C;return s.index++,d}function ua(o,s){return typeof s=="function"?s(o):s}function nc(o){var s=Vt();return Lp(s,kt,o)}function Lp(o,s,d){var h=o.queue;if(h===null)throw Error(r(311));h.lastRenderedReducer=d;var y=o.baseQueue,E=h.pending;if(E!==null){if(y!==null){var F=y.next;y.next=E.next,E.next=F}s.baseQueue=y=E,h.pending=null}if(E=o.baseState,y===null)o.memoizedState=E;else{s=y.next;var $=F=null,K=null,ne=s,be=!1;do{var Te=ne.lane&-536870913;if(Te!==ne.lane?(ht&Te)===Te:(Ga&Te)===Te){var de=ne.revertLane;if(de===0)K!==null&&(K=K.next={lane:0,revertLane:0,action:ne.action,hasEagerState:ne.hasEagerState,eagerState:ne.eagerState,next:null}),Te===Ni&&(be=!0);else if((Ga&de)===de){ne=ne.next,de===Ni&&(be=!0);continue}else Te={lane:0,revertLane:ne.revertLane,action:ne.action,hasEagerState:ne.hasEagerState,eagerState:ne.eagerState,next:null},K===null?($=K=Te,F=E):K=K.next=Te,ot.lanes|=de,Qa|=de;Te=ne.action,Fo&&d(E,Te),E=ne.hasEagerState?ne.eagerState:d(E,Te)}else de={lane:Te,revertLane:ne.revertLane,action:ne.action,hasEagerState:ne.hasEagerState,eagerState:ne.eagerState,next:null},K===null?($=K=de,F=E):K=K.next=de,ot.lanes|=Te,Qa|=Te;ne=ne.next}while(ne!==null&&ne!==s);if(K===null?F=E:K.next=$,!Hn(E,o.memoizedState)&&(en=!0,be&&(d=Oi,d!==null)))throw d;o.memoizedState=E,o.baseState=F,o.baseQueue=K,h.lastRenderedState=E}return y===null&&(h.lanes=0),[o.memoizedState,h.dispatch]}function Mp(o){var s=Vt(),d=s.queue;if(d===null)throw Error(r(311));d.lastRenderedReducer=o;var h=d.dispatch,y=d.pending,E=s.memoizedState;if(y!==null){d.pending=null;var F=y=y.next;do E=o(E,F.action),F=F.next;while(F!==y);Hn(E,s.memoizedState)||(en=!0),s.memoizedState=E,s.baseQueue===null&&(s.baseState=E),d.lastRenderedState=E}return[E,h]}function TT(o,s,d){var h=ot,y=Vt(),E=yt;if(E){if(d===void 0)throw Error(r(407));d=d()}else d=s();var F=!Hn((kt||y).memoizedState,d);if(F&&(y.memoizedState=d,en=!0),y=y.queue,Pp(CT.bind(null,h,y,o),[o]),y.getSnapshot!==s||F||qt!==null&&qt.memoizedState.tag&1){if(h.flags|=2048,Li(9,RT.bind(null,h,y,d,s),{destroy:void 0},null),Ot===null)throw Error(r(349));E||Ga&60||_T(h,s,d)}return d}function _T(o,s,d){o.flags|=16384,o={getSnapshot:s,value:d},s=ot.updateQueue,s===null?(s=ec(),ot.updateQueue=s,s.stores=[o]):(d=s.stores,d===null?s.stores=[o]:d.push(o))}function RT(o,s,d,h){s.value=d,s.getSnapshot=h,NT(s)&&OT(o)}function CT(o,s,d){return d(function(){NT(s)&&OT(o)})}function NT(o){var s=o.getSnapshot;o=o.value;try{var d=s();return!Hn(o,d)}catch{return!0}}function OT(o){var s=Ba(o,2);s!==null&&Tn(s,o,2)}function Fp(o){var s=In();if(typeof o=="function"){var d=o;if(o=d(),Fo){rt(!0);try{d()}finally{rt(!1)}}}return s.memoizedState=s.baseState=o,s.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:ua,lastRenderedState:o},s}function DT(o,s,d,h){return o.baseState=d,Lp(o,kt,typeof h=="function"?h:ua)}function r6(o,s,d,h,y){if(oc(o))throw Error(r(485));if(o=s.action,o!==null){var E={payload:y,action:o,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(F){E.listeners.push(F)}};I.T!==null?d(!0):E.isTransition=!1,h(E),d=s.pending,d===null?(E.next=s.pending=E,IT(s,E)):(E.next=d.next,s.pending=d.next=E)}}function IT(o,s){var d=s.action,h=s.payload,y=o.state;if(s.isTransition){var E=I.T,F={};I.T=F;try{var $=d(y,h),K=I.S;K!==null&&K(F,$),LT(o,s,$)}catch(ne){zp(o,s,ne)}finally{I.T=E}}else try{E=d(y,h),LT(o,s,E)}catch(ne){zp(o,s,ne)}}function LT(o,s,d){d!==null&&typeof d=="object"&&typeof d.then=="function"?d.then(function(h){MT(o,s,h)},function(h){return zp(o,s,h)}):MT(o,s,d)}function MT(o,s,d){s.status="fulfilled",s.value=d,FT(s),o.state=d,s=o.pending,s!==null&&(d=s.next,d===s?o.pending=null:(d=d.next,s.next=d,IT(o,d)))}function zp(o,s,d){var h=o.pending;if(o.pending=null,h!==null){h=h.next;do s.status="rejected",s.reason=d,FT(s),s=s.next;while(s!==h)}o.action=null}function FT(o){o=o.listeners;for(var s=0;s<o.length;s++)(0,o[s])()}function zT(o,s){return s}function PT(o,s){if(yt){var d=Ot.formState;if(d!==null){e:{var h=ot;if(yt){if(un){t:{for(var y=un,E=Pr;y.nodeType!==8;){if(!E){y=null;break t}if(y=kr(y.nextSibling),y===null){y=null;break t}}E=y.data,y=E==="F!"||E==="F"?y:null}if(y){un=kr(y.nextSibling),h=y.data==="F!";break e}}Io(h)}h=!1}h&&(s=d[0])}}return d=In(),d.memoizedState=d.baseState=s,h={pending:null,lanes:0,dispatch:null,lastRenderedReducer:zT,lastRenderedState:s},d.queue=h,d=n_.bind(null,ot,h),h.dispatch=d,h=Fp(!1),E=Hp.bind(null,ot,!1,h.queue),h=In(),y={state:s,dispatch:null,action:o,pending:null},h.queue=y,d=r6.bind(null,ot,y,E,d),y.dispatch=d,h.memoizedState=o,[s,d,!1]}function BT(o){var s=Vt();return UT(s,kt,o)}function UT(o,s,d){s=Lp(o,s,zT)[0],o=nc(ua)[0],s=typeof s=="object"&&s!==null&&typeof s.then=="function"?ls(s):s;var h=Vt(),y=h.queue,E=y.dispatch;return d!==h.memoizedState&&(ot.flags|=2048,Li(9,a6.bind(null,y,d),{destroy:void 0},null)),[s,E,o]}function a6(o,s){o.action=s}function jT(o){var s=Vt(),d=kt;if(d!==null)return UT(s,d,o);Vt(),s=s.memoizedState,d=Vt();var h=d.queue.dispatch;return d.memoizedState=o,[s,h,!1]}function Li(o,s,d,h){return o={tag:o,create:s,inst:d,deps:h,next:null},s=ot.updateQueue,s===null&&(s=ec(),ot.updateQueue=s),d=s.lastEffect,d===null?s.lastEffect=o.next=o:(h=d.next,d.next=o,o.next=h,s.lastEffect=o),o}function GT(){return Vt().memoizedState}function rc(o,s,d,h){var y=In();ot.flags|=o,y.memoizedState=Li(1|s,d,{destroy:void 0},h===void 0?null:h)}function ac(o,s,d,h){var y=Vt();h=h===void 0?null:h;var E=y.memoizedState.inst;kt!==null&&h!==null&&Rp(h,kt.memoizedState.deps)?y.memoizedState=Li(s,d,E,h):(ot.flags|=o,y.memoizedState=Li(1|s,d,E,h))}function HT(o,s){rc(8390656,8,o,s)}function Pp(o,s){ac(2048,8,o,s)}function $T(o,s){return ac(4,2,o,s)}function qT(o,s){return ac(4,4,o,s)}function VT(o,s){if(typeof s=="function"){o=o();var d=s(o);return function(){typeof d=="function"?d():s(null)}}if(s!=null)return o=o(),s.current=o,function(){s.current=null}}function WT(o,s,d){d=d!=null?d.concat([o]):null,ac(4,4,VT.bind(null,s,o),d)}function Bp(){}function YT(o,s){var d=Vt();s=s===void 0?null:s;var h=d.memoizedState;return s!==null&&Rp(s,h[1])?h[0]:(d.memoizedState=[o,s],o)}function KT(o,s){var d=Vt();s=s===void 0?null:s;var h=d.memoizedState;if(s!==null&&Rp(s,h[1]))return h[0];if(h=o(),Fo){rt(!0);try{o()}finally{rt(!1)}}return d.memoizedState=[h,s],h}function Up(o,s,d){return d===void 0||Ga&1073741824?o.memoizedState=s:(o.memoizedState=d,o=Z_(),ot.lanes|=o,Qa|=o,d)}function XT(o,s,d,h){return Hn(d,s)?d:Ci.current!==null?(o=Up(o,d,h),Hn(o,s)||(en=!0),o):Ga&42?(o=Z_(),ot.lanes|=o,Qa|=o,s):(en=!0,o.memoizedState=d)}function ZT(o,s,d,h,y){var E=Y.p;Y.p=E!==0&&8>E?E:8;var F=I.T,$={};I.T=$,Hp(o,!1,s,d);try{var K=y(),ne=I.S;if(ne!==null&&ne($,K),K!==null&&typeof K=="object"&&typeof K.then=="function"){var be=e6(K,h);ss(o,s,be,Wn(o))}else ss(o,s,h,Wn(o))}catch(Te){ss(o,s,{then:function(){},status:"rejected",reason:Te},Wn())}finally{Y.p=E,I.T=F}}function o6(){}function jp(o,s,d,h){if(o.tag!==5)throw Error(r(476));var y=QT(o).queue;ZT(o,y,s,Q,d===null?o6:function(){return JT(o),d(h)})}function QT(o){var s=o.memoizedState;if(s!==null)return s;s={memoizedState:Q,baseState:Q,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:ua,lastRenderedState:Q},next:null};var d={};return s.next={memoizedState:d,baseState:d,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:ua,lastRenderedState:d},next:null},o.memoizedState=s,o=o.alternate,o!==null&&(o.memoizedState=s),s}function JT(o){var s=QT(o).next.queue;ss(o,s,{},Wn())}function Gp(){return mn(Rs)}function e_(){return Vt().memoizedState}function t_(){return Vt().memoizedState}function i6(o){for(var s=o.return;s!==null;){switch(s.tag){case 24:case 3:var d=Wn();o=Va(d);var h=Wa(s,o,d);h!==null&&(Tn(h,s,d),ds(h,s,d)),s={cache:Ap()},o.payload=s;return}s=s.return}}function l6(o,s,d){var h=Wn();d={lane:h,revertLane:0,action:d,hasEagerState:!1,eagerState:null,next:null},oc(o)?r_(s,d):(d=yp(o,s,d,h),d!==null&&(Tn(d,o,h),a_(d,s,h)))}function n_(o,s,d){var h=Wn();ss(o,s,d,h)}function ss(o,s,d,h){var y={lane:h,revertLane:0,action:d,hasEagerState:!1,eagerState:null,next:null};if(oc(o))r_(s,y);else{var E=o.alternate;if(o.lanes===0&&(E===null||E.lanes===0)&&(E=s.lastRenderedReducer,E!==null))try{var F=s.lastRenderedState,$=E(F,d);if(y.hasEagerState=!0,y.eagerState=$,Hn($,F))return Gu(o,s,y,0),Ot===null&&ju(),!1}catch{}finally{}if(d=yp(o,s,y,h),d!==null)return Tn(d,o,h),a_(d,s,h),!0}return!1}function Hp(o,s,d,h){if(h={lane:2,revertLane:Dg(),action:h,hasEagerState:!1,eagerState:null,next:null},oc(o)){if(s)throw Error(r(479))}else s=yp(o,d,h,2),s!==null&&Tn(s,o,2)}function oc(o){var s=o.alternate;return o===ot||s!==null&&s===ot}function r_(o,s){Di=Qu=!0;var d=o.pending;d===null?s.next=s:(s.next=d.next,d.next=s),o.pending=s}function a_(o,s,d){if(d&4194176){var h=s.lanes;h&=o.pendingLanes,d|=h,s.lanes=d,Sr(o,d)}}var Ur={readContext:mn,use:tc,useCallback:Ht,useContext:Ht,useEffect:Ht,useImperativeHandle:Ht,useLayoutEffect:Ht,useInsertionEffect:Ht,useMemo:Ht,useReducer:Ht,useRef:Ht,useState:Ht,useDebugValue:Ht,useDeferredValue:Ht,useTransition:Ht,useSyncExternalStore:Ht,useId:Ht};Ur.useCacheRefresh=Ht,Ur.useMemoCache=Ht,Ur.useHostTransitionStatus=Ht,Ur.useFormState=Ht,Ur.useActionState=Ht,Ur.useOptimistic=Ht;var zo={readContext:mn,use:tc,useCallback:function(o,s){return In().memoizedState=[o,s===void 0?null:s],o},useContext:mn,useEffect:HT,useImperativeHandle:function(o,s,d){d=d!=null?d.concat([o]):null,rc(4194308,4,VT.bind(null,s,o),d)},useLayoutEffect:function(o,s){return rc(4194308,4,o,s)},useInsertionEffect:function(o,s){rc(4,2,o,s)},useMemo:function(o,s){var d=In();s=s===void 0?null:s;var h=o();if(Fo){rt(!0);try{o()}finally{rt(!1)}}return d.memoizedState=[h,s],h},useReducer:function(o,s,d){var h=In();if(d!==void 0){var y=d(s);if(Fo){rt(!0);try{d(s)}finally{rt(!1)}}}else y=s;return h.memoizedState=h.baseState=y,o={pending:null,lanes:0,dispatch:null,lastRenderedReducer:o,lastRenderedState:y},h.queue=o,o=o.dispatch=l6.bind(null,ot,o),[h.memoizedState,o]},useRef:function(o){var s=In();return o={current:o},s.memoizedState=o},useState:function(o){o=Fp(o);var s=o.queue,d=n_.bind(null,ot,s);return s.dispatch=d,[o.memoizedState,d]},useDebugValue:Bp,useDeferredValue:function(o,s){var d=In();return Up(d,o,s)},useTransition:function(){var o=Fp(!1);return o=ZT.bind(null,ot,o.queue,!0,!1),In().memoizedState=o,[!1,o]},useSyncExternalStore:function(o,s,d){var h=ot,y=In();if(yt){if(d===void 0)throw Error(r(407));d=d()}else{if(d=s(),Ot===null)throw Error(r(349));ht&60||_T(h,s,d)}y.memoizedState=d;var E={value:d,getSnapshot:s};return y.queue=E,HT(CT.bind(null,h,E,o),[o]),h.flags|=2048,Li(9,RT.bind(null,h,E,d,s),{destroy:void 0},null),d},useId:function(){var o=In(),s=Ot.identifierPrefix;if(yt){var d=la,h=ia;d=(h&~(1<<32-bt(h)-1)).toString(32)+d,s=":"+s+"R"+d,d=Ju++,0<d&&(s+="H"+d.toString(32)),s+=":"}else d=t6++,s=":"+s+"r"+d.toString(32)+":";return o.memoizedState=s},useCacheRefresh:function(){return In().memoizedState=i6.bind(null,ot)}};zo.useMemoCache=Ip,zo.useHostTransitionStatus=Gp,zo.useFormState=PT,zo.useActionState=PT,zo.useOptimistic=function(o){var s=In();s.memoizedState=s.baseState=o;var d={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return s.queue=d,s=Hp.bind(null,ot,!0,d),d.dispatch=s,[o,s]};var Ha={readContext:mn,use:tc,useCallback:YT,useContext:mn,useEffect:Pp,useImperativeHandle:WT,useInsertionEffect:$T,useLayoutEffect:qT,useMemo:KT,useReducer:nc,useRef:GT,useState:function(){return nc(ua)},useDebugValue:Bp,useDeferredValue:function(o,s){var d=Vt();return XT(d,kt.memoizedState,o,s)},useTransition:function(){var o=nc(ua)[0],s=Vt().memoizedState;return[typeof o=="boolean"?o:ls(o),s]},useSyncExternalStore:TT,useId:e_};Ha.useCacheRefresh=t_,Ha.useMemoCache=Ip,Ha.useHostTransitionStatus=Gp,Ha.useFormState=BT,Ha.useActionState=BT,Ha.useOptimistic=function(o,s){var d=Vt();return DT(d,kt,o,s)};var Po={readContext:mn,use:tc,useCallback:YT,useContext:mn,useEffect:Pp,useImperativeHandle:WT,useInsertionEffect:$T,useLayoutEffect:qT,useMemo:KT,useReducer:Mp,useRef:GT,useState:function(){return Mp(ua)},useDebugValue:Bp,useDeferredValue:function(o,s){var d=Vt();return kt===null?Up(d,o,s):XT(d,kt.memoizedState,o,s)},useTransition:function(){var o=Mp(ua)[0],s=Vt().memoizedState;return[typeof o=="boolean"?o:ls(o),s]},useSyncExternalStore:TT,useId:e_};Po.useCacheRefresh=t_,Po.useMemoCache=Ip,Po.useHostTransitionStatus=Gp,Po.useFormState=jT,Po.useActionState=jT,Po.useOptimistic=function(o,s){var d=Vt();return kt!==null?DT(d,kt,o,s):(d.baseState=o,[o,d.queue.dispatch])};function $p(o,s,d,h){s=o.memoizedState,d=d(h,s),d=d==null?s:M({},s,d),o.memoizedState=d,o.lanes===0&&(o.updateQueue.baseState=d)}var qp={isMounted:function(o){return(o=o._reactInternals)?B(o)===o:!1},enqueueSetState:function(o,s,d){o=o._reactInternals;var h=Wn(),y=Va(h);y.payload=s,d!=null&&(y.callback=d),s=Wa(o,y,h),s!==null&&(Tn(s,o,h),ds(s,o,h))},enqueueReplaceState:function(o,s,d){o=o._reactInternals;var h=Wn(),y=Va(h);y.tag=1,y.payload=s,d!=null&&(y.callback=d),s=Wa(o,y,h),s!==null&&(Tn(s,o,h),ds(s,o,h))},enqueueForceUpdate:function(o,s){o=o._reactInternals;var d=Wn(),h=Va(d);h.tag=2,s!=null&&(h.callback=s),s=Wa(o,h,d),s!==null&&(Tn(s,o,d),ds(s,o,d))}};function o_(o,s,d,h,y,E,F){return o=o.stateNode,typeof o.shouldComponentUpdate=="function"?o.shouldComponentUpdate(h,E,F):s.prototype&&s.prototype.isPureReactComponent?!Kl(d,h)||!Kl(y,E):!0}function i_(o,s,d,h){o=s.state,typeof s.componentWillReceiveProps=="function"&&s.componentWillReceiveProps(d,h),typeof s.UNSAFE_componentWillReceiveProps=="function"&&s.UNSAFE_componentWillReceiveProps(d,h),s.state!==o&&qp.enqueueReplaceState(s,s.state,null)}function Bo(o,s){var d=s;if("ref"in s){d={};for(var h in s)h!=="ref"&&(d[h]=s[h])}if(o=o.defaultProps){d===s&&(d=M({},d));for(var y in o)d[y]===void 0&&(d[y]=o[y])}return d}var ic=typeof reportError=="function"?reportError:function(o){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var s=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof o=="object"&&o!==null&&typeof o.message=="string"?String(o.message):String(o),error:o});if(!window.dispatchEvent(s))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",o);return}console.error(o)};function l_(o){ic(o)}function s_(o){console.error(o)}function u_(o){ic(o)}function lc(o,s){try{var d=o.onUncaughtError;d(s.value,{componentStack:s.stack})}catch(h){setTimeout(function(){throw h})}}function c_(o,s,d){try{var h=o.onCaughtError;h(d.value,{componentStack:d.stack,errorBoundary:s.tag===1?s.stateNode:null})}catch(y){setTimeout(function(){throw y})}}function Vp(o,s,d){return d=Va(d),d.tag=3,d.payload={element:null},d.callback=function(){lc(o,s)},d}function d_(o){return o=Va(o),o.tag=3,o}function f_(o,s,d,h){var y=d.type.getDerivedStateFromError;if(typeof y=="function"){var E=h.value;o.payload=function(){return y(E)},o.callback=function(){c_(s,d,h)}}var F=d.stateNode;F!==null&&typeof F.componentDidCatch=="function"&&(o.callback=function(){c_(s,d,h),typeof y!="function"&&(Ja===null?Ja=new Set([this]):Ja.add(this));var $=h.stack;this.componentDidCatch(h.value,{componentStack:$!==null?$:""})})}function s6(o,s,d,h,y){if(d.flags|=32768,h!==null&&typeof h=="object"&&typeof h.then=="function"){if(s=d.alternate,s!==null&&cs(s,d,y,!0),d=lr.current,d!==null){switch(d.tag){case 13:return Br===null?_g():d.alternate===null&&jt===0&&(jt=3),d.flags&=-257,d.flags|=65536,d.lanes=y,h===wp?d.flags|=16384:(s=d.updateQueue,s===null?d.updateQueue=new Set([h]):s.add(h),Cg(o,h,y)),!1;case 22:return d.flags|=65536,h===wp?d.flags|=16384:(s=d.updateQueue,s===null?(s={transitions:null,markerInstances:null,retryQueue:new Set([h])},d.updateQueue=s):(d=s.retryQueue,d===null?s.retryQueue=new Set([h]):d.add(h)),Cg(o,h,y)),!1}throw Error(r(435,d.tag))}return Cg(o,h,y),_g(),!1}if(yt)return s=lr.current,s!==null?(!(s.flags&65536)&&(s.flags|=256),s.flags|=65536,s.lanes=y,h!==Ep&&(o=Error(r(422),{cause:h}),Jl(ar(o,d)))):(h!==Ep&&(s=Error(r(423),{cause:h}),Jl(ar(s,d))),o=o.current.alternate,o.flags|=65536,y&=-y,o.lanes|=y,h=ar(h,d),y=Vp(o.stateNode,h,y),lg(o,y),jt!==4&&(jt=2)),!1;var E=Error(r(520),{cause:h});if(E=ar(E,d),vs===null?vs=[E]:vs.push(E),jt!==4&&(jt=2),s===null)return!0;h=ar(h,d),d=s;do{switch(d.tag){case 3:return d.flags|=65536,o=y&-y,d.lanes|=o,o=Vp(d.stateNode,h,o),lg(d,o),!1;case 1:if(s=d.type,E=d.stateNode,(d.flags&128)===0&&(typeof s.getDerivedStateFromError=="function"||E!==null&&typeof E.componentDidCatch=="function"&&(Ja===null||!Ja.has(E))))return d.flags|=65536,y&=-y,d.lanes|=y,y=d_(y),f_(y,o,d,h),lg(d,y),!1}d=d.return}while(d!==null);return!1}var p_=Error(r(461)),en=!1;function cn(o,s,d,h){s.child=o===null?yT(s,null,d,h):Lo(s,o.child,d,h)}function g_(o,s,d,h,y){d=d.render;var E=s.ref;if("ref"in h){var F={};for(var $ in h)$!=="ref"&&(F[$]=h[$])}else F=h;return jo(s),h=Cp(o,s,d,F,E,y),$=Np(),o!==null&&!en?(Op(o,s,y),ca(o,s,y)):(yt&&$&&vp(s),s.flags|=1,cn(o,s,h,y),s.child)}function h_(o,s,d,h,y){if(o===null){var E=d.type;return typeof E=="function"&&!hg(E)&&E.defaultProps===void 0&&d.compare===null?(s.tag=15,s.type=E,m_(o,s,E,h,y)):(o=fc(d.type,null,h,s,s.mode,y),o.ref=s.ref,o.return=s,s.child=o)}if(E=o.child,!tg(o,y)){var F=E.memoizedProps;if(d=d.compare,d=d!==null?d:Kl,d(F,h)&&o.ref===s.ref)return ca(o,s,y)}return s.flags|=1,o=Za(E,h),o.ref=s.ref,o.return=s,s.child=o}function m_(o,s,d,h,y){if(o!==null){var E=o.memoizedProps;if(Kl(E,h)&&o.ref===s.ref)if(en=!1,s.pendingProps=h=E,tg(o,y))o.flags&131072&&(en=!0);else return s.lanes=o.lanes,ca(o,s,y)}return Wp(o,s,d,h,y)}function b_(o,s,d){var h=s.pendingProps,y=h.children,E=(s.stateNode._pendingVisibility&2)!==0,F=o!==null?o.memoizedState:null;if(us(o,s),h.mode==="hidden"||E){if(s.flags&128){if(h=F!==null?F.baseLanes|d:d,o!==null){for(y=s.child=o.child,E=0;y!==null;)E=E|y.lanes|y.childLanes,y=y.sibling;s.childLanes=E&~h}else s.childLanes=0,s.child=null;return y_(o,s,h,d)}if(d&536870912)s.memoizedState={baseLanes:0,cachePool:null},o!==null&&Zu(s,F!==null?F.cachePool:null),F!==null?vT(s,F):xp(),ST(s);else return s.lanes=s.childLanes=536870912,y_(o,s,F!==null?F.baseLanes|d:d,d)}else F!==null?(Zu(s,F.cachePool),vT(s,F),ja(),s.memoizedState=null):(o!==null&&Zu(s,null),xp(),ja());return cn(o,s,y,d),s.child}function y_(o,s,d,h){var y=_p();return y=y===null?null:{parent:Zt._currentValue,pool:y},s.memoizedState={baseLanes:d,cachePool:y},o!==null&&Zu(s,null),xp(),ST(s),o!==null&&cs(o,s,h,!0),null}function us(o,s){var d=s.ref;if(d===null)o!==null&&o.ref!==null&&(s.flags|=2097664);else{if(typeof d!="function"&&typeof d!="object")throw Error(r(284));(o===null||o.ref!==d)&&(s.flags|=2097664)}}function Wp(o,s,d,h,y){return jo(s),d=Cp(o,s,d,h,void 0,y),h=Np(),o!==null&&!en?(Op(o,s,y),ca(o,s,y)):(yt&&h&&vp(s),s.flags|=1,cn(o,s,d,y),s.child)}function v_(o,s,d,h,y,E){return jo(s),s.updateQueue=null,d=AT(s,h,d,y),kT(o),h=Np(),o!==null&&!en?(Op(o,s,E),ca(o,s,E)):(yt&&h&&vp(s),s.flags|=1,cn(o,s,d,E),s.child)}function S_(o,s,d,h,y){if(jo(s),s.stateNode===null){var E=Ai,F=d.contextType;typeof F=="object"&&F!==null&&(E=mn(F)),E=new d(h,E),s.memoizedState=E.state!==null&&E.state!==void 0?E.state:null,E.updater=qp,s.stateNode=E,E._reactInternals=s,E=s.stateNode,E.props=h,E.state=s.memoizedState,E.refs={},og(s),F=d.contextType,E.context=typeof F=="object"&&F!==null?mn(F):Ai,E.state=s.memoizedState,F=d.getDerivedStateFromProps,typeof F=="function"&&($p(s,d,F,h),E.state=s.memoizedState),typeof d.getDerivedStateFromProps=="function"||typeof E.getSnapshotBeforeUpdate=="function"||typeof E.UNSAFE_componentWillMount!="function"&&typeof E.componentWillMount!="function"||(F=E.state,typeof E.componentWillMount=="function"&&E.componentWillMount(),typeof E.UNSAFE_componentWillMount=="function"&&E.UNSAFE_componentWillMount(),F!==E.state&&qp.enqueueReplaceState(E,E.state,null),ps(s,h,E,y),fs(),E.state=s.memoizedState),typeof E.componentDidMount=="function"&&(s.flags|=4194308),h=!0}else if(o===null){E=s.stateNode;var $=s.memoizedProps,K=Bo(d,$);E.props=K;var ne=E.context,be=d.contextType;F=Ai,typeof be=="object"&&be!==null&&(F=mn(be));var Te=d.getDerivedStateFromProps;be=typeof Te=="function"||typeof E.getSnapshotBeforeUpdate=="function",$=s.pendingProps!==$,be||typeof E.UNSAFE_componentWillReceiveProps!="function"&&typeof E.componentWillReceiveProps!="function"||($||ne!==F)&&i_(s,E,h,F),qa=!1;var de=s.memoizedState;E.state=de,ps(s,h,E,y),fs(),ne=s.memoizedState,$||de!==ne||qa?(typeof Te=="function"&&($p(s,d,Te,h),ne=s.memoizedState),(K=qa||o_(s,d,K,h,de,ne,F))?(be||typeof E.UNSAFE_componentWillMount!="function"&&typeof E.componentWillMount!="function"||(typeof E.componentWillMount=="function"&&E.componentWillMount(),typeof E.UNSAFE_componentWillMount=="function"&&E.UNSAFE_componentWillMount()),typeof E.componentDidMount=="function"&&(s.flags|=4194308)):(typeof E.componentDidMount=="function"&&(s.flags|=4194308),s.memoizedProps=h,s.memoizedState=ne),E.props=h,E.state=ne,E.context=F,h=K):(typeof E.componentDidMount=="function"&&(s.flags|=4194308),h=!1)}else{E=s.stateNode,ig(o,s),F=s.memoizedProps,be=Bo(d,F),E.props=be,Te=s.pendingProps,de=E.context,ne=d.contextType,K=Ai,typeof ne=="object"&&ne!==null&&(K=mn(ne)),$=d.getDerivedStateFromProps,(ne=typeof $=="function"||typeof E.getSnapshotBeforeUpdate=="function")||typeof E.UNSAFE_componentWillReceiveProps!="function"&&typeof E.componentWillReceiveProps!="function"||(F!==Te||de!==K)&&i_(s,E,h,K),qa=!1,de=s.memoizedState,E.state=de,ps(s,h,E,y),fs();var ge=s.memoizedState;F!==Te||de!==ge||qa||o!==null&&o.dependencies!==null&&sc(o.dependencies)?(typeof $=="function"&&($p(s,d,$,h),ge=s.memoizedState),(be=qa||o_(s,d,be,h,de,ge,K)||o!==null&&o.dependencies!==null&&sc(o.dependencies))?(ne||typeof E.UNSAFE_componentWillUpdate!="function"&&typeof E.componentWillUpdate!="function"||(typeof E.componentWillUpdate=="function"&&E.componentWillUpdate(h,ge,K),typeof E.UNSAFE_componentWillUpdate=="function"&&E.UNSAFE_componentWillUpdate(h,ge,K)),typeof E.componentDidUpdate=="function"&&(s.flags|=4),typeof E.getSnapshotBeforeUpdate=="function"&&(s.flags|=1024)):(typeof E.componentDidUpdate!="function"||F===o.memoizedProps&&de===o.memoizedState||(s.flags|=4),typeof E.getSnapshotBeforeUpdate!="function"||F===o.memoizedProps&&de===o.memoizedState||(s.flags|=1024),s.memoizedProps=h,s.memoizedState=ge),E.props=h,E.state=ge,E.context=K,h=be):(typeof E.componentDidUpdate!="function"||F===o.memoizedProps&&de===o.memoizedState||(s.flags|=4),typeof E.getSnapshotBeforeUpdate!="function"||F===o.memoizedProps&&de===o.memoizedState||(s.flags|=1024),h=!1)}return E=h,us(o,s),h=(s.flags&128)!==0,E||h?(E=s.stateNode,d=h&&typeof d.getDerivedStateFromError!="function"?null:E.render(),s.flags|=1,o!==null&&h?(s.child=Lo(s,o.child,null,y),s.child=Lo(s,null,d,y)):cn(o,s,d,y),s.memoizedState=E.state,o=s.child):o=ca(o,s,y),o}function E_(o,s,d,h){return Ql(),s.flags|=256,cn(o,s,d,h),s.child}var Yp={dehydrated:null,treeContext:null,retryLane:0};function Kp(o){return{baseLanes:o,cachePool:xT()}}function Xp(o,s,d){return o=o!==null?o.childLanes&~d:0,s&&(o|=dr),o}function w_(o,s,d){var h=s.pendingProps,y=!1,E=(s.flags&128)!==0,F;if((F=E)||(F=o!==null&&o.memoizedState===null?!1:(Xt.current&2)!==0),F&&(y=!0,s.flags&=-129),F=(s.flags&32)!==0,s.flags&=-33,o===null){if(yt){if(y?Ua(s):ja(),yt){var $=un,K;if(K=$){e:{for(K=$,$=Pr;K.nodeType!==8;){if(!$){$=null;break e}if(K=kr(K.nextSibling),K===null){$=null;break e}}$=K}$!==null?(s.memoizedState={dehydrated:$,treeContext:Oo!==null?{id:ia,overflow:la}:null,retryLane:536870912},K=cr(18,null,null,0),K.stateNode=$,K.return=s,s.child=K,An=s,un=null,K=!0):K=!1}K||Io(s)}if($=s.memoizedState,$!==null&&($=$.dehydrated,$!==null))return $.data==="$!"?s.lanes=16:s.lanes=536870912,null;sa(s)}return $=h.children,h=h.fallback,y?(ja(),y=s.mode,$=Qp({mode:"hidden",children:$},y),h=Ho(h,y,d,null),$.return=s,h.return=s,$.sibling=h,s.child=$,y=s.child,y.memoizedState=Kp(d),y.childLanes=Xp(o,F,d),s.memoizedState=Yp,h):(Ua(s),Zp(s,$))}if(K=o.memoizedState,K!==null&&($=K.dehydrated,$!==null)){if(E)s.flags&256?(Ua(s),s.flags&=-257,s=Jp(o,s,d)):s.memoizedState!==null?(ja(),s.child=o.child,s.flags|=128,s=null):(ja(),y=h.fallback,$=s.mode,h=Qp({mode:"visible",children:h.children},$),y=Ho(y,$,d,null),y.flags|=2,h.return=s,y.return=s,h.sibling=y,s.child=h,Lo(s,o.child,null,d),h=s.child,h.memoizedState=Kp(d),h.childLanes=Xp(o,F,d),s.memoizedState=Yp,s=y);else if(Ua(s),$.data==="$!"){if(F=$.nextSibling&&$.nextSibling.dataset,F)var ne=F.dgst;F=ne,h=Error(r(419)),h.stack="",h.digest=F,Jl({value:h,source:null,stack:null}),s=Jp(o,s,d)}else if(en||cs(o,s,d,!1),F=(d&o.childLanes)!==0,en||F){if(F=Ot,F!==null){if(h=d&-d,h&42)h=1;else switch(h){case 2:h=1;break;case 8:h=4;break;case 32:h=16;break;case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:h=64;break;case 268435456:h=134217728;break;default:h=0}if(h=h&(F.suspendedLanes|d)?0:h,h!==0&&h!==K.retryLane)throw K.retryLane=h,Ba(o,h),Tn(F,o,h),p_}$.data==="$?"||_g(),s=Jp(o,s,d)}else $.data==="$?"?(s.flags|=128,s.child=o.child,s=x6.bind(null,o),$._reactRetry=s,s=null):(o=K.treeContext,un=kr($.nextSibling),An=s,yt=!0,wr=null,Pr=!1,o!==null&&(or[ir++]=ia,or[ir++]=la,or[ir++]=Oo,ia=o.id,la=o.overflow,Oo=s),s=Zp(s,h.children),s.flags|=4096);return s}return y?(ja(),y=h.fallback,$=s.mode,K=o.child,ne=K.sibling,h=Za(K,{mode:"hidden",children:h.children}),h.subtreeFlags=K.subtreeFlags&31457280,ne!==null?y=Za(ne,y):(y=Ho(y,$,d,null),y.flags|=2),y.return=s,h.return=s,h.sibling=y,s.child=h,h=y,y=s.child,$=o.child.memoizedState,$===null?$=Kp(d):(K=$.cachePool,K!==null?(ne=Zt._currentValue,K=K.parent!==ne?{parent:ne,pool:ne}:K):K=xT(),$={baseLanes:$.baseLanes|d,cachePool:K}),y.memoizedState=$,y.childLanes=Xp(o,F,d),s.memoizedState=Yp,h):(Ua(s),d=o.child,o=d.sibling,d=Za(d,{mode:"visible",children:h.children}),d.return=s,d.sibling=null,o!==null&&(F=s.deletions,F===null?(s.deletions=[o],s.flags|=16):F.push(o)),s.child=d,s.memoizedState=null,d)}function Zp(o,s){return s=Qp({mode:"visible",children:s},o.mode),s.return=o,o.child=s}function Qp(o,s){return Y_(o,s,0,null)}function Jp(o,s,d){return Lo(s,o.child,null,d),o=Zp(s,s.pendingProps.children),o.flags|=2,s.memoizedState=null,o}function x_(o,s,d){o.lanes|=s;var h=o.alternate;h!==null&&(h.lanes|=s),rg(o.return,s,d)}function eg(o,s,d,h,y){var E=o.memoizedState;E===null?o.memoizedState={isBackwards:s,rendering:null,renderingStartTime:0,last:h,tail:d,tailMode:y}:(E.isBackwards=s,E.rendering=null,E.renderingStartTime=0,E.last=h,E.tail=d,E.tailMode=y)}function k_(o,s,d){var h=s.pendingProps,y=h.revealOrder,E=h.tail;if(cn(o,s,h.children,d),h=Xt.current,h&2)h=h&1|2,s.flags|=128;else{if(o!==null&&o.flags&128)e:for(o=s.child;o!==null;){if(o.tag===13)o.memoizedState!==null&&x_(o,d,s);else if(o.tag===19)x_(o,d,s);else if(o.child!==null){o.child.return=o,o=o.child;continue}if(o===s)break e;for(;o.sibling===null;){if(o.return===null||o.return===s)break e;o=o.return}o.sibling.return=o.return,o=o.sibling}h&=1}switch(ae(Xt,h),y){case"forwards":for(d=s.child,y=null;d!==null;)o=d.alternate,o!==null&&Xu(o)===null&&(y=d),d=d.sibling;d=y,d===null?(y=s.child,s.child=null):(y=d.sibling,d.sibling=null),eg(s,!1,y,d,E);break;case"backwards":for(d=null,y=s.child,s.child=null;y!==null;){if(o=y.alternate,o!==null&&Xu(o)===null){s.child=y;break}o=y.sibling,y.sibling=d,d=y,y=o}eg(s,!0,d,null,E);break;case"together":eg(s,!1,null,null,void 0);break;default:s.memoizedState=null}return s.child}function ca(o,s,d){if(o!==null&&(s.dependencies=o.dependencies),Qa|=s.lanes,!(d&s.childLanes))if(o!==null){if(cs(o,s,d,!1),(d&s.childLanes)===0)return null}else return null;if(o!==null&&s.child!==o.child)throw Error(r(153));if(s.child!==null){for(o=s.child,d=Za(o,o.pendingProps),s.child=d,d.return=s;o.sibling!==null;)o=o.sibling,d=d.sibling=Za(o,o.pendingProps),d.return=s;d.sibling=null}return s.child}function tg(o,s){return o.lanes&s?!0:(o=o.dependencies,!!(o!==null&&sc(o)))}function u6(o,s,d){switch(s.tag){case 3:Ee(s,s.stateNode.containerInfo),$a(s,Zt,o.memoizedState.cache),Ql();break;case 27:case 5:fe(s);break;case 4:Ee(s,s.stateNode.containerInfo);break;case 10:$a(s,s.type,s.memoizedProps.value);break;case 13:var h=s.memoizedState;if(h!==null)return h.dehydrated!==null?(Ua(s),s.flags|=128,null):d&s.child.childLanes?w_(o,s,d):(Ua(s),o=ca(o,s,d),o!==null?o.sibling:null);Ua(s);break;case 19:var y=(o.flags&128)!==0;if(h=(d&s.childLanes)!==0,h||(cs(o,s,d,!1),h=(d&s.childLanes)!==0),y){if(h)return k_(o,s,d);s.flags|=128}if(y=s.memoizedState,y!==null&&(y.rendering=null,y.tail=null,y.lastEffect=null),ae(Xt,Xt.current),h)break;return null;case 22:case 23:return s.lanes=0,b_(o,s,d);case 24:$a(s,Zt,o.memoizedState.cache)}return ca(o,s,d)}function A_(o,s,d){if(o!==null)if(o.memoizedProps!==s.pendingProps)en=!0;else{if(!tg(o,d)&&!(s.flags&128))return en=!1,u6(o,s,d);en=!!(o.flags&131072)}else en=!1,yt&&s.flags&1048576&&uT(s,qu,s.index);switch(s.lanes=0,s.tag){case 16:e:{o=s.pendingProps;var h=s.elementType,y=h._init;if(h=y(h._payload),s.type=h,typeof h=="function")hg(h)?(o=Bo(h,o),s.tag=1,s=S_(null,s,h,o,d)):(s.tag=0,s=Wp(null,s,h,o,d));else{if(h!=null){if(y=h.$$typeof,y===S){s.tag=11,s=g_(null,s,h,o,d);break e}else if(y===R){s.tag=14,s=h_(null,s,h,o,d);break e}}throw s=z(h)||h,Error(r(306,s,""))}}return s;case 0:return Wp(o,s,s.type,s.pendingProps,d);case 1:return h=s.type,y=Bo(h,s.pendingProps),S_(o,s,h,y,d);case 3:e:{if(Ee(s,s.stateNode.containerInfo),o===null)throw Error(r(387));var E=s.pendingProps;y=s.memoizedState,h=y.element,ig(o,s),ps(s,E,null,d);var F=s.memoizedState;if(E=F.cache,$a(s,Zt,E),E!==y.cache&&ag(s,[Zt],d,!0),fs(),E=F.element,y.isDehydrated)if(y={element:E,isDehydrated:!1,cache:F.cache},s.updateQueue.baseState=y,s.memoizedState=y,s.flags&256){s=E_(o,s,E,d);break e}else if(E!==h){h=ar(Error(r(424)),s),Jl(h),s=E_(o,s,E,d);break e}else for(un=kr(s.stateNode.containerInfo.firstChild),An=s,yt=!0,wr=null,Pr=!0,d=yT(s,null,E,d),s.child=d;d;)d.flags=d.flags&-3|4096,d=d.sibling;else{if(Ql(),E===h){s=ca(o,s,d);break e}cn(o,s,E,d)}s=s.child}return s;case 26:return us(o,s),o===null?(d=R1(s.type,null,s.pendingProps,null))?s.memoizedState=d:yt||(d=s.type,o=s.pendingProps,h=kc(Ie.current).createElement(d),h[hn]=s,h[On]=o,dn(h,d,o),Jt(h),s.stateNode=h):s.memoizedState=R1(s.type,o.memoizedProps,s.pendingProps,o.memoizedState),null;case 27:return fe(s),o===null&&yt&&(h=s.stateNode=A1(s.type,s.pendingProps,Ie.current),An=s,Pr=!0,un=kr(h.firstChild)),h=s.pendingProps.children,o!==null||yt?cn(o,s,h,d):s.child=Lo(s,null,h,d),us(o,s),s.child;case 5:return o===null&&yt&&((y=h=un)&&(h=B6(h,s.type,s.pendingProps,Pr),h!==null?(s.stateNode=h,An=s,un=kr(h.firstChild),Pr=!1,y=!0):y=!1),y||Io(s)),fe(s),y=s.type,E=s.pendingProps,F=o!==null?o.memoizedProps:null,h=E.children,jg(y,E)?h=null:F!==null&&jg(y,F)&&(s.flags|=32),s.memoizedState!==null&&(y=Cp(o,s,n6,null,null,d),Rs._currentValue=y),us(o,s),cn(o,s,h,d),s.child;case 6:return o===null&&yt&&((o=d=un)&&(d=U6(d,s.pendingProps,Pr),d!==null?(s.stateNode=d,An=s,un=null,o=!0):o=!1),o||Io(s)),null;case 13:return w_(o,s,d);case 4:return Ee(s,s.stateNode.containerInfo),h=s.pendingProps,o===null?s.child=Lo(s,null,h,d):cn(o,s,h,d),s.child;case 11:return g_(o,s,s.type,s.pendingProps,d);case 7:return cn(o,s,s.pendingProps,d),s.child;case 8:return cn(o,s,s.pendingProps.children,d),s.child;case 12:return cn(o,s,s.pendingProps.children,d),s.child;case 10:return h=s.pendingProps,$a(s,s.type,h.value),cn(o,s,h.children,d),s.child;case 9:return y=s.type._context,h=s.pendingProps.children,jo(s),y=mn(y),h=h(y),s.flags|=1,cn(o,s,h,d),s.child;case 14:return h_(o,s,s.type,s.pendingProps,d);case 15:return m_(o,s,s.type,s.pendingProps,d);case 19:return k_(o,s,d);case 22:return b_(o,s,d);case 24:return jo(s),h=mn(Zt),o===null?(y=_p(),y===null&&(y=Ot,E=Ap(),y.pooledCache=E,E.refCount++,E!==null&&(y.pooledCacheLanes|=d),y=E),s.memoizedState={parent:h,cache:y},og(s),$a(s,Zt,y)):(o.lanes&d&&(ig(o,s),ps(s,null,null,d),fs()),y=o.memoizedState,E=s.memoizedState,y.parent!==h?(y={parent:h,cache:h},s.memoizedState=y,s.lanes===0&&(s.memoizedState=s.updateQueue.baseState=y),$a(s,Zt,h)):(h=E.cache,$a(s,Zt,h),h!==y.cache&&ag(s,[Zt],d,!0))),cn(o,s,s.pendingProps.children,d),s.child;case 29:throw s.pendingProps}throw Error(r(156,s.tag))}var ng=le(null),Uo=null,da=null;function $a(o,s,d){ae(ng,s._currentValue),s._currentValue=d}function fa(o){o._currentValue=ng.current,Ae(ng)}function rg(o,s,d){for(;o!==null;){var h=o.alternate;if((o.childLanes&s)!==s?(o.childLanes|=s,h!==null&&(h.childLanes|=s)):h!==null&&(h.childLanes&s)!==s&&(h.childLanes|=s),o===d)break;o=o.return}}function ag(o,s,d,h){var y=o.child;for(y!==null&&(y.return=o);y!==null;){var E=y.dependencies;if(E!==null){var F=y.child;E=E.firstContext;e:for(;E!==null;){var $=E;E=y;for(var K=0;K<s.length;K++)if($.context===s[K]){E.lanes|=d,$=E.alternate,$!==null&&($.lanes|=d),rg(E.return,d,o),h||(F=null);break e}E=$.next}}else if(y.tag===18){if(F=y.return,F===null)throw Error(r(341));F.lanes|=d,E=F.alternate,E!==null&&(E.lanes|=d),rg(F,d,o),F=null}else F=y.child;if(F!==null)F.return=y;else for(F=y;F!==null;){if(F===o){F=null;break}if(y=F.sibling,y!==null){y.return=F.return,F=y;break}F=F.return}y=F}}function cs(o,s,d,h){o=null;for(var y=s,E=!1;y!==null;){if(!E){if(y.flags&524288)E=!0;else if(y.flags&262144)break}if(y.tag===10){var F=y.alternate;if(F===null)throw Error(r(387));if(F=F.memoizedProps,F!==null){var $=y.type;Hn(y.pendingProps.value,F.value)||(o!==null?o.push($):o=[$])}}else if(y===Ce.current){if(F=y.alternate,F===null)throw Error(r(387));F.memoizedState.memoizedState!==y.memoizedState.memoizedState&&(o!==null?o.push(Rs):o=[Rs])}y=y.return}o!==null&&ag(s,o,d,h),s.flags|=262144}function sc(o){for(o=o.firstContext;o!==null;){if(!Hn(o.context._currentValue,o.memoizedValue))return!0;o=o.next}return!1}function jo(o){Uo=o,da=null,o=o.dependencies,o!==null&&(o.firstContext=null)}function mn(o){return T_(Uo,o)}function uc(o,s){return Uo===null&&jo(o),T_(o,s)}function T_(o,s){var d=s._currentValue;if(s={context:s,memoizedValue:d,next:null},da===null){if(o===null)throw Error(r(308));da=s,o.dependencies={lanes:0,firstContext:s},o.flags|=524288}else da=da.next=s;return d}var qa=!1;function og(o){o.updateQueue={baseState:o.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function ig(o,s){o=o.updateQueue,s.updateQueue===o&&(s.updateQueue={baseState:o.baseState,firstBaseUpdate:o.firstBaseUpdate,lastBaseUpdate:o.lastBaseUpdate,shared:o.shared,callbacks:null})}function Va(o){return{lane:o,tag:0,payload:null,callback:null,next:null}}function Wa(o,s,d){var h=o.updateQueue;if(h===null)return null;if(h=h.shared,zt&2){var y=h.pending;return y===null?s.next=s:(s.next=y.next,y.next=s),h.pending=s,s=Hu(o),lT(o,null,d),s}return Gu(o,h,s,d),Hu(o)}function ds(o,s,d){if(s=s.updateQueue,s!==null&&(s=s.shared,(d&4194176)!==0)){var h=s.lanes;h&=o.pendingLanes,d|=h,s.lanes=d,Sr(o,d)}}function lg(o,s){var d=o.updateQueue,h=o.alternate;if(h!==null&&(h=h.updateQueue,d===h)){var y=null,E=null;if(d=d.firstBaseUpdate,d!==null){do{var F={lane:d.lane,tag:d.tag,payload:d.payload,callback:null,next:null};E===null?y=E=F:E=E.next=F,d=d.next}while(d!==null);E===null?y=E=s:E=E.next=s}else y=E=s;d={baseState:h.baseState,firstBaseUpdate:y,lastBaseUpdate:E,shared:h.shared,callbacks:h.callbacks},o.updateQueue=d;return}o=d.lastBaseUpdate,o===null?d.firstBaseUpdate=s:o.next=s,d.lastBaseUpdate=s}var sg=!1;function fs(){if(sg){var o=Oi;if(o!==null)throw o}}function ps(o,s,d,h){sg=!1;var y=o.updateQueue;qa=!1;var E=y.firstBaseUpdate,F=y.lastBaseUpdate,$=y.shared.pending;if($!==null){y.shared.pending=null;var K=$,ne=K.next;K.next=null,F===null?E=ne:F.next=ne,F=K;var be=o.alternate;be!==null&&(be=be.updateQueue,$=be.lastBaseUpdate,$!==F&&($===null?be.firstBaseUpdate=ne:$.next=ne,be.lastBaseUpdate=K))}if(E!==null){var Te=y.baseState;F=0,be=ne=K=null,$=E;do{var de=$.lane&-536870913,ge=de!==$.lane;if(ge?(ht&de)===de:(h&de)===de){de!==0&&de===Ni&&(sg=!0),be!==null&&(be=be.next={lane:0,tag:$.tag,payload:$.payload,callback:null,next:null});e:{var He=o,et=$;de=s;var Gt=d;switch(et.tag){case 1:if(He=et.payload,typeof He=="function"){Te=He.call(Gt,Te,de);break e}Te=He;break e;case 3:He.flags=He.flags&-65537|128;case 0:if(He=et.payload,de=typeof He=="function"?He.call(Gt,Te,de):He,de==null)break e;Te=M({},Te,de);break e;case 2:qa=!0}}de=$.callback,de!==null&&(o.flags|=64,ge&&(o.flags|=8192),ge=y.callbacks,ge===null?y.callbacks=[de]:ge.push(de))}else ge={lane:de,tag:$.tag,payload:$.payload,callback:$.callback,next:null},be===null?(ne=be=ge,K=Te):be=be.next=ge,F|=de;if($=$.next,$===null){if($=y.shared.pending,$===null)break;ge=$,$=ge.next,ge.next=null,y.lastBaseUpdate=ge,y.shared.pending=null}}while(!0);be===null&&(K=Te),y.baseState=K,y.firstBaseUpdate=ne,y.lastBaseUpdate=be,E===null&&(y.shared.lanes=0),Qa|=F,o.lanes=F,o.memoizedState=Te}}function __(o,s){if(typeof o!="function")throw Error(r(191,o));o.call(s)}function R_(o,s){var d=o.callbacks;if(d!==null)for(o.callbacks=null,o=0;o<d.length;o++)__(d[o],s)}function gs(o,s){try{var d=s.updateQueue,h=d!==null?d.lastEffect:null;if(h!==null){var y=h.next;d=y;do{if((d.tag&o)===o){h=void 0;var E=d.create,F=d.inst;h=E(),F.destroy=h}d=d.next}while(d!==y)}}catch($){Rt(s,s.return,$)}}function Ya(o,s,d){try{var h=s.updateQueue,y=h!==null?h.lastEffect:null;if(y!==null){var E=y.next;h=E;do{if((h.tag&o)===o){var F=h.inst,$=F.destroy;if($!==void 0){F.destroy=void 0,y=s;var K=d;try{$()}catch(ne){Rt(y,K,ne)}}}h=h.next}while(h!==E)}}catch(ne){Rt(s,s.return,ne)}}function C_(o){var s=o.updateQueue;if(s!==null){var d=o.stateNode;try{R_(s,d)}catch(h){Rt(o,o.return,h)}}}function N_(o,s,d){d.props=Bo(o.type,o.memoizedProps),d.state=o.memoizedState;try{d.componentWillUnmount()}catch(h){Rt(o,s,h)}}function Go(o,s){try{var d=o.ref;if(d!==null){var h=o.stateNode;switch(o.tag){case 26:case 27:case 5:var y=h;break;default:y=h}typeof d=="function"?o.refCleanup=d(y):d.current=y}}catch(E){Rt(o,s,E)}}function $n(o,s){var d=o.ref,h=o.refCleanup;if(d!==null)if(typeof h=="function")try{h()}catch(y){Rt(o,s,y)}finally{o.refCleanup=null,o=o.alternate,o!=null&&(o.refCleanup=null)}else if(typeof d=="function")try{d(null)}catch(y){Rt(o,s,y)}else d.current=null}function O_(o){var s=o.type,d=o.memoizedProps,h=o.stateNode;try{e:switch(s){case"button":case"input":case"select":case"textarea":d.autoFocus&&h.focus();break e;case"img":d.src?h.src=d.src:d.srcSet&&(h.srcset=d.srcSet)}}catch(y){Rt(o,o.return,y)}}function D_(o,s,d){try{var h=o.stateNode;L6(h,o.type,d,s),h[On]=s}catch(y){Rt(o,o.return,y)}}function I_(o){return o.tag===5||o.tag===3||o.tag===26||o.tag===27||o.tag===4}function ug(o){e:for(;;){for(;o.sibling===null;){if(o.return===null||I_(o.return))return null;o=o.return}for(o.sibling.return=o.return,o=o.sibling;o.tag!==5&&o.tag!==6&&o.tag!==27&&o.tag!==18;){if(o.flags&2||o.child===null||o.tag===4)continue e;o.child.return=o,o=o.child}if(!(o.flags&2))return o.stateNode}}function cg(o,s,d){var h=o.tag;if(h===5||h===6)o=o.stateNode,s?d.nodeType===8?d.parentNode.insertBefore(o,s):d.insertBefore(o,s):(d.nodeType===8?(s=d.parentNode,s.insertBefore(o,d)):(s=d,s.appendChild(o)),d=d._reactRootContainer,d!=null||s.onclick!==null||(s.onclick=xc));else if(h!==4&&h!==27&&(o=o.child,o!==null))for(cg(o,s,d),o=o.sibling;o!==null;)cg(o,s,d),o=o.sibling}function cc(o,s,d){var h=o.tag;if(h===5||h===6)o=o.stateNode,s?d.insertBefore(o,s):d.appendChild(o);else if(h!==4&&h!==27&&(o=o.child,o!==null))for(cc(o,s,d),o=o.sibling;o!==null;)cc(o,s,d),o=o.sibling}var pa=!1,Ut=!1,dg=!1,L_=typeof WeakSet=="function"?WeakSet:Set,tn=null,M_=!1;function c6(o,s){if(o=o.containerInfo,Bg=Nc,o=QA(o),pp(o)){if("selectionStart"in o)var d={start:o.selectionStart,end:o.selectionEnd};else e:{d=(d=o.ownerDocument)&&d.defaultView||window;var h=d.getSelection&&d.getSelection();if(h&&h.rangeCount!==0){d=h.anchorNode;var y=h.anchorOffset,E=h.focusNode;h=h.focusOffset;try{d.nodeType,E.nodeType}catch{d=null;break e}var F=0,$=-1,K=-1,ne=0,be=0,Te=o,de=null;t:for(;;){for(var ge;Te!==d||y!==0&&Te.nodeType!==3||($=F+y),Te!==E||h!==0&&Te.nodeType!==3||(K=F+h),Te.nodeType===3&&(F+=Te.nodeValue.length),(ge=Te.firstChild)!==null;)de=Te,Te=ge;for(;;){if(Te===o)break t;if(de===d&&++ne===y&&($=F),de===E&&++be===h&&(K=F),(ge=Te.nextSibling)!==null)break;Te=de,de=Te.parentNode}Te=ge}d=$===-1||K===-1?null:{start:$,end:K}}else d=null}d=d||{start:0,end:0}}else d=null;for(Ug={focusedElem:o,selectionRange:d},Nc=!1,tn=s;tn!==null;)if(s=tn,o=s.child,(s.subtreeFlags&1028)!==0&&o!==null)o.return=s,tn=o;else for(;tn!==null;){switch(s=tn,E=s.alternate,o=s.flags,s.tag){case 0:break;case 11:case 15:break;case 1:if(o&1024&&E!==null){o=void 0,d=s,y=E.memoizedProps,E=E.memoizedState,h=d.stateNode;try{var He=Bo(d.type,y,d.elementType===d.type);o=h.getSnapshotBeforeUpdate(He,E),h.__reactInternalSnapshotBeforeUpdate=o}catch(et){Rt(d,d.return,et)}}break;case 3:if(o&1024){if(o=s.stateNode.containerInfo,d=o.nodeType,d===9)$g(o);else if(d===1)switch(o.nodeName){case"HEAD":case"HTML":case"BODY":$g(o);break;default:o.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if(o&1024)throw Error(r(163))}if(o=s.sibling,o!==null){o.return=s.return,tn=o;break}tn=s.return}return He=M_,M_=!1,He}function F_(o,s,d){var h=d.flags;switch(d.tag){case 0:case 11:case 15:ha(o,d),h&4&&gs(5,d);break;case 1:if(ha(o,d),h&4)if(o=d.stateNode,s===null)try{o.componentDidMount()}catch($){Rt(d,d.return,$)}else{var y=Bo(d.type,s.memoizedProps);s=s.memoizedState;try{o.componentDidUpdate(y,s,o.__reactInternalSnapshotBeforeUpdate)}catch($){Rt(d,d.return,$)}}h&64&&C_(d),h&512&&Go(d,d.return);break;case 3:if(ha(o,d),h&64&&(h=d.updateQueue,h!==null)){if(o=null,d.child!==null)switch(d.child.tag){case 27:case 5:o=d.child.stateNode;break;case 1:o=d.child.stateNode}try{R_(h,o)}catch($){Rt(d,d.return,$)}}break;case 26:ha(o,d),h&512&&Go(d,d.return);break;case 27:case 5:ha(o,d),s===null&&h&4&&O_(d),h&512&&Go(d,d.return);break;case 12:ha(o,d);break;case 13:ha(o,d),h&4&&B_(o,d);break;case 22:if(y=d.memoizedState!==null||pa,!y){s=s!==null&&s.memoizedState!==null||Ut;var E=pa,F=Ut;pa=y,(Ut=s)&&!F?Ka(o,d,(d.subtreeFlags&8772)!==0):ha(o,d),pa=E,Ut=F}h&512&&(d.memoizedProps.mode==="manual"?Go(d,d.return):$n(d,d.return));break;default:ha(o,d)}}function z_(o){var s=o.alternate;s!==null&&(o.alternate=null,z_(s)),o.child=null,o.deletions=null,o.sibling=null,o.tag===5&&(s=o.stateNode,s!==null&&Zf(s)),o.stateNode=null,o.return=null,o.dependencies=null,o.memoizedProps=null,o.memoizedState=null,o.pendingProps=null,o.stateNode=null,o.updateQueue=null}var Wt=null,qn=!1;function ga(o,s,d){for(d=d.child;d!==null;)P_(o,s,d),d=d.sibling}function P_(o,s,d){if(Je&&typeof Je.onCommitFiberUnmount=="function")try{Je.onCommitFiberUnmount(pt,d)}catch{}switch(d.tag){case 26:Ut||$n(d,s),ga(o,s,d),d.memoizedState?d.memoizedState.count--:d.stateNode&&(d=d.stateNode,d.parentNode.removeChild(d));break;case 27:Ut||$n(d,s);var h=Wt,y=qn;for(Wt=d.stateNode,ga(o,s,d),d=d.stateNode,s=d.attributes;s.length;)d.removeAttributeNode(s[0]);Zf(d),Wt=h,qn=y;break;case 5:Ut||$n(d,s);case 6:y=Wt;var E=qn;if(Wt=null,ga(o,s,d),Wt=y,qn=E,Wt!==null)if(qn)try{o=Wt,h=d.stateNode,o.nodeType===8?o.parentNode.removeChild(h):o.removeChild(h)}catch(F){Rt(d,s,F)}else try{Wt.removeChild(d.stateNode)}catch(F){Rt(d,s,F)}break;case 18:Wt!==null&&(qn?(s=Wt,d=d.stateNode,s.nodeType===8?Hg(s.parentNode,d):s.nodeType===1&&Hg(s,d),Ds(s)):Hg(Wt,d.stateNode));break;case 4:h=Wt,y=qn,Wt=d.stateNode.containerInfo,qn=!0,ga(o,s,d),Wt=h,qn=y;break;case 0:case 11:case 14:case 15:Ut||Ya(2,d,s),Ut||Ya(4,d,s),ga(o,s,d);break;case 1:Ut||($n(d,s),h=d.stateNode,typeof h.componentWillUnmount=="function"&&N_(d,s,h)),ga(o,s,d);break;case 21:ga(o,s,d);break;case 22:Ut||$n(d,s),Ut=(h=Ut)||d.memoizedState!==null,ga(o,s,d),Ut=h;break;default:ga(o,s,d)}}function B_(o,s){if(s.memoizedState===null&&(o=s.alternate,o!==null&&(o=o.memoizedState,o!==null&&(o=o.dehydrated,o!==null))))try{Ds(o)}catch(d){Rt(s,s.return,d)}}function d6(o){switch(o.tag){case 13:case 19:var s=o.stateNode;return s===null&&(s=o.stateNode=new L_),s;case 22:return o=o.stateNode,s=o._retryCache,s===null&&(s=o._retryCache=new L_),s;default:throw Error(r(435,o.tag))}}function fg(o,s){var d=d6(o);s.forEach(function(h){var y=k6.bind(null,o,h);d.has(h)||(d.add(h),h.then(y,y))})}function sr(o,s){var d=s.deletions;if(d!==null)for(var h=0;h<d.length;h++){var y=d[h],E=o,F=s,$=F;e:for(;$!==null;){switch($.tag){case 27:case 5:Wt=$.stateNode,qn=!1;break e;case 3:Wt=$.stateNode.containerInfo,qn=!0;break e;case 4:Wt=$.stateNode.containerInfo,qn=!0;break e}$=$.return}if(Wt===null)throw Error(r(160));P_(E,F,y),Wt=null,qn=!1,E=y.alternate,E!==null&&(E.return=null),y.return=null}if(s.subtreeFlags&13878)for(s=s.child;s!==null;)U_(s,o),s=s.sibling}var xr=null;function U_(o,s){var d=o.alternate,h=o.flags;switch(o.tag){case 0:case 11:case 14:case 15:sr(s,o),ur(o),h&4&&(Ya(3,o,o.return),gs(3,o),Ya(5,o,o.return));break;case 1:sr(s,o),ur(o),h&512&&(Ut||d===null||$n(d,d.return)),h&64&&pa&&(o=o.updateQueue,o!==null&&(h=o.callbacks,h!==null&&(d=o.shared.hiddenCallbacks,o.shared.hiddenCallbacks=d===null?h:d.concat(h))));break;case 26:var y=xr;if(sr(s,o),ur(o),h&512&&(Ut||d===null||$n(d,d.return)),h&4){var E=d!==null?d.memoizedState:null;if(h=o.memoizedState,d===null)if(h===null)if(o.stateNode===null){e:{h=o.type,d=o.memoizedProps,y=y.ownerDocument||y;t:switch(h){case"title":E=y.getElementsByTagName("title")[0],(!E||E[Ul]||E[hn]||E.namespaceURI==="http://www.w3.org/2000/svg"||E.hasAttribute("itemprop"))&&(E=y.createElement(h),y.head.insertBefore(E,y.querySelector("head > title"))),dn(E,h,d),E[hn]=o,Jt(E),h=E;break e;case"link":var F=O1("link","href",y).get(h+(d.href||""));if(F){for(var $=0;$<F.length;$++)if(E=F[$],E.getAttribute("href")===(d.href==null?null:d.href)&&E.getAttribute("rel")===(d.rel==null?null:d.rel)&&E.getAttribute("title")===(d.title==null?null:d.title)&&E.getAttribute("crossorigin")===(d.crossOrigin==null?null:d.crossOrigin)){F.splice($,1);break t}}E=y.createElement(h),dn(E,h,d),y.head.appendChild(E);break;case"meta":if(F=O1("meta","content",y).get(h+(d.content||""))){for($=0;$<F.length;$++)if(E=F[$],E.getAttribute("content")===(d.content==null?null:""+d.content)&&E.getAttribute("name")===(d.name==null?null:d.name)&&E.getAttribute("property")===(d.property==null?null:d.property)&&E.getAttribute("http-equiv")===(d.httpEquiv==null?null:d.httpEquiv)&&E.getAttribute("charset")===(d.charSet==null?null:d.charSet)){F.splice($,1);break t}}E=y.createElement(h),dn(E,h,d),y.head.appendChild(E);break;default:throw Error(r(468,h))}E[hn]=o,Jt(E),h=E}o.stateNode=h}else D1(y,o.type,o.stateNode);else o.stateNode=N1(y,h,o.memoizedProps);else E!==h?(E===null?d.stateNode!==null&&(d=d.stateNode,d.parentNode.removeChild(d)):E.count--,h===null?D1(y,o.type,o.stateNode):N1(y,h,o.memoizedProps)):h===null&&o.stateNode!==null&&D_(o,o.memoizedProps,d.memoizedProps)}break;case 27:if(h&4&&o.alternate===null){y=o.stateNode,E=o.memoizedProps;try{for(var K=y.firstChild;K;){var ne=K.nextSibling,be=K.nodeName;K[Ul]||be==="HEAD"||be==="BODY"||be==="SCRIPT"||be==="STYLE"||be==="LINK"&&K.rel.toLowerCase()==="stylesheet"||y.removeChild(K),K=ne}for(var Te=o.type,de=y.attributes;de.length;)y.removeAttributeNode(de[0]);dn(y,Te,E),y[hn]=o,y[On]=E}catch(He){Rt(o,o.return,He)}}case 5:if(sr(s,o),ur(o),h&512&&(Ut||d===null||$n(d,d.return)),o.flags&32){y=o.stateNode;try{yi(y,"")}catch(He){Rt(o,o.return,He)}}h&4&&o.stateNode!=null&&(y=o.memoizedProps,D_(o,y,d!==null?d.memoizedProps:y)),h&1024&&(dg=!0);break;case 6:if(sr(s,o),ur(o),h&4){if(o.stateNode===null)throw Error(r(162));h=o.memoizedProps,d=o.stateNode;try{d.nodeValue=h}catch(He){Rt(o,o.return,He)}}break;case 3:if(_c=null,y=xr,xr=Ac(s.containerInfo),sr(s,o),xr=y,ur(o),h&4&&d!==null&&d.memoizedState.isDehydrated)try{Ds(s.containerInfo)}catch(He){Rt(o,o.return,He)}dg&&(dg=!1,j_(o));break;case 4:h=xr,xr=Ac(o.stateNode.containerInfo),sr(s,o),ur(o),xr=h;break;case 12:sr(s,o),ur(o);break;case 13:sr(s,o),ur(o),o.child.flags&8192&&o.memoizedState!==null!=(d!==null&&d.memoizedState!==null)&&(Eg=he()),h&4&&(h=o.updateQueue,h!==null&&(o.updateQueue=null,fg(o,h)));break;case 22:if(h&512&&(Ut||d===null||$n(d,d.return)),K=o.memoizedState!==null,ne=d!==null&&d.memoizedState!==null,be=pa,Te=Ut,pa=be||K,Ut=Te||ne,sr(s,o),Ut=Te,pa=be,ur(o),s=o.stateNode,s._current=o,s._visibility&=-3,s._visibility|=s._pendingVisibility&2,h&8192&&(s._visibility=K?s._visibility&-2:s._visibility|1,K&&(s=pa||Ut,d===null||ne||s||Mi(o)),o.memoizedProps===null||o.memoizedProps.mode!=="manual"))e:for(d=null,s=o;;){if(s.tag===5||s.tag===26||s.tag===27){if(d===null){ne=d=s;try{if(y=ne.stateNode,K)E=y.style,typeof E.setProperty=="function"?E.setProperty("display","none","important"):E.display="none";else{F=ne.stateNode,$=ne.memoizedProps.style;var ge=$!=null&&$.hasOwnProperty("display")?$.display:null;F.style.display=ge==null||typeof ge=="boolean"?"":(""+ge).trim()}}catch(He){Rt(ne,ne.return,He)}}}else if(s.tag===6){if(d===null){ne=s;try{ne.stateNode.nodeValue=K?"":ne.memoizedProps}catch(He){Rt(ne,ne.return,He)}}}else if((s.tag!==22&&s.tag!==23||s.memoizedState===null||s===o)&&s.child!==null){s.child.return=s,s=s.child;continue}if(s===o)break e;for(;s.sibling===null;){if(s.return===null||s.return===o)break e;d===s&&(d=null),s=s.return}d===s&&(d=null),s.sibling.return=s.return,s=s.sibling}h&4&&(h=o.updateQueue,h!==null&&(d=h.retryQueue,d!==null&&(h.retryQueue=null,fg(o,d))));break;case 19:sr(s,o),ur(o),h&4&&(h=o.updateQueue,h!==null&&(o.updateQueue=null,fg(o,h)));break;case 21:break;default:sr(s,o),ur(o)}}function ur(o){var s=o.flags;if(s&2){try{if(o.tag!==27){e:{for(var d=o.return;d!==null;){if(I_(d)){var h=d;break e}d=d.return}throw Error(r(160))}switch(h.tag){case 27:var y=h.stateNode,E=ug(o);cc(o,E,y);break;case 5:var F=h.stateNode;h.flags&32&&(yi(F,""),h.flags&=-33);var $=ug(o);cc(o,$,F);break;case 3:case 4:var K=h.stateNode.containerInfo,ne=ug(o);cg(o,ne,K);break;default:throw Error(r(161))}}}catch(be){Rt(o,o.return,be)}o.flags&=-3}s&4096&&(o.flags&=-4097)}function j_(o){if(o.subtreeFlags&1024)for(o=o.child;o!==null;){var s=o;j_(s),s.tag===5&&s.flags&1024&&s.stateNode.reset(),o=o.sibling}}function ha(o,s){if(s.subtreeFlags&8772)for(s=s.child;s!==null;)F_(o,s.alternate,s),s=s.sibling}function Mi(o){for(o=o.child;o!==null;){var s=o;switch(s.tag){case 0:case 11:case 14:case 15:Ya(4,s,s.return),Mi(s);break;case 1:$n(s,s.return);var d=s.stateNode;typeof d.componentWillUnmount=="function"&&N_(s,s.return,d),Mi(s);break;case 26:case 27:case 5:$n(s,s.return),Mi(s);break;case 22:$n(s,s.return),s.memoizedState===null&&Mi(s);break;default:Mi(s)}o=o.sibling}}function Ka(o,s,d){for(d=d&&(s.subtreeFlags&8772)!==0,s=s.child;s!==null;){var h=s.alternate,y=o,E=s,F=E.flags;switch(E.tag){case 0:case 11:case 15:Ka(y,E,d),gs(4,E);break;case 1:if(Ka(y,E,d),h=E,y=h.stateNode,typeof y.componentDidMount=="function")try{y.componentDidMount()}catch(ne){Rt(h,h.return,ne)}if(h=E,y=h.updateQueue,y!==null){var $=h.stateNode;try{var K=y.shared.hiddenCallbacks;if(K!==null)for(y.shared.hiddenCallbacks=null,y=0;y<K.length;y++)__(K[y],$)}catch(ne){Rt(h,h.return,ne)}}d&&F&64&&C_(E),Go(E,E.return);break;case 26:case 27:case 5:Ka(y,E,d),d&&h===null&&F&4&&O_(E),Go(E,E.return);break;case 12:Ka(y,E,d);break;case 13:Ka(y,E,d),d&&F&4&&B_(y,E);break;case 22:E.memoizedState===null&&Ka(y,E,d),Go(E,E.return);break;default:Ka(y,E,d)}s=s.sibling}}function pg(o,s){var d=null;o!==null&&o.memoizedState!==null&&o.memoizedState.cachePool!==null&&(d=o.memoizedState.cachePool.pool),o=null,s.memoizedState!==null&&s.memoizedState.cachePool!==null&&(o=s.memoizedState.cachePool.pool),o!==d&&(o!=null&&o.refCount++,d!=null&&as(d))}function gg(o,s){o=null,s.alternate!==null&&(o=s.alternate.memoizedState.cache),s=s.memoizedState.cache,s!==o&&(s.refCount++,o!=null&&as(o))}function Xa(o,s,d,h){if(s.subtreeFlags&10256)for(s=s.child;s!==null;)G_(o,s,d,h),s=s.sibling}function G_(o,s,d,h){var y=s.flags;switch(s.tag){case 0:case 11:case 15:Xa(o,s,d,h),y&2048&&gs(9,s);break;case 3:Xa(o,s,d,h),y&2048&&(o=null,s.alternate!==null&&(o=s.alternate.memoizedState.cache),s=s.memoizedState.cache,s!==o&&(s.refCount++,o!=null&&as(o)));break;case 12:if(y&2048){Xa(o,s,d,h),o=s.stateNode;try{var E=s.memoizedProps,F=E.id,$=E.onPostCommit;typeof $=="function"&&$(F,s.alternate===null?"mount":"update",o.passiveEffectDuration,-0)}catch(K){Rt(s,s.return,K)}}else Xa(o,s,d,h);break;case 23:break;case 22:E=s.stateNode,s.memoizedState!==null?E._visibility&4?Xa(o,s,d,h):hs(o,s):E._visibility&4?Xa(o,s,d,h):(E._visibility|=4,Fi(o,s,d,h,(s.subtreeFlags&10256)!==0)),y&2048&&pg(s.alternate,s);break;case 24:Xa(o,s,d,h),y&2048&&gg(s.alternate,s);break;default:Xa(o,s,d,h)}}function Fi(o,s,d,h,y){for(y=y&&(s.subtreeFlags&10256)!==0,s=s.child;s!==null;){var E=o,F=s,$=d,K=h,ne=F.flags;switch(F.tag){case 0:case 11:case 15:Fi(E,F,$,K,y),gs(8,F);break;case 23:break;case 22:var be=F.stateNode;F.memoizedState!==null?be._visibility&4?Fi(E,F,$,K,y):hs(E,F):(be._visibility|=4,Fi(E,F,$,K,y)),y&&ne&2048&&pg(F.alternate,F);break;case 24:Fi(E,F,$,K,y),y&&ne&2048&&gg(F.alternate,F);break;default:Fi(E,F,$,K,y)}s=s.sibling}}function hs(o,s){if(s.subtreeFlags&10256)for(s=s.child;s!==null;){var d=o,h=s,y=h.flags;switch(h.tag){case 22:hs(d,h),y&2048&&pg(h.alternate,h);break;case 24:hs(d,h),y&2048&&gg(h.alternate,h);break;default:hs(d,h)}s=s.sibling}}var ms=8192;function zi(o){if(o.subtreeFlags&ms)for(o=o.child;o!==null;)H_(o),o=o.sibling}function H_(o){switch(o.tag){case 26:zi(o),o.flags&ms&&o.memoizedState!==null&&J6(xr,o.memoizedState,o.memoizedProps);break;case 5:zi(o);break;case 3:case 4:var s=xr;xr=Ac(o.stateNode.containerInfo),zi(o),xr=s;break;case 22:o.memoizedState===null&&(s=o.alternate,s!==null&&s.memoizedState!==null?(s=ms,ms=16777216,zi(o),ms=s):zi(o));break;default:zi(o)}}function $_(o){var s=o.alternate;if(s!==null&&(o=s.child,o!==null)){s.child=null;do s=o.sibling,o.sibling=null,o=s;while(o!==null)}}function bs(o){var s=o.deletions;if(o.flags&16){if(s!==null)for(var d=0;d<s.length;d++){var h=s[d];tn=h,V_(h,o)}$_(o)}if(o.subtreeFlags&10256)for(o=o.child;o!==null;)q_(o),o=o.sibling}function q_(o){switch(o.tag){case 0:case 11:case 15:bs(o),o.flags&2048&&Ya(9,o,o.return);break;case 3:bs(o);break;case 12:bs(o);break;case 22:var s=o.stateNode;o.memoizedState!==null&&s._visibility&4&&(o.return===null||o.return.tag!==13)?(s._visibility&=-5,dc(o)):bs(o);break;default:bs(o)}}function dc(o){var s=o.deletions;if(o.flags&16){if(s!==null)for(var d=0;d<s.length;d++){var h=s[d];tn=h,V_(h,o)}$_(o)}for(o=o.child;o!==null;){switch(s=o,s.tag){case 0:case 11:case 15:Ya(8,s,s.return),dc(s);break;case 22:d=s.stateNode,d._visibility&4&&(d._visibility&=-5,dc(s));break;default:dc(s)}o=o.sibling}}function V_(o,s){for(;tn!==null;){var d=tn;switch(d.tag){case 0:case 11:case 15:Ya(8,d,s);break;case 23:case 22:if(d.memoizedState!==null&&d.memoizedState.cachePool!==null){var h=d.memoizedState.cachePool.pool;h!=null&&h.refCount++}break;case 24:as(d.memoizedState.cache)}if(h=d.child,h!==null)h.return=d,tn=h;else e:for(d=o;tn!==null;){h=tn;var y=h.sibling,E=h.return;if(z_(h),h===d){tn=null;break e}if(y!==null){y.return=E,tn=y;break e}tn=E}}}function f6(o,s,d,h){this.tag=o,this.key=d,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=s,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=h,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function cr(o,s,d,h){return new f6(o,s,d,h)}function hg(o){return o=o.prototype,!(!o||!o.isReactComponent)}function Za(o,s){var d=o.alternate;return d===null?(d=cr(o.tag,s,o.key,o.mode),d.elementType=o.elementType,d.type=o.type,d.stateNode=o.stateNode,d.alternate=o,o.alternate=d):(d.pendingProps=s,d.type=o.type,d.flags=0,d.subtreeFlags=0,d.deletions=null),d.flags=o.flags&31457280,d.childLanes=o.childLanes,d.lanes=o.lanes,d.child=o.child,d.memoizedProps=o.memoizedProps,d.memoizedState=o.memoizedState,d.updateQueue=o.updateQueue,s=o.dependencies,d.dependencies=s===null?null:{lanes:s.lanes,firstContext:s.firstContext},d.sibling=o.sibling,d.index=o.index,d.ref=o.ref,d.refCleanup=o.refCleanup,d}function W_(o,s){o.flags&=31457282;var d=o.alternate;return d===null?(o.childLanes=0,o.lanes=s,o.child=null,o.subtreeFlags=0,o.memoizedProps=null,o.memoizedState=null,o.updateQueue=null,o.dependencies=null,o.stateNode=null):(o.childLanes=d.childLanes,o.lanes=d.lanes,o.child=d.child,o.subtreeFlags=0,o.deletions=null,o.memoizedProps=d.memoizedProps,o.memoizedState=d.memoizedState,o.updateQueue=d.updateQueue,o.type=d.type,s=d.dependencies,o.dependencies=s===null?null:{lanes:s.lanes,firstContext:s.firstContext}),o}function fc(o,s,d,h,y,E){var F=0;if(h=o,typeof o=="function")hg(o)&&(F=1);else if(typeof o=="string")F=Z6(o,d,we.current)?26:o==="html"||o==="head"||o==="body"?27:5;else e:switch(o){case c:return Ho(d.children,y,E,s);case f:F=8,y|=24;break;case p:return o=cr(12,d,s,y|2),o.elementType=p,o.lanes=E,o;case v:return o=cr(13,d,s,y),o.elementType=v,o.lanes=E,o;case A:return o=cr(19,d,s,y),o.elementType=A,o.lanes=E,o;case T:return Y_(d,y,E,s);default:if(typeof o=="object"&&o!==null)switch(o.$$typeof){case g:case m:F=10;break e;case b:F=9;break e;case S:F=11;break e;case R:F=14;break e;case x:F=16,h=null;break e}F=29,d=Error(r(130,o===null?"null":typeof o,"")),h=null}return s=cr(F,d,s,y),s.elementType=o,s.type=h,s.lanes=E,s}function Ho(o,s,d,h){return o=cr(7,o,h,s),o.lanes=d,o}function Y_(o,s,d,h){o=cr(22,o,h,s),o.elementType=T,o.lanes=d;var y={_visibility:1,_pendingVisibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null,_current:null,detach:function(){var E=y._current;if(E===null)throw Error(r(456));if(!(y._pendingVisibility&2)){var F=Ba(E,2);F!==null&&(y._pendingVisibility|=2,Tn(F,E,2))}},attach:function(){var E=y._current;if(E===null)throw Error(r(456));if(y._pendingVisibility&2){var F=Ba(E,2);F!==null&&(y._pendingVisibility&=-3,Tn(F,E,2))}}};return o.stateNode=y,o}function mg(o,s,d){return o=cr(6,o,null,s),o.lanes=d,o}function bg(o,s,d){return s=cr(4,o.children!==null?o.children:[],o.key,s),s.lanes=d,s.stateNode={containerInfo:o.containerInfo,pendingChildren:null,implementation:o.implementation},s}function ma(o){o.flags|=4}function K_(o,s){if(s.type!=="stylesheet"||s.state.loading&4)o.flags&=-16777217;else if(o.flags|=16777216,!I1(s)){if(s=lr.current,s!==null&&((ht&4194176)===ht?Br!==null:(ht&62914560)!==ht&&!(ht&536870912)||s!==Br))throw ts=wp,fT;o.flags|=8192}}function pc(o,s){s!==null&&(o.flags|=4),o.flags&16384&&(s=o.tag!==22?Rn():536870912,o.lanes|=s,Bi|=s)}function ys(o,s){if(!yt)switch(o.tailMode){case"hidden":s=o.tail;for(var d=null;s!==null;)s.alternate!==null&&(d=s),s=s.sibling;d===null?o.tail=null:d.sibling=null;break;case"collapsed":d=o.tail;for(var h=null;d!==null;)d.alternate!==null&&(h=d),d=d.sibling;h===null?s||o.tail===null?o.tail=null:o.tail.sibling=null:h.sibling=null}}function Ft(o){var s=o.alternate!==null&&o.alternate.child===o.child,d=0,h=0;if(s)for(var y=o.child;y!==null;)d|=y.lanes|y.childLanes,h|=y.subtreeFlags&31457280,h|=y.flags&31457280,y.return=o,y=y.sibling;else for(y=o.child;y!==null;)d|=y.lanes|y.childLanes,h|=y.subtreeFlags,h|=y.flags,y.return=o,y=y.sibling;return o.subtreeFlags|=h,o.childLanes=d,s}function p6(o,s,d){var h=s.pendingProps;switch(Sp(s),s.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Ft(s),null;case 1:return Ft(s),null;case 3:return d=s.stateNode,h=null,o!==null&&(h=o.memoizedState.cache),s.memoizedState.cache!==h&&(s.flags|=2048),fa(Zt),J(),d.pendingContext&&(d.context=d.pendingContext,d.pendingContext=null),(o===null||o.child===null)&&(Zl(s)?ma(s):o===null||o.memoizedState.isDehydrated&&!(s.flags&256)||(s.flags|=1024,wr!==null&&(Ag(wr),wr=null))),Ft(s),null;case 26:return d=s.memoizedState,o===null?(ma(s),d!==null?(Ft(s),K_(s,d)):(Ft(s),s.flags&=-16777217)):d?d!==o.memoizedState?(ma(s),Ft(s),K_(s,d)):(Ft(s),s.flags&=-16777217):(o.memoizedProps!==h&&ma(s),Ft(s),s.flags&=-16777217),null;case 27:ke(s),d=Ie.current;var y=s.type;if(o!==null&&s.stateNode!=null)o.memoizedProps!==h&&ma(s);else{if(!h){if(s.stateNode===null)throw Error(r(166));return Ft(s),null}o=we.current,Zl(s)?cT(s):(o=A1(y,h,d),s.stateNode=o,ma(s))}return Ft(s),null;case 5:if(ke(s),d=s.type,o!==null&&s.stateNode!=null)o.memoizedProps!==h&&ma(s);else{if(!h){if(s.stateNode===null)throw Error(r(166));return Ft(s),null}if(o=we.current,Zl(s))cT(s);else{switch(y=kc(Ie.current),o){case 1:o=y.createElementNS("http://www.w3.org/2000/svg",d);break;case 2:o=y.createElementNS("http://www.w3.org/1998/Math/MathML",d);break;default:switch(d){case"svg":o=y.createElementNS("http://www.w3.org/2000/svg",d);break;case"math":o=y.createElementNS("http://www.w3.org/1998/Math/MathML",d);break;case"script":o=y.createElement("div"),o.innerHTML="<script><\/script>",o=o.removeChild(o.firstChild);break;case"select":o=typeof h.is=="string"?y.createElement("select",{is:h.is}):y.createElement("select"),h.multiple?o.multiple=!0:h.size&&(o.size=h.size);break;default:o=typeof h.is=="string"?y.createElement(d,{is:h.is}):y.createElement(d)}}o[hn]=s,o[On]=h;e:for(y=s.child;y!==null;){if(y.tag===5||y.tag===6)o.appendChild(y.stateNode);else if(y.tag!==4&&y.tag!==27&&y.child!==null){y.child.return=y,y=y.child;continue}if(y===s)break e;for(;y.sibling===null;){if(y.return===null||y.return===s)break e;y=y.return}y.sibling.return=y.return,y=y.sibling}s.stateNode=o;e:switch(dn(o,d,h),d){case"button":case"input":case"select":case"textarea":o=!!h.autoFocus;break e;case"img":o=!0;break e;default:o=!1}o&&ma(s)}}return Ft(s),s.flags&=-16777217,null;case 6:if(o&&s.stateNode!=null)o.memoizedProps!==h&&ma(s);else{if(typeof h!="string"&&s.stateNode===null)throw Error(r(166));if(o=Ie.current,Zl(s)){if(o=s.stateNode,d=s.memoizedProps,h=null,y=An,y!==null)switch(y.tag){case 27:case 5:h=y.memoizedProps}o[hn]=s,o=!!(o.nodeValue===d||h!==null&&h.suppressHydrationWarning===!0||v1(o.nodeValue,d)),o||Io(s)}else o=kc(o).createTextNode(h),o[hn]=s,s.stateNode=o}return Ft(s),null;case 13:if(h=s.memoizedState,o===null||o.memoizedState!==null&&o.memoizedState.dehydrated!==null){if(y=Zl(s),h!==null&&h.dehydrated!==null){if(o===null){if(!y)throw Error(r(318));if(y=s.memoizedState,y=y!==null?y.dehydrated:null,!y)throw Error(r(317));y[hn]=s}else Ql(),!(s.flags&128)&&(s.memoizedState=null),s.flags|=4;Ft(s),y=!1}else wr!==null&&(Ag(wr),wr=null),y=!0;if(!y)return s.flags&256?(sa(s),s):(sa(s),null)}if(sa(s),s.flags&128)return s.lanes=d,s;if(d=h!==null,o=o!==null&&o.memoizedState!==null,d){h=s.child,y=null,h.alternate!==null&&h.alternate.memoizedState!==null&&h.alternate.memoizedState.cachePool!==null&&(y=h.alternate.memoizedState.cachePool.pool);var E=null;h.memoizedState!==null&&h.memoizedState.cachePool!==null&&(E=h.memoizedState.cachePool.pool),E!==y&&(h.flags|=2048)}return d!==o&&d&&(s.child.flags|=8192),pc(s,s.updateQueue),Ft(s),null;case 4:return J(),o===null&&Fg(s.stateNode.containerInfo),Ft(s),null;case 10:return fa(s.type),Ft(s),null;case 19:if(Ae(Xt),y=s.memoizedState,y===null)return Ft(s),null;if(h=(s.flags&128)!==0,E=y.rendering,E===null)if(h)ys(y,!1);else{if(jt!==0||o!==null&&o.flags&128)for(o=s.child;o!==null;){if(E=Xu(o),E!==null){for(s.flags|=128,ys(y,!1),o=E.updateQueue,s.updateQueue=o,pc(s,o),s.subtreeFlags=0,o=d,d=s.child;d!==null;)W_(d,o),d=d.sibling;return ae(Xt,Xt.current&1|2),s.child}o=o.sibling}y.tail!==null&&he()>gc&&(s.flags|=128,h=!0,ys(y,!1),s.lanes=4194304)}else{if(!h)if(o=Xu(E),o!==null){if(s.flags|=128,h=!0,o=o.updateQueue,s.updateQueue=o,pc(s,o),ys(y,!0),y.tail===null&&y.tailMode==="hidden"&&!E.alternate&&!yt)return Ft(s),null}else 2*he()-y.renderingStartTime>gc&&d!==536870912&&(s.flags|=128,h=!0,ys(y,!1),s.lanes=4194304);y.isBackwards?(E.sibling=s.child,s.child=E):(o=y.last,o!==null?o.sibling=E:s.child=E,y.last=E)}return y.tail!==null?(s=y.tail,y.rendering=s,y.tail=s.sibling,y.renderingStartTime=he(),s.sibling=null,o=Xt.current,ae(Xt,h?o&1|2:o&1),s):(Ft(s),null);case 22:case 23:return sa(s),kp(),h=s.memoizedState!==null,o!==null?o.memoizedState!==null!==h&&(s.flags|=8192):h&&(s.flags|=8192),h?d&536870912&&!(s.flags&128)&&(Ft(s),s.subtreeFlags&6&&(s.flags|=8192)):Ft(s),d=s.updateQueue,d!==null&&pc(s,d.retryQueue),d=null,o!==null&&o.memoizedState!==null&&o.memoizedState.cachePool!==null&&(d=o.memoizedState.cachePool.pool),h=null,s.memoizedState!==null&&s.memoizedState.cachePool!==null&&(h=s.memoizedState.cachePool.pool),h!==d&&(s.flags|=2048),o!==null&&Ae(Mo),null;case 24:return d=null,o!==null&&(d=o.memoizedState.cache),s.memoizedState.cache!==d&&(s.flags|=2048),fa(Zt),Ft(s),null;case 25:return null}throw Error(r(156,s.tag))}function g6(o,s){switch(Sp(s),s.tag){case 1:return o=s.flags,o&65536?(s.flags=o&-65537|128,s):null;case 3:return fa(Zt),J(),o=s.flags,o&65536&&!(o&128)?(s.flags=o&-65537|128,s):null;case 26:case 27:case 5:return ke(s),null;case 13:if(sa(s),o=s.memoizedState,o!==null&&o.dehydrated!==null){if(s.alternate===null)throw Error(r(340));Ql()}return o=s.flags,o&65536?(s.flags=o&-65537|128,s):null;case 19:return Ae(Xt),null;case 4:return J(),null;case 10:return fa(s.type),null;case 22:case 23:return sa(s),kp(),o!==null&&Ae(Mo),o=s.flags,o&65536?(s.flags=o&-65537|128,s):null;case 24:return fa(Zt),null;case 25:return null;default:return null}}function X_(o,s){switch(Sp(s),s.tag){case 3:fa(Zt),J();break;case 26:case 27:case 5:ke(s);break;case 4:J();break;case 13:sa(s);break;case 19:Ae(Xt);break;case 10:fa(s.type);break;case 22:case 23:sa(s),kp(),o!==null&&Ae(Mo);break;case 24:fa(Zt)}}var h6={getCacheForType:function(o){var s=mn(Zt),d=s.data.get(o);return d===void 0&&(d=o(),s.data.set(o,d)),d}},m6=typeof WeakMap=="function"?WeakMap:Map,zt=0,Ot=null,st=null,ht=0,Dt=0,Vn=null,ba=!1,Pi=!1,yg=!1,ya=0,jt=0,Qa=0,$o=0,vg=0,dr=0,Bi=0,vs=null,jr=null,Sg=!1,Eg=0,gc=1/0,hc=null,Ja=null,mc=!1,qo=null,Ss=0,wg=0,xg=null,Es=0,kg=null;function Wn(){if(zt&2&&ht!==0)return ht&-ht;if(I.T!==null){var o=Ni;return o!==0?o:Dg()}return bA()}function Z_(){dr===0&&(dr=!(ht&536870912)||yt?_t():536870912);var o=lr.current;return o!==null&&(o.flags|=32),dr}function Tn(o,s,d){(o===Ot&&Dt===2||o.cancelPendingCommit!==null)&&(Ui(o,0),va(o,ht,dr,!1)),Cn(o,d),(!(zt&2)||o!==Ot)&&(o===Ot&&(!(zt&2)&&($o|=d),jt===4&&va(o,ht,dr,!1)),Gr(o))}function Q_(o,s,d){if(zt&6)throw Error(r(327));var h=!d&&(s&60)===0&&(s&o.expiredLanes)===0||Ke(o,s),y=h?v6(o,s):Rg(o,s,!0),E=h;do{if(y===0){Pi&&!h&&va(o,s,0,!1);break}else if(y===6)va(o,s,0,!ba);else{if(d=o.current.alternate,E&&!b6(d)){y=Rg(o,s,!1),E=!1;continue}if(y===2){if(E=s,o.errorRecoveryDisabledLanes&E)var F=0;else F=o.pendingLanes&-536870913,F=F!==0?F:F&536870912?536870912:0;if(F!==0){s=F;e:{var $=o;y=vs;var K=$.current.memoizedState.isDehydrated;if(K&&(Ui($,F).flags|=256),F=Rg($,F,!1),F!==2){if(yg&&!K){$.errorRecoveryDisabledLanes|=E,$o|=E,y=4;break e}E=jr,jr=y,E!==null&&Ag(E)}y=F}if(E=!1,y!==2)continue}}if(y===1){Ui(o,0),va(o,s,0,!0);break}e:{switch(h=o,y){case 0:case 1:throw Error(r(345));case 4:if((s&4194176)===s){va(h,s,dr,!ba);break e}break;case 2:jr=null;break;case 3:case 5:break;default:throw Error(r(329))}if(h.finishedWork=d,h.finishedLanes=s,(s&62914560)===s&&(E=Eg+300-he(),10<E)){if(va(h,s,dr,!ba),na(h,0)!==0)break e;h.timeoutHandle=w1(J_.bind(null,h,d,jr,hc,Sg,s,dr,$o,Bi,ba,2,-0,0),E);break e}J_(h,d,jr,hc,Sg,s,dr,$o,Bi,ba,0,-0,0)}}break}while(!0);Gr(o)}function Ag(o){jr===null?jr=o:jr.push.apply(jr,o)}function J_(o,s,d,h,y,E,F,$,K,ne,be,Te,de){var ge=s.subtreeFlags;if((ge&8192||(ge&16785408)===16785408)&&(_s={stylesheets:null,count:0,unsuspend:Q6},H_(s),s=eH(),s!==null)){o.cancelPendingCommit=s(i1.bind(null,o,d,h,y,F,$,K,1,Te,de)),va(o,E,F,!ne);return}i1(o,d,h,y,F,$,K,be,Te,de)}function b6(o){for(var s=o;;){var d=s.tag;if((d===0||d===11||d===15)&&s.flags&16384&&(d=s.updateQueue,d!==null&&(d=d.stores,d!==null)))for(var h=0;h<d.length;h++){var y=d[h],E=y.getSnapshot;y=y.value;try{if(!Hn(E(),y))return!1}catch{return!1}}if(d=s.child,s.subtreeFlags&16384&&d!==null)d.return=s,s=d;else{if(s===o)break;for(;s.sibling===null;){if(s.return===null||s.return===o)return!0;s=s.return}s.sibling.return=s.return,s=s.sibling}}return!0}function va(o,s,d,h){s&=~vg,s&=~$o,o.suspendedLanes|=s,o.pingedLanes&=~s,h&&(o.warmLanes|=s),h=o.expirationTimes;for(var y=s;0<y;){var E=31-bt(y),F=1<<E;h[E]=-1,y&=~F}d!==0&&Nn(o,d,s)}function bc(){return zt&6?!0:(ws(0),!1)}function Tg(){if(st!==null){if(Dt===0)var o=st.return;else o=st,da=Uo=null,Dp(o),Ri=null,ns=0,o=st;for(;o!==null;)X_(o.alternate,o),o=o.return;st=null}}function Ui(o,s){o.finishedWork=null,o.finishedLanes=0;var d=o.timeoutHandle;d!==-1&&(o.timeoutHandle=-1,F6(d)),d=o.cancelPendingCommit,d!==null&&(o.cancelPendingCommit=null,d()),Tg(),Ot=o,st=d=Za(o.current,null),ht=s,Dt=0,Vn=null,ba=!1,Pi=Ke(o,s),yg=!1,Bi=dr=vg=$o=Qa=jt=0,jr=vs=null,Sg=!1,s&8&&(s|=s&32);var h=o.entangledLanes;if(h!==0)for(o=o.entanglements,h&=s;0<h;){var y=31-bt(h),E=1<<y;s|=o[y],h&=~E}return ya=s,ju(),d}function e1(o,s){ot=null,I.H=Ur,s===es?(s=hT(),Dt=3):s===fT?(s=hT(),Dt=4):Dt=s===p_?8:s!==null&&typeof s=="object"&&typeof s.then=="function"?6:1,Vn=s,st===null&&(jt=1,lc(o,ar(s,o.current)))}function t1(){var o=I.H;return I.H=Ur,o===null?Ur:o}function n1(){var o=I.A;return I.A=h6,o}function _g(){jt=4,ba||(ht&4194176)!==ht&&lr.current!==null||(Pi=!0),!(Qa&134217727)&&!($o&134217727)||Ot===null||va(Ot,ht,dr,!1)}function Rg(o,s,d){var h=zt;zt|=2;var y=t1(),E=n1();(Ot!==o||ht!==s)&&(hc=null,Ui(o,s)),s=!1;var F=jt;e:do try{if(Dt!==0&&st!==null){var $=st,K=Vn;switch(Dt){case 8:Tg(),F=6;break e;case 3:case 2:case 6:lr.current===null&&(s=!0);var ne=Dt;if(Dt=0,Vn=null,ji(o,$,K,ne),d&&Pi){F=0;break e}break;default:ne=Dt,Dt=0,Vn=null,ji(o,$,K,ne)}}y6(),F=jt;break}catch(be){e1(o,be)}while(!0);return s&&o.shellSuspendCounter++,da=Uo=null,zt=h,I.H=y,I.A=E,st===null&&(Ot=null,ht=0,ju()),F}function y6(){for(;st!==null;)r1(st)}function v6(o,s){var d=zt;zt|=2;var h=t1(),y=n1();Ot!==o||ht!==s?(hc=null,gc=he()+500,Ui(o,s)):Pi=Ke(o,s);e:do try{if(Dt!==0&&st!==null){s=st;var E=Vn;t:switch(Dt){case 1:Dt=0,Vn=null,ji(o,s,E,1);break;case 2:if(pT(E)){Dt=0,Vn=null,a1(s);break}s=function(){Dt===2&&Ot===o&&(Dt=7),Gr(o)},E.then(s,s);break e;case 3:Dt=7;break e;case 4:Dt=5;break e;case 7:pT(E)?(Dt=0,Vn=null,a1(s)):(Dt=0,Vn=null,ji(o,s,E,7));break;case 5:var F=null;switch(st.tag){case 26:F=st.memoizedState;case 5:case 27:var $=st;if(!F||I1(F)){Dt=0,Vn=null;var K=$.sibling;if(K!==null)st=K;else{var ne=$.return;ne!==null?(st=ne,yc(ne)):st=null}break t}}Dt=0,Vn=null,ji(o,s,E,5);break;case 6:Dt=0,Vn=null,ji(o,s,E,6);break;case 8:Tg(),jt=6;break e;default:throw Error(r(462))}}S6();break}catch(be){e1(o,be)}while(!0);return da=Uo=null,I.H=h,I.A=y,zt=d,st!==null?0:(Ot=null,ht=0,ju(),jt)}function S6(){for(;st!==null&&!ze();)r1(st)}function r1(o){var s=A_(o.alternate,o,ya);o.memoizedProps=o.pendingProps,s===null?yc(o):st=s}function a1(o){var s=o,d=s.alternate;switch(s.tag){case 15:case 0:s=v_(d,s,s.pendingProps,s.type,void 0,ht);break;case 11:s=v_(d,s,s.pendingProps,s.type.render,s.ref,ht);break;case 5:Dp(s);default:X_(d,s),s=st=W_(s,ya),s=A_(d,s,ya)}o.memoizedProps=o.pendingProps,s===null?yc(o):st=s}function ji(o,s,d,h){da=Uo=null,Dp(s),Ri=null,ns=0;var y=s.return;try{if(s6(o,y,s,d,ht)){jt=1,lc(o,ar(d,o.current)),st=null;return}}catch(E){if(y!==null)throw st=y,E;jt=1,lc(o,ar(d,o.current)),st=null;return}s.flags&32768?(yt||h===1?o=!0:Pi||ht&536870912?o=!1:(ba=o=!0,(h===2||h===3||h===6)&&(h=lr.current,h!==null&&h.tag===13&&(h.flags|=16384))),o1(s,o)):yc(s)}function yc(o){var s=o;do{if(s.flags&32768){o1(s,ba);return}o=s.return;var d=p6(s.alternate,s,ya);if(d!==null){st=d;return}if(s=s.sibling,s!==null){st=s;return}st=s=o}while(s!==null);jt===0&&(jt=5)}function o1(o,s){do{var d=g6(o.alternate,o);if(d!==null){d.flags&=32767,st=d;return}if(d=o.return,d!==null&&(d.flags|=32768,d.subtreeFlags=0,d.deletions=null),!s&&(o=o.sibling,o!==null)){st=o;return}st=o=d}while(o!==null);jt=6,st=null}function i1(o,s,d,h,y,E,F,$,K,ne){var be=I.T,Te=Y.p;try{Y.p=2,I.T=null,E6(o,s,d,h,Te,y,E,F,$,K,ne)}finally{I.T=be,Y.p=Te}}function E6(o,s,d,h,y,E,F,$){do Gi();while(qo!==null);if(zt&6)throw Error(r(327));var K=o.finishedWork;if(h=o.finishedLanes,K===null)return null;if(o.finishedWork=null,o.finishedLanes=0,K===o.current)throw Error(r(177));o.callbackNode=null,o.callbackPriority=0,o.cancelPendingCommit=null;var ne=K.lanes|K.childLanes;if(ne|=bp,ra(o,h,ne,E,F,$),o===Ot&&(st=Ot=null,ht=0),!(K.subtreeFlags&10256)&&!(K.flags&10256)||mc||(mc=!0,wg=ne,xg=d,A6(Re,function(){return Gi(),null})),d=(K.flags&15990)!==0,K.subtreeFlags&15990||d?(d=I.T,I.T=null,E=Y.p,Y.p=2,F=zt,zt|=4,c6(o,K),U_(K,o),qG(Ug,o.containerInfo),Nc=!!Bg,Ug=Bg=null,o.current=K,F_(o,K.alternate,K),Pe(),zt=F,Y.p=E,I.T=d):o.current=K,mc?(mc=!1,qo=o,Ss=h):l1(o,ne),ne=o.pendingLanes,ne===0&&(Ja=null),wt(K.stateNode),Gr(o),s!==null)for(y=o.onRecoverableError,K=0;K<s.length;K++)ne=s[K],y(ne.value,{componentStack:ne.stack});return Ss&3&&Gi(),ne=o.pendingLanes,h&4194218&&ne&42?o===kg?Es++:(Es=0,kg=o):Es=0,ws(0),null}function l1(o,s){(o.pooledCacheLanes&=s)===0&&(s=o.pooledCache,s!=null&&(o.pooledCache=null,as(s)))}function Gi(){if(qo!==null){var o=qo,s=wg;wg=0;var d=mA(Ss),h=I.T,y=Y.p;try{if(Y.p=32>d?32:d,I.T=null,qo===null)var E=!1;else{d=xg,xg=null;var F=qo,$=Ss;if(qo=null,Ss=0,zt&6)throw Error(r(331));var K=zt;if(zt|=4,q_(F.current),G_(F,F.current,$,d),zt=K,ws(0,!1),Je&&typeof Je.onPostCommitFiberRoot=="function")try{Je.onPostCommitFiberRoot(pt,F)}catch{}E=!0}return E}finally{Y.p=y,I.T=h,l1(o,s)}}return!1}function s1(o,s,d){s=ar(d,s),s=Vp(o.stateNode,s,2),o=Wa(o,s,2),o!==null&&(Cn(o,2),Gr(o))}function Rt(o,s,d){if(o.tag===3)s1(o,o,d);else for(;s!==null;){if(s.tag===3){s1(s,o,d);break}else if(s.tag===1){var h=s.stateNode;if(typeof s.type.getDerivedStateFromError=="function"||typeof h.componentDidCatch=="function"&&(Ja===null||!Ja.has(h))){o=ar(d,o),d=d_(2),h=Wa(s,d,2),h!==null&&(f_(d,h,s,o),Cn(h,2),Gr(h));break}}s=s.return}}function Cg(o,s,d){var h=o.pingCache;if(h===null){h=o.pingCache=new m6;var y=new Set;h.set(s,y)}else y=h.get(s),y===void 0&&(y=new Set,h.set(s,y));y.has(d)||(yg=!0,y.add(d),o=w6.bind(null,o,s,d),s.then(o,o))}function w6(o,s,d){var h=o.pingCache;h!==null&&h.delete(s),o.pingedLanes|=o.suspendedLanes&d,o.warmLanes&=~d,Ot===o&&(ht&d)===d&&(jt===4||jt===3&&(ht&62914560)===ht&&300>he()-Eg?!(zt&2)&&Ui(o,0):vg|=d,Bi===ht&&(Bi=0)),Gr(o)}function u1(o,s){s===0&&(s=Rn()),o=Ba(o,s),o!==null&&(Cn(o,s),Gr(o))}function x6(o){var s=o.memoizedState,d=0;s!==null&&(d=s.retryLane),u1(o,d)}function k6(o,s){var d=0;switch(o.tag){case 13:var h=o.stateNode,y=o.memoizedState;y!==null&&(d=y.retryLane);break;case 19:h=o.stateNode;break;case 22:h=o.stateNode._retryCache;break;default:throw Error(r(314))}h!==null&&h.delete(s),u1(o,d)}function A6(o,s){return ve(o,s)}var vc=null,Hi=null,Ng=!1,Sc=!1,Og=!1,Vo=0;function Gr(o){o!==Hi&&o.next===null&&(Hi===null?vc=Hi=o:Hi=Hi.next=o),Sc=!0,Ng||(Ng=!0,_6(T6))}function ws(o,s){if(!Og&&Sc){Og=!0;do for(var d=!1,h=vc;h!==null;){if(o!==0){var y=h.pendingLanes;if(y===0)var E=0;else{var F=h.suspendedLanes,$=h.pingedLanes;E=(1<<31-bt(42|o)+1)-1,E&=y&~(F&~$),E=E&201326677?E&201326677|1:E?E|2:0}E!==0&&(d=!0,f1(h,E))}else E=ht,E=na(h,h===Ot?E:0),!(E&3)||Ke(h,E)||(d=!0,f1(h,E));h=h.next}while(d);Og=!1}}function T6(){Sc=Ng=!1;var o=0;Vo!==0&&(M6()&&(o=Vo),Vo=0);for(var s=he(),d=null,h=vc;h!==null;){var y=h.next,E=c1(h,s);E===0?(h.next=null,d===null?vc=y:d.next=y,y===null&&(Hi=d)):(d=h,(o!==0||E&3)&&(Sc=!0)),h=y}ws(o)}function c1(o,s){for(var d=o.suspendedLanes,h=o.pingedLanes,y=o.expirationTimes,E=o.pendingLanes&-62914561;0<E;){var F=31-bt(E),$=1<<F,K=y[F];K===-1?(!($&d)||$&h)&&(y[F]=gt($,s)):K<=s&&(o.expiredLanes|=$),E&=~$}if(s=Ot,d=ht,d=na(o,o===s?d:0),h=o.callbackNode,d===0||o===s&&Dt===2||o.cancelPendingCommit!==null)return h!==null&&h!==null&&ie(h),o.callbackNode=null,o.callbackPriority=0;if(!(d&3)||Ke(o,d)){if(s=d&-d,s===o.callbackPriority)return s;switch(h!==null&&ie(h),mA(d)){case 2:case 8:d=ce;break;case 32:d=Re;break;case 268435456:d=qe;break;default:d=Re}return h=d1.bind(null,o),d=ve(d,h),o.callbackPriority=s,o.callbackNode=d,s}return h!==null&&h!==null&&ie(h),o.callbackPriority=2,o.callbackNode=null,2}function d1(o,s){var d=o.callbackNode;if(Gi()&&o.callbackNode!==d)return null;var h=ht;return h=na(o,o===Ot?h:0),h===0?null:(Q_(o,h,s),c1(o,he()),o.callbackNode!=null&&o.callbackNode===d?d1.bind(null,o):null)}function f1(o,s){if(Gi())return null;Q_(o,s,!0)}function _6(o){z6(function(){zt&6?ve(ee,o):o()})}function Dg(){return Vo===0&&(Vo=_t()),Vo}function p1(o){return o==null||typeof o=="symbol"||typeof o=="boolean"?null:typeof o=="function"?o:Lu(""+o)}function g1(o,s){var d=s.ownerDocument.createElement("input");return d.name=s.name,d.value=s.value,o.id&&d.setAttribute("form",o.id),s.parentNode.insertBefore(d,s),o=new FormData(o),d.parentNode.removeChild(d),o}function R6(o,s,d,h,y){if(s==="submit"&&d&&d.stateNode===y){var E=p1((y[On]||null).action),F=h.submitter;F&&(s=(s=F[On]||null)?p1(s.formAction):F.getAttribute("formAction"),s!==null&&(E=s,F=null));var $=new Pu("action","action",null,h,y);o.push({event:$,listeners:[{instance:null,listener:function(){if(h.defaultPrevented){if(Vo!==0){var K=F?g1(y,F):new FormData(y);jp(d,{pending:!0,data:K,method:y.method,action:E},null,K)}}else typeof E=="function"&&($.preventDefault(),K=F?g1(y,F):new FormData(y),jp(d,{pending:!0,data:K,method:y.method,action:E},E,K))},currentTarget:y}]})}}for(var Ig=0;Ig<iT.length;Ig++){var Lg=iT[Ig],C6=Lg.toLowerCase(),N6=Lg[0].toUpperCase()+Lg.slice(1);Er(C6,"on"+N6)}Er(tT,"onAnimationEnd"),Er(nT,"onAnimationIteration"),Er(rT,"onAnimationStart"),Er("dblclick","onDoubleClick"),Er("focusin","onFocus"),Er("focusout","onBlur"),Er(WG,"onTransitionRun"),Er(YG,"onTransitionStart"),Er(KG,"onTransitionCancel"),Er(aT,"onTransitionEnd"),mi("onMouseEnter",["mouseout","mouseover"]),mi("onMouseLeave",["mouseout","mouseover"]),mi("onPointerEnter",["pointerout","pointerover"]),mi("onPointerLeave",["pointerout","pointerover"]),_o("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),_o("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),_o("onBeforeInput",["compositionend","keypress","textInput","paste"]),_o("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),_o("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),_o("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var xs="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),O6=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(xs));function h1(o,s){s=(s&4)!==0;for(var d=0;d<o.length;d++){var h=o[d],y=h.event;h=h.listeners;e:{var E=void 0;if(s)for(var F=h.length-1;0<=F;F--){var $=h[F],K=$.instance,ne=$.currentTarget;if($=$.listener,K!==E&&y.isPropagationStopped())break e;E=$,y.currentTarget=ne;try{E(y)}catch(be){ic(be)}y.currentTarget=null,E=K}else for(F=0;F<h.length;F++){if($=h[F],K=$.instance,ne=$.currentTarget,$=$.listener,K!==E&&y.isPropagationStopped())break e;E=$,y.currentTarget=ne;try{E(y)}catch(be){ic(be)}y.currentTarget=null,E=K}}}}function dt(o,s){var d=s[Xf];d===void 0&&(d=s[Xf]=new Set);var h=o+"__bubble";d.has(h)||(m1(s,o,2,!1),d.add(h))}function Mg(o,s,d){var h=0;s&&(h|=4),m1(d,o,h,s)}var Ec="_reactListening"+Math.random().toString(36).slice(2);function Fg(o){if(!o[Ec]){o[Ec]=!0,vA.forEach(function(d){d!=="selectionchange"&&(O6.has(d)||Mg(d,!1,o),Mg(d,!0,o))});var s=o.nodeType===9?o:o.ownerDocument;s===null||s[Ec]||(s[Ec]=!0,Mg("selectionchange",!1,s))}}function m1(o,s,d,h){switch(B1(s)){case 2:var y=rH;break;case 8:y=aH;break;default:y=Kg}d=y.bind(null,s,d,o),y=void 0,!ap||s!=="touchstart"&&s!=="touchmove"&&s!=="wheel"||(y=!0),h?y!==void 0?o.addEventListener(s,d,{capture:!0,passive:y}):o.addEventListener(s,d,!0):y!==void 0?o.addEventListener(s,d,{passive:y}):o.addEventListener(s,d,!1)}function zg(o,s,d,h,y){var E=h;if(!(s&1)&&!(s&2)&&h!==null)e:for(;;){if(h===null)return;var F=h.tag;if(F===3||F===4){var $=h.stateNode.containerInfo;if($===y||$.nodeType===8&&$.parentNode===y)break;if(F===4)for(F=h.return;F!==null;){var K=F.tag;if((K===3||K===4)&&(K=F.stateNode.containerInfo,K===y||K.nodeType===8&&K.parentNode===y))return;F=F.return}for(;$!==null;){if(F=To($),F===null)return;if(K=F.tag,K===5||K===6||K===26||K===27){h=E=F;continue e}$=$.parentNode}}h=h.return}OA(function(){var ne=E,be=np(d),Te=[];e:{var de=oT.get(o);if(de!==void 0){var ge=Pu,He=o;switch(o){case"keypress":if(Fu(d)===0)break e;case"keydown":case"keyup":ge=kG;break;case"focusin":He="focus",ge=sp;break;case"focusout":He="blur",ge=sp;break;case"beforeblur":case"afterblur":ge=sp;break;case"click":if(d.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":ge=LA;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":ge=fG;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":ge=_G;break;case tT:case nT:case rT:ge=hG;break;case aT:ge=CG;break;case"scroll":case"scrollend":ge=cG;break;case"wheel":ge=OG;break;case"copy":case"cut":case"paste":ge=bG;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":ge=FA;break;case"toggle":case"beforetoggle":ge=IG}var et=(s&4)!==0,Gt=!et&&(o==="scroll"||o==="scrollend"),oe=et?de!==null?de+"Capture":null:de;et=[];for(var te=ne,ue;te!==null;){var Se=te;if(ue=Se.stateNode,Se=Se.tag,Se!==5&&Se!==26&&Se!==27||ue===null||oe===null||(Se=Gl(te,oe),Se!=null&&et.push(ks(te,Se,ue))),Gt)break;te=te.return}0<et.length&&(de=new ge(de,He,null,d,be),Te.push({event:de,listeners:et}))}}if(!(s&7)){e:{if(de=o==="mouseover"||o==="pointerover",ge=o==="mouseout"||o==="pointerout",de&&d!==tp&&(He=d.relatedTarget||d.fromElement)&&(To(He)||He[pi]))break e;if((ge||de)&&(de=be.window===be?be:(de=be.ownerDocument)?de.defaultView||de.parentWindow:window,ge?(He=d.relatedTarget||d.toElement,ge=ne,He=He?To(He):null,He!==null&&(Gt=B(He),et=He.tag,He!==Gt||et!==5&&et!==27&&et!==6)&&(He=null)):(ge=null,He=ne),ge!==He)){if(et=LA,Se="onMouseLeave",oe="onMouseEnter",te="mouse",(o==="pointerout"||o==="pointerover")&&(et=FA,Se="onPointerLeave",oe="onPointerEnter",te="pointer"),Gt=ge==null?de:jl(ge),ue=He==null?de:jl(He),de=new et(Se,te+"leave",ge,d,be),de.target=Gt,de.relatedTarget=ue,Se=null,To(be)===ne&&(et=new et(oe,te+"enter",He,d,be),et.target=ue,et.relatedTarget=Gt,Se=et),Gt=Se,ge&&He)t:{for(et=ge,oe=He,te=0,ue=et;ue;ue=$i(ue))te++;for(ue=0,Se=oe;Se;Se=$i(Se))ue++;for(;0<te-ue;)et=$i(et),te--;for(;0<ue-te;)oe=$i(oe),ue--;for(;te--;){if(et===oe||oe!==null&&et===oe.alternate)break t;et=$i(et),oe=$i(oe)}et=null}else et=null;ge!==null&&b1(Te,de,ge,et,!1),He!==null&&Gt!==null&&b1(Te,Gt,He,et,!0)}}e:{if(de=ne?jl(ne):window,ge=de.nodeName&&de.nodeName.toLowerCase(),ge==="select"||ge==="input"&&de.type==="file")var Ue=$A;else if(GA(de))if(qA)Ue=HG;else{Ue=jG;var it=UG}else ge=de.nodeName,!ge||ge.toLowerCase()!=="input"||de.type!=="checkbox"&&de.type!=="radio"?ne&&ep(ne.elementType)&&(Ue=$A):Ue=GG;if(Ue&&(Ue=Ue(o,ne))){HA(Te,Ue,d,be);break e}it&&it(o,de,ne),o==="focusout"&&ne&&de.type==="number"&&ne.memoizedProps.value!=null&&Jf(de,"number",de.value)}switch(it=ne?jl(ne):window,o){case"focusin":(GA(it)||it.contentEditable==="true")&&(wi=it,gp=ne,Xl=null);break;case"focusout":Xl=gp=wi=null;break;case"mousedown":hp=!0;break;case"contextmenu":case"mouseup":case"dragend":hp=!1,JA(Te,d,be);break;case"selectionchange":if(VG)break;case"keydown":case"keyup":JA(Te,d,be)}var Ve;if(cp)e:{switch(o){case"compositionstart":var Qe="onCompositionStart";break e;case"compositionend":Qe="onCompositionEnd";break e;case"compositionupdate":Qe="onCompositionUpdate";break e}Qe=void 0}else Ei?UA(o,d)&&(Qe="onCompositionEnd"):o==="keydown"&&d.keyCode===229&&(Qe="onCompositionStart");Qe&&(zA&&d.locale!=="ko"&&(Ei||Qe!=="onCompositionStart"?Qe==="onCompositionEnd"&&Ei&&(Ve=DA()):(Pa=be,op="value"in Pa?Pa.value:Pa.textContent,Ei=!0)),it=wc(ne,Qe),0<it.length&&(Qe=new MA(Qe,o,null,d,be),Te.push({event:Qe,listeners:it}),Ve?Qe.data=Ve:(Ve=jA(d),Ve!==null&&(Qe.data=Ve)))),(Ve=MG?FG(o,d):zG(o,d))&&(Qe=wc(ne,"onBeforeInput"),0<Qe.length&&(it=new MA("onBeforeInput","beforeinput",null,d,be),Te.push({event:it,listeners:Qe}),it.data=Ve)),R6(Te,o,ne,d,be)}h1(Te,s)})}function ks(o,s,d){return{instance:o,listener:s,currentTarget:d}}function wc(o,s){for(var d=s+"Capture",h=[];o!==null;){var y=o,E=y.stateNode;y=y.tag,y!==5&&y!==26&&y!==27||E===null||(y=Gl(o,d),y!=null&&h.unshift(ks(o,y,E)),y=Gl(o,s),y!=null&&h.push(ks(o,y,E))),o=o.return}return h}function $i(o){if(o===null)return null;do o=o.return;while(o&&o.tag!==5&&o.tag!==27);return o||null}function b1(o,s,d,h,y){for(var E=s._reactName,F=[];d!==null&&d!==h;){var $=d,K=$.alternate,ne=$.stateNode;if($=$.tag,K!==null&&K===h)break;$!==5&&$!==26&&$!==27||ne===null||(K=ne,y?(ne=Gl(d,E),ne!=null&&F.unshift(ks(d,ne,K))):y||(ne=Gl(d,E),ne!=null&&F.push(ks(d,ne,K)))),d=d.return}F.length!==0&&o.push({event:s,listeners:F})}var D6=/\r\n?/g,I6=/\u0000|\uFFFD/g;function y1(o){return(typeof o=="string"?o:""+o).replace(D6,`
`).replace(I6,"")}function v1(o,s){return s=y1(s),y1(o)===s}function xc(){}function At(o,s,d,h,y,E){switch(d){case"children":typeof h=="string"?s==="body"||s==="textarea"&&h===""||yi(o,h):(typeof h=="number"||typeof h=="bigint")&&s!=="body"&&yi(o,""+h);break;case"className":Ou(o,"class",h);break;case"tabIndex":Ou(o,"tabindex",h);break;case"dir":case"role":case"viewBox":case"width":case"height":Ou(o,d,h);break;case"style":CA(o,h,E);break;case"data":if(s!=="object"){Ou(o,"data",h);break}case"src":case"href":if(h===""&&(s!=="a"||d!=="href")){o.removeAttribute(d);break}if(h==null||typeof h=="function"||typeof h=="symbol"||typeof h=="boolean"){o.removeAttribute(d);break}h=Lu(""+h),o.setAttribute(d,h);break;case"action":case"formAction":if(typeof h=="function"){o.setAttribute(d,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof E=="function"&&(d==="formAction"?(s!=="input"&&At(o,s,"name",y.name,y,null),At(o,s,"formEncType",y.formEncType,y,null),At(o,s,"formMethod",y.formMethod,y,null),At(o,s,"formTarget",y.formTarget,y,null)):(At(o,s,"encType",y.encType,y,null),At(o,s,"method",y.method,y,null),At(o,s,"target",y.target,y,null)));if(h==null||typeof h=="symbol"||typeof h=="boolean"){o.removeAttribute(d);break}h=Lu(""+h),o.setAttribute(d,h);break;case"onClick":h!=null&&(o.onclick=xc);break;case"onScroll":h!=null&&dt("scroll",o);break;case"onScrollEnd":h!=null&&dt("scrollend",o);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(d=h.__html,d!=null){if(y.children!=null)throw Error(r(60));o.innerHTML=d}}break;case"multiple":o.multiple=h&&typeof h!="function"&&typeof h!="symbol";break;case"muted":o.muted=h&&typeof h!="function"&&typeof h!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(h==null||typeof h=="function"||typeof h=="boolean"||typeof h=="symbol"){o.removeAttribute("xlink:href");break}d=Lu(""+h),o.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",d);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":h!=null&&typeof h!="function"&&typeof h!="symbol"?o.setAttribute(d,""+h):o.removeAttribute(d);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":h&&typeof h!="function"&&typeof h!="symbol"?o.setAttribute(d,""):o.removeAttribute(d);break;case"capture":case"download":h===!0?o.setAttribute(d,""):h!==!1&&h!=null&&typeof h!="function"&&typeof h!="symbol"?o.setAttribute(d,h):o.removeAttribute(d);break;case"cols":case"rows":case"size":case"span":h!=null&&typeof h!="function"&&typeof h!="symbol"&&!isNaN(h)&&1<=h?o.setAttribute(d,h):o.removeAttribute(d);break;case"rowSpan":case"start":h==null||typeof h=="function"||typeof h=="symbol"||isNaN(h)?o.removeAttribute(d):o.setAttribute(d,h);break;case"popover":dt("beforetoggle",o),dt("toggle",o),Nu(o,"popover",h);break;case"xlinkActuate":oa(o,"http://www.w3.org/1999/xlink","xlink:actuate",h);break;case"xlinkArcrole":oa(o,"http://www.w3.org/1999/xlink","xlink:arcrole",h);break;case"xlinkRole":oa(o,"http://www.w3.org/1999/xlink","xlink:role",h);break;case"xlinkShow":oa(o,"http://www.w3.org/1999/xlink","xlink:show",h);break;case"xlinkTitle":oa(o,"http://www.w3.org/1999/xlink","xlink:title",h);break;case"xlinkType":oa(o,"http://www.w3.org/1999/xlink","xlink:type",h);break;case"xmlBase":oa(o,"http://www.w3.org/XML/1998/namespace","xml:base",h);break;case"xmlLang":oa(o,"http://www.w3.org/XML/1998/namespace","xml:lang",h);break;case"xmlSpace":oa(o,"http://www.w3.org/XML/1998/namespace","xml:space",h);break;case"is":Nu(o,"is",h);break;case"innerText":case"textContent":break;default:(!(2<d.length)||d[0]!=="o"&&d[0]!=="O"||d[1]!=="n"&&d[1]!=="N")&&(d=sG.get(d)||d,Nu(o,d,h))}}function Pg(o,s,d,h,y,E){switch(d){case"style":CA(o,h,E);break;case"dangerouslySetInnerHTML":if(h!=null){if(typeof h!="object"||!("__html"in h))throw Error(r(61));if(d=h.__html,d!=null){if(y.children!=null)throw Error(r(60));o.innerHTML=d}}break;case"children":typeof h=="string"?yi(o,h):(typeof h=="number"||typeof h=="bigint")&&yi(o,""+h);break;case"onScroll":h!=null&&dt("scroll",o);break;case"onScrollEnd":h!=null&&dt("scrollend",o);break;case"onClick":h!=null&&(o.onclick=xc);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!SA.hasOwnProperty(d))e:{if(d[0]==="o"&&d[1]==="n"&&(y=d.endsWith("Capture"),s=d.slice(2,y?d.length-7:void 0),E=o[On]||null,E=E!=null?E[d]:null,typeof E=="function"&&o.removeEventListener(s,E,y),typeof h=="function")){typeof E!="function"&&E!==null&&(d in o?o[d]=null:o.hasAttribute(d)&&o.removeAttribute(d)),o.addEventListener(s,h,y);break e}d in o?o[d]=h:h===!0?o.setAttribute(d,""):Nu(o,d,h)}}}function dn(o,s,d){switch(s){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":dt("error",o),dt("load",o);var h=!1,y=!1,E;for(E in d)if(d.hasOwnProperty(E)){var F=d[E];if(F!=null)switch(E){case"src":h=!0;break;case"srcSet":y=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,s));default:At(o,s,E,F,d,null)}}y&&At(o,s,"srcSet",d.srcSet,d,null),h&&At(o,s,"src",d.src,d,null);return;case"input":dt("invalid",o);var $=E=F=y=null,K=null,ne=null;for(h in d)if(d.hasOwnProperty(h)){var be=d[h];if(be!=null)switch(h){case"name":y=be;break;case"type":F=be;break;case"checked":K=be;break;case"defaultChecked":ne=be;break;case"value":E=be;break;case"defaultValue":$=be;break;case"children":case"dangerouslySetInnerHTML":if(be!=null)throw Error(r(137,s));break;default:At(o,s,h,be,d,null)}}AA(o,E,$,K,ne,F,y,!1),Du(o);return;case"select":dt("invalid",o),h=F=E=null;for(y in d)if(d.hasOwnProperty(y)&&($=d[y],$!=null))switch(y){case"value":E=$;break;case"defaultValue":F=$;break;case"multiple":h=$;default:At(o,s,y,$,d,null)}s=E,d=F,o.multiple=!!h,s!=null?bi(o,!!h,s,!1):d!=null&&bi(o,!!h,d,!0);return;case"textarea":dt("invalid",o),E=y=h=null;for(F in d)if(d.hasOwnProperty(F)&&($=d[F],$!=null))switch(F){case"value":h=$;break;case"defaultValue":y=$;break;case"children":E=$;break;case"dangerouslySetInnerHTML":if($!=null)throw Error(r(91));break;default:At(o,s,F,$,d,null)}_A(o,h,y,E),Du(o);return;case"option":for(K in d)if(d.hasOwnProperty(K)&&(h=d[K],h!=null))switch(K){case"selected":o.selected=h&&typeof h!="function"&&typeof h!="symbol";break;default:At(o,s,K,h,d,null)}return;case"dialog":dt("cancel",o),dt("close",o);break;case"iframe":case"object":dt("load",o);break;case"video":case"audio":for(h=0;h<xs.length;h++)dt(xs[h],o);break;case"image":dt("error",o),dt("load",o);break;case"details":dt("toggle",o);break;case"embed":case"source":case"link":dt("error",o),dt("load",o);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(ne in d)if(d.hasOwnProperty(ne)&&(h=d[ne],h!=null))switch(ne){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,s));default:At(o,s,ne,h,d,null)}return;default:if(ep(s)){for(be in d)d.hasOwnProperty(be)&&(h=d[be],h!==void 0&&Pg(o,s,be,h,d,void 0));return}}for($ in d)d.hasOwnProperty($)&&(h=d[$],h!=null&&At(o,s,$,h,d,null))}function L6(o,s,d,h){switch(s){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var y=null,E=null,F=null,$=null,K=null,ne=null,be=null;for(ge in d){var Te=d[ge];if(d.hasOwnProperty(ge)&&Te!=null)switch(ge){case"checked":break;case"value":break;case"defaultValue":K=Te;default:h.hasOwnProperty(ge)||At(o,s,ge,null,h,Te)}}for(var de in h){var ge=h[de];if(Te=d[de],h.hasOwnProperty(de)&&(ge!=null||Te!=null))switch(de){case"type":E=ge;break;case"name":y=ge;break;case"checked":ne=ge;break;case"defaultChecked":be=ge;break;case"value":F=ge;break;case"defaultValue":$=ge;break;case"children":case"dangerouslySetInnerHTML":if(ge!=null)throw Error(r(137,s));break;default:ge!==Te&&At(o,s,de,ge,h,Te)}}Qf(o,F,$,K,ne,be,E,y);return;case"select":ge=F=$=de=null;for(E in d)if(K=d[E],d.hasOwnProperty(E)&&K!=null)switch(E){case"value":break;case"multiple":ge=K;default:h.hasOwnProperty(E)||At(o,s,E,null,h,K)}for(y in h)if(E=h[y],K=d[y],h.hasOwnProperty(y)&&(E!=null||K!=null))switch(y){case"value":de=E;break;case"defaultValue":$=E;break;case"multiple":F=E;default:E!==K&&At(o,s,y,E,h,K)}s=$,d=F,h=ge,de!=null?bi(o,!!d,de,!1):!!h!=!!d&&(s!=null?bi(o,!!d,s,!0):bi(o,!!d,d?[]:"",!1));return;case"textarea":ge=de=null;for($ in d)if(y=d[$],d.hasOwnProperty($)&&y!=null&&!h.hasOwnProperty($))switch($){case"value":break;case"children":break;default:At(o,s,$,null,h,y)}for(F in h)if(y=h[F],E=d[F],h.hasOwnProperty(F)&&(y!=null||E!=null))switch(F){case"value":de=y;break;case"defaultValue":ge=y;break;case"children":break;case"dangerouslySetInnerHTML":if(y!=null)throw Error(r(91));break;default:y!==E&&At(o,s,F,y,h,E)}TA(o,de,ge);return;case"option":for(var He in d)if(de=d[He],d.hasOwnProperty(He)&&de!=null&&!h.hasOwnProperty(He))switch(He){case"selected":o.selected=!1;break;default:At(o,s,He,null,h,de)}for(K in h)if(de=h[K],ge=d[K],h.hasOwnProperty(K)&&de!==ge&&(de!=null||ge!=null))switch(K){case"selected":o.selected=de&&typeof de!="function"&&typeof de!="symbol";break;default:At(o,s,K,de,h,ge)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var et in d)de=d[et],d.hasOwnProperty(et)&&de!=null&&!h.hasOwnProperty(et)&&At(o,s,et,null,h,de);for(ne in h)if(de=h[ne],ge=d[ne],h.hasOwnProperty(ne)&&de!==ge&&(de!=null||ge!=null))switch(ne){case"children":case"dangerouslySetInnerHTML":if(de!=null)throw Error(r(137,s));break;default:At(o,s,ne,de,h,ge)}return;default:if(ep(s)){for(var Gt in d)de=d[Gt],d.hasOwnProperty(Gt)&&de!==void 0&&!h.hasOwnProperty(Gt)&&Pg(o,s,Gt,void 0,h,de);for(be in h)de=h[be],ge=d[be],!h.hasOwnProperty(be)||de===ge||de===void 0&&ge===void 0||Pg(o,s,be,de,h,ge);return}}for(var oe in d)de=d[oe],d.hasOwnProperty(oe)&&de!=null&&!h.hasOwnProperty(oe)&&At(o,s,oe,null,h,de);for(Te in h)de=h[Te],ge=d[Te],!h.hasOwnProperty(Te)||de===ge||de==null&&ge==null||At(o,s,Te,de,h,ge)}var Bg=null,Ug=null;function kc(o){return o.nodeType===9?o:o.ownerDocument}function S1(o){switch(o){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function E1(o,s){if(o===0)switch(s){case"svg":return 1;case"math":return 2;default:return 0}return o===1&&s==="foreignObject"?0:o}function jg(o,s){return o==="textarea"||o==="noscript"||typeof s.children=="string"||typeof s.children=="number"||typeof s.children=="bigint"||typeof s.dangerouslySetInnerHTML=="object"&&s.dangerouslySetInnerHTML!==null&&s.dangerouslySetInnerHTML.__html!=null}var Gg=null;function M6(){var o=window.event;return o&&o.type==="popstate"?o===Gg?!1:(Gg=o,!0):(Gg=null,!1)}var w1=typeof setTimeout=="function"?setTimeout:void 0,F6=typeof clearTimeout=="function"?clearTimeout:void 0,x1=typeof Promise=="function"?Promise:void 0,z6=typeof queueMicrotask=="function"?queueMicrotask:typeof x1<"u"?function(o){return x1.resolve(null).then(o).catch(P6)}:w1;function P6(o){setTimeout(function(){throw o})}function Hg(o,s){var d=s,h=0;do{var y=d.nextSibling;if(o.removeChild(d),y&&y.nodeType===8)if(d=y.data,d==="/$"){if(h===0){o.removeChild(y),Ds(s);return}h--}else d!=="$"&&d!=="$?"&&d!=="$!"||h++;d=y}while(d);Ds(s)}function $g(o){var s=o.firstChild;for(s&&s.nodeType===10&&(s=s.nextSibling);s;){var d=s;switch(s=s.nextSibling,d.nodeName){case"HTML":case"HEAD":case"BODY":$g(d),Zf(d);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(d.rel.toLowerCase()==="stylesheet")continue}o.removeChild(d)}}function B6(o,s,d,h){for(;o.nodeType===1;){var y=d;if(o.nodeName.toLowerCase()!==s.toLowerCase()){if(!h&&(o.nodeName!=="INPUT"||o.type!=="hidden"))break}else if(h){if(!o[Ul])switch(s){case"meta":if(!o.hasAttribute("itemprop"))break;return o;case"link":if(E=o.getAttribute("rel"),E==="stylesheet"&&o.hasAttribute("data-precedence"))break;if(E!==y.rel||o.getAttribute("href")!==(y.href==null?null:y.href)||o.getAttribute("crossorigin")!==(y.crossOrigin==null?null:y.crossOrigin)||o.getAttribute("title")!==(y.title==null?null:y.title))break;return o;case"style":if(o.hasAttribute("data-precedence"))break;return o;case"script":if(E=o.getAttribute("src"),(E!==(y.src==null?null:y.src)||o.getAttribute("type")!==(y.type==null?null:y.type)||o.getAttribute("crossorigin")!==(y.crossOrigin==null?null:y.crossOrigin))&&E&&o.hasAttribute("async")&&!o.hasAttribute("itemprop"))break;return o;default:return o}}else if(s==="input"&&o.type==="hidden"){var E=y.name==null?null:""+y.name;if(y.type==="hidden"&&o.getAttribute("name")===E)return o}else return o;if(o=kr(o.nextSibling),o===null)break}return null}function U6(o,s,d){if(s==="")return null;for(;o.nodeType!==3;)if((o.nodeType!==1||o.nodeName!=="INPUT"||o.type!=="hidden")&&!d||(o=kr(o.nextSibling),o===null))return null;return o}function kr(o){for(;o!=null;o=o.nextSibling){var s=o.nodeType;if(s===1||s===3)break;if(s===8){if(s=o.data,s==="$"||s==="$!"||s==="$?"||s==="F!"||s==="F")break;if(s==="/$")return null}}return o}function k1(o){o=o.previousSibling;for(var s=0;o;){if(o.nodeType===8){var d=o.data;if(d==="$"||d==="$!"||d==="$?"){if(s===0)return o;s--}else d==="/$"&&s++}o=o.previousSibling}return null}function A1(o,s,d){switch(s=kc(d),o){case"html":if(o=s.documentElement,!o)throw Error(r(452));return o;case"head":if(o=s.head,!o)throw Error(r(453));return o;case"body":if(o=s.body,!o)throw Error(r(454));return o;default:throw Error(r(451))}}var fr=new Map,T1=new Set;function Ac(o){return typeof o.getRootNode=="function"?o.getRootNode():o.ownerDocument}var Sa=Y.d;Y.d={f:j6,r:G6,D:H6,C:$6,L:q6,m:V6,X:Y6,S:W6,M:K6};function j6(){var o=Sa.f(),s=bc();return o||s}function G6(o){var s=gi(o);s!==null&&s.tag===5&&s.type==="form"?JT(s):Sa.r(o)}var qi=typeof document>"u"?null:document;function _1(o,s,d){var h=qi;if(h&&typeof s=="string"&&s){var y=nr(s);y='link[rel="'+o+'"][href="'+y+'"]',typeof d=="string"&&(y+='[crossorigin="'+d+'"]'),T1.has(y)||(T1.add(y),o={rel:o,crossOrigin:d,href:s},h.querySelector(y)===null&&(s=h.createElement("link"),dn(s,"link",o),Jt(s),h.head.appendChild(s)))}}function H6(o){Sa.D(o),_1("dns-prefetch",o,null)}function $6(o,s){Sa.C(o,s),_1("preconnect",o,s)}function q6(o,s,d){Sa.L(o,s,d);var h=qi;if(h&&o&&s){var y='link[rel="preload"][as="'+nr(s)+'"]';s==="image"&&d&&d.imageSrcSet?(y+='[imagesrcset="'+nr(d.imageSrcSet)+'"]',typeof d.imageSizes=="string"&&(y+='[imagesizes="'+nr(d.imageSizes)+'"]')):y+='[href="'+nr(o)+'"]';var E=y;switch(s){case"style":E=Vi(o);break;case"script":E=Wi(o)}fr.has(E)||(o=M({rel:"preload",href:s==="image"&&d&&d.imageSrcSet?void 0:o,as:s},d),fr.set(E,o),h.querySelector(y)!==null||s==="style"&&h.querySelector(As(E))||s==="script"&&h.querySelector(Ts(E))||(s=h.createElement("link"),dn(s,"link",o),Jt(s),h.head.appendChild(s)))}}function V6(o,s){Sa.m(o,s);var d=qi;if(d&&o){var h=s&&typeof s.as=="string"?s.as:"script",y='link[rel="modulepreload"][as="'+nr(h)+'"][href="'+nr(o)+'"]',E=y;switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":E=Wi(o)}if(!fr.has(E)&&(o=M({rel:"modulepreload",href:o},s),fr.set(E,o),d.querySelector(y)===null)){switch(h){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(d.querySelector(Ts(E)))return}h=d.createElement("link"),dn(h,"link",o),Jt(h),d.head.appendChild(h)}}}function W6(o,s,d){Sa.S(o,s,d);var h=qi;if(h&&o){var y=hi(h).hoistableStyles,E=Vi(o);s=s||"default";var F=y.get(E);if(!F){var $={loading:0,preload:null};if(F=h.querySelector(As(E)))$.loading=5;else{o=M({rel:"stylesheet",href:o,"data-precedence":s},d),(d=fr.get(E))&&qg(o,d);var K=F=h.createElement("link");Jt(K),dn(K,"link",o),K._p=new Promise(function(ne,be){K.onload=ne,K.onerror=be}),K.addEventListener("load",function(){$.loading|=1}),K.addEventListener("error",function(){$.loading|=2}),$.loading|=4,Tc(F,s,h)}F={type:"stylesheet",instance:F,count:1,state:$},y.set(E,F)}}}function Y6(o,s){Sa.X(o,s);var d=qi;if(d&&o){var h=hi(d).hoistableScripts,y=Wi(o),E=h.get(y);E||(E=d.querySelector(Ts(y)),E||(o=M({src:o,async:!0},s),(s=fr.get(y))&&Vg(o,s),E=d.createElement("script"),Jt(E),dn(E,"link",o),d.head.appendChild(E)),E={type:"script",instance:E,count:1,state:null},h.set(y,E))}}function K6(o,s){Sa.M(o,s);var d=qi;if(d&&o){var h=hi(d).hoistableScripts,y=Wi(o),E=h.get(y);E||(E=d.querySelector(Ts(y)),E||(o=M({src:o,async:!0,type:"module"},s),(s=fr.get(y))&&Vg(o,s),E=d.createElement("script"),Jt(E),dn(E,"link",o),d.head.appendChild(E)),E={type:"script",instance:E,count:1,state:null},h.set(y,E))}}function R1(o,s,d,h){var y=(y=Ie.current)?Ac(y):null;if(!y)throw Error(r(446));switch(o){case"meta":case"title":return null;case"style":return typeof d.precedence=="string"&&typeof d.href=="string"?(s=Vi(d.href),d=hi(y).hoistableStyles,h=d.get(s),h||(h={type:"style",instance:null,count:0,state:null},d.set(s,h)),h):{type:"void",instance:null,count:0,state:null};case"link":if(d.rel==="stylesheet"&&typeof d.href=="string"&&typeof d.precedence=="string"){o=Vi(d.href);var E=hi(y).hoistableStyles,F=E.get(o);if(F||(y=y.ownerDocument||y,F={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},E.set(o,F),(E=y.querySelector(As(o)))&&!E._p&&(F.instance=E,F.state.loading=5),fr.has(o)||(d={rel:"preload",as:"style",href:d.href,crossOrigin:d.crossOrigin,integrity:d.integrity,media:d.media,hrefLang:d.hrefLang,referrerPolicy:d.referrerPolicy},fr.set(o,d),E||X6(y,o,d,F.state))),s&&h===null)throw Error(r(528,""));return F}if(s&&h!==null)throw Error(r(529,""));return null;case"script":return s=d.async,d=d.src,typeof d=="string"&&s&&typeof s!="function"&&typeof s!="symbol"?(s=Wi(d),d=hi(y).hoistableScripts,h=d.get(s),h||(h={type:"script",instance:null,count:0,state:null},d.set(s,h)),h):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,o))}}function Vi(o){return'href="'+nr(o)+'"'}function As(o){return'link[rel="stylesheet"]['+o+"]"}function C1(o){return M({},o,{"data-precedence":o.precedence,precedence:null})}function X6(o,s,d,h){o.querySelector('link[rel="preload"][as="style"]['+s+"]")?h.loading=1:(s=o.createElement("link"),h.preload=s,s.addEventListener("load",function(){return h.loading|=1}),s.addEventListener("error",function(){return h.loading|=2}),dn(s,"link",d),Jt(s),o.head.appendChild(s))}function Wi(o){return'[src="'+nr(o)+'"]'}function Ts(o){return"script[async]"+o}function N1(o,s,d){if(s.count++,s.instance===null)switch(s.type){case"style":var h=o.querySelector('style[data-href~="'+nr(d.href)+'"]');if(h)return s.instance=h,Jt(h),h;var y=M({},d,{"data-href":d.href,"data-precedence":d.precedence,href:null,precedence:null});return h=(o.ownerDocument||o).createElement("style"),Jt(h),dn(h,"style",y),Tc(h,d.precedence,o),s.instance=h;case"stylesheet":y=Vi(d.href);var E=o.querySelector(As(y));if(E)return s.state.loading|=4,s.instance=E,Jt(E),E;h=C1(d),(y=fr.get(y))&&qg(h,y),E=(o.ownerDocument||o).createElement("link"),Jt(E);var F=E;return F._p=new Promise(function($,K){F.onload=$,F.onerror=K}),dn(E,"link",h),s.state.loading|=4,Tc(E,d.precedence,o),s.instance=E;case"script":return E=Wi(d.src),(y=o.querySelector(Ts(E)))?(s.instance=y,Jt(y),y):(h=d,(y=fr.get(E))&&(h=M({},d),Vg(h,y)),o=o.ownerDocument||o,y=o.createElement("script"),Jt(y),dn(y,"link",h),o.head.appendChild(y),s.instance=y);case"void":return null;default:throw Error(r(443,s.type))}else s.type==="stylesheet"&&!(s.state.loading&4)&&(h=s.instance,s.state.loading|=4,Tc(h,d.precedence,o));return s.instance}function Tc(o,s,d){for(var h=d.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),y=h.length?h[h.length-1]:null,E=y,F=0;F<h.length;F++){var $=h[F];if($.dataset.precedence===s)E=$;else if(E!==y)break}E?E.parentNode.insertBefore(o,E.nextSibling):(s=d.nodeType===9?d.head:d,s.insertBefore(o,s.firstChild))}function qg(o,s){o.crossOrigin==null&&(o.crossOrigin=s.crossOrigin),o.referrerPolicy==null&&(o.referrerPolicy=s.referrerPolicy),o.title==null&&(o.title=s.title)}function Vg(o,s){o.crossOrigin==null&&(o.crossOrigin=s.crossOrigin),o.referrerPolicy==null&&(o.referrerPolicy=s.referrerPolicy),o.integrity==null&&(o.integrity=s.integrity)}var _c=null;function O1(o,s,d){if(_c===null){var h=new Map,y=_c=new Map;y.set(d,h)}else y=_c,h=y.get(d),h||(h=new Map,y.set(d,h));if(h.has(o))return h;for(h.set(o,null),d=d.getElementsByTagName(o),y=0;y<d.length;y++){var E=d[y];if(!(E[Ul]||E[hn]||o==="link"&&E.getAttribute("rel")==="stylesheet")&&E.namespaceURI!=="http://www.w3.org/2000/svg"){var F=E.getAttribute(s)||"";F=o+F;var $=h.get(F);$?$.push(E):h.set(F,[E])}}return h}function D1(o,s,d){o=o.ownerDocument||o,o.head.insertBefore(d,s==="title"?o.querySelector("head > title"):null)}function Z6(o,s,d){if(d===1||s.itemProp!=null)return!1;switch(o){case"meta":case"title":return!0;case"style":if(typeof s.precedence!="string"||typeof s.href!="string"||s.href==="")break;return!0;case"link":if(typeof s.rel!="string"||typeof s.href!="string"||s.href===""||s.onLoad||s.onError)break;switch(s.rel){case"stylesheet":return o=s.disabled,typeof s.precedence=="string"&&o==null;default:return!0}case"script":if(s.async&&typeof s.async!="function"&&typeof s.async!="symbol"&&!s.onLoad&&!s.onError&&s.src&&typeof s.src=="string")return!0}return!1}function I1(o){return!(o.type==="stylesheet"&&!(o.state.loading&3))}var _s=null;function Q6(){}function J6(o,s,d){if(_s===null)throw Error(r(475));var h=_s;if(s.type==="stylesheet"&&(typeof d.media!="string"||matchMedia(d.media).matches!==!1)&&!(s.state.loading&4)){if(s.instance===null){var y=Vi(d.href),E=o.querySelector(As(y));if(E){o=E._p,o!==null&&typeof o=="object"&&typeof o.then=="function"&&(h.count++,h=Rc.bind(h),o.then(h,h)),s.state.loading|=4,s.instance=E,Jt(E);return}E=o.ownerDocument||o,d=C1(d),(y=fr.get(y))&&qg(d,y),E=E.createElement("link"),Jt(E);var F=E;F._p=new Promise(function($,K){F.onload=$,F.onerror=K}),dn(E,"link",d),s.instance=E}h.stylesheets===null&&(h.stylesheets=new Map),h.stylesheets.set(s,o),(o=s.state.preload)&&!(s.state.loading&3)&&(h.count++,s=Rc.bind(h),o.addEventListener("load",s),o.addEventListener("error",s))}}function eH(){if(_s===null)throw Error(r(475));var o=_s;return o.stylesheets&&o.count===0&&Wg(o,o.stylesheets),0<o.count?function(s){var d=setTimeout(function(){if(o.stylesheets&&Wg(o,o.stylesheets),o.unsuspend){var h=o.unsuspend;o.unsuspend=null,h()}},6e4);return o.unsuspend=s,function(){o.unsuspend=null,clearTimeout(d)}}:null}function Rc(){if(this.count--,this.count===0){if(this.stylesheets)Wg(this,this.stylesheets);else if(this.unsuspend){var o=this.unsuspend;this.unsuspend=null,o()}}}var Cc=null;function Wg(o,s){o.stylesheets=null,o.unsuspend!==null&&(o.count++,Cc=new Map,s.forEach(tH,o),Cc=null,Rc.call(o))}function tH(o,s){if(!(s.state.loading&4)){var d=Cc.get(o);if(d)var h=d.get(null);else{d=new Map,Cc.set(o,d);for(var y=o.querySelectorAll("link[data-precedence],style[data-precedence]"),E=0;E<y.length;E++){var F=y[E];(F.nodeName==="LINK"||F.getAttribute("media")!=="not all")&&(d.set(F.dataset.precedence,F),h=F)}h&&d.set(null,h)}y=s.instance,F=y.getAttribute("data-precedence"),E=d.get(F)||h,E===h&&d.set(null,y),d.set(F,y),this.count++,h=Rc.bind(this),y.addEventListener("load",h),y.addEventListener("error",h),E?E.parentNode.insertBefore(y,E.nextSibling):(o=o.nodeType===9?o.head:o,o.insertBefore(y,o.firstChild)),s.state.loading|=4}}var Rs={$$typeof:m,Provider:null,Consumer:null,_currentValue:Q,_currentValue2:Q,_threadCount:0};function nH(o,s,d,h,y,E,F,$){this.tag=1,this.containerInfo=o,this.finishedWork=this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=kn(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.finishedLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=kn(0),this.hiddenUpdates=kn(null),this.identifierPrefix=h,this.onUncaughtError=y,this.onCaughtError=E,this.onRecoverableError=F,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=$,this.incompleteTransitions=new Map}function L1(o,s,d,h,y,E,F,$,K,ne,be,Te){return o=new nH(o,s,d,F,$,K,ne,Te),s=1,E===!0&&(s|=24),E=cr(3,null,null,s),o.current=E,E.stateNode=o,s=Ap(),s.refCount++,o.pooledCache=s,s.refCount++,E.memoizedState={element:h,isDehydrated:d,cache:s},og(E),o}function M1(o){return o?(o=Ai,o):Ai}function F1(o,s,d,h,y,E){y=M1(y),h.context===null?h.context=y:h.pendingContext=y,h=Va(s),h.payload={element:d},E=E===void 0?null:E,E!==null&&(h.callback=E),d=Wa(o,h,s),d!==null&&(Tn(d,o,s),ds(d,o,s))}function z1(o,s){if(o=o.memoizedState,o!==null&&o.dehydrated!==null){var d=o.retryLane;o.retryLane=d!==0&&d<s?d:s}}function Yg(o,s){z1(o,s),(o=o.alternate)&&z1(o,s)}function P1(o){if(o.tag===13){var s=Ba(o,67108864);s!==null&&Tn(s,o,67108864),Yg(o,67108864)}}var Nc=!0;function rH(o,s,d,h){var y=I.T;I.T=null;var E=Y.p;try{Y.p=2,Kg(o,s,d,h)}finally{Y.p=E,I.T=y}}function aH(o,s,d,h){var y=I.T;I.T=null;var E=Y.p;try{Y.p=8,Kg(o,s,d,h)}finally{Y.p=E,I.T=y}}function Kg(o,s,d,h){if(Nc){var y=Xg(h);if(y===null)zg(o,s,h,Oc,d),U1(o,h);else if(iH(y,o,s,d,h))h.stopPropagation();else if(U1(o,h),s&4&&-1<oH.indexOf(o)){for(;y!==null;){var E=gi(y);if(E!==null)switch(E.tag){case 3:if(E=E.stateNode,E.current.memoizedState.isDehydrated){var F=Kt(E.pendingLanes);if(F!==0){var $=E;for($.pendingLanes|=2,$.entangledLanes|=2;F;){var K=1<<31-bt(F);$.entanglements[1]|=K,F&=~K}Gr(E),!(zt&6)&&(gc=he()+500,ws(0))}}break;case 13:$=Ba(E,2),$!==null&&Tn($,E,2),bc(),Yg(E,2)}if(E=Xg(h),E===null&&zg(o,s,h,Oc,d),E===y)break;y=E}y!==null&&h.stopPropagation()}else zg(o,s,h,null,d)}}function Xg(o){return o=np(o),Zg(o)}var Oc=null;function Zg(o){if(Oc=null,o=To(o),o!==null){var s=B(o);if(s===null)o=null;else{var d=s.tag;if(d===13){if(o=X(s),o!==null)return o;o=null}else if(d===3){if(s.stateNode.current.memoizedState.isDehydrated)return s.tag===3?s.stateNode.containerInfo:null;o=null}else s!==o&&(o=null)}}return Oc=o,null}function B1(o){switch(o){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Ne()){case ee:return 2;case ce:return 8;case Re:case Fe:return 32;case qe:return 268435456;default:return 32}default:return 32}}var Qg=!1,eo=null,to=null,no=null,Cs=new Map,Ns=new Map,ro=[],oH="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function U1(o,s){switch(o){case"focusin":case"focusout":eo=null;break;case"dragenter":case"dragleave":to=null;break;case"mouseover":case"mouseout":no=null;break;case"pointerover":case"pointerout":Cs.delete(s.pointerId);break;case"gotpointercapture":case"lostpointercapture":Ns.delete(s.pointerId)}}function Os(o,s,d,h,y,E){return o===null||o.nativeEvent!==E?(o={blockedOn:s,domEventName:d,eventSystemFlags:h,nativeEvent:E,targetContainers:[y]},s!==null&&(s=gi(s),s!==null&&P1(s)),o):(o.eventSystemFlags|=h,s=o.targetContainers,y!==null&&s.indexOf(y)===-1&&s.push(y),o)}function iH(o,s,d,h,y){switch(s){case"focusin":return eo=Os(eo,o,s,d,h,y),!0;case"dragenter":return to=Os(to,o,s,d,h,y),!0;case"mouseover":return no=Os(no,o,s,d,h,y),!0;case"pointerover":var E=y.pointerId;return Cs.set(E,Os(Cs.get(E)||null,o,s,d,h,y)),!0;case"gotpointercapture":return E=y.pointerId,Ns.set(E,Os(Ns.get(E)||null,o,s,d,h,y)),!0}return!1}function j1(o){var s=To(o.target);if(s!==null){var d=B(s);if(d!==null){if(s=d.tag,s===13){if(s=X(d),s!==null){o.blockedOn=s,eG(o.priority,function(){if(d.tag===13){var h=Wn(),y=Ba(d,h);y!==null&&Tn(y,d,h),Yg(d,h)}});return}}else if(s===3&&d.stateNode.current.memoizedState.isDehydrated){o.blockedOn=d.tag===3?d.stateNode.containerInfo:null;return}}}o.blockedOn=null}function Dc(o){if(o.blockedOn!==null)return!1;for(var s=o.targetContainers;0<s.length;){var d=Xg(o.nativeEvent);if(d===null){d=o.nativeEvent;var h=new d.constructor(d.type,d);tp=h,d.target.dispatchEvent(h),tp=null}else return s=gi(d),s!==null&&P1(s),o.blockedOn=d,!1;s.shift()}return!0}function G1(o,s,d){Dc(o)&&d.delete(s)}function lH(){Qg=!1,eo!==null&&Dc(eo)&&(eo=null),to!==null&&Dc(to)&&(to=null),no!==null&&Dc(no)&&(no=null),Cs.forEach(G1),Ns.forEach(G1)}function Ic(o,s){o.blockedOn===s&&(o.blockedOn=null,Qg||(Qg=!0,e.unstable_scheduleCallback(e.unstable_NormalPriority,lH)))}var Lc=null;function H1(o){Lc!==o&&(Lc=o,e.unstable_scheduleCallback(e.unstable_NormalPriority,function(){Lc===o&&(Lc=null);for(var s=0;s<o.length;s+=3){var d=o[s],h=o[s+1],y=o[s+2];if(typeof h!="function"){if(Zg(h||d)===null)continue;break}var E=gi(d);E!==null&&(o.splice(s,3),s-=3,jp(E,{pending:!0,data:y,method:d.method,action:h},h,y))}}))}function Ds(o){function s(K){return Ic(K,o)}eo!==null&&Ic(eo,o),to!==null&&Ic(to,o),no!==null&&Ic(no,o),Cs.forEach(s),Ns.forEach(s);for(var d=0;d<ro.length;d++){var h=ro[d];h.blockedOn===o&&(h.blockedOn=null)}for(;0<ro.length&&(d=ro[0],d.blockedOn===null);)j1(d),d.blockedOn===null&&ro.shift();if(d=(o.ownerDocument||o).$$reactFormReplay,d!=null)for(h=0;h<d.length;h+=3){var y=d[h],E=d[h+1],F=y[On]||null;if(typeof E=="function")F||H1(d);else if(F){var $=null;if(E&&E.hasAttribute("formAction")){if(y=E,F=E[On]||null)$=F.formAction;else if(Zg(y)!==null)continue}else $=F.action;typeof $=="function"?d[h+1]=$:(d.splice(h,3),h-=3),H1(d)}}}function Jg(o){this._internalRoot=o}Mc.prototype.render=Jg.prototype.render=function(o){var s=this._internalRoot;if(s===null)throw Error(r(409));var d=s.current,h=Wn();F1(d,h,o,s,null,null)},Mc.prototype.unmount=Jg.prototype.unmount=function(){var o=this._internalRoot;if(o!==null){this._internalRoot=null;var s=o.containerInfo;o.tag===0&&Gi(),F1(o.current,2,null,o,null,null),bc(),s[pi]=null}};function Mc(o){this._internalRoot=o}Mc.prototype.unstable_scheduleHydration=function(o){if(o){var s=bA();o={blockedOn:null,target:o,priority:s};for(var d=0;d<ro.length&&s!==0&&s<ro[d].priority;d++);ro.splice(d,0,o),d===0&&j1(o)}};var $1=t.version;if($1!=="19.0.0")throw Error(r(527,$1,"19.0.0"));Y.findDOMNode=function(o){var s=o._reactInternals;if(s===void 0)throw typeof o.render=="function"?Error(r(188)):(o=Object.keys(o).join(","),Error(r(268,o)));return o=V(s),o=o!==null?U(o):null,o=o===null?null:o.stateNode,o};var sH={bundleType:0,version:"19.0.0",rendererPackageName:"react-dom",currentDispatcherRef:I,findFiberByHostInstance:To,reconcilerVersion:"19.0.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var Fc=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!Fc.isDisabled&&Fc.supportsFiber)try{pt=Fc.inject(sH),Je=Fc}catch{}}return Ls.createRoot=function(o,s){if(!a(o))throw Error(r(299));var d=!1,h="",y=l_,E=s_,F=u_,$=null;return s!=null&&(s.unstable_strictMode===!0&&(d=!0),s.identifierPrefix!==void 0&&(h=s.identifierPrefix),s.onUncaughtError!==void 0&&(y=s.onUncaughtError),s.onCaughtError!==void 0&&(E=s.onCaughtError),s.onRecoverableError!==void 0&&(F=s.onRecoverableError),s.unstable_transitionCallbacks!==void 0&&($=s.unstable_transitionCallbacks)),s=L1(o,1,!1,null,null,d,h,y,E,F,$,null),o[pi]=s.current,Fg(o.nodeType===8?o.parentNode:o),new Jg(s)},Ls.hydrateRoot=function(o,s,d){if(!a(o))throw Error(r(299));var h=!1,y="",E=l_,F=s_,$=u_,K=null,ne=null;return d!=null&&(d.unstable_strictMode===!0&&(h=!0),d.identifierPrefix!==void 0&&(y=d.identifierPrefix),d.onUncaughtError!==void 0&&(E=d.onUncaughtError),d.onCaughtError!==void 0&&(F=d.onCaughtError),d.onRecoverableError!==void 0&&($=d.onRecoverableError),d.unstable_transitionCallbacks!==void 0&&(K=d.unstable_transitionCallbacks),d.formState!==void 0&&(ne=d.formState)),s=L1(o,1,!0,s,d??null,h,y,E,F,$,K,ne),s.context=M1(null),d=s.current,h=Wn(),y=Va(h),y.callback=null,Wa(d,y,h),s.current.lanes=h,Cn(s,h),Gr(s),o[pi]=s.current,Fg(o),new Mc(s)},Ls.version="19.0.0",Ls}var eR;function wH(){if(eR)return nh.exports;eR=1;function e(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(e)}catch(t){console.error(t)}}return e(),nh.exports=EH(),nh.exports}var xH=wH();const tR=e=>{let t;const n=new Set,r=(f,p)=>{const g=typeof f=="function"?f(t):f;if(!Object.is(g,t)){const b=t;t=p??(typeof g!="object"||g===null)?g:Object.assign({},t,g),n.forEach(m=>m(t,b))}},a=()=>t,u={setState:r,getState:a,getInitialState:()=>c,subscribe:f=>(n.add(f),()=>n.delete(f))},c=t=e(r,a,u);return u},kH=e=>e?tR(e):tR,AH=e=>e;function TH(e,t=AH){const n=ye.useSyncExternalStore(e.subscribe,()=>t(e.getState()),()=>t(e.getInitialState()));return ye.useDebugValue(n),n}const _H=e=>{const t=kH(e),n=r=>TH(t,r);return Object.assign(n,t),n},xk=e=>_H;function bz(e,t){let n;try{n=e()}catch{return}return{getItem:a=>{var i;const l=c=>c===null?null:JSON.parse(c,void 0),u=(i=n.getItem(a))!=null?i:null;return u instanceof Promise?u.then(l):l(u)},setItem:(a,i)=>n.setItem(a,JSON.stringify(i,void 0)),removeItem:a=>n.removeItem(a)}}const fx=e=>t=>{try{const n=e(t);return n instanceof Promise?n:{then(r){return fx(r)(n)},catch(r){return this}}}catch(n){return{then(r){return this},catch(r){return fx(r)(n)}}}},RH=(e,t)=>(n,r,a)=>{let i={storage:bz(()=>localStorage),partialize:v=>v,version:0,merge:(v,A)=>({...A,...v}),...t},l=!1;const u=new Set,c=new Set;let f=i.storage;if(!f)return e((...v)=>{console.warn(`[zustand persist middleware] Unable to update item '${i.name}', the given storage is currently unavailable.`),n(...v)},r,a);const p=()=>{const v=i.partialize({...r()});return f.setItem(i.name,{state:v,version:i.version})},g=a.setState;a.setState=(v,A)=>{g(v,A),p()};const b=e((...v)=>{n(...v),p()},r,a);a.getInitialState=()=>b;let m;const S=()=>{var v,A;if(!f)return;l=!1,u.forEach(x=>{var T;return x((T=r())!=null?T:b)});const R=((A=i.onRehydrateStorage)==null?void 0:A.call(i,(v=r())!=null?v:b))||void 0;return fx(f.getItem.bind(f))(i.name).then(x=>{if(x)if(typeof x.version=="number"&&x.version!==i.version){if(i.migrate){const T=i.migrate(x.state,x.version);return T instanceof Promise?T.then(C=>[!0,C]):[!0,T]}console.error("State loaded from storage couldn't be migrated since no migrate function was provided")}else return[!1,x.state];return[!1,void 0]}).then(x=>{var T;const[C,N]=x;if(m=i.merge(N,(T=r())!=null?T:b),n(m,!0),C)return p()}).then(()=>{R==null||R(m,void 0),m=r(),l=!0,c.forEach(x=>x(m))}).catch(x=>{R==null||R(void 0,x)})};return a.persist={setOptions:v=>{i={...i,...v},v.storage&&(f=v.storage)},clearStorage:()=>{f==null||f.removeItem(i.name)},getOptions:()=>i,rehydrate:()=>S(),hasHydrated:()=>l,onHydrate:v=>(u.add(v),()=>{u.delete(v)}),onFinishHydration:v=>(c.add(v),()=>{c.delete(v)})},i.skipHydration||S(),m||b},CH=RH;function yz(e){var t,n,r="";if(typeof e=="string"||typeof e=="number")r+=e;else if(typeof e=="object")if(Array.isArray(e)){var a=e.length;for(t=0;t<a;t++)e[t]&&(n=yz(e[t]))&&(r&&(r+=" "),r+=n)}else for(n in e)e[n]&&(r&&(r+=" "),r+=n);return r}function vz(){for(var e,t,n=0,r="",a=arguments.length;n<a;n++)(e=arguments[n])&&(t=yz(e))&&(r&&(r+=" "),r+=t);return r}const kk="-",NH=e=>{const t=DH(e),{conflictingClassGroups:n,conflictingClassGroupModifiers:r}=e;return{getClassGroupId:l=>{const u=l.split(kk);return u[0]===""&&u.length!==1&&u.shift(),Sz(u,t)||OH(l)},getConflictingClassGroupIds:(l,u)=>{const c=n[l]||[];return u&&r[l]?[...c,...r[l]]:c}}},Sz=(e,t)=>{var l;if(e.length===0)return t.classGroupId;const n=e[0],r=t.nextPart.get(n),a=r?Sz(e.slice(1),r):void 0;if(a)return a;if(t.validators.length===0)return;const i=e.join(kk);return(l=t.validators.find(({validator:u})=>u(i)))==null?void 0:l.classGroupId},nR=/^\[(.+)\]$/,OH=e=>{if(nR.test(e)){const t=nR.exec(e)[1],n=t==null?void 0:t.substring(0,t.indexOf(":"));if(n)return"arbitrary.."+n}},DH=e=>{const{theme:t,classGroups:n}=e,r={nextPart:new Map,validators:[]};for(const a in n)px(n[a],r,a,t);return r},px=(e,t,n,r)=>{e.forEach(a=>{if(typeof a=="string"){const i=a===""?t:rR(t,a);i.classGroupId=n;return}if(typeof a=="function"){if(IH(a)){px(a(r),t,n,r);return}t.validators.push({validator:a,classGroupId:n});return}Object.entries(a).forEach(([i,l])=>{px(l,rR(t,i),n,r)})})},rR=(e,t)=>{let n=e;return t.split(kk).forEach(r=>{n.nextPart.has(r)||n.nextPart.set(r,{nextPart:new Map,validators:[]}),n=n.nextPart.get(r)}),n},IH=e=>e.isThemeGetter,LH=e=>{if(e<1)return{get:()=>{},set:()=>{}};let t=0,n=new Map,r=new Map;const a=(i,l)=>{n.set(i,l),t++,t>e&&(t=0,r=n,n=new Map)};return{get(i){let l=n.get(i);if(l!==void 0)return l;if((l=r.get(i))!==void 0)return a(i,l),l},set(i,l){n.has(i)?n.set(i,l):a(i,l)}}},gx="!",hx=":",MH=hx.length,FH=e=>{const{prefix:t,experimentalParseClassName:n}=e;let r=a=>{const i=[];let l=0,u=0,c=0,f;for(let S=0;S<a.length;S++){let v=a[S];if(l===0&&u===0){if(v===hx){i.push(a.slice(c,S)),c=S+MH;continue}if(v==="/"){f=S;continue}}v==="["?l++:v==="]"?l--:v==="("?u++:v===")"&&u--}const p=i.length===0?a:a.substring(c),g=zH(p),b=g!==p,m=f&&f>c?f-c:void 0;return{modifiers:i,hasImportantModifier:b,baseClassName:g,maybePostfixModifierPosition:m}};if(t){const a=t+hx,i=r;r=l=>l.startsWith(a)?i(l.substring(a.length)):{isExternal:!0,modifiers:[],hasImportantModifier:!1,baseClassName:l,maybePostfixModifierPosition:void 0}}if(n){const a=r;r=i=>n({className:i,parseClassName:a})}return r},zH=e=>e.endsWith(gx)?e.substring(0,e.length-1):e.startsWith(gx)?e.substring(1):e,PH=e=>{const t=Object.fromEntries(e.orderSensitiveModifiers.map(r=>[r,!0]));return r=>{if(r.length<=1)return r;const a=[];let i=[];return r.forEach(l=>{l[0]==="["||t[l]?(a.push(...i.sort(),l),i=[]):i.push(l)}),a.push(...i.sort()),a}},BH=e=>({cache:LH(e.cacheSize),parseClassName:FH(e),sortModifiers:PH(e),...NH(e)}),UH=/\s+/,jH=(e,t)=>{const{parseClassName:n,getClassGroupId:r,getConflictingClassGroupIds:a,sortModifiers:i}=t,l=[],u=e.trim().split(UH);let c="";for(let f=u.length-1;f>=0;f-=1){const p=u[f],{isExternal:g,modifiers:b,hasImportantModifier:m,baseClassName:S,maybePostfixModifierPosition:v}=n(p);if(g){c=p+(c.length>0?" "+c:c);continue}let A=!!v,R=r(A?S.substring(0,v):S);if(!R){if(!A){c=p+(c.length>0?" "+c:c);continue}if(R=r(S),!R){c=p+(c.length>0?" "+c:c);continue}A=!1}const x=i(b).join(":"),T=m?x+gx:x,C=T+R;if(l.includes(C))continue;l.push(C);const N=a(R,A);for(let _=0;_<N.length;++_){const O=N[_];l.push(T+O)}c=p+(c.length>0?" "+c:c)}return c};function GH(){let e=0,t,n,r="";for(;e<arguments.length;)(t=arguments[e++])&&(n=Ez(t))&&(r&&(r+=" "),r+=n);return r}const Ez=e=>{if(typeof e=="string")return e;let t,n="";for(let r=0;r<e.length;r++)e[r]&&(t=Ez(e[r]))&&(n&&(n+=" "),n+=t);return n};function HH(e,...t){let n,r,a,i=l;function l(c){const f=t.reduce((p,g)=>g(p),e());return n=BH(f),r=n.cache.get,a=n.cache.set,i=u,u(c)}function u(c){const f=r(c);if(f)return f;const p=jH(c,n);return a(c,p),p}return function(){return i(GH.apply(null,arguments))}}const rn=e=>{const t=n=>n[e]||[];return t.isThemeGetter=!0,t},wz=/^\[(?:(\w[\w-]*):)?(.+)\]$/i,xz=/^\((?:(\w[\w-]*):)?(.+)\)$/i,$H=/^\d+\/\d+$/,qH=/^(\d+(\.\d+)?)?(xs|sm|md|lg|xl)$/,VH=/\d+(%|px|r?em|[sdl]?v([hwib]|min|max)|pt|pc|in|cm|mm|cap|ch|ex|r?lh|cq(w|h|i|b|min|max))|\b(calc|min|max|clamp)\(.+\)|^0$/,WH=/^(rgba?|hsla?|hwb|(ok)?(lab|lch))\(.+\)$/,YH=/^(inset_)?-?((\d+)?\.?(\d+)[a-z]+|0)_-?((\d+)?\.?(\d+)[a-z]+|0)/,KH=/^(url|image|image-set|cross-fade|element|(repeating-)?(linear|radial|conic)-gradient)\(.+\)$/,Yi=e=>$H.test(e),ct=e=>!!e&&!Number.isNaN(Number(e)),Wo=e=>!!e&&Number.isInteger(Number(e)),aR=e=>e.endsWith("%")&&ct(e.slice(0,-1)),oo=e=>qH.test(e),XH=()=>!0,ZH=e=>VH.test(e)&&!WH.test(e),Ak=()=>!1,QH=e=>YH.test(e),JH=e=>KH.test(e),e9=e=>!je(e)&&!Ge(e),t9=e=>kl(e,Tz,Ak),je=e=>wz.test(e),Yo=e=>kl(e,_z,ZH),ih=e=>kl(e,f9,ct),n9=e=>kl(e,kz,Ak),r9=e=>kl(e,Az,JH),a9=e=>kl(e,Ak,QH),Ge=e=>xz.test(e),zc=e=>Al(e,_z),o9=e=>Al(e,p9),i9=e=>Al(e,kz),l9=e=>Al(e,Tz),s9=e=>Al(e,Az),u9=e=>Al(e,g9,!0),kl=(e,t,n)=>{const r=wz.exec(e);return r?r[1]?t(r[1]):n(r[2]):!1},Al=(e,t,n=!1)=>{const r=xz.exec(e);return r?r[1]?t(r[1]):n:!1},kz=e=>e==="position",c9=new Set(["image","url"]),Az=e=>c9.has(e),d9=new Set(["length","size","percentage"]),Tz=e=>d9.has(e),_z=e=>e==="length",f9=e=>e==="number",p9=e=>e==="family-name",g9=e=>e==="shadow",h9=()=>{const e=rn("color"),t=rn("font"),n=rn("text"),r=rn("font-weight"),a=rn("tracking"),i=rn("leading"),l=rn("breakpoint"),u=rn("container"),c=rn("spacing"),f=rn("radius"),p=rn("shadow"),g=rn("inset-shadow"),b=rn("drop-shadow"),m=rn("blur"),S=rn("perspective"),v=rn("aspect"),A=rn("ease"),R=rn("animate"),x=()=>["auto","avoid","all","avoid-page","page","left","right","column"],T=()=>["bottom","center","left","left-bottom","left-top","right","right-bottom","right-top","top"],C=()=>["auto","hidden","clip","visible","scroll"],N=()=>["auto","contain","none"],_=()=>[Ge,je,c],O=()=>[Yi,"full","auto",..._()],z=()=>[Wo,"none","subgrid",Ge,je],I=()=>["auto",{span:["full",Wo,Ge,je]},Ge,je],M=()=>[Wo,"auto",Ge,je],H=()=>["auto","min","max","fr",Ge,je],q=()=>["start","end","center","between","around","evenly","stretch","baseline"],P=()=>["start","end","center","stretch"],W=()=>["auto",..._()],Z=()=>[Yi,"auto","full","dvw","dvh","lvw","lvh","svw","svh","min","max","fit",..._()],j=()=>[e,Ge,je],G=()=>[aR,Yo],B=()=>["","none","full",f,Ge,je],X=()=>["",ct,zc,Yo],D=()=>["solid","dashed","dotted","double"],V=()=>["normal","multiply","screen","overlay","darken","lighten","color-dodge","color-burn","hard-light","soft-light","difference","exclusion","hue","saturation","color","luminosity"],U=()=>["","none",m,Ge,je],L=()=>["center","top","top-right","right","bottom-right","bottom","bottom-left","left","top-left",Ge,je],Y=()=>["none",ct,Ge,je],Q=()=>["none",ct,Ge,je],se=()=>[ct,Ge,je],re=()=>[Yi,"full",..._()];return{cacheSize:500,theme:{animate:["spin","ping","pulse","bounce"],aspect:["video"],blur:[oo],breakpoint:[oo],color:[XH],container:[oo],"drop-shadow":[oo],ease:["in","out","in-out"],font:[e9],"font-weight":["thin","extralight","light","normal","medium","semibold","bold","extrabold","black"],"inset-shadow":[oo],leading:["none","tight","snug","normal","relaxed","loose"],perspective:["dramatic","near","normal","midrange","distant","none"],radius:[oo],shadow:[oo],spacing:["px",ct],text:[oo],tracking:["tighter","tight","normal","wide","wider","widest"]},classGroups:{aspect:[{aspect:["auto","square",Yi,je,Ge,v]}],container:["container"],columns:[{columns:[ct,je,Ge,u]}],"break-after":[{"break-after":x()}],"break-before":[{"break-before":x()}],"break-inside":[{"break-inside":["auto","avoid","avoid-page","avoid-column"]}],"box-decoration":[{"box-decoration":["slice","clone"]}],box:[{box:["border","content"]}],display:["block","inline-block","inline","flex","inline-flex","table","inline-table","table-caption","table-cell","table-column","table-column-group","table-footer-group","table-header-group","table-row-group","table-row","flow-root","grid","inline-grid","contents","list-item","hidden"],sr:["sr-only","not-sr-only"],float:[{float:["right","left","none","start","end"]}],clear:[{clear:["left","right","both","none","start","end"]}],isolation:["isolate","isolation-auto"],"object-fit":[{object:["contain","cover","fill","none","scale-down"]}],"object-position":[{object:[...T(),je,Ge]}],overflow:[{overflow:C()}],"overflow-x":[{"overflow-x":C()}],"overflow-y":[{"overflow-y":C()}],overscroll:[{overscroll:N()}],"overscroll-x":[{"overscroll-x":N()}],"overscroll-y":[{"overscroll-y":N()}],position:["static","fixed","absolute","relative","sticky"],inset:[{inset:O()}],"inset-x":[{"inset-x":O()}],"inset-y":[{"inset-y":O()}],start:[{start:O()}],end:[{end:O()}],top:[{top:O()}],right:[{right:O()}],bottom:[{bottom:O()}],left:[{left:O()}],visibility:["visible","invisible","collapse"],z:[{z:[Wo,"auto",Ge,je]}],basis:[{basis:[Yi,"full","auto",u,..._()]}],"flex-direction":[{flex:["row","row-reverse","col","col-reverse"]}],"flex-wrap":[{flex:["nowrap","wrap","wrap-reverse"]}],flex:[{flex:[ct,Yi,"auto","initial","none",je]}],grow:[{grow:["",ct,Ge,je]}],shrink:[{shrink:["",ct,Ge,je]}],order:[{order:[Wo,"first","last","none",Ge,je]}],"grid-cols":[{"grid-cols":z()}],"col-start-end":[{col:I()}],"col-start":[{"col-start":M()}],"col-end":[{"col-end":M()}],"grid-rows":[{"grid-rows":z()}],"row-start-end":[{row:I()}],"row-start":[{"row-start":M()}],"row-end":[{"row-end":M()}],"grid-flow":[{"grid-flow":["row","col","dense","row-dense","col-dense"]}],"auto-cols":[{"auto-cols":H()}],"auto-rows":[{"auto-rows":H()}],gap:[{gap:_()}],"gap-x":[{"gap-x":_()}],"gap-y":[{"gap-y":_()}],"justify-content":[{justify:[...q(),"normal"]}],"justify-items":[{"justify-items":[...P(),"normal"]}],"justify-self":[{"justify-self":["auto",...P()]}],"align-content":[{content:["normal",...q()]}],"align-items":[{items:[...P(),"baseline"]}],"align-self":[{self:["auto",...P(),"baseline"]}],"place-content":[{"place-content":q()}],"place-items":[{"place-items":[...P(),"baseline"]}],"place-self":[{"place-self":["auto",...P()]}],p:[{p:_()}],px:[{px:_()}],py:[{py:_()}],ps:[{ps:_()}],pe:[{pe:_()}],pt:[{pt:_()}],pr:[{pr:_()}],pb:[{pb:_()}],pl:[{pl:_()}],m:[{m:W()}],mx:[{mx:W()}],my:[{my:W()}],ms:[{ms:W()}],me:[{me:W()}],mt:[{mt:W()}],mr:[{mr:W()}],mb:[{mb:W()}],ml:[{ml:W()}],"space-x":[{"space-x":_()}],"space-x-reverse":["space-x-reverse"],"space-y":[{"space-y":_()}],"space-y-reverse":["space-y-reverse"],size:[{size:Z()}],w:[{w:[u,"screen",...Z()]}],"min-w":[{"min-w":[u,"screen","none",...Z()]}],"max-w":[{"max-w":[u,"screen","none","prose",{screen:[l]},...Z()]}],h:[{h:["screen",...Z()]}],"min-h":[{"min-h":["screen","none",...Z()]}],"max-h":[{"max-h":["screen",...Z()]}],"font-size":[{text:["base",n,zc,Yo]}],"font-smoothing":["antialiased","subpixel-antialiased"],"font-style":["italic","not-italic"],"font-weight":[{font:[r,Ge,ih]}],"font-stretch":[{"font-stretch":["ultra-condensed","extra-condensed","condensed","semi-condensed","normal","semi-expanded","expanded","extra-expanded","ultra-expanded",aR,je]}],"font-family":[{font:[o9,je,t]}],"fvn-normal":["normal-nums"],"fvn-ordinal":["ordinal"],"fvn-slashed-zero":["slashed-zero"],"fvn-figure":["lining-nums","oldstyle-nums"],"fvn-spacing":["proportional-nums","tabular-nums"],"fvn-fraction":["diagonal-fractions","stacked-fractions"],tracking:[{tracking:[a,Ge,je]}],"line-clamp":[{"line-clamp":[ct,"none",Ge,ih]}],leading:[{leading:[i,..._()]}],"list-image":[{"list-image":["none",Ge,je]}],"list-style-position":[{list:["inside","outside"]}],"list-style-type":[{list:["disc","decimal","none",Ge,je]}],"text-alignment":[{text:["left","center","right","justify","start","end"]}],"placeholder-color":[{placeholder:j()}],"text-color":[{text:j()}],"text-decoration":["underline","overline","line-through","no-underline"],"text-decoration-style":[{decoration:[...D(),"wavy"]}],"text-decoration-thickness":[{decoration:[ct,"from-font","auto",Ge,Yo]}],"text-decoration-color":[{decoration:j()}],"underline-offset":[{"underline-offset":[ct,"auto",Ge,je]}],"text-transform":["uppercase","lowercase","capitalize","normal-case"],"text-overflow":["truncate","text-ellipsis","text-clip"],"text-wrap":[{text:["wrap","nowrap","balance","pretty"]}],indent:[{indent:_()}],"vertical-align":[{align:["baseline","top","middle","bottom","text-top","text-bottom","sub","super",Ge,je]}],whitespace:[{whitespace:["normal","nowrap","pre","pre-line","pre-wrap","break-spaces"]}],break:[{break:["normal","words","all","keep"]}],hyphens:[{hyphens:["none","manual","auto"]}],content:[{content:["none",Ge,je]}],"bg-attachment":[{bg:["fixed","local","scroll"]}],"bg-clip":[{"bg-clip":["border","padding","content","text"]}],"bg-origin":[{"bg-origin":["border","padding","content"]}],"bg-position":[{bg:[...T(),i9,n9]}],"bg-repeat":[{bg:["no-repeat",{repeat:["","x","y","space","round"]}]}],"bg-size":[{bg:["auto","cover","contain",l9,t9]}],"bg-image":[{bg:["none",{linear:[{to:["t","tr","r","br","b","bl","l","tl"]},Wo,Ge,je],radial:["",Ge,je],conic:[Wo,Ge,je]},s9,r9]}],"bg-color":[{bg:j()}],"gradient-from-pos":[{from:G()}],"gradient-via-pos":[{via:G()}],"gradient-to-pos":[{to:G()}],"gradient-from":[{from:j()}],"gradient-via":[{via:j()}],"gradient-to":[{to:j()}],rounded:[{rounded:B()}],"rounded-s":[{"rounded-s":B()}],"rounded-e":[{"rounded-e":B()}],"rounded-t":[{"rounded-t":B()}],"rounded-r":[{"rounded-r":B()}],"rounded-b":[{"rounded-b":B()}],"rounded-l":[{"rounded-l":B()}],"rounded-ss":[{"rounded-ss":B()}],"rounded-se":[{"rounded-se":B()}],"rounded-ee":[{"rounded-ee":B()}],"rounded-es":[{"rounded-es":B()}],"rounded-tl":[{"rounded-tl":B()}],"rounded-tr":[{"rounded-tr":B()}],"rounded-br":[{"rounded-br":B()}],"rounded-bl":[{"rounded-bl":B()}],"border-w":[{border:X()}],"border-w-x":[{"border-x":X()}],"border-w-y":[{"border-y":X()}],"border-w-s":[{"border-s":X()}],"border-w-e":[{"border-e":X()}],"border-w-t":[{"border-t":X()}],"border-w-r":[{"border-r":X()}],"border-w-b":[{"border-b":X()}],"border-w-l":[{"border-l":X()}],"divide-x":[{"divide-x":X()}],"divide-x-reverse":["divide-x-reverse"],"divide-y":[{"divide-y":X()}],"divide-y-reverse":["divide-y-reverse"],"border-style":[{border:[...D(),"hidden","none"]}],"divide-style":[{divide:[...D(),"hidden","none"]}],"border-color":[{border:j()}],"border-color-x":[{"border-x":j()}],"border-color-y":[{"border-y":j()}],"border-color-s":[{"border-s":j()}],"border-color-e":[{"border-e":j()}],"border-color-t":[{"border-t":j()}],"border-color-r":[{"border-r":j()}],"border-color-b":[{"border-b":j()}],"border-color-l":[{"border-l":j()}],"divide-color":[{divide:j()}],"outline-style":[{outline:[...D(),"none","hidden"]}],"outline-offset":[{"outline-offset":[ct,Ge,je]}],"outline-w":[{outline:["",ct,zc,Yo]}],"outline-color":[{outline:[e]}],shadow:[{shadow:["","none",p,u9,a9]}],"shadow-color":[{shadow:j()}],"inset-shadow":[{"inset-shadow":["none",Ge,je,g]}],"inset-shadow-color":[{"inset-shadow":j()}],"ring-w":[{ring:X()}],"ring-w-inset":["ring-inset"],"ring-color":[{ring:j()}],"ring-offset-w":[{"ring-offset":[ct,Yo]}],"ring-offset-color":[{"ring-offset":j()}],"inset-ring-w":[{"inset-ring":X()}],"inset-ring-color":[{"inset-ring":j()}],opacity:[{opacity:[ct,Ge,je]}],"mix-blend":[{"mix-blend":[...V(),"plus-darker","plus-lighter"]}],"bg-blend":[{"bg-blend":V()}],filter:[{filter:["","none",Ge,je]}],blur:[{blur:U()}],brightness:[{brightness:[ct,Ge,je]}],contrast:[{contrast:[ct,Ge,je]}],"drop-shadow":[{"drop-shadow":["","none",b,Ge,je]}],grayscale:[{grayscale:["",ct,Ge,je]}],"hue-rotate":[{"hue-rotate":[ct,Ge,je]}],invert:[{invert:["",ct,Ge,je]}],saturate:[{saturate:[ct,Ge,je]}],sepia:[{sepia:["",ct,Ge,je]}],"backdrop-filter":[{"backdrop-filter":["","none",Ge,je]}],"backdrop-blur":[{"backdrop-blur":U()}],"backdrop-brightness":[{"backdrop-brightness":[ct,Ge,je]}],"backdrop-contrast":[{"backdrop-contrast":[ct,Ge,je]}],"backdrop-grayscale":[{"backdrop-grayscale":["",ct,Ge,je]}],"backdrop-hue-rotate":[{"backdrop-hue-rotate":[ct,Ge,je]}],"backdrop-invert":[{"backdrop-invert":["",ct,Ge,je]}],"backdrop-opacity":[{"backdrop-opacity":[ct,Ge,je]}],"backdrop-saturate":[{"backdrop-saturate":[ct,Ge,je]}],"backdrop-sepia":[{"backdrop-sepia":["",ct,Ge,je]}],"border-collapse":[{border:["collapse","separate"]}],"border-spacing":[{"border-spacing":_()}],"border-spacing-x":[{"border-spacing-x":_()}],"border-spacing-y":[{"border-spacing-y":_()}],"table-layout":[{table:["auto","fixed"]}],caption:[{caption:["top","bottom"]}],transition:[{transition:["","all","colors","opacity","shadow","transform","none",Ge,je]}],"transition-behavior":[{transition:["normal","discrete"]}],duration:[{duration:[ct,"initial",Ge,je]}],ease:[{ease:["linear","initial",A,Ge,je]}],delay:[{delay:[ct,Ge,je]}],animate:[{animate:["none",R,Ge,je]}],backface:[{backface:["hidden","visible"]}],perspective:[{perspective:[S,Ge,je]}],"perspective-origin":[{"perspective-origin":L()}],rotate:[{rotate:Y()}],"rotate-x":[{"rotate-x":Y()}],"rotate-y":[{"rotate-y":Y()}],"rotate-z":[{"rotate-z":Y()}],scale:[{scale:Q()}],"scale-x":[{"scale-x":Q()}],"scale-y":[{"scale-y":Q()}],"scale-z":[{"scale-z":Q()}],"scale-3d":["scale-3d"],skew:[{skew:se()}],"skew-x":[{"skew-x":se()}],"skew-y":[{"skew-y":se()}],transform:[{transform:[Ge,je,"","none","gpu","cpu"]}],"transform-origin":[{origin:L()}],"transform-style":[{transform:["3d","flat"]}],translate:[{translate:re()}],"translate-x":[{"translate-x":re()}],"translate-y":[{"translate-y":re()}],"translate-z":[{"translate-z":re()}],"translate-none":["translate-none"],accent:[{accent:j()}],appearance:[{appearance:["none","auto"]}],"caret-color":[{caret:j()}],"color-scheme":[{scheme:["normal","dark","light","light-dark","only-dark","only-light"]}],cursor:[{cursor:["auto","default","pointer","wait","text","move","help","not-allowed","none","context-menu","progress","cell","crosshair","vertical-text","alias","copy","no-drop","grab","grabbing","all-scroll","col-resize","row-resize","n-resize","e-resize","s-resize","w-resize","ne-resize","nw-resize","se-resize","sw-resize","ew-resize","ns-resize","nesw-resize","nwse-resize","zoom-in","zoom-out",Ge,je]}],"field-sizing":[{"field-sizing":["fixed","content"]}],"pointer-events":[{"pointer-events":["auto","none"]}],resize:[{resize:["none","","y","x"]}],"scroll-behavior":[{scroll:["auto","smooth"]}],"scroll-m":[{"scroll-m":_()}],"scroll-mx":[{"scroll-mx":_()}],"scroll-my":[{"scroll-my":_()}],"scroll-ms":[{"scroll-ms":_()}],"scroll-me":[{"scroll-me":_()}],"scroll-mt":[{"scroll-mt":_()}],"scroll-mr":[{"scroll-mr":_()}],"scroll-mb":[{"scroll-mb":_()}],"scroll-ml":[{"scroll-ml":_()}],"scroll-p":[{"scroll-p":_()}],"scroll-px":[{"scroll-px":_()}],"scroll-py":[{"scroll-py":_()}],"scroll-ps":[{"scroll-ps":_()}],"scroll-pe":[{"scroll-pe":_()}],"scroll-pt":[{"scroll-pt":_()}],"scroll-pr":[{"scroll-pr":_()}],"scroll-pb":[{"scroll-pb":_()}],"scroll-pl":[{"scroll-pl":_()}],"snap-align":[{snap:["start","end","center","align-none"]}],"snap-stop":[{snap:["normal","always"]}],"snap-type":[{snap:["none","x","y","both"]}],"snap-strictness":[{snap:["mandatory","proximity"]}],touch:[{touch:["auto","none","manipulation"]}],"touch-x":[{"touch-pan":["x","left","right"]}],"touch-y":[{"touch-pan":["y","up","down"]}],"touch-pz":["touch-pinch-zoom"],select:[{select:["none","text","all","auto"]}],"will-change":[{"will-change":["auto","scroll","contents","transform",Ge,je]}],fill:[{fill:["none",...j()]}],"stroke-w":[{stroke:[ct,zc,Yo,ih]}],stroke:[{stroke:["none",...j()]}],"forced-color-adjust":[{"forced-color-adjust":["auto","none"]}]},conflictingClassGroups:{overflow:["overflow-x","overflow-y"],overscroll:["overscroll-x","overscroll-y"],inset:["inset-x","inset-y","start","end","top","right","bottom","left"],"inset-x":["right","left"],"inset-y":["top","bottom"],flex:["basis","grow","shrink"],gap:["gap-x","gap-y"],p:["px","py","ps","pe","pt","pr","pb","pl"],px:["pr","pl"],py:["pt","pb"],m:["mx","my","ms","me","mt","mr","mb","ml"],mx:["mr","ml"],my:["mt","mb"],size:["w","h"],"font-size":["leading"],"fvn-normal":["fvn-ordinal","fvn-slashed-zero","fvn-figure","fvn-spacing","fvn-fraction"],"fvn-ordinal":["fvn-normal"],"fvn-slashed-zero":["fvn-normal"],"fvn-figure":["fvn-normal"],"fvn-spacing":["fvn-normal"],"fvn-fraction":["fvn-normal"],"line-clamp":["display","overflow"],rounded:["rounded-s","rounded-e","rounded-t","rounded-r","rounded-b","rounded-l","rounded-ss","rounded-se","rounded-ee","rounded-es","rounded-tl","rounded-tr","rounded-br","rounded-bl"],"rounded-s":["rounded-ss","rounded-es"],"rounded-e":["rounded-se","rounded-ee"],"rounded-t":["rounded-tl","rounded-tr"],"rounded-r":["rounded-tr","rounded-br"],"rounded-b":["rounded-br","rounded-bl"],"rounded-l":["rounded-tl","rounded-bl"],"border-spacing":["border-spacing-x","border-spacing-y"],"border-w":["border-w-s","border-w-e","border-w-t","border-w-r","border-w-b","border-w-l"],"border-w-x":["border-w-r","border-w-l"],"border-w-y":["border-w-t","border-w-b"],"border-color":["border-color-s","border-color-e","border-color-t","border-color-r","border-color-b","border-color-l"],"border-color-x":["border-color-r","border-color-l"],"border-color-y":["border-color-t","border-color-b"],translate:["translate-x","translate-y","translate-none"],"translate-none":["translate","translate-x","translate-y","translate-z"],"scroll-m":["scroll-mx","scroll-my","scroll-ms","scroll-me","scroll-mt","scroll-mr","scroll-mb","scroll-ml"],"scroll-mx":["scroll-mr","scroll-ml"],"scroll-my":["scroll-mt","scroll-mb"],"scroll-p":["scroll-px","scroll-py","scroll-ps","scroll-pe","scroll-pt","scroll-pr","scroll-pb","scroll-pl"],"scroll-px":["scroll-pr","scroll-pl"],"scroll-py":["scroll-pt","scroll-pb"],touch:["touch-x","touch-y","touch-pz"],"touch-x":["touch"],"touch-y":["touch"],"touch-pz":["touch"]},conflictingClassGroupModifiers:{"font-size":["leading"]},orderSensitiveModifiers:["before","after","placeholder","file","marker","selection","first-line","first-letter","backdrop","*","**"]}},m9=HH(h9);function Me(...e){return m9(vz(e))}function b9(){const e="0123456789abcdef";let t="#";for(let n=0;n<6;n++)t+=e.charAt(Math.floor(Math.random()*16));return t}function Nr(e){return e instanceof Error?e.message:`${e}`}const Tk=e=>{const t=e;t.use={};for(const n of Object.keys(t.getState()))t.use[n]=()=>t(r=>r[n]);return t},Rz="",Yr="ghost",y9="#B2EBF2",v9="#000",S9="#E2E2E2",E9="#EEEEEE",w9="#F57F17",x9="#969696",k9="#F57F17",oR="#B2EBF2",lh=20,sh=40,iR=4,A9=20,T9=15,lR="*",_9={"text/plain":[".txt",".md",".html",".htm",".tex",".json",".xml",".yaml",".yml",".rtf",".odt",".epub",".csv",".log",".conf",".ini",".properties",".sql",".bat",".sh",".c",".cpp",".py",".java",".js",".ts",".swift",".go",".rb",".php",".css",".scss",".less"],"application/pdf":[".pdf"],"application/msword":[".doc"],"application/vnd.openxmlformats-officedocument.wordprocessingml.document":[".docx"],"application/vnd.openxmlformats-officedocument.presentationml.presentation":[".pptx"]},sR={name:"LightRAG",github:"https://github.com/HKUDS/LightRAG"},R9=xk()(CH(e=>({theme:"system",showPropertyPanel:!0,showNodeSearchBar:!0,showNodeLabel:!0,enableNodeDrag:!0,showEdgeLabel:!1,enableHideUnselectedEdges:!0,enableEdgeEvents:!1,graphQueryMaxDepth:3,graphMinDegree:0,graphLayoutMaxIterations:10,queryLabel:lR,enableHealthCheck:!0,apiKey:null,currentTab:"documents",retrievalHistory:[],querySettings:{mode:"global",response_type:"Multiple Paragraphs",top_k:10,max_token_for_text_unit:4e3,max_token_for_global_context:4e3,max_token_for_local_context:4e3,only_need_context:!1,only_need_prompt:!1,stream:!0,history_turns:3,hl_keywords:[],ll_keywords:[]},setTheme:t=>e({theme:t}),setGraphLayoutMaxIterations:t=>e({graphLayoutMaxIterations:t}),setQueryLabel:t=>e({queryLabel:t}),setGraphQueryMaxDepth:t=>e({graphQueryMaxDepth:t}),setGraphMinDegree:t=>e({graphMinDegree:t}),setEnableHealthCheck:t=>e({enableHealthCheck:t}),setApiKey:t=>e({apiKey:t}),setCurrentTab:t=>e({currentTab:t}),setRetrievalHistory:t=>e({retrievalHistory:t}),updateQuerySettings:t=>e(n=>({querySettings:{...n.querySettings,...t}}))}),{name:"settings-storage",storage:bz(()=>localStorage),version:7,migrate:(e,t)=>(t<2&&(e.showEdgeLabel=!1),t<3&&(e.queryLabel=lR),t<4&&(e.showPropertyPanel=!0,e.showNodeSearchBar=!0,e.showNodeLabel=!0,e.enableHealthCheck=!0,e.apiKey=null),t<5&&(e.currentTab="documents"),t<6&&(e.querySettings={mode:"global",response_type:"Multiple Paragraphs",top_k:10,max_token_for_text_unit:4e3,max_token_for_global_context:4e3,max_token_for_local_context:4e3,only_need_context:!1,only_need_prompt:!1,stream:!0,history_turns:3,hl_keywords:[],ll_keywords:[]},e.retrievalHistory=[]),t<7&&(e.graphQueryMaxDepth=3,e.graphLayoutMaxIterations=10),e)})),We=Tk(R9),C9={theme:"system",setTheme:()=>null},Cz=k.createContext(C9);function N9({children:e,...t}){const[n,r]=k.useState(We.getState().theme);k.useEffect(()=>{const i=window.document.documentElement;if(i.classList.remove("light","dark"),n==="system"){const l=window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light";i.classList.add(l),r(l);return}i.classList.add(n)},[n]);const a={theme:n,setTheme:i=>{We.getState().setTheme(i),r(i)}};return w.jsx(Cz.Provider,{...t,value:a,children:e})}const uR=e=>typeof e=="boolean"?`${e}`:e===0?"0":e,cR=vz,Nz=(e,t)=>n=>{var r;if((t==null?void 0:t.variants)==null)return cR(e,n==null?void 0:n.class,n==null?void 0:n.className);const{variants:a,defaultVariants:i}=t,l=Object.keys(a).map(f=>{const p=n==null?void 0:n[f],g=i==null?void 0:i[f];if(p===null)return null;const b=uR(p)||uR(g);return a[f][b]}),u=n&&Object.entries(n).reduce((f,p)=>{let[g,b]=p;return b===void 0||(f[g]=b),f},{}),c=t==null||(r=t.compoundVariants)===null||r===void 0?void 0:r.reduce((f,p)=>{let{class:g,className:b,...m}=p;return Object.entries(m).every(S=>{let[v,A]=S;return Array.isArray(A)?A.includes({...i,...u}[v]):{...i,...u}[v]===A})?[...f,g,b]:f},[]);return cR(e,l,c,n==null?void 0:n.class,n==null?void 0:n.className)},O9=Nz("relative w-full rounded-lg border px-4 py-3 text-sm [&>svg+div]:translate-y-[-3px] [&>svg]:absolute [&>svg]:left-4 [&>svg]:top-4 [&>svg]:text-foreground [&>svg~*]:pl-7",{variants:{variant:{default:"bg-background text-foreground",destructive:"border-destructive/50 text-destructive dark:border-destructive [&>svg]:text-destructive"}},defaultVariants:{variant:"default"}}),Oz=k.forwardRef(({className:e,variant:t,...n},r)=>w.jsx("div",{ref:r,role:"alert",className:Me(O9({variant:t}),e),...n}));Oz.displayName="Alert";const Dz=k.forwardRef(({className:e,...t},n)=>w.jsx("h5",{ref:n,className:Me("mb-1 leading-none font-medium tracking-tight",e),...t}));Dz.displayName="AlertTitle";const Iz=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("text-sm [&_p]:leading-relaxed",e),...t}));Iz.displayName="AlertDescription";function Lz(e,t){return function(){return e.apply(t,arguments)}}const{toString:D9}=Object.prototype,{getPrototypeOf:_k}=Object,rf=(e=>t=>{const n=D9.call(t);return e[n]||(e[n]=n.slice(8,-1).toLowerCase())})(Object.create(null)),Lr=e=>(e=e.toLowerCase(),t=>rf(t)===e),af=e=>t=>typeof t===e,{isArray:Tl}=Array,Js=af("undefined");function I9(e){return e!==null&&!Js(e)&&e.constructor!==null&&!Js(e.constructor)&&Xn(e.constructor.isBuffer)&&e.constructor.isBuffer(e)}const Mz=Lr("ArrayBuffer");function L9(e){let t;return typeof ArrayBuffer<"u"&&ArrayBuffer.isView?t=ArrayBuffer.isView(e):t=e&&e.buffer&&Mz(e.buffer),t}const M9=af("string"),Xn=af("function"),Fz=af("number"),of=e=>e!==null&&typeof e=="object",F9=e=>e===!0||e===!1,fd=e=>{if(rf(e)!=="object")return!1;const t=_k(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)},z9=Lr("Date"),P9=Lr("File"),B9=Lr("Blob"),U9=Lr("FileList"),j9=e=>of(e)&&Xn(e.pipe),G9=e=>{let t;return e&&(typeof FormData=="function"&&e instanceof FormData||Xn(e.append)&&((t=rf(e))==="formdata"||t==="object"&&Xn(e.toString)&&e.toString()==="[object FormData]"))},H9=Lr("URLSearchParams"),[$9,q9,V9,W9]=["ReadableStream","Request","Response","Headers"].map(Lr),Y9=e=>e.trim?e.trim():e.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"");function fu(e,t,{allOwnKeys:n=!1}={}){if(e===null||typeof e>"u")return;let r,a;if(typeof e!="object"&&(e=[e]),Tl(e))for(r=0,a=e.length;r<a;r++)t.call(null,e[r],r,e);else{const i=n?Object.getOwnPropertyNames(e):Object.keys(e),l=i.length;let u;for(r=0;r<l;r++)u=i[r],t.call(null,e[u],u,e)}}function zz(e,t){t=t.toLowerCase();const n=Object.keys(e);let r=n.length,a;for(;r-- >0;)if(a=n[r],t===a.toLowerCase())return a;return null}const ti=typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:global,Pz=e=>!Js(e)&&e!==ti;function mx(){const{caseless:e}=Pz(this)&&this||{},t={},n=(r,a)=>{const i=e&&zz(t,a)||a;fd(t[i])&&fd(r)?t[i]=mx(t[i],r):fd(r)?t[i]=mx({},r):Tl(r)?t[i]=r.slice():t[i]=r};for(let r=0,a=arguments.length;r<a;r++)arguments[r]&&fu(arguments[r],n);return t}const K9=(e,t,n,{allOwnKeys:r}={})=>(fu(t,(a,i)=>{n&&Xn(a)?e[i]=Lz(a,n):e[i]=a},{allOwnKeys:r}),e),X9=e=>(e.charCodeAt(0)===65279&&(e=e.slice(1)),e),Z9=(e,t,n,r)=>{e.prototype=Object.create(t.prototype,r),e.prototype.constructor=e,Object.defineProperty(e,"super",{value:t.prototype}),n&&Object.assign(e.prototype,n)},Q9=(e,t,n,r)=>{let a,i,l;const u={};if(t=t||{},e==null)return t;do{for(a=Object.getOwnPropertyNames(e),i=a.length;i-- >0;)l=a[i],(!r||r(l,e,t))&&!u[l]&&(t[l]=e[l],u[l]=!0);e=n!==!1&&_k(e)}while(e&&(!n||n(e,t))&&e!==Object.prototype);return t},J9=(e,t,n)=>{e=String(e),(n===void 0||n>e.length)&&(n=e.length),n-=t.length;const r=e.indexOf(t,n);return r!==-1&&r===n},e$=e=>{if(!e)return null;if(Tl(e))return e;let t=e.length;if(!Fz(t))return null;const n=new Array(t);for(;t-- >0;)n[t]=e[t];return n},t$=(e=>t=>e&&t instanceof e)(typeof Uint8Array<"u"&&_k(Uint8Array)),n$=(e,t)=>{const r=(e&&e[Symbol.iterator]).call(e);let a;for(;(a=r.next())&&!a.done;){const i=a.value;t.call(e,i[0],i[1])}},r$=(e,t)=>{let n;const r=[];for(;(n=e.exec(t))!==null;)r.push(n);return r},a$=Lr("HTMLFormElement"),o$=e=>e.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(n,r,a){return r.toUpperCase()+a}),dR=(({hasOwnProperty:e})=>(t,n)=>e.call(t,n))(Object.prototype),i$=Lr("RegExp"),Bz=(e,t)=>{const n=Object.getOwnPropertyDescriptors(e),r={};fu(n,(a,i)=>{let l;(l=t(a,i,e))!==!1&&(r[i]=l||a)}),Object.defineProperties(e,r)},l$=e=>{Bz(e,(t,n)=>{if(Xn(e)&&["arguments","caller","callee"].indexOf(n)!==-1)return!1;const r=e[n];if(Xn(r)){if(t.enumerable=!1,"writable"in t){t.writable=!1;return}t.set||(t.set=()=>{throw Error("Can not rewrite read-only method '"+n+"'")})}})},s$=(e,t)=>{const n={},r=a=>{a.forEach(i=>{n[i]=!0})};return Tl(e)?r(e):r(String(e).split(t)),n},u$=()=>{},c$=(e,t)=>e!=null&&Number.isFinite(e=+e)?e:t,uh="abcdefghijklmnopqrstuvwxyz",fR="0123456789",Uz={DIGIT:fR,ALPHA:uh,ALPHA_DIGIT:uh+uh.toUpperCase()+fR},d$=(e=16,t=Uz.ALPHA_DIGIT)=>{let n="";const{length:r}=t;for(;e--;)n+=t[Math.random()*r|0];return n};function f$(e){return!!(e&&Xn(e.append)&&e[Symbol.toStringTag]==="FormData"&&e[Symbol.iterator])}const p$=e=>{const t=new Array(10),n=(r,a)=>{if(of(r)){if(t.indexOf(r)>=0)return;if(!("toJSON"in r)){t[a]=r;const i=Tl(r)?[]:{};return fu(r,(l,u)=>{const c=n(l,a+1);!Js(c)&&(i[u]=c)}),t[a]=void 0,i}}return r};return n(e,0)},g$=Lr("AsyncFunction"),h$=e=>e&&(of(e)||Xn(e))&&Xn(e.then)&&Xn(e.catch),jz=((e,t)=>e?setImmediate:t?((n,r)=>(ti.addEventListener("message",({source:a,data:i})=>{a===ti&&i===n&&r.length&&r.shift()()},!1),a=>{r.push(a),ti.postMessage(n,"*")}))(`axios@${Math.random()}`,[]):n=>setTimeout(n))(typeof setImmediate=="function",Xn(ti.postMessage)),m$=typeof queueMicrotask<"u"?queueMicrotask.bind(ti):typeof process<"u"&&process.nextTick||jz,pe={isArray:Tl,isArrayBuffer:Mz,isBuffer:I9,isFormData:G9,isArrayBufferView:L9,isString:M9,isNumber:Fz,isBoolean:F9,isObject:of,isPlainObject:fd,isReadableStream:$9,isRequest:q9,isResponse:V9,isHeaders:W9,isUndefined:Js,isDate:z9,isFile:P9,isBlob:B9,isRegExp:i$,isFunction:Xn,isStream:j9,isURLSearchParams:H9,isTypedArray:t$,isFileList:U9,forEach:fu,merge:mx,extend:K9,trim:Y9,stripBOM:X9,inherits:Z9,toFlatObject:Q9,kindOf:rf,kindOfTest:Lr,endsWith:J9,toArray:e$,forEachEntry:n$,matchAll:r$,isHTMLForm:a$,hasOwnProperty:dR,hasOwnProp:dR,reduceDescriptors:Bz,freezeMethods:l$,toObjectSet:s$,toCamelCase:o$,noop:u$,toFiniteNumber:c$,findKey:zz,global:ti,isContextDefined:Pz,ALPHABET:Uz,generateString:d$,isSpecCompliantForm:f$,toJSONObject:p$,isAsyncFn:g$,isThenable:h$,setImmediate:jz,asap:m$};function nt(e,t,n,r,a){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack,this.message=e,this.name="AxiosError",t&&(this.code=t),n&&(this.config=n),r&&(this.request=r),a&&(this.response=a,this.status=a.status?a.status:null)}pe.inherits(nt,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:pe.toJSONObject(this.config),code:this.code,status:this.status}}});const Gz=nt.prototype,Hz={};["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach(e=>{Hz[e]={value:e}});Object.defineProperties(nt,Hz);Object.defineProperty(Gz,"isAxiosError",{value:!0});nt.from=(e,t,n,r,a,i)=>{const l=Object.create(Gz);return pe.toFlatObject(e,l,function(c){return c!==Error.prototype},u=>u!=="isAxiosError"),nt.call(l,e.message,t,n,r,a),l.cause=e,l.name=e.name,i&&Object.assign(l,i),l};const b$=null;function bx(e){return pe.isPlainObject(e)||pe.isArray(e)}function $z(e){return pe.endsWith(e,"[]")?e.slice(0,-2):e}function pR(e,t,n){return e?e.concat(t).map(function(a,i){return a=$z(a),!n&&i?"["+a+"]":a}).join(n?".":""):t}function y$(e){return pe.isArray(e)&&!e.some(bx)}const v$=pe.toFlatObject(pe,{},null,function(t){return/^is[A-Z]/.test(t)});function lf(e,t,n){if(!pe.isObject(e))throw new TypeError("target must be an object");t=t||new FormData,n=pe.toFlatObject(n,{metaTokens:!0,dots:!1,indexes:!1},!1,function(v,A){return!pe.isUndefined(A[v])});const r=n.metaTokens,a=n.visitor||p,i=n.dots,l=n.indexes,c=(n.Blob||typeof Blob<"u"&&Blob)&&pe.isSpecCompliantForm(t);if(!pe.isFunction(a))throw new TypeError("visitor must be a function");function f(S){if(S===null)return"";if(pe.isDate(S))return S.toISOString();if(!c&&pe.isBlob(S))throw new nt("Blob is not supported. Use a Buffer instead.");return pe.isArrayBuffer(S)||pe.isTypedArray(S)?c&&typeof Blob=="function"?new Blob([S]):Buffer.from(S):S}function p(S,v,A){let R=S;if(S&&!A&&typeof S=="object"){if(pe.endsWith(v,"{}"))v=r?v:v.slice(0,-2),S=JSON.stringify(S);else if(pe.isArray(S)&&y$(S)||(pe.isFileList(S)||pe.endsWith(v,"[]"))&&(R=pe.toArray(S)))return v=$z(v),R.forEach(function(T,C){!(pe.isUndefined(T)||T===null)&&t.append(l===!0?pR([v],C,i):l===null?v:v+"[]",f(T))}),!1}return bx(S)?!0:(t.append(pR(A,v,i),f(S)),!1)}const g=[],b=Object.assign(v$,{defaultVisitor:p,convertValue:f,isVisitable:bx});function m(S,v){if(!pe.isUndefined(S)){if(g.indexOf(S)!==-1)throw Error("Circular reference detected in "+v.join("."));g.push(S),pe.forEach(S,function(R,x){(!(pe.isUndefined(R)||R===null)&&a.call(t,R,pe.isString(x)?x.trim():x,v,b))===!0&&m(R,v?v.concat(x):[x])}),g.pop()}}if(!pe.isObject(e))throw new TypeError("data must be an object");return m(e),t}function gR(e){const t={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(e).replace(/[!'()~]|%20|%00/g,function(r){return t[r]})}function Rk(e,t){this._pairs=[],e&&lf(e,this,t)}const qz=Rk.prototype;qz.append=function(t,n){this._pairs.push([t,n])};qz.toString=function(t){const n=t?function(r){return t.call(this,r,gR)}:gR;return this._pairs.map(function(a){return n(a[0])+"="+n(a[1])},"").join("&")};function S$(e){return encodeURIComponent(e).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function Vz(e,t,n){if(!t)return e;const r=n&&n.encode||S$;pe.isFunction(n)&&(n={serialize:n});const a=n&&n.serialize;let i;if(a?i=a(t,n):i=pe.isURLSearchParams(t)?t.toString():new Rk(t,n).toString(r),i){const l=e.indexOf("#");l!==-1&&(e=e.slice(0,l)),e+=(e.indexOf("?")===-1?"?":"&")+i}return e}class hR{constructor(){this.handlers=[]}use(t,n,r){return this.handlers.push({fulfilled:t,rejected:n,synchronous:r?r.synchronous:!1,runWhen:r?r.runWhen:null}),this.handlers.length-1}eject(t){this.handlers[t]&&(this.handlers[t]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(t){pe.forEach(this.handlers,function(r){r!==null&&t(r)})}}const Wz={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},E$=typeof URLSearchParams<"u"?URLSearchParams:Rk,w$=typeof FormData<"u"?FormData:null,x$=typeof Blob<"u"?Blob:null,k$={isBrowser:!0,classes:{URLSearchParams:E$,FormData:w$,Blob:x$},protocols:["http","https","file","blob","url","data"]},Ck=typeof window<"u"&&typeof document<"u",yx=typeof navigator=="object"&&navigator||void 0,A$=Ck&&(!yx||["ReactNative","NativeScript","NS"].indexOf(yx.product)<0),T$=typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope&&typeof self.importScripts=="function",_$=Ck&&window.location.href||"http://localhost",R$=Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv:Ck,hasStandardBrowserEnv:A$,hasStandardBrowserWebWorkerEnv:T$,navigator:yx,origin:_$},Symbol.toStringTag,{value:"Module"})),yn={...R$,...k$};function C$(e,t){return lf(e,new yn.classes.URLSearchParams,Object.assign({visitor:function(n,r,a,i){return yn.isNode&&pe.isBuffer(n)?(this.append(r,n.toString("base64")),!1):i.defaultVisitor.apply(this,arguments)}},t))}function N$(e){return pe.matchAll(/\w+|\[(\w*)]/g,e).map(t=>t[0]==="[]"?"":t[1]||t[0])}function O$(e){const t={},n=Object.keys(e);let r;const a=n.length;let i;for(r=0;r<a;r++)i=n[r],t[i]=e[i];return t}function Yz(e){function t(n,r,a,i){let l=n[i++];if(l==="__proto__")return!0;const u=Number.isFinite(+l),c=i>=n.length;return l=!l&&pe.isArray(a)?a.length:l,c?(pe.hasOwnProp(a,l)?a[l]=[a[l],r]:a[l]=r,!u):((!a[l]||!pe.isObject(a[l]))&&(a[l]=[]),t(n,r,a[l],i)&&pe.isArray(a[l])&&(a[l]=O$(a[l])),!u)}if(pe.isFormData(e)&&pe.isFunction(e.entries)){const n={};return pe.forEachEntry(e,(r,a)=>{t(N$(r),a,n,0)}),n}return null}function D$(e,t,n){if(pe.isString(e))try{return(t||JSON.parse)(e),pe.trim(e)}catch(r){if(r.name!=="SyntaxError")throw r}return(n||JSON.stringify)(e)}const pu={transitional:Wz,adapter:["xhr","http","fetch"],transformRequest:[function(t,n){const r=n.getContentType()||"",a=r.indexOf("application/json")>-1,i=pe.isObject(t);if(i&&pe.isHTMLForm(t)&&(t=new FormData(t)),pe.isFormData(t))return a?JSON.stringify(Yz(t)):t;if(pe.isArrayBuffer(t)||pe.isBuffer(t)||pe.isStream(t)||pe.isFile(t)||pe.isBlob(t)||pe.isReadableStream(t))return t;if(pe.isArrayBufferView(t))return t.buffer;if(pe.isURLSearchParams(t))return n.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),t.toString();let u;if(i){if(r.indexOf("application/x-www-form-urlencoded")>-1)return C$(t,this.formSerializer).toString();if((u=pe.isFileList(t))||r.indexOf("multipart/form-data")>-1){const c=this.env&&this.env.FormData;return lf(u?{"files[]":t}:t,c&&new c,this.formSerializer)}}return i||a?(n.setContentType("application/json",!1),D$(t)):t}],transformResponse:[function(t){const n=this.transitional||pu.transitional,r=n&&n.forcedJSONParsing,a=this.responseType==="json";if(pe.isResponse(t)||pe.isReadableStream(t))return t;if(t&&pe.isString(t)&&(r&&!this.responseType||a)){const l=!(n&&n.silentJSONParsing)&&a;try{return JSON.parse(t)}catch(u){if(l)throw u.name==="SyntaxError"?nt.from(u,nt.ERR_BAD_RESPONSE,this,null,this.response):u}}return t}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:yn.classes.FormData,Blob:yn.classes.Blob},validateStatus:function(t){return t>=200&&t<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};pe.forEach(["delete","get","head","post","put","patch"],e=>{pu.headers[e]={}});const I$=pe.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),L$=e=>{const t={};let n,r,a;return e&&e.split(`
`).forEach(function(l){a=l.indexOf(":"),n=l.substring(0,a).trim().toLowerCase(),r=l.substring(a+1).trim(),!(!n||t[n]&&I$[n])&&(n==="set-cookie"?t[n]?t[n].push(r):t[n]=[r]:t[n]=t[n]?t[n]+", "+r:r)}),t},mR=Symbol("internals");function Ms(e){return e&&String(e).trim().toLowerCase()}function pd(e){return e===!1||e==null?e:pe.isArray(e)?e.map(pd):String(e)}function M$(e){const t=Object.create(null),n=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let r;for(;r=n.exec(e);)t[r[1]]=r[2];return t}const F$=e=>/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(e.trim());function ch(e,t,n,r,a){if(pe.isFunction(r))return r.call(this,t,n);if(a&&(t=n),!!pe.isString(t)){if(pe.isString(r))return t.indexOf(r)!==-1;if(pe.isRegExp(r))return r.test(t)}}function z$(e){return e.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(t,n,r)=>n.toUpperCase()+r)}function P$(e,t){const n=pe.toCamelCase(" "+t);["get","set","has"].forEach(r=>{Object.defineProperty(e,r+n,{value:function(a,i,l){return this[r].call(this,t,a,i,l)},configurable:!0})})}let zn=class{constructor(t){t&&this.set(t)}set(t,n,r){const a=this;function i(u,c,f){const p=Ms(c);if(!p)throw new Error("header name must be a non-empty string");const g=pe.findKey(a,p);(!g||a[g]===void 0||f===!0||f===void 0&&a[g]!==!1)&&(a[g||c]=pd(u))}const l=(u,c)=>pe.forEach(u,(f,p)=>i(f,p,c));if(pe.isPlainObject(t)||t instanceof this.constructor)l(t,n);else if(pe.isString(t)&&(t=t.trim())&&!F$(t))l(L$(t),n);else if(pe.isHeaders(t))for(const[u,c]of t.entries())i(c,u,r);else t!=null&&i(n,t,r);return this}get(t,n){if(t=Ms(t),t){const r=pe.findKey(this,t);if(r){const a=this[r];if(!n)return a;if(n===!0)return M$(a);if(pe.isFunction(n))return n.call(this,a,r);if(pe.isRegExp(n))return n.exec(a);throw new TypeError("parser must be boolean|regexp|function")}}}has(t,n){if(t=Ms(t),t){const r=pe.findKey(this,t);return!!(r&&this[r]!==void 0&&(!n||ch(this,this[r],r,n)))}return!1}delete(t,n){const r=this;let a=!1;function i(l){if(l=Ms(l),l){const u=pe.findKey(r,l);u&&(!n||ch(r,r[u],u,n))&&(delete r[u],a=!0)}}return pe.isArray(t)?t.forEach(i):i(t),a}clear(t){const n=Object.keys(this);let r=n.length,a=!1;for(;r--;){const i=n[r];(!t||ch(this,this[i],i,t,!0))&&(delete this[i],a=!0)}return a}normalize(t){const n=this,r={};return pe.forEach(this,(a,i)=>{const l=pe.findKey(r,i);if(l){n[l]=pd(a),delete n[i];return}const u=t?z$(i):String(i).trim();u!==i&&delete n[i],n[u]=pd(a),r[u]=!0}),this}concat(...t){return this.constructor.concat(this,...t)}toJSON(t){const n=Object.create(null);return pe.forEach(this,(r,a)=>{r!=null&&r!==!1&&(n[a]=t&&pe.isArray(r)?r.join(", "):r)}),n}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([t,n])=>t+": "+n).join(`
`)}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(t){return t instanceof this?t:new this(t)}static concat(t,...n){const r=new this(t);return n.forEach(a=>r.set(a)),r}static accessor(t){const r=(this[mR]=this[mR]={accessors:{}}).accessors,a=this.prototype;function i(l){const u=Ms(l);r[u]||(P$(a,l),r[u]=!0)}return pe.isArray(t)?t.forEach(i):i(t),this}};zn.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]);pe.reduceDescriptors(zn.prototype,({value:e},t)=>{let n=t[0].toUpperCase()+t.slice(1);return{get:()=>e,set(r){this[n]=r}}});pe.freezeMethods(zn);function dh(e,t){const n=this||pu,r=t||n,a=zn.from(r.headers);let i=r.data;return pe.forEach(e,function(u){i=u.call(n,i,a.normalize(),t?t.status:void 0)}),a.normalize(),i}function Kz(e){return!!(e&&e.__CANCEL__)}function _l(e,t,n){nt.call(this,e??"canceled",nt.ERR_CANCELED,t,n),this.name="CanceledError"}pe.inherits(_l,nt,{__CANCEL__:!0});function Xz(e,t,n){const r=n.config.validateStatus;!n.status||!r||r(n.status)?e(n):t(new nt("Request failed with status code "+n.status,[nt.ERR_BAD_REQUEST,nt.ERR_BAD_RESPONSE][Math.floor(n.status/100)-4],n.config,n.request,n))}function B$(e){const t=/^([-+\w]{1,25})(:?\/\/|:)/.exec(e);return t&&t[1]||""}function U$(e,t){e=e||10;const n=new Array(e),r=new Array(e);let a=0,i=0,l;return t=t!==void 0?t:1e3,function(c){const f=Date.now(),p=r[i];l||(l=f),n[a]=c,r[a]=f;let g=i,b=0;for(;g!==a;)b+=n[g++],g=g%e;if(a=(a+1)%e,a===i&&(i=(i+1)%e),f-l<t)return;const m=p&&f-p;return m?Math.round(b*1e3/m):void 0}}function j$(e,t){let n=0,r=1e3/t,a,i;const l=(f,p=Date.now())=>{n=p,a=null,i&&(clearTimeout(i),i=null),e.apply(null,f)};return[(...f)=>{const p=Date.now(),g=p-n;g>=r?l(f,p):(a=f,i||(i=setTimeout(()=>{i=null,l(a)},r-g)))},()=>a&&l(a)]}const Nd=(e,t,n=3)=>{let r=0;const a=U$(50,250);return j$(i=>{const l=i.loaded,u=i.lengthComputable?i.total:void 0,c=l-r,f=a(c),p=l<=u;r=l;const g={loaded:l,total:u,progress:u?l/u:void 0,bytes:c,rate:f||void 0,estimated:f&&u&&p?(u-l)/f:void 0,event:i,lengthComputable:u!=null,[t?"download":"upload"]:!0};e(g)},n)},bR=(e,t)=>{const n=e!=null;return[r=>t[0]({lengthComputable:n,total:e,loaded:r}),t[1]]},yR=e=>(...t)=>pe.asap(()=>e(...t)),G$=yn.hasStandardBrowserEnv?((e,t)=>n=>(n=new URL(n,yn.origin),e.protocol===n.protocol&&e.host===n.host&&(t||e.port===n.port)))(new URL(yn.origin),yn.navigator&&/(msie|trident)/i.test(yn.navigator.userAgent)):()=>!0,H$=yn.hasStandardBrowserEnv?{write(e,t,n,r,a,i){const l=[e+"="+encodeURIComponent(t)];pe.isNumber(n)&&l.push("expires="+new Date(n).toGMTString()),pe.isString(r)&&l.push("path="+r),pe.isString(a)&&l.push("domain="+a),i===!0&&l.push("secure"),document.cookie=l.join("; ")},read(e){const t=document.cookie.match(new RegExp("(^|;\\s*)("+e+")=([^;]*)"));return t?decodeURIComponent(t[3]):null},remove(e){this.write(e,"",Date.now()-864e5)}}:{write(){},read(){return null},remove(){}};function $$(e){return/^([a-z][a-z\d+\-.]*:)?\/\//i.test(e)}function q$(e,t){return t?e.replace(/\/?\/$/,"")+"/"+t.replace(/^\/+/,""):e}function Zz(e,t){return e&&!$$(t)?q$(e,t):t}const vR=e=>e instanceof zn?{...e}:e;function ri(e,t){t=t||{};const n={};function r(f,p,g,b){return pe.isPlainObject(f)&&pe.isPlainObject(p)?pe.merge.call({caseless:b},f,p):pe.isPlainObject(p)?pe.merge({},p):pe.isArray(p)?p.slice():p}function a(f,p,g,b){if(pe.isUndefined(p)){if(!pe.isUndefined(f))return r(void 0,f,g,b)}else return r(f,p,g,b)}function i(f,p){if(!pe.isUndefined(p))return r(void 0,p)}function l(f,p){if(pe.isUndefined(p)){if(!pe.isUndefined(f))return r(void 0,f)}else return r(void 0,p)}function u(f,p,g){if(g in t)return r(f,p);if(g in e)return r(void 0,f)}const c={url:i,method:i,data:i,baseURL:l,transformRequest:l,transformResponse:l,paramsSerializer:l,timeout:l,timeoutMessage:l,withCredentials:l,withXSRFToken:l,adapter:l,responseType:l,xsrfCookieName:l,xsrfHeaderName:l,onUploadProgress:l,onDownloadProgress:l,decompress:l,maxContentLength:l,maxBodyLength:l,beforeRedirect:l,transport:l,httpAgent:l,httpsAgent:l,cancelToken:l,socketPath:l,responseEncoding:l,validateStatus:u,headers:(f,p,g)=>a(vR(f),vR(p),g,!0)};return pe.forEach(Object.keys(Object.assign({},e,t)),function(p){const g=c[p]||a,b=g(e[p],t[p],p);pe.isUndefined(b)&&g!==u||(n[p]=b)}),n}const Qz=e=>{const t=ri({},e);let{data:n,withXSRFToken:r,xsrfHeaderName:a,xsrfCookieName:i,headers:l,auth:u}=t;t.headers=l=zn.from(l),t.url=Vz(Zz(t.baseURL,t.url),e.params,e.paramsSerializer),u&&l.set("Authorization","Basic "+btoa((u.username||"")+":"+(u.password?unescape(encodeURIComponent(u.password)):"")));let c;if(pe.isFormData(n)){if(yn.hasStandardBrowserEnv||yn.hasStandardBrowserWebWorkerEnv)l.setContentType(void 0);else if((c=l.getContentType())!==!1){const[f,...p]=c?c.split(";").map(g=>g.trim()).filter(Boolean):[];l.setContentType([f||"multipart/form-data",...p].join("; "))}}if(yn.hasStandardBrowserEnv&&(r&&pe.isFunction(r)&&(r=r(t)),r||r!==!1&&G$(t.url))){const f=a&&i&&H$.read(i);f&&l.set(a,f)}return t},V$=typeof XMLHttpRequest<"u",W$=V$&&function(e){return new Promise(function(n,r){const a=Qz(e);let i=a.data;const l=zn.from(a.headers).normalize();let{responseType:u,onUploadProgress:c,onDownloadProgress:f}=a,p,g,b,m,S;function v(){m&&m(),S&&S(),a.cancelToken&&a.cancelToken.unsubscribe(p),a.signal&&a.signal.removeEventListener("abort",p)}let A=new XMLHttpRequest;A.open(a.method.toUpperCase(),a.url,!0),A.timeout=a.timeout;function R(){if(!A)return;const T=zn.from("getAllResponseHeaders"in A&&A.getAllResponseHeaders()),N={data:!u||u==="text"||u==="json"?A.responseText:A.response,status:A.status,statusText:A.statusText,headers:T,config:e,request:A};Xz(function(O){n(O),v()},function(O){r(O),v()},N),A=null}"onloadend"in A?A.onloadend=R:A.onreadystatechange=function(){!A||A.readyState!==4||A.status===0&&!(A.responseURL&&A.responseURL.indexOf("file:")===0)||setTimeout(R)},A.onabort=function(){A&&(r(new nt("Request aborted",nt.ECONNABORTED,e,A)),A=null)},A.onerror=function(){r(new nt("Network Error",nt.ERR_NETWORK,e,A)),A=null},A.ontimeout=function(){let C=a.timeout?"timeout of "+a.timeout+"ms exceeded":"timeout exceeded";const N=a.transitional||Wz;a.timeoutErrorMessage&&(C=a.timeoutErrorMessage),r(new nt(C,N.clarifyTimeoutError?nt.ETIMEDOUT:nt.ECONNABORTED,e,A)),A=null},i===void 0&&l.setContentType(null),"setRequestHeader"in A&&pe.forEach(l.toJSON(),function(C,N){A.setRequestHeader(N,C)}),pe.isUndefined(a.withCredentials)||(A.withCredentials=!!a.withCredentials),u&&u!=="json"&&(A.responseType=a.responseType),f&&([b,S]=Nd(f,!0),A.addEventListener("progress",b)),c&&A.upload&&([g,m]=Nd(c),A.upload.addEventListener("progress",g),A.upload.addEventListener("loadend",m)),(a.cancelToken||a.signal)&&(p=T=>{A&&(r(!T||T.type?new _l(null,e,A):T),A.abort(),A=null)},a.cancelToken&&a.cancelToken.subscribe(p),a.signal&&(a.signal.aborted?p():a.signal.addEventListener("abort",p)));const x=B$(a.url);if(x&&yn.protocols.indexOf(x)===-1){r(new nt("Unsupported protocol "+x+":",nt.ERR_BAD_REQUEST,e));return}A.send(i||null)})},Y$=(e,t)=>{const{length:n}=e=e?e.filter(Boolean):[];if(t||n){let r=new AbortController,a;const i=function(f){if(!a){a=!0,u();const p=f instanceof Error?f:this.reason;r.abort(p instanceof nt?p:new _l(p instanceof Error?p.message:p))}};let l=t&&setTimeout(()=>{l=null,i(new nt(`timeout ${t} of ms exceeded`,nt.ETIMEDOUT))},t);const u=()=>{e&&(l&&clearTimeout(l),l=null,e.forEach(f=>{f.unsubscribe?f.unsubscribe(i):f.removeEventListener("abort",i)}),e=null)};e.forEach(f=>f.addEventListener("abort",i));const{signal:c}=r;return c.unsubscribe=()=>pe.asap(u),c}},K$=function*(e,t){let n=e.byteLength;if(n<t){yield e;return}let r=0,a;for(;r<n;)a=r+t,yield e.slice(r,a),r=a},X$=async function*(e,t){for await(const n of Z$(e))yield*K$(n,t)},Z$=async function*(e){if(e[Symbol.asyncIterator]){yield*e;return}const t=e.getReader();try{for(;;){const{done:n,value:r}=await t.read();if(n)break;yield r}}finally{await t.cancel()}},SR=(e,t,n,r)=>{const a=X$(e,t);let i=0,l,u=c=>{l||(l=!0,r&&r(c))};return new ReadableStream({async pull(c){try{const{done:f,value:p}=await a.next();if(f){u(),c.close();return}let g=p.byteLength;if(n){let b=i+=g;n(b)}c.enqueue(new Uint8Array(p))}catch(f){throw u(f),f}},cancel(c){return u(c),a.return()}},{highWaterMark:2})},sf=typeof fetch=="function"&&typeof Request=="function"&&typeof Response=="function",Jz=sf&&typeof ReadableStream=="function",Q$=sf&&(typeof TextEncoder=="function"?(e=>t=>e.encode(t))(new TextEncoder):async e=>new Uint8Array(await new Response(e).arrayBuffer())),eP=(e,...t)=>{try{return!!e(...t)}catch{return!1}},J$=Jz&&eP(()=>{let e=!1;const t=new Request(yn.origin,{body:new ReadableStream,method:"POST",get duplex(){return e=!0,"half"}}).headers.has("Content-Type");return e&&!t}),ER=64*1024,vx=Jz&&eP(()=>pe.isReadableStream(new Response("").body)),Od={stream:vx&&(e=>e.body)};sf&&(e=>{["text","arrayBuffer","blob","formData","stream"].forEach(t=>{!Od[t]&&(Od[t]=pe.isFunction(e[t])?n=>n[t]():(n,r)=>{throw new nt(`Response type '${t}' is not supported`,nt.ERR_NOT_SUPPORT,r)})})})(new Response);const eq=async e=>{if(e==null)return 0;if(pe.isBlob(e))return e.size;if(pe.isSpecCompliantForm(e))return(await new Request(yn.origin,{method:"POST",body:e}).arrayBuffer()).byteLength;if(pe.isArrayBufferView(e)||pe.isArrayBuffer(e))return e.byteLength;if(pe.isURLSearchParams(e)&&(e=e+""),pe.isString(e))return(await Q$(e)).byteLength},tq=async(e,t)=>{const n=pe.toFiniteNumber(e.getContentLength());return n??eq(t)},nq=sf&&(async e=>{let{url:t,method:n,data:r,signal:a,cancelToken:i,timeout:l,onDownloadProgress:u,onUploadProgress:c,responseType:f,headers:p,withCredentials:g="same-origin",fetchOptions:b}=Qz(e);f=f?(f+"").toLowerCase():"text";let m=Y$([a,i&&i.toAbortSignal()],l),S;const v=m&&m.unsubscribe&&(()=>{m.unsubscribe()});let A;try{if(c&&J$&&n!=="get"&&n!=="head"&&(A=await tq(p,r))!==0){let N=new Request(t,{method:"POST",body:r,duplex:"half"}),_;if(pe.isFormData(r)&&(_=N.headers.get("content-type"))&&p.setContentType(_),N.body){const[O,z]=bR(A,Nd(yR(c)));r=SR(N.body,ER,O,z)}}pe.isString(g)||(g=g?"include":"omit");const R="credentials"in Request.prototype;S=new Request(t,{...b,signal:m,method:n.toUpperCase(),headers:p.normalize().toJSON(),body:r,duplex:"half",credentials:R?g:void 0});let x=await fetch(S);const T=vx&&(f==="stream"||f==="response");if(vx&&(u||T&&v)){const N={};["status","statusText","headers"].forEach(I=>{N[I]=x[I]});const _=pe.toFiniteNumber(x.headers.get("content-length")),[O,z]=u&&bR(_,Nd(yR(u),!0))||[];x=new Response(SR(x.body,ER,O,()=>{z&&z(),v&&v()}),N)}f=f||"text";let C=await Od[pe.findKey(Od,f)||"text"](x,e);return!T&&v&&v(),await new Promise((N,_)=>{Xz(N,_,{data:C,headers:zn.from(x.headers),status:x.status,statusText:x.statusText,config:e,request:S})})}catch(R){throw v&&v(),R&&R.name==="TypeError"&&/fetch/i.test(R.message)?Object.assign(new nt("Network Error",nt.ERR_NETWORK,e,S),{cause:R.cause||R}):nt.from(R,R&&R.code,e,S)}}),Sx={http:b$,xhr:W$,fetch:nq};pe.forEach(Sx,(e,t)=>{if(e){try{Object.defineProperty(e,"name",{value:t})}catch{}Object.defineProperty(e,"adapterName",{value:t})}});const wR=e=>`- ${e}`,rq=e=>pe.isFunction(e)||e===null||e===!1,tP={getAdapter:e=>{e=pe.isArray(e)?e:[e];const{length:t}=e;let n,r;const a={};for(let i=0;i<t;i++){n=e[i];let l;if(r=n,!rq(n)&&(r=Sx[(l=String(n)).toLowerCase()],r===void 0))throw new nt(`Unknown adapter '${l}'`);if(r)break;a[l||"#"+i]=r}if(!r){const i=Object.entries(a).map(([u,c])=>`adapter ${u} `+(c===!1?"is not supported by the environment":"is not available in the build"));let l=t?i.length>1?`since :
`+i.map(wR).join(`
`):" "+wR(i[0]):"as no adapter specified";throw new nt("There is no suitable adapter to dispatch the request "+l,"ERR_NOT_SUPPORT")}return r},adapters:Sx};function fh(e){if(e.cancelToken&&e.cancelToken.throwIfRequested(),e.signal&&e.signal.aborted)throw new _l(null,e)}function xR(e){return fh(e),e.headers=zn.from(e.headers),e.data=dh.call(e,e.transformRequest),["post","put","patch"].indexOf(e.method)!==-1&&e.headers.setContentType("application/x-www-form-urlencoded",!1),tP.getAdapter(e.adapter||pu.adapter)(e).then(function(r){return fh(e),r.data=dh.call(e,e.transformResponse,r),r.headers=zn.from(r.headers),r},function(r){return Kz(r)||(fh(e),r&&r.response&&(r.response.data=dh.call(e,e.transformResponse,r.response),r.response.headers=zn.from(r.response.headers))),Promise.reject(r)})}const nP="1.7.9",uf={};["object","boolean","number","function","string","symbol"].forEach((e,t)=>{uf[e]=function(r){return typeof r===e||"a"+(t<1?"n ":" ")+e}});const kR={};uf.transitional=function(t,n,r){function a(i,l){return"[Axios v"+nP+"] Transitional option '"+i+"'"+l+(r?". "+r:"")}return(i,l,u)=>{if(t===!1)throw new nt(a(l," has been removed"+(n?" in "+n:"")),nt.ERR_DEPRECATED);return n&&!kR[l]&&(kR[l]=!0,console.warn(a(l," has been deprecated since v"+n+" and will be removed in the near future"))),t?t(i,l,u):!0}};uf.spelling=function(t){return(n,r)=>(console.warn(`${r} is likely a misspelling of ${t}`),!0)};function aq(e,t,n){if(typeof e!="object")throw new nt("options must be an object",nt.ERR_BAD_OPTION_VALUE);const r=Object.keys(e);let a=r.length;for(;a-- >0;){const i=r[a],l=t[i];if(l){const u=e[i],c=u===void 0||l(u,i,e);if(c!==!0)throw new nt("option "+i+" must be "+c,nt.ERR_BAD_OPTION_VALUE);continue}if(n!==!0)throw new nt("Unknown option "+i,nt.ERR_BAD_OPTION)}}const gd={assertOptions:aq,validators:uf},Hr=gd.validators;let ni=class{constructor(t){this.defaults=t,this.interceptors={request:new hR,response:new hR}}async request(t,n){try{return await this._request(t,n)}catch(r){if(r instanceof Error){let a={};Error.captureStackTrace?Error.captureStackTrace(a):a=new Error;const i=a.stack?a.stack.replace(/^.+\n/,""):"";try{r.stack?i&&!String(r.stack).endsWith(i.replace(/^.+\n.+\n/,""))&&(r.stack+=`
`+i):r.stack=i}catch{}}throw r}}_request(t,n){typeof t=="string"?(n=n||{},n.url=t):n=t||{},n=ri(this.defaults,n);const{transitional:r,paramsSerializer:a,headers:i}=n;r!==void 0&&gd.assertOptions(r,{silentJSONParsing:Hr.transitional(Hr.boolean),forcedJSONParsing:Hr.transitional(Hr.boolean),clarifyTimeoutError:Hr.transitional(Hr.boolean)},!1),a!=null&&(pe.isFunction(a)?n.paramsSerializer={serialize:a}:gd.assertOptions(a,{encode:Hr.function,serialize:Hr.function},!0)),gd.assertOptions(n,{baseUrl:Hr.spelling("baseURL"),withXsrfToken:Hr.spelling("withXSRFToken")},!0),n.method=(n.method||this.defaults.method||"get").toLowerCase();let l=i&&pe.merge(i.common,i[n.method]);i&&pe.forEach(["delete","get","head","post","put","patch","common"],S=>{delete i[S]}),n.headers=zn.concat(l,i);const u=[];let c=!0;this.interceptors.request.forEach(function(v){typeof v.runWhen=="function"&&v.runWhen(n)===!1||(c=c&&v.synchronous,u.unshift(v.fulfilled,v.rejected))});const f=[];this.interceptors.response.forEach(function(v){f.push(v.fulfilled,v.rejected)});let p,g=0,b;if(!c){const S=[xR.bind(this),void 0];for(S.unshift.apply(S,u),S.push.apply(S,f),b=S.length,p=Promise.resolve(n);g<b;)p=p.then(S[g++],S[g++]);return p}b=u.length;let m=n;for(g=0;g<b;){const S=u[g++],v=u[g++];try{m=S(m)}catch(A){v.call(this,A);break}}try{p=xR.call(this,m)}catch(S){return Promise.reject(S)}for(g=0,b=f.length;g<b;)p=p.then(f[g++],f[g++]);return p}getUri(t){t=ri(this.defaults,t);const n=Zz(t.baseURL,t.url);return Vz(n,t.params,t.paramsSerializer)}};pe.forEach(["delete","get","head","options"],function(t){ni.prototype[t]=function(n,r){return this.request(ri(r||{},{method:t,url:n,data:(r||{}).data}))}});pe.forEach(["post","put","patch"],function(t){function n(r){return function(i,l,u){return this.request(ri(u||{},{method:t,headers:r?{"Content-Type":"multipart/form-data"}:{},url:i,data:l}))}}ni.prototype[t]=n(),ni.prototype[t+"Form"]=n(!0)});let oq=class rP{constructor(t){if(typeof t!="function")throw new TypeError("executor must be a function.");let n;this.promise=new Promise(function(i){n=i});const r=this;this.promise.then(a=>{if(!r._listeners)return;let i=r._listeners.length;for(;i-- >0;)r._listeners[i](a);r._listeners=null}),this.promise.then=a=>{let i;const l=new Promise(u=>{r.subscribe(u),i=u}).then(a);return l.cancel=function(){r.unsubscribe(i)},l},t(function(i,l,u){r.reason||(r.reason=new _l(i,l,u),n(r.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(t){if(this.reason){t(this.reason);return}this._listeners?this._listeners.push(t):this._listeners=[t]}unsubscribe(t){if(!this._listeners)return;const n=this._listeners.indexOf(t);n!==-1&&this._listeners.splice(n,1)}toAbortSignal(){const t=new AbortController,n=r=>{t.abort(r)};return this.subscribe(n),t.signal.unsubscribe=()=>this.unsubscribe(n),t.signal}static source(){let t;return{token:new rP(function(a){t=a}),cancel:t}}};function iq(e){return function(n){return e.apply(null,n)}}function lq(e){return pe.isObject(e)&&e.isAxiosError===!0}const Ex={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(Ex).forEach(([e,t])=>{Ex[t]=e});function aP(e){const t=new ni(e),n=Lz(ni.prototype.request,t);return pe.extend(n,ni.prototype,t,{allOwnKeys:!0}),pe.extend(n,t,null,{allOwnKeys:!0}),n.create=function(a){return aP(ri(e,a))},n}const $t=aP(pu);$t.Axios=ni;$t.CanceledError=_l;$t.CancelToken=oq;$t.isCancel=Kz;$t.VERSION=nP;$t.toFormData=lf;$t.AxiosError=nt;$t.Cancel=$t.CanceledError;$t.all=function(t){return Promise.all(t)};$t.spread=iq;$t.isAxiosError=lq;$t.mergeConfig=ri;$t.AxiosHeaders=zn;$t.formToJSON=e=>Yz(pe.isHTMLForm(e)?new FormData(e):e);$t.getAdapter=tP.getAdapter;$t.HttpStatusCode=Ex;$t.default=$t;const{Axios:Fye,AxiosError:zye,CanceledError:Pye,isCancel:Bye,CancelToken:Uye,VERSION:jye,all:Gye,Cancel:Hye,isAxiosError:$ye,spread:qye,toFormData:Vye,AxiosHeaders:Wye,HttpStatusCode:Yye,formToJSON:Kye,getAdapter:Xye,mergeConfig:Zye}=$t,oP="Invalid API Key",iP="API Key required",Mr=$t.create({baseURL:Rz,headers:{"Content-Type":"application/json"}});Mr.interceptors.request.use(e=>{const t=We.getState().apiKey;return t&&(e.headers["X-API-Key"]=t),e});Mr.interceptors.response.use(e=>e,e=>{var t;throw e.response?new Error(`${e.response.status} ${e.response.statusText}
${JSON.stringify(e.response.data)}
${(t=e.config)==null?void 0:t.url}`):e});const sq=async(e,t,n)=>(await Mr.get(`/graphs?label=${encodeURIComponent(e)}&max_depth=${t}&min_degree=${n}`)).data,uq=async()=>(await Mr.get("/graph/label/list")).data,cq=async()=>{try{return(await Mr.get("/health")).data}catch(e){return{status:"error",message:Nr(e)}}},dq=async()=>(await Mr.get("/documents")).data,fq=async()=>(await Mr.post("/documents/scan")).data,pq=async e=>(await Mr.post("/query",e)).data,gq=async(e,t,n)=>{try{let r="";if(await Mr.post("/query/stream",e,{responseType:"text",headers:{Accept:"application/x-ndjson"},transformResponse:[a=>{r+=a;const i=r.split(`
`);r=i.pop()||"";for(const l of i)if(l.trim())try{const u=JSON.parse(l);u.response?t(u.response):u.error&&n&&n(u.error)}catch(u){console.error("Error parsing stream chunk:",u),n&&n("Error parsing server response")}return a}]}).catch(a=>{n&&n(Nr(a))}),r.trim())try{const a=JSON.parse(r);a.response?t(a.response):a.error&&n&&n(a.error)}catch(a){console.error("Error parsing final chunk:",a),n&&n("Error parsing server response")}}catch(r){const a=Nr(r);console.error("Stream request failed:",a),n&&n(a)}},hq=async(e,t)=>{const n=new FormData;return n.append("file",e),(await Mr.post("/documents/upload",n,{headers:{"Content-Type":"multipart/form-data"},onUploadProgress:t!==void 0?a=>{const i=Math.round(a.loaded*100/a.total);t(i)}:void 0})).data},mq=async()=>(await Mr.delete("/documents")).data,bq=xk()(e=>({health:!0,message:null,messageTitle:null,lastCheckTime:Date.now(),status:null,check:async()=>{const t=await cq();return t.status==="healthy"?(e({health:!0,message:null,messageTitle:null,lastCheckTime:Date.now(),status:t}),!0):(e({health:!1,message:t.message,messageTitle:"Backend Health Check Error!",lastCheckTime:Date.now(),status:null}),!1)},clear:()=>{e({health:!0,message:null,messageTitle:null})},setErrorMessage:(t,n)=>{e({health:!1,message:t,messageTitle:n})}})),Pn=Tk(bq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const yq=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),lP=(...e)=>e.filter((t,n,r)=>!!t&&t.trim()!==""&&r.indexOf(t)===n).join(" ").trim();/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var vq={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Sq=k.forwardRef(({color:e="currentColor",size:t=24,strokeWidth:n=2,absoluteStrokeWidth:r,className:a="",children:i,iconNode:l,...u},c)=>k.createElement("svg",{ref:c,...vq,width:t,height:t,stroke:e,strokeWidth:r?Number(n)*24/Number(t):n,className:lP("lucide",a),...u},[...l.map(([f,p])=>k.createElement(f,p)),...Array.isArray(i)?i:[i]]));/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const xt=(e,t)=>{const n=k.forwardRef(({className:r,...a},i)=>k.createElement(Sq,{ref:i,iconNode:t,className:lP(`lucide-${yq(e)}`,r),...a}));return n.displayName=`${e}`,n};/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Eq=[["path",{d:"M20 6 9 17l-5-5",key:"1gmf2c"}]],Nk=xt("Check",Eq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const wq=[["path",{d:"m6 9 6 6 6-6",key:"qrunsl"}]],Ok=xt("ChevronDown",wq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const xq=[["path",{d:"m18 15-6-6-6 6",key:"153udz"}]],sP=xt("ChevronUp",xq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const kq=[["path",{d:"m7 15 5 5 5-5",key:"1hf1tw"}],["path",{d:"m7 9 5-5 5 5",key:"sgt6xg"}]],Aq=xt("ChevronsUpDown",kq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Tq=[["circle",{cx:"12",cy:"12",r:"10",key:"1mglay"}],["line",{x1:"12",x2:"12",y1:"8",y2:"12",key:"1pkeuh"}],["line",{x1:"12",x2:"12.01",y1:"16",y2:"16",key:"4dfq90"}]],_q=xt("CircleAlert",Tq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Rq=[["rect",{width:"14",height:"14",x:"8",y:"8",rx:"2",ry:"2",key:"17jyea"}],["path",{d:"M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2",key:"zix9uf"}]],Cq=xt("Copy",Rq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Nq=[["path",{d:"m7 21-4.3-4.3c-1-1-1-2.5 0-3.4l9.6-9.6c1-1 2.5-1 3.4 0l5.6 5.6c1 1 1 2.5 0 3.4L13 21",key:"182aya"}],["path",{d:"M22 21H7",key:"t4ddhn"}],["path",{d:"m5 11 9 9",key:"1mo9qw"}]],uP=xt("Eraser",Nq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Oq=[["path",{d:"M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z",key:"1rqfz7"}],["path",{d:"M14 2v4a2 2 0 0 0 2 2h4",key:"tnqrlb"}],["path",{d:"M10 9H8",key:"b1mrlr"}],["path",{d:"M16 13H8",key:"t4e002"}],["path",{d:"M16 17H8",key:"z1uh3a"}]],Dq=xt("FileText",Oq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Iq=[["path",{d:"M20 7h-3a2 2 0 0 1-2-2V2",key:"x099mo"}],["path",{d:"M9 18a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h7l4 4v10a2 2 0 0 1-2 2Z",key:"18t6ie"}],["path",{d:"M3 7.6v12.8A1.6 1.6 0 0 0 4.6 22h9.8",key:"1nja0z"}]],Lq=xt("Files",Iq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Mq=[["path",{d:"M3 7V5a2 2 0 0 1 2-2h2",key:"aa7l1z"}],["path",{d:"M17 3h2a2 2 0 0 1 2 2v2",key:"4qcy5o"}],["path",{d:"M21 17v2a2 2 0 0 1-2 2h-2",key:"6vwrx8"}],["path",{d:"M7 21H5a2 2 0 0 1-2-2v-2",key:"ioqczr"}],["rect",{width:"10",height:"8",x:"7",y:"8",rx:"1",key:"vys8me"}]],Fq=xt("Fullscreen",Mq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const zq=[["path",{d:"M15 22v-4a4.8 4.8 0 0 0-1-3.5c3 0 6-2 6-5.5.08-1.25-.27-2.48-1-3.5.28-1.15.28-2.35 0-3.5 0 0-1 0-3 1.5-2.64-.5-5.36-.5-8 0C6 2 5 2 5 2c-.3 1.15-.3 2.35 0 3.5A5.403 5.403 0 0 0 4 9c0 3.5 3 5.5 6 5.5-.39.49-.68 1.05-.85 1.65-.17.6-.22 1.23-.15 1.85v4",key:"tonef"}],["path",{d:"M9 18c-4.51 2-5-2-7-2",key:"9comsn"}]],Pq=xt("Github",zq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Bq=[["circle",{cx:"12",cy:"5",r:"1",key:"gxeob9"}],["circle",{cx:"19",cy:"5",r:"1",key:"w8mnmm"}],["circle",{cx:"5",cy:"5",r:"1",key:"lttvr7"}],["circle",{cx:"12",cy:"12",r:"1",key:"41hilf"}],["circle",{cx:"19",cy:"12",r:"1",key:"1wjl8i"}],["circle",{cx:"5",cy:"12",r:"1",key:"1pcz8c"}],["circle",{cx:"12",cy:"19",r:"1",key:"lyex9k"}],["circle",{cx:"19",cy:"19",r:"1",key:"shf9b7"}],["circle",{cx:"5",cy:"19",r:"1",key:"bfqh0e"}]],Uq=xt("Grip",Bq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const jq=[["path",{d:"M21 12a9 9 0 1 1-6.219-8.56",key:"13zald"}]],cP=xt("LoaderCircle",jq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Gq=[["path",{d:"M12 2v4",key:"3427ic"}],["path",{d:"m16.2 7.8 2.9-2.9",key:"r700ao"}],["path",{d:"M18 12h4",key:"wj9ykh"}],["path",{d:"m16.2 16.2 2.9 2.9",key:"1bxg5t"}],["path",{d:"M12 18v4",key:"jadmvz"}],["path",{d:"m4.9 19.1 2.9-2.9",key:"bwix9q"}],["path",{d:"M2 12h4",key:"j09sii"}],["path",{d:"m4.9 4.9 2.9 2.9",key:"giyufr"}]],Hq=xt("Loader",Gq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const $q=[["path",{d:"M8 3H5a2 2 0 0 0-2 2v3",key:"1dcmit"}],["path",{d:"M21 8V5a2 2 0 0 0-2-2h-3",key:"1e4gt3"}],["path",{d:"M3 16v3a2 2 0 0 0 2 2h3",key:"wsl5sc"}],["path",{d:"M16 21h3a2 2 0 0 0 2-2v-3",key:"18trek"}]],qq=xt("Maximize",$q);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Vq=[["path",{d:"M8 3v3a2 2 0 0 1-2 2H3",key:"hohbtr"}],["path",{d:"M21 8h-3a2 2 0 0 1-2-2V3",key:"5jw1f3"}],["path",{d:"M3 16h3a2 2 0 0 1 2 2v3",key:"198tvr"}],["path",{d:"M16 21v-3a2 2 0 0 1 2-2h3",key:"ph8mxp"}]],Wq=xt("Minimize",Vq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Yq=[["path",{d:"M12 3a6 6 0 0 0 9 9 9 9 0 1 1-9-9Z",key:"a7tn18"}]],Kq=xt("Moon",Yq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Xq=[["rect",{x:"14",y:"4",width:"4",height:"16",rx:"1",key:"zuxfzm"}],["rect",{x:"6",y:"4",width:"4",height:"16",rx:"1",key:"1okwgv"}]],Zq=xt("Pause",Xq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const Qq=[["polygon",{points:"6 3 20 12 6 21 6 3",key:"1oa8hb"}]],Jq=xt("Play",Qq);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const e8=[["path",{d:"M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8",key:"v9h5vc"}],["path",{d:"M21 3v5h-5",key:"1q7to0"}],["path",{d:"M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16",key:"3uifl3"}],["path",{d:"M8 16H3v5",key:"1cv678"}]],t8=xt("RefreshCw",e8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const n8=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["path",{d:"m21 21-4.3-4.3",key:"1qie3q"}]],r8=xt("Search",n8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const a8=[["path",{d:"M14.536 21.686a.5.5 0 0 0 .937-.024l6.5-19a.496.496 0 0 0-.635-.635l-19 6.5a.5.5 0 0 0-.024.937l7.93 3.18a2 2 0 0 1 1.112 1.11z",key:"1ffxy3"}],["path",{d:"m21.854 2.147-10.94 10.939",key:"12cjpa"}]],o8=xt("Send",a8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const i8=[["path",{d:"M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z",key:"1qme2f"}],["circle",{cx:"12",cy:"12",r:"3",key:"1v7zrd"}]],l8=xt("Settings",i8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const s8=[["circle",{cx:"12",cy:"12",r:"4",key:"4exip2"}],["path",{d:"M12 2v2",key:"tus03m"}],["path",{d:"M12 20v2",key:"1lh1kg"}],["path",{d:"m4.93 4.93 1.41 1.41",key:"149t6j"}],["path",{d:"m17.66 17.66 1.41 1.41",key:"ptbguv"}],["path",{d:"M2 12h2",key:"1t8f8n"}],["path",{d:"M20 12h2",key:"1q8mjw"}],["path",{d:"m6.34 17.66-1.41 1.41",key:"1m8zz5"}],["path",{d:"m19.07 4.93-1.41 1.41",key:"1shlcs"}]],u8=xt("Sun",s8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const c8=[["path",{d:"M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4",key:"ih7n3h"}],["polyline",{points:"17 8 12 3 7 8",key:"t8dd8p"}],["line",{x1:"12",x2:"12",y1:"3",y2:"15",key:"widbto"}]],wx=xt("Upload",c8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const d8=[["path",{d:"M18 6 6 18",key:"1bl5f8"}],["path",{d:"m6 6 12 12",key:"d8bk6v"}]],dP=xt("X",d8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const f8=[["path",{d:"M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",key:"1xq2db"}]],p8=xt("Zap",f8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const g8=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["line",{x1:"21",x2:"16.65",y1:"21",y2:"16.65",key:"13gj7c"}],["line",{x1:"11",x2:"11",y1:"8",y2:"14",key:"1vmskp"}],["line",{x1:"8",x2:"14",y1:"11",y2:"11",key:"durymu"}]],h8=xt("ZoomIn",g8);/**
 * @license lucide-react v0.475.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */const m8=[["circle",{cx:"11",cy:"11",r:"8",key:"4ej97u"}],["line",{x1:"21",x2:"16.65",y1:"21",y2:"16.65",key:"13gj7c"}],["line",{x1:"8",x2:"14",y1:"11",y2:"11",key:"durymu"}]],b8=xt("ZoomOut",m8),y8=()=>{const e=Pn.use.health(),t=Pn.use.message(),n=Pn.use.messageTitle(),[r,a]=k.useState(!1);return k.useEffect(()=>{setTimeout(()=>{a(!0)},50)},[]),w.jsxs(Oz,{className:Me("bg-background/90 absolute top-12 left-1/2 flex w-auto max-w-lg -translate-x-1/2 transform items-center gap-4 shadow-md backdrop-blur-lg transition-all duration-500 ease-in-out",r?"translate-y-0 opacity-100":"-translate-y-20 opacity-0",!e&&"bg-red-700 text-white"),children:[!e&&w.jsx("div",{children:w.jsx(_q,{className:"size-4"})}),w.jsxs("div",{children:[w.jsx(Dz,{className:"font-bold",children:n}),w.jsx(Iz,{children:t})]})]})};function v8(e,t){const n=k.createContext(t),r=i=>{const{children:l,...u}=i,c=k.useMemo(()=>u,Object.values(u));return w.jsx(n.Provider,{value:c,children:l})};r.displayName=e+"Provider";function a(i){const l=k.useContext(n);if(l)return l;if(t!==void 0)return t;throw new Error(`\`${i}\` must be used within \`${e}\``)}return[r,a]}function mr(e,t=[]){let n=[];function r(i,l){const u=k.createContext(l),c=n.length;n=[...n,l];const f=g=>{var R;const{scope:b,children:m,...S}=g,v=((R=b==null?void 0:b[e])==null?void 0:R[c])||u,A=k.useMemo(()=>S,Object.values(S));return w.jsx(v.Provider,{value:A,children:m})};f.displayName=i+"Provider";function p(g,b){var v;const m=((v=b==null?void 0:b[e])==null?void 0:v[c])||u,S=k.useContext(m);if(S)return S;if(l!==void 0)return l;throw new Error(`\`${g}\` must be used within \`${i}\``)}return[f,p]}const a=()=>{const i=n.map(l=>k.createContext(l));return function(u){const c=(u==null?void 0:u[e])||i;return k.useMemo(()=>({[`__scope${e}`]:{...u,[e]:c}}),[u,c])}};return a.scopeName=e,[r,S8(a,...t)]}function S8(...e){const t=e[0];if(e.length===1)return t;const n=()=>{const r=e.map(a=>({useScope:a(),scopeName:a.scopeName}));return function(i){const l=r.reduce((u,{useScope:c,scopeName:f})=>{const g=c(i)[`__scope${f}`];return{...u,...g}},{});return k.useMemo(()=>({[`__scope${t.scopeName}`]:l}),[l])}};return n.scopeName=t.scopeName,n}function AR(e,t){if(typeof e=="function")return e(t);e!=null&&(e.current=t)}function fP(...e){return t=>{let n=!1;const r=e.map(a=>{const i=AR(a,t);return!n&&typeof i=="function"&&(n=!0),i});if(n)return()=>{for(let a=0;a<r.length;a++){const i=r[a];typeof i=="function"?i():AR(e[a],null)}}}}function ft(...e){return k.useCallback(fP(...e),e)}function Ye(e,t,{checkForDefaultPrevented:n=!0}={}){return function(a){if(e==null||e(a),n===!1||!a.defaultPrevented)return t==null?void 0:t(a)}}var wn=globalThis!=null&&globalThis.document?k.useLayoutEffect:()=>{},E8=bH.useId||(()=>{}),w8=0;function En(e){const[t,n]=k.useState(E8());return wn(()=>{n(r=>r??String(w8++))},[e]),t?`radix-${t}`:""}function pn(e){const t=k.useRef(e);return k.useEffect(()=>{t.current=e}),k.useMemo(()=>(...n)=>{var r;return(r=t.current)==null?void 0:r.call(t,...n)},[])}function Oa({prop:e,defaultProp:t,onChange:n=()=>{}}){const[r,a]=x8({defaultProp:t,onChange:n}),i=e!==void 0,l=i?e:r,u=pn(n),c=k.useCallback(f=>{if(i){const g=typeof f=="function"?f(e):f;g!==e&&u(g)}else a(f)},[i,e,a,u]);return[l,c]}function x8({defaultProp:e,onChange:t}){const n=k.useState(e),[r]=n,a=k.useRef(r),i=pn(t);return k.useEffect(()=>{a.current!==r&&(i(r),a.current=r)},[r,a,i]),n}var gu=mz();const pP=an(gu);var bo=k.forwardRef((e,t)=>{const{children:n,...r}=e,a=k.Children.toArray(n),i=a.find(k8);if(i){const l=i.props.children,u=a.map(c=>c===i?k.Children.count(l)>1?k.Children.only(null):k.isValidElement(l)?l.props.children:null:c);return w.jsx(xx,{...r,ref:t,children:k.isValidElement(l)?k.cloneElement(l,void 0,u):null})}return w.jsx(xx,{...r,ref:t,children:n})});bo.displayName="Slot";var xx=k.forwardRef((e,t)=>{const{children:n,...r}=e;if(k.isValidElement(n)){const a=T8(n),i=A8(r,n.props);return n.type!==k.Fragment&&(i.ref=t?fP(t,a):a),k.cloneElement(n,i)}return k.Children.count(n)>1?k.Children.only(null):null});xx.displayName="SlotClone";var Dk=({children:e})=>w.jsx(w.Fragment,{children:e});function k8(e){return k.isValidElement(e)&&e.type===Dk}function A8(e,t){const n={...t};for(const r in t){const a=e[r],i=t[r];/^on[A-Z]/.test(r)?a&&i?n[r]=(...u)=>{i(...u),a(...u)}:a&&(n[r]=a):r==="style"?n[r]={...a,...i}:r==="className"&&(n[r]=[a,i].filter(Boolean).join(" "))}return{...e,...n}}function T8(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var _8=["a","button","div","form","h2","h3","img","input","label","li","nav","ol","p","span","svg","ul"],Xe=_8.reduce((e,t)=>{const n=k.forwardRef((r,a)=>{const{asChild:i,...l}=r,u=i?bo:t;return typeof window<"u"&&(window[Symbol.for("radix-ui")]=!0),w.jsx(u,{...l,ref:a})});return n.displayName=`Primitive.${t}`,{...e,[t]:n}},{});function R8(e,t){e&&gu.flushSync(()=>e.dispatchEvent(t))}function C8(e,t=globalThis==null?void 0:globalThis.document){const n=pn(e);k.useEffect(()=>{const r=a=>{a.key==="Escape"&&n(a)};return t.addEventListener("keydown",r,{capture:!0}),()=>t.removeEventListener("keydown",r,{capture:!0})},[n,t])}var N8="DismissableLayer",kx="dismissableLayer.update",O8="dismissableLayer.pointerDownOutside",D8="dismissableLayer.focusOutside",TR,gP=k.createContext({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),hu=k.forwardRef((e,t)=>{const{disableOutsidePointerEvents:n=!1,onEscapeKeyDown:r,onPointerDownOutside:a,onFocusOutside:i,onInteractOutside:l,onDismiss:u,...c}=e,f=k.useContext(gP),[p,g]=k.useState(null),b=(p==null?void 0:p.ownerDocument)??(globalThis==null?void 0:globalThis.document),[,m]=k.useState({}),S=ft(t,O=>g(O)),v=Array.from(f.layers),[A]=[...f.layersWithOutsidePointerEventsDisabled].slice(-1),R=v.indexOf(A),x=p?v.indexOf(p):-1,T=f.layersWithOutsidePointerEventsDisabled.size>0,C=x>=R,N=M8(O=>{const z=O.target,I=[...f.branches].some(M=>M.contains(z));!C||I||(a==null||a(O),l==null||l(O),O.defaultPrevented||u==null||u())},b),_=F8(O=>{const z=O.target;[...f.branches].some(M=>M.contains(z))||(i==null||i(O),l==null||l(O),O.defaultPrevented||u==null||u())},b);return C8(O=>{x===f.layers.size-1&&(r==null||r(O),!O.defaultPrevented&&u&&(O.preventDefault(),u()))},b),k.useEffect(()=>{if(p)return n&&(f.layersWithOutsidePointerEventsDisabled.size===0&&(TR=b.body.style.pointerEvents,b.body.style.pointerEvents="none"),f.layersWithOutsidePointerEventsDisabled.add(p)),f.layers.add(p),_R(),()=>{n&&f.layersWithOutsidePointerEventsDisabled.size===1&&(b.body.style.pointerEvents=TR)}},[p,b,n,f]),k.useEffect(()=>()=>{p&&(f.layers.delete(p),f.layersWithOutsidePointerEventsDisabled.delete(p),_R())},[p,f]),k.useEffect(()=>{const O=()=>m({});return document.addEventListener(kx,O),()=>document.removeEventListener(kx,O)},[]),w.jsx(Xe.div,{...c,ref:S,style:{pointerEvents:T?C?"auto":"none":void 0,...e.style},onFocusCapture:Ye(e.onFocusCapture,_.onFocusCapture),onBlurCapture:Ye(e.onBlurCapture,_.onBlurCapture),onPointerDownCapture:Ye(e.onPointerDownCapture,N.onPointerDownCapture)})});hu.displayName=N8;var I8="DismissableLayerBranch",L8=k.forwardRef((e,t)=>{const n=k.useContext(gP),r=k.useRef(null),a=ft(t,r);return k.useEffect(()=>{const i=r.current;if(i)return n.branches.add(i),()=>{n.branches.delete(i)}},[n.branches]),w.jsx(Xe.div,{...e,ref:a})});L8.displayName=I8;function M8(e,t=globalThis==null?void 0:globalThis.document){const n=pn(e),r=k.useRef(!1),a=k.useRef(()=>{});return k.useEffect(()=>{const i=u=>{if(u.target&&!r.current){let c=function(){hP(O8,n,f,{discrete:!0})};const f={originalEvent:u};u.pointerType==="touch"?(t.removeEventListener("click",a.current),a.current=c,t.addEventListener("click",a.current,{once:!0})):c()}else t.removeEventListener("click",a.current);r.current=!1},l=window.setTimeout(()=>{t.addEventListener("pointerdown",i)},0);return()=>{window.clearTimeout(l),t.removeEventListener("pointerdown",i),t.removeEventListener("click",a.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}function F8(e,t=globalThis==null?void 0:globalThis.document){const n=pn(e),r=k.useRef(!1);return k.useEffect(()=>{const a=i=>{i.target&&!r.current&&hP(D8,n,{originalEvent:i},{discrete:!1})};return t.addEventListener("focusin",a),()=>t.removeEventListener("focusin",a)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}function _R(){const e=new CustomEvent(kx);document.dispatchEvent(e)}function hP(e,t,n,{discrete:r}){const a=n.originalEvent.target,i=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&a.addEventListener(e,t,{once:!0}),r?R8(a,i):a.dispatchEvent(i)}var ph="focusScope.autoFocusOnMount",gh="focusScope.autoFocusOnUnmount",RR={bubbles:!1,cancelable:!0},z8="FocusScope",cf=k.forwardRef((e,t)=>{const{loop:n=!1,trapped:r=!1,onMountAutoFocus:a,onUnmountAutoFocus:i,...l}=e,[u,c]=k.useState(null),f=pn(a),p=pn(i),g=k.useRef(null),b=ft(t,v=>c(v)),m=k.useRef({paused:!1,pause(){this.paused=!0},resume(){this.paused=!1}}).current;k.useEffect(()=>{if(r){let v=function(T){if(m.paused||!u)return;const C=T.target;u.contains(C)?g.current=C:co(g.current,{select:!0})},A=function(T){if(m.paused||!u)return;const C=T.relatedTarget;C!==null&&(u.contains(C)||co(g.current,{select:!0}))},R=function(T){if(document.activeElement===document.body)for(const N of T)N.removedNodes.length>0&&co(u)};document.addEventListener("focusin",v),document.addEventListener("focusout",A);const x=new MutationObserver(R);return u&&x.observe(u,{childList:!0,subtree:!0}),()=>{document.removeEventListener("focusin",v),document.removeEventListener("focusout",A),x.disconnect()}}},[r,u,m.paused]),k.useEffect(()=>{if(u){NR.add(m);const v=document.activeElement;if(!u.contains(v)){const R=new CustomEvent(ph,RR);u.addEventListener(ph,f),u.dispatchEvent(R),R.defaultPrevented||(P8(H8(mP(u)),{select:!0}),document.activeElement===v&&co(u))}return()=>{u.removeEventListener(ph,f),setTimeout(()=>{const R=new CustomEvent(gh,RR);u.addEventListener(gh,p),u.dispatchEvent(R),R.defaultPrevented||co(v??document.body,{select:!0}),u.removeEventListener(gh,p),NR.remove(m)},0)}}},[u,f,p,m]);const S=k.useCallback(v=>{if(!n&&!r||m.paused)return;const A=v.key==="Tab"&&!v.altKey&&!v.ctrlKey&&!v.metaKey,R=document.activeElement;if(A&&R){const x=v.currentTarget,[T,C]=B8(x);T&&C?!v.shiftKey&&R===C?(v.preventDefault(),n&&co(T,{select:!0})):v.shiftKey&&R===T&&(v.preventDefault(),n&&co(C,{select:!0})):R===x&&v.preventDefault()}},[n,r,m.paused]);return w.jsx(Xe.div,{tabIndex:-1,...l,ref:b,onKeyDown:S})});cf.displayName=z8;function P8(e,{select:t=!1}={}){const n=document.activeElement;for(const r of e)if(co(r,{select:t}),document.activeElement!==n)return}function B8(e){const t=mP(e),n=CR(t,e),r=CR(t.reverse(),e);return[n,r]}function mP(e){const t=[],n=document.createTreeWalker(e,NodeFilter.SHOW_ELEMENT,{acceptNode:r=>{const a=r.tagName==="INPUT"&&r.type==="hidden";return r.disabled||r.hidden||a?NodeFilter.FILTER_SKIP:r.tabIndex>=0?NodeFilter.FILTER_ACCEPT:NodeFilter.FILTER_SKIP}});for(;n.nextNode();)t.push(n.currentNode);return t}function CR(e,t){for(const n of e)if(!U8(n,{upTo:t}))return n}function U8(e,{upTo:t}){if(getComputedStyle(e).visibility==="hidden")return!0;for(;e;){if(t!==void 0&&e===t)return!1;if(getComputedStyle(e).display==="none")return!0;e=e.parentElement}return!1}function j8(e){return e instanceof HTMLInputElement&&"select"in e}function co(e,{select:t=!1}={}){if(e&&e.focus){const n=document.activeElement;e.focus({preventScroll:!0}),e!==n&&j8(e)&&t&&e.select()}}var NR=G8();function G8(){let e=[];return{add(t){const n=e[0];t!==n&&(n==null||n.pause()),e=OR(e,t),e.unshift(t)},remove(t){var n;e=OR(e,t),(n=e[0])==null||n.resume()}}}function OR(e,t){const n=[...e],r=n.indexOf(t);return r!==-1&&n.splice(r,1),n}function H8(e){return e.filter(t=>t.tagName!=="A")}var $8="Portal",df=k.forwardRef((e,t)=>{var u;const{container:n,...r}=e,[a,i]=k.useState(!1);wn(()=>i(!0),[]);const l=n||a&&((u=globalThis==null?void 0:globalThis.document)==null?void 0:u.body);return l?pP.createPortal(w.jsx(Xe.div,{...r,ref:t}),l):null});df.displayName=$8;function q8(e,t){return k.useReducer((n,r)=>t[n][r]??n,e)}var Jn=e=>{const{present:t,children:n}=e,r=V8(t),a=typeof n=="function"?n({present:r.isPresent}):k.Children.only(n),i=ft(r.ref,W8(a));return typeof n=="function"||r.isPresent?k.cloneElement(a,{ref:i}):null};Jn.displayName="Presence";function V8(e){const[t,n]=k.useState(),r=k.useRef({}),a=k.useRef(e),i=k.useRef("none"),l=e?"mounted":"unmounted",[u,c]=q8(l,{mounted:{UNMOUNT:"unmounted",ANIMATION_OUT:"unmountSuspended"},unmountSuspended:{MOUNT:"mounted",ANIMATION_END:"unmounted"},unmounted:{MOUNT:"mounted"}});return k.useEffect(()=>{const f=Pc(r.current);i.current=u==="mounted"?f:"none"},[u]),wn(()=>{const f=r.current,p=a.current;if(p!==e){const b=i.current,m=Pc(f);e?c("MOUNT"):m==="none"||(f==null?void 0:f.display)==="none"?c("UNMOUNT"):c(p&&b!==m?"ANIMATION_OUT":"UNMOUNT"),a.current=e}},[e,c]),wn(()=>{if(t){let f;const p=t.ownerDocument.defaultView??window,g=m=>{const v=Pc(r.current).includes(m.animationName);if(m.target===t&&v&&(c("ANIMATION_END"),!a.current)){const A=t.style.animationFillMode;t.style.animationFillMode="forwards",f=p.setTimeout(()=>{t.style.animationFillMode==="forwards"&&(t.style.animationFillMode=A)})}},b=m=>{m.target===t&&(i.current=Pc(r.current))};return t.addEventListener("animationstart",b),t.addEventListener("animationcancel",g),t.addEventListener("animationend",g),()=>{p.clearTimeout(f),t.removeEventListener("animationstart",b),t.removeEventListener("animationcancel",g),t.removeEventListener("animationend",g)}}else c("ANIMATION_END")},[t,c]),{isPresent:["mounted","unmountSuspended"].includes(u),ref:k.useCallback(f=>{f&&(r.current=getComputedStyle(f)),n(f)},[])}}function Pc(e){return(e==null?void 0:e.animationName)||"none"}function W8(e){var r,a;let t=(r=Object.getOwnPropertyDescriptor(e.props,"ref"))==null?void 0:r.get,n=t&&"isReactWarning"in t&&t.isReactWarning;return n?e.ref:(t=(a=Object.getOwnPropertyDescriptor(e,"ref"))==null?void 0:a.get,n=t&&"isReactWarning"in t&&t.isReactWarning,n?e.props.ref:e.props.ref||e.ref)}var hh=0;function Ik(){k.useEffect(()=>{const e=document.querySelectorAll("[data-radix-focus-guard]");return document.body.insertAdjacentElement("afterbegin",e[0]??DR()),document.body.insertAdjacentElement("beforeend",e[1]??DR()),hh++,()=>{hh===1&&document.querySelectorAll("[data-radix-focus-guard]").forEach(t=>t.remove()),hh--}},[])}function DR(){const e=document.createElement("span");return e.setAttribute("data-radix-focus-guard",""),e.tabIndex=0,e.style.outline="none",e.style.opacity="0",e.style.position="fixed",e.style.pointerEvents="none",e}var Vr=function(){return Vr=Object.assign||function(t){for(var n,r=1,a=arguments.length;r<a;r++){n=arguments[r];for(var i in n)Object.prototype.hasOwnProperty.call(n,i)&&(t[i]=n[i])}return t},Vr.apply(this,arguments)};function bP(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,r=Object.getOwnPropertySymbols(e);a<r.length;a++)t.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(n[r[a]]=e[r[a]]);return n}function ci(e,t,n,r){function a(i){return i instanceof n?i:new n(function(l){l(i)})}return new(n||(n=Promise))(function(i,l){function u(p){try{f(r.next(p))}catch(g){l(g)}}function c(p){try{f(r.throw(p))}catch(g){l(g)}}function f(p){p.done?i(p.value):a(p.value).then(u,c)}f((r=r.apply(e,t||[])).next())})}function Y8(e,t,n){if(n||arguments.length===2)for(var r=0,a=t.length,i;r<a;r++)(i||!(r in t))&&(i||(i=Array.prototype.slice.call(t,0,r)),i[r]=t[r]);return e.concat(i||Array.prototype.slice.call(t))}var hd="right-scroll-bar-position",md="width-before-scroll-bar",K8="with-scroll-bars-hidden",X8="--removed-body-scroll-bar-size";function mh(e,t){return typeof e=="function"?e(t):e&&(e.current=t),e}function Z8(e,t){var n=k.useState(function(){return{value:e,callback:t,facade:{get current(){return n.value},set current(r){var a=n.value;a!==r&&(n.value=r,n.callback(r,a))}}}})[0];return n.callback=t,n.facade}var Q8=typeof window<"u"?k.useLayoutEffect:k.useEffect,IR=new WeakMap;function J8(e,t){var n=Z8(null,function(r){return e.forEach(function(a){return mh(a,r)})});return Q8(function(){var r=IR.get(n);if(r){var a=new Set(r),i=new Set(e),l=n.current;a.forEach(function(u){i.has(u)||mh(u,null)}),i.forEach(function(u){a.has(u)||mh(u,l)})}IR.set(n,e)},[e]),n}function e7(e){return e}function t7(e,t){t===void 0&&(t=e7);var n=[],r=!1,a={read:function(){if(r)throw new Error("Sidecar: could not `read` from an `assigned` medium. `read` could be used only with `useMedium`.");return n.length?n[n.length-1]:e},useMedium:function(i){var l=t(i,r);return n.push(l),function(){n=n.filter(function(u){return u!==l})}},assignSyncMedium:function(i){for(r=!0;n.length;){var l=n;n=[],l.forEach(i)}n={push:function(u){return i(u)},filter:function(){return n}}},assignMedium:function(i){r=!0;var l=[];if(n.length){var u=n;n=[],u.forEach(i),l=n}var c=function(){var p=l;l=[],p.forEach(i)},f=function(){return Promise.resolve().then(c)};f(),n={push:function(p){l.push(p),f()},filter:function(p){return l=l.filter(p),n}}}};return a}function n7(e){e===void 0&&(e={});var t=t7(null);return t.options=Vr({async:!0,ssr:!1},e),t}var yP=function(e){var t=e.sideCar,n=bP(e,["sideCar"]);if(!t)throw new Error("Sidecar: please provide `sideCar` property to import the right car");var r=t.read();if(!r)throw new Error("Sidecar medium not found");return k.createElement(r,Vr({},n))};yP.isSideCarExport=!0;function r7(e,t){return e.useMedium(t),yP}var vP=n7(),bh=function(){},ff=k.forwardRef(function(e,t){var n=k.useRef(null),r=k.useState({onScrollCapture:bh,onWheelCapture:bh,onTouchMoveCapture:bh}),a=r[0],i=r[1],l=e.forwardProps,u=e.children,c=e.className,f=e.removeScrollBar,p=e.enabled,g=e.shards,b=e.sideCar,m=e.noIsolation,S=e.inert,v=e.allowPinchZoom,A=e.as,R=A===void 0?"div":A,x=e.gapMode,T=bP(e,["forwardProps","children","className","removeScrollBar","enabled","shards","sideCar","noIsolation","inert","allowPinchZoom","as","gapMode"]),C=b,N=J8([n,t]),_=Vr(Vr({},T),a);return k.createElement(k.Fragment,null,p&&k.createElement(C,{sideCar:vP,removeScrollBar:f,shards:g,noIsolation:m,inert:S,setCallbacks:i,allowPinchZoom:!!v,lockRef:n,gapMode:x}),l?k.cloneElement(k.Children.only(u),Vr(Vr({},_),{ref:N})):k.createElement(R,Vr({},_,{className:c,ref:N}),u))});ff.defaultProps={enabled:!0,removeScrollBar:!0,inert:!1};ff.classNames={fullWidth:md,zeroRight:hd};var a7=function(){if(typeof __webpack_nonce__<"u")return __webpack_nonce__};function o7(){if(!document)return null;var e=document.createElement("style");e.type="text/css";var t=a7();return t&&e.setAttribute("nonce",t),e}function i7(e,t){e.styleSheet?e.styleSheet.cssText=t:e.appendChild(document.createTextNode(t))}function l7(e){var t=document.head||document.getElementsByTagName("head")[0];t.appendChild(e)}var s7=function(){var e=0,t=null;return{add:function(n){e==0&&(t=o7())&&(i7(t,n),l7(t)),e++},remove:function(){e--,!e&&t&&(t.parentNode&&t.parentNode.removeChild(t),t=null)}}},u7=function(){var e=s7();return function(t,n){k.useEffect(function(){return e.add(t),function(){e.remove()}},[t&&n])}},SP=function(){var e=u7(),t=function(n){var r=n.styles,a=n.dynamic;return e(r,a),null};return t},c7={left:0,top:0,right:0,gap:0},yh=function(e){return parseInt(e||"",10)||0},d7=function(e){var t=window.getComputedStyle(document.body),n=t[e==="padding"?"paddingLeft":"marginLeft"],r=t[e==="padding"?"paddingTop":"marginTop"],a=t[e==="padding"?"paddingRight":"marginRight"];return[yh(n),yh(r),yh(a)]},f7=function(e){if(e===void 0&&(e="margin"),typeof window>"u")return c7;var t=d7(e),n=document.documentElement.clientWidth,r=window.innerWidth;return{left:t[0],top:t[1],right:t[2],gap:Math.max(0,r-n+t[2]-t[0])}},p7=SP(),cl="data-scroll-locked",g7=function(e,t,n,r){var a=e.left,i=e.top,l=e.right,u=e.gap;return n===void 0&&(n="margin"),`
  .`.concat(K8,` {
   overflow: hidden `).concat(r,`;
   padding-right: `).concat(u,"px ").concat(r,`;
  }
  body[`).concat(cl,`] {
    overflow: hidden `).concat(r,`;
    overscroll-behavior: contain;
    `).concat([t&&"position: relative ".concat(r,";"),n==="margin"&&`
    padding-left: `.concat(a,`px;
    padding-top: `).concat(i,`px;
    padding-right: `).concat(l,`px;
    margin-left:0;
    margin-top:0;
    margin-right: `).concat(u,"px ").concat(r,`;
    `),n==="padding"&&"padding-right: ".concat(u,"px ").concat(r,";")].filter(Boolean).join(""),`
  }
  
  .`).concat(hd,` {
    right: `).concat(u,"px ").concat(r,`;
  }
  
  .`).concat(md,` {
    margin-right: `).concat(u,"px ").concat(r,`;
  }
  
  .`).concat(hd," .").concat(hd,` {
    right: 0 `).concat(r,`;
  }
  
  .`).concat(md," .").concat(md,` {
    margin-right: 0 `).concat(r,`;
  }
  
  body[`).concat(cl,`] {
    `).concat(X8,": ").concat(u,`px;
  }
`)},LR=function(){var e=parseInt(document.body.getAttribute(cl)||"0",10);return isFinite(e)?e:0},h7=function(){k.useEffect(function(){return document.body.setAttribute(cl,(LR()+1).toString()),function(){var e=LR()-1;e<=0?document.body.removeAttribute(cl):document.body.setAttribute(cl,e.toString())}},[])},m7=function(e){var t=e.noRelative,n=e.noImportant,r=e.gapMode,a=r===void 0?"margin":r;h7();var i=k.useMemo(function(){return f7(a)},[a]);return k.createElement(p7,{styles:g7(i,!t,a,n?"":"!important")})},Ax=!1;if(typeof window<"u")try{var Bc=Object.defineProperty({},"passive",{get:function(){return Ax=!0,!0}});window.addEventListener("test",Bc,Bc),window.removeEventListener("test",Bc,Bc)}catch{Ax=!1}var Ki=Ax?{passive:!1}:!1,b7=function(e){return e.tagName==="TEXTAREA"},EP=function(e,t){if(!(e instanceof Element))return!1;var n=window.getComputedStyle(e);return n[t]!=="hidden"&&!(n.overflowY===n.overflowX&&!b7(e)&&n[t]==="visible")},y7=function(e){return EP(e,"overflowY")},v7=function(e){return EP(e,"overflowX")},MR=function(e,t){var n=t.ownerDocument,r=t;do{typeof ShadowRoot<"u"&&r instanceof ShadowRoot&&(r=r.host);var a=wP(e,r);if(a){var i=xP(e,r),l=i[1],u=i[2];if(l>u)return!0}r=r.parentNode}while(r&&r!==n.body);return!1},S7=function(e){var t=e.scrollTop,n=e.scrollHeight,r=e.clientHeight;return[t,n,r]},E7=function(e){var t=e.scrollLeft,n=e.scrollWidth,r=e.clientWidth;return[t,n,r]},wP=function(e,t){return e==="v"?y7(t):v7(t)},xP=function(e,t){return e==="v"?S7(t):E7(t)},w7=function(e,t){return e==="h"&&t==="rtl"?-1:1},x7=function(e,t,n,r,a){var i=w7(e,window.getComputedStyle(t).direction),l=i*r,u=n.target,c=t.contains(u),f=!1,p=l>0,g=0,b=0;do{var m=xP(e,u),S=m[0],v=m[1],A=m[2],R=v-A-i*S;(S||R)&&wP(e,u)&&(g+=R,b+=S),u instanceof ShadowRoot?u=u.host:u=u.parentNode}while(!c&&u!==document.body||c&&(t.contains(u)||t===u));return(p&&Math.abs(g)<1||!p&&Math.abs(b)<1)&&(f=!0),f},Uc=function(e){return"changedTouches"in e?[e.changedTouches[0].clientX,e.changedTouches[0].clientY]:[0,0]},FR=function(e){return[e.deltaX,e.deltaY]},zR=function(e){return e&&"current"in e?e.current:e},k7=function(e,t){return e[0]===t[0]&&e[1]===t[1]},A7=function(e){return`
  .block-interactivity-`.concat(e,` {pointer-events: none;}
  .allow-interactivity-`).concat(e,` {pointer-events: all;}
`)},T7=0,Xi=[];function _7(e){var t=k.useRef([]),n=k.useRef([0,0]),r=k.useRef(),a=k.useState(T7++)[0],i=k.useState(SP)[0],l=k.useRef(e);k.useEffect(function(){l.current=e},[e]),k.useEffect(function(){if(e.inert){document.body.classList.add("block-interactivity-".concat(a));var v=Y8([e.lockRef.current],(e.shards||[]).map(zR),!0).filter(Boolean);return v.forEach(function(A){return A.classList.add("allow-interactivity-".concat(a))}),function(){document.body.classList.remove("block-interactivity-".concat(a)),v.forEach(function(A){return A.classList.remove("allow-interactivity-".concat(a))})}}},[e.inert,e.lockRef.current,e.shards]);var u=k.useCallback(function(v,A){if("touches"in v&&v.touches.length===2||v.type==="wheel"&&v.ctrlKey)return!l.current.allowPinchZoom;var R=Uc(v),x=n.current,T="deltaX"in v?v.deltaX:x[0]-R[0],C="deltaY"in v?v.deltaY:x[1]-R[1],N,_=v.target,O=Math.abs(T)>Math.abs(C)?"h":"v";if("touches"in v&&O==="h"&&_.type==="range")return!1;var z=MR(O,_);if(!z)return!0;if(z?N=O:(N=O==="v"?"h":"v",z=MR(O,_)),!z)return!1;if(!r.current&&"changedTouches"in v&&(T||C)&&(r.current=N),!N)return!0;var I=r.current||N;return x7(I,A,v,I==="h"?T:C)},[]),c=k.useCallback(function(v){var A=v;if(!(!Xi.length||Xi[Xi.length-1]!==i)){var R="deltaY"in A?FR(A):Uc(A),x=t.current.filter(function(N){return N.name===A.type&&(N.target===A.target||A.target===N.shadowParent)&&k7(N.delta,R)})[0];if(x&&x.should){A.cancelable&&A.preventDefault();return}if(!x){var T=(l.current.shards||[]).map(zR).filter(Boolean).filter(function(N){return N.contains(A.target)}),C=T.length>0?u(A,T[0]):!l.current.noIsolation;C&&A.cancelable&&A.preventDefault()}}},[]),f=k.useCallback(function(v,A,R,x){var T={name:v,delta:A,target:R,should:x,shadowParent:R7(R)};t.current.push(T),setTimeout(function(){t.current=t.current.filter(function(C){return C!==T})},1)},[]),p=k.useCallback(function(v){n.current=Uc(v),r.current=void 0},[]),g=k.useCallback(function(v){f(v.type,FR(v),v.target,u(v,e.lockRef.current))},[]),b=k.useCallback(function(v){f(v.type,Uc(v),v.target,u(v,e.lockRef.current))},[]);k.useEffect(function(){return Xi.push(i),e.setCallbacks({onScrollCapture:g,onWheelCapture:g,onTouchMoveCapture:b}),document.addEventListener("wheel",c,Ki),document.addEventListener("touchmove",c,Ki),document.addEventListener("touchstart",p,Ki),function(){Xi=Xi.filter(function(v){return v!==i}),document.removeEventListener("wheel",c,Ki),document.removeEventListener("touchmove",c,Ki),document.removeEventListener("touchstart",p,Ki)}},[]);var m=e.removeScrollBar,S=e.inert;return k.createElement(k.Fragment,null,S?k.createElement(i,{styles:A7(a)}):null,m?k.createElement(m7,{gapMode:e.gapMode}):null)}function R7(e){for(var t=null;e!==null;)e instanceof ShadowRoot&&(t=e.host,e=e.host),e=e.parentNode;return t}const C7=r7(vP,_7);var pf=k.forwardRef(function(e,t){return k.createElement(ff,Vr({},e,{ref:t,sideCar:C7}))});pf.classNames=ff.classNames;var N7=function(e){if(typeof document>"u")return null;var t=Array.isArray(e)?e[0]:e;return t.ownerDocument.body},Zi=new WeakMap,jc=new WeakMap,Gc={},vh=0,kP=function(e){return e&&(e.host||kP(e.parentNode))},O7=function(e,t){return t.map(function(n){if(e.contains(n))return n;var r=kP(n);return r&&e.contains(r)?r:(console.error("aria-hidden",n,"in not contained inside",e,". Doing nothing"),null)}).filter(function(n){return!!n})},D7=function(e,t,n,r){var a=O7(t,Array.isArray(e)?e:[e]);Gc[n]||(Gc[n]=new WeakMap);var i=Gc[n],l=[],u=new Set,c=new Set(a),f=function(g){!g||u.has(g)||(u.add(g),f(g.parentNode))};a.forEach(f);var p=function(g){!g||c.has(g)||Array.prototype.forEach.call(g.children,function(b){if(u.has(b))p(b);else try{var m=b.getAttribute(r),S=m!==null&&m!=="false",v=(Zi.get(b)||0)+1,A=(i.get(b)||0)+1;Zi.set(b,v),i.set(b,A),l.push(b),v===1&&S&&jc.set(b,!0),A===1&&b.setAttribute(n,"true"),S||b.setAttribute(r,"true")}catch(R){console.error("aria-hidden: cannot operate on ",b,R)}})};return p(t),u.clear(),vh++,function(){l.forEach(function(g){var b=Zi.get(g)-1,m=i.get(g)-1;Zi.set(g,b),i.set(g,m),b||(jc.has(g)||g.removeAttribute(r),jc.delete(g)),m||g.removeAttribute(n)}),vh--,vh||(Zi=new WeakMap,Zi=new WeakMap,jc=new WeakMap,Gc={})}},Lk=function(e,t,n){n===void 0&&(n="data-aria-hidden");var r=Array.from(Array.isArray(e)?e:[e]),a=N7(e);return a?(r.push.apply(r,Array.from(a.querySelectorAll("[aria-live]"))),D7(r,a,n,"aria-hidden")):function(){return null}},Mk="Dialog",[AP,TP]=mr(Mk),[I7,Fr]=AP(Mk),_P=e=>{const{__scopeDialog:t,children:n,open:r,defaultOpen:a,onOpenChange:i,modal:l=!0}=e,u=k.useRef(null),c=k.useRef(null),[f=!1,p]=Oa({prop:r,defaultProp:a,onChange:i});return w.jsx(I7,{scope:t,triggerRef:u,contentRef:c,contentId:En(),titleId:En(),descriptionId:En(),open:f,onOpenChange:p,onOpenToggle:k.useCallback(()=>p(g=>!g),[p]),modal:l,children:n})};_P.displayName=Mk;var RP="DialogTrigger",CP=k.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=Fr(RP,n),i=ft(t,a.triggerRef);return w.jsx(Xe.button,{type:"button","aria-haspopup":"dialog","aria-expanded":a.open,"aria-controls":a.contentId,"data-state":Pk(a.open),...r,ref:i,onClick:Ye(e.onClick,a.onOpenToggle)})});CP.displayName=RP;var Fk="DialogPortal",[L7,NP]=AP(Fk,{forceMount:void 0}),OP=e=>{const{__scopeDialog:t,forceMount:n,children:r,container:a}=e,i=Fr(Fk,t);return w.jsx(L7,{scope:t,forceMount:n,children:k.Children.map(r,l=>w.jsx(Jn,{present:n||i.open,children:w.jsx(df,{asChild:!0,container:a,children:l})}))})};OP.displayName=Fk;var Dd="DialogOverlay",DP=k.forwardRef((e,t)=>{const n=NP(Dd,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,i=Fr(Dd,e.__scopeDialog);return i.modal?w.jsx(Jn,{present:r||i.open,children:w.jsx(M7,{...a,ref:t})}):null});DP.displayName=Dd;var M7=k.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=Fr(Dd,n);return w.jsx(pf,{as:bo,allowPinchZoom:!0,shards:[a.contentRef],children:w.jsx(Xe.div,{"data-state":Pk(a.open),...r,ref:t,style:{pointerEvents:"auto",...r.style}})})}),ai="DialogContent",IP=k.forwardRef((e,t)=>{const n=NP(ai,e.__scopeDialog),{forceMount:r=n.forceMount,...a}=e,i=Fr(ai,e.__scopeDialog);return w.jsx(Jn,{present:r||i.open,children:i.modal?w.jsx(F7,{...a,ref:t}):w.jsx(z7,{...a,ref:t})})});IP.displayName=ai;var F7=k.forwardRef((e,t)=>{const n=Fr(ai,e.__scopeDialog),r=k.useRef(null),a=ft(t,n.contentRef,r);return k.useEffect(()=>{const i=r.current;if(i)return Lk(i)},[]),w.jsx(LP,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:Ye(e.onCloseAutoFocus,i=>{var l;i.preventDefault(),(l=n.triggerRef.current)==null||l.focus()}),onPointerDownOutside:Ye(e.onPointerDownOutside,i=>{const l=i.detail.originalEvent,u=l.button===0&&l.ctrlKey===!0;(l.button===2||u)&&i.preventDefault()}),onFocusOutside:Ye(e.onFocusOutside,i=>i.preventDefault())})}),z7=k.forwardRef((e,t)=>{const n=Fr(ai,e.__scopeDialog),r=k.useRef(!1),a=k.useRef(!1);return w.jsx(LP,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:i=>{var l,u;(l=e.onCloseAutoFocus)==null||l.call(e,i),i.defaultPrevented||(r.current||(u=n.triggerRef.current)==null||u.focus(),i.preventDefault()),r.current=!1,a.current=!1},onInteractOutside:i=>{var c,f;(c=e.onInteractOutside)==null||c.call(e,i),i.defaultPrevented||(r.current=!0,i.detail.originalEvent.type==="pointerdown"&&(a.current=!0));const l=i.target;((f=n.triggerRef.current)==null?void 0:f.contains(l))&&i.preventDefault(),i.detail.originalEvent.type==="focusin"&&a.current&&i.preventDefault()}})}),LP=k.forwardRef((e,t)=>{const{__scopeDialog:n,trapFocus:r,onOpenAutoFocus:a,onCloseAutoFocus:i,...l}=e,u=Fr(ai,n),c=k.useRef(null),f=ft(t,c);return Ik(),w.jsxs(w.Fragment,{children:[w.jsx(cf,{asChild:!0,loop:!0,trapped:r,onMountAutoFocus:a,onUnmountAutoFocus:i,children:w.jsx(hu,{role:"dialog",id:u.contentId,"aria-describedby":u.descriptionId,"aria-labelledby":u.titleId,"data-state":Pk(u.open),...l,ref:f,onDismiss:()=>u.onOpenChange(!1)})}),w.jsxs(w.Fragment,{children:[w.jsx(B7,{titleId:u.titleId}),w.jsx(j7,{contentRef:c,descriptionId:u.descriptionId})]})]})}),zk="DialogTitle",MP=k.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=Fr(zk,n);return w.jsx(Xe.h2,{id:a.titleId,...r,ref:t})});MP.displayName=zk;var FP="DialogDescription",zP=k.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=Fr(FP,n);return w.jsx(Xe.p,{id:a.descriptionId,...r,ref:t})});zP.displayName=FP;var PP="DialogClose",BP=k.forwardRef((e,t)=>{const{__scopeDialog:n,...r}=e,a=Fr(PP,n);return w.jsx(Xe.button,{type:"button",...r,ref:t,onClick:Ye(e.onClick,()=>a.onOpenChange(!1))})});BP.displayName=PP;function Pk(e){return e?"open":"closed"}var UP="DialogTitleWarning",[P7,jP]=v8(UP,{contentName:ai,titleName:zk,docsSlug:"dialog"}),B7=({titleId:e})=>{const t=jP(UP),n=`\`${t.contentName}\` requires a \`${t.titleName}\` for the component to be accessible for screen reader users.

If you want to hide the \`${t.titleName}\`, you can wrap it with our VisuallyHidden component.

For more information, see https://radix-ui.com/primitives/docs/components/${t.docsSlug}`;return k.useEffect(()=>{e&&(document.getElementById(e)||console.error(n))},[n,e]),null},U7="DialogDescriptionWarning",j7=({contentRef:e,descriptionId:t})=>{const r=`Warning: Missing \`Description\` or \`aria-describedby={undefined}\` for {${jP(U7).contentName}}.`;return k.useEffect(()=>{var i;const a=(i=e.current)==null?void 0:i.getAttribute("aria-describedby");t&&a&&(document.getElementById(t)||console.warn(r))},[r,e,t]),null},Bk=_P,GP=CP,Uk=OP,gf=DP,hf=IP,jk=MP,Gk=zP,Hk=BP,HP="AlertDialog",[G7,Qye]=mr(HP,[TP]),La=TP(),$P=e=>{const{__scopeAlertDialog:t,...n}=e,r=La(t);return w.jsx(Bk,{...r,...n,modal:!0})};$P.displayName=HP;var H7="AlertDialogTrigger",$7=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=La(n);return w.jsx(GP,{...a,...r,ref:t})});$7.displayName=H7;var q7="AlertDialogPortal",qP=e=>{const{__scopeAlertDialog:t,...n}=e,r=La(t);return w.jsx(Uk,{...r,...n})};qP.displayName=q7;var V7="AlertDialogOverlay",VP=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=La(n);return w.jsx(gf,{...a,...r,ref:t})});VP.displayName=V7;var dl="AlertDialogContent",[W7,Y7]=G7(dl),WP=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,children:r,...a}=e,i=La(n),l=k.useRef(null),u=ft(t,l),c=k.useRef(null);return w.jsx(P7,{contentName:dl,titleName:YP,docsSlug:"alert-dialog",children:w.jsx(W7,{scope:n,cancelRef:c,children:w.jsxs(hf,{role:"alertdialog",...i,...a,ref:u,onOpenAutoFocus:Ye(a.onOpenAutoFocus,f=>{var p;f.preventDefault(),(p=c.current)==null||p.focus({preventScroll:!0})}),onPointerDownOutside:f=>f.preventDefault(),onInteractOutside:f=>f.preventDefault(),children:[w.jsx(Dk,{children:r}),w.jsx(X7,{contentRef:l})]})})})});WP.displayName=dl;var YP="AlertDialogTitle",KP=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=La(n);return w.jsx(jk,{...a,...r,ref:t})});KP.displayName=YP;var XP="AlertDialogDescription",ZP=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=La(n);return w.jsx(Gk,{...a,...r,ref:t})});ZP.displayName=XP;var K7="AlertDialogAction",QP=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,a=La(n);return w.jsx(Hk,{...a,...r,ref:t})});QP.displayName=K7;var JP="AlertDialogCancel",eB=k.forwardRef((e,t)=>{const{__scopeAlertDialog:n,...r}=e,{cancelRef:a}=Y7(JP,n),i=La(n),l=ft(t,a);return w.jsx(Hk,{...i,...r,ref:l})});eB.displayName=JP;var X7=({contentRef:e})=>{const t=`\`${dl}\` requires a description for the component to be accessible for screen reader users.

You can add a description to the \`${dl}\` by passing a \`${XP}\` component as a child, which also benefits sighted users by adding visible context to the dialog.

Alternatively, you can use your own component as a description by assigning it an \`id\` and passing the same value to the \`aria-describedby\` prop in \`${dl}\`. If the description is confusing or duplicative for sighted users, you can use the \`@radix-ui/react-visually-hidden\` primitive as a wrapper around your description component.

For more information, see https://radix-ui.com/primitives/docs/components/alert-dialog`;return k.useEffect(()=>{var r;document.getElementById((r=e.current)==null?void 0:r.getAttribute("aria-describedby"))||console.warn(t)},[t,e]),null},Z7=$P,Q7=qP,tB=VP,nB=WP,rB=QP,aB=eB,oB=KP,iB=ZP;const J7=["top","right","bottom","left"],yo=Math.min,Kn=Math.max,Id=Math.round,Hc=Math.floor,Kr=e=>({x:e,y:e}),eV={left:"right",right:"left",bottom:"top",top:"bottom"},tV={start:"end",end:"start"};function Tx(e,t,n){return Kn(e,yo(t,n))}function Da(e,t){return typeof e=="function"?e(t):e}function Ia(e){return e.split("-")[0]}function Rl(e){return e.split("-")[1]}function $k(e){return e==="x"?"y":"x"}function qk(e){return e==="y"?"height":"width"}function vo(e){return["top","bottom"].includes(Ia(e))?"y":"x"}function Vk(e){return $k(vo(e))}function nV(e,t,n){n===void 0&&(n=!1);const r=Rl(e),a=Vk(e),i=qk(a);let l=a==="x"?r===(n?"end":"start")?"right":"left":r==="start"?"bottom":"top";return t.reference[i]>t.floating[i]&&(l=Ld(l)),[l,Ld(l)]}function rV(e){const t=Ld(e);return[_x(e),t,_x(t)]}function _x(e){return e.replace(/start|end/g,t=>tV[t])}function aV(e,t,n){const r=["left","right"],a=["right","left"],i=["top","bottom"],l=["bottom","top"];switch(e){case"top":case"bottom":return n?t?a:r:t?r:a;case"left":case"right":return t?i:l;default:return[]}}function oV(e,t,n,r){const a=Rl(e);let i=aV(Ia(e),n==="start",r);return a&&(i=i.map(l=>l+"-"+a),t&&(i=i.concat(i.map(_x)))),i}function Ld(e){return e.replace(/left|right|bottom|top/g,t=>eV[t])}function iV(e){return{top:0,right:0,bottom:0,left:0,...e}}function lB(e){return typeof e!="number"?iV(e):{top:e,right:e,bottom:e,left:e}}function Md(e){const{x:t,y:n,width:r,height:a}=e;return{width:r,height:a,top:n,left:t,right:t+r,bottom:n+a,x:t,y:n}}function PR(e,t,n){let{reference:r,floating:a}=e;const i=vo(t),l=Vk(t),u=qk(l),c=Ia(t),f=i==="y",p=r.x+r.width/2-a.width/2,g=r.y+r.height/2-a.height/2,b=r[u]/2-a[u]/2;let m;switch(c){case"top":m={x:p,y:r.y-a.height};break;case"bottom":m={x:p,y:r.y+r.height};break;case"right":m={x:r.x+r.width,y:g};break;case"left":m={x:r.x-a.width,y:g};break;default:m={x:r.x,y:r.y}}switch(Rl(t)){case"start":m[l]-=b*(n&&f?-1:1);break;case"end":m[l]+=b*(n&&f?-1:1);break}return m}const lV=async(e,t,n)=>{const{placement:r="bottom",strategy:a="absolute",middleware:i=[],platform:l}=n,u=i.filter(Boolean),c=await(l.isRTL==null?void 0:l.isRTL(t));let f=await l.getElementRects({reference:e,floating:t,strategy:a}),{x:p,y:g}=PR(f,r,c),b=r,m={},S=0;for(let v=0;v<u.length;v++){const{name:A,fn:R}=u[v],{x,y:T,data:C,reset:N}=await R({x:p,y:g,initialPlacement:r,placement:b,strategy:a,middlewareData:m,rects:f,platform:l,elements:{reference:e,floating:t}});p=x??p,g=T??g,m={...m,[A]:{...m[A],...C}},N&&S<=50&&(S++,typeof N=="object"&&(N.placement&&(b=N.placement),N.rects&&(f=N.rects===!0?await l.getElementRects({reference:e,floating:t,strategy:a}):N.rects),{x:p,y:g}=PR(f,b,c)),v=-1)}return{x:p,y:g,placement:b,strategy:a,middlewareData:m}};async function eu(e,t){var n;t===void 0&&(t={});const{x:r,y:a,platform:i,rects:l,elements:u,strategy:c}=e,{boundary:f="clippingAncestors",rootBoundary:p="viewport",elementContext:g="floating",altBoundary:b=!1,padding:m=0}=Da(t,e),S=lB(m),A=u[b?g==="floating"?"reference":"floating":g],R=Md(await i.getClippingRect({element:(n=await(i.isElement==null?void 0:i.isElement(A)))==null||n?A:A.contextElement||await(i.getDocumentElement==null?void 0:i.getDocumentElement(u.floating)),boundary:f,rootBoundary:p,strategy:c})),x=g==="floating"?{x:r,y:a,width:l.floating.width,height:l.floating.height}:l.reference,T=await(i.getOffsetParent==null?void 0:i.getOffsetParent(u.floating)),C=await(i.isElement==null?void 0:i.isElement(T))?await(i.getScale==null?void 0:i.getScale(T))||{x:1,y:1}:{x:1,y:1},N=Md(i.convertOffsetParentRelativeRectToViewportRelativeRect?await i.convertOffsetParentRelativeRectToViewportRelativeRect({elements:u,rect:x,offsetParent:T,strategy:c}):x);return{top:(R.top-N.top+S.top)/C.y,bottom:(N.bottom-R.bottom+S.bottom)/C.y,left:(R.left-N.left+S.left)/C.x,right:(N.right-R.right+S.right)/C.x}}const sV=e=>({name:"arrow",options:e,async fn(t){const{x:n,y:r,placement:a,rects:i,platform:l,elements:u,middlewareData:c}=t,{element:f,padding:p=0}=Da(e,t)||{};if(f==null)return{};const g=lB(p),b={x:n,y:r},m=Vk(a),S=qk(m),v=await l.getDimensions(f),A=m==="y",R=A?"top":"left",x=A?"bottom":"right",T=A?"clientHeight":"clientWidth",C=i.reference[S]+i.reference[m]-b[m]-i.floating[S],N=b[m]-i.reference[m],_=await(l.getOffsetParent==null?void 0:l.getOffsetParent(f));let O=_?_[T]:0;(!O||!await(l.isElement==null?void 0:l.isElement(_)))&&(O=u.floating[T]||i.floating[S]);const z=C/2-N/2,I=O/2-v[S]/2-1,M=yo(g[R],I),H=yo(g[x],I),q=M,P=O-v[S]-H,W=O/2-v[S]/2+z,Z=Tx(q,W,P),j=!c.arrow&&Rl(a)!=null&&W!==Z&&i.reference[S]/2-(W<q?M:H)-v[S]/2<0,G=j?W<q?W-q:W-P:0;return{[m]:b[m]+G,data:{[m]:Z,centerOffset:W-Z-G,...j&&{alignmentOffset:G}},reset:j}}}),uV=function(e){return e===void 0&&(e={}),{name:"flip",options:e,async fn(t){var n,r;const{placement:a,middlewareData:i,rects:l,initialPlacement:u,platform:c,elements:f}=t,{mainAxis:p=!0,crossAxis:g=!0,fallbackPlacements:b,fallbackStrategy:m="bestFit",fallbackAxisSideDirection:S="none",flipAlignment:v=!0,...A}=Da(e,t);if((n=i.arrow)!=null&&n.alignmentOffset)return{};const R=Ia(a),x=vo(u),T=Ia(u)===u,C=await(c.isRTL==null?void 0:c.isRTL(f.floating)),N=b||(T||!v?[Ld(u)]:rV(u)),_=S!=="none";!b&&_&&N.push(...oV(u,v,S,C));const O=[u,...N],z=await eu(t,A),I=[];let M=((r=i.flip)==null?void 0:r.overflows)||[];if(p&&I.push(z[R]),g){const W=nV(a,l,C);I.push(z[W[0]],z[W[1]])}if(M=[...M,{placement:a,overflows:I}],!I.every(W=>W<=0)){var H,q;const W=(((H=i.flip)==null?void 0:H.index)||0)+1,Z=O[W];if(Z)return{data:{index:W,overflows:M},reset:{placement:Z}};let j=(q=M.filter(G=>G.overflows[0]<=0).sort((G,B)=>G.overflows[1]-B.overflows[1])[0])==null?void 0:q.placement;if(!j)switch(m){case"bestFit":{var P;const G=(P=M.filter(B=>{if(_){const X=vo(B.placement);return X===x||X==="y"}return!0}).map(B=>[B.placement,B.overflows.filter(X=>X>0).reduce((X,D)=>X+D,0)]).sort((B,X)=>B[1]-X[1])[0])==null?void 0:P[0];G&&(j=G);break}case"initialPlacement":j=u;break}if(a!==j)return{reset:{placement:j}}}return{}}}};function BR(e,t){return{top:e.top-t.height,right:e.right-t.width,bottom:e.bottom-t.height,left:e.left-t.width}}function UR(e){return J7.some(t=>e[t]>=0)}const cV=function(e){return e===void 0&&(e={}),{name:"hide",options:e,async fn(t){const{rects:n}=t,{strategy:r="referenceHidden",...a}=Da(e,t);switch(r){case"referenceHidden":{const i=await eu(t,{...a,elementContext:"reference"}),l=BR(i,n.reference);return{data:{referenceHiddenOffsets:l,referenceHidden:UR(l)}}}case"escaped":{const i=await eu(t,{...a,altBoundary:!0}),l=BR(i,n.floating);return{data:{escapedOffsets:l,escaped:UR(l)}}}default:return{}}}}};async function dV(e,t){const{placement:n,platform:r,elements:a}=e,i=await(r.isRTL==null?void 0:r.isRTL(a.floating)),l=Ia(n),u=Rl(n),c=vo(n)==="y",f=["left","top"].includes(l)?-1:1,p=i&&c?-1:1,g=Da(t,e);let{mainAxis:b,crossAxis:m,alignmentAxis:S}=typeof g=="number"?{mainAxis:g,crossAxis:0,alignmentAxis:null}:{mainAxis:g.mainAxis||0,crossAxis:g.crossAxis||0,alignmentAxis:g.alignmentAxis};return u&&typeof S=="number"&&(m=u==="end"?S*-1:S),c?{x:m*p,y:b*f}:{x:b*f,y:m*p}}const fV=function(e){return e===void 0&&(e=0),{name:"offset",options:e,async fn(t){var n,r;const{x:a,y:i,placement:l,middlewareData:u}=t,c=await dV(t,e);return l===((n=u.offset)==null?void 0:n.placement)&&(r=u.arrow)!=null&&r.alignmentOffset?{}:{x:a+c.x,y:i+c.y,data:{...c,placement:l}}}}},pV=function(e){return e===void 0&&(e={}),{name:"shift",options:e,async fn(t){const{x:n,y:r,placement:a}=t,{mainAxis:i=!0,crossAxis:l=!1,limiter:u={fn:A=>{let{x:R,y:x}=A;return{x:R,y:x}}},...c}=Da(e,t),f={x:n,y:r},p=await eu(t,c),g=vo(Ia(a)),b=$k(g);let m=f[b],S=f[g];if(i){const A=b==="y"?"top":"left",R=b==="y"?"bottom":"right",x=m+p[A],T=m-p[R];m=Tx(x,m,T)}if(l){const A=g==="y"?"top":"left",R=g==="y"?"bottom":"right",x=S+p[A],T=S-p[R];S=Tx(x,S,T)}const v=u.fn({...t,[b]:m,[g]:S});return{...v,data:{x:v.x-n,y:v.y-r,enabled:{[b]:i,[g]:l}}}}}},gV=function(e){return e===void 0&&(e={}),{options:e,fn(t){const{x:n,y:r,placement:a,rects:i,middlewareData:l}=t,{offset:u=0,mainAxis:c=!0,crossAxis:f=!0}=Da(e,t),p={x:n,y:r},g=vo(a),b=$k(g);let m=p[b],S=p[g];const v=Da(u,t),A=typeof v=="number"?{mainAxis:v,crossAxis:0}:{mainAxis:0,crossAxis:0,...v};if(c){const T=b==="y"?"height":"width",C=i.reference[b]-i.floating[T]+A.mainAxis,N=i.reference[b]+i.reference[T]-A.mainAxis;m<C?m=C:m>N&&(m=N)}if(f){var R,x;const T=b==="y"?"width":"height",C=["top","left"].includes(Ia(a)),N=i.reference[g]-i.floating[T]+(C&&((R=l.offset)==null?void 0:R[g])||0)+(C?0:A.crossAxis),_=i.reference[g]+i.reference[T]+(C?0:((x=l.offset)==null?void 0:x[g])||0)-(C?A.crossAxis:0);S<N?S=N:S>_&&(S=_)}return{[b]:m,[g]:S}}}},hV=function(e){return e===void 0&&(e={}),{name:"size",options:e,async fn(t){var n,r;const{placement:a,rects:i,platform:l,elements:u}=t,{apply:c=()=>{},...f}=Da(e,t),p=await eu(t,f),g=Ia(a),b=Rl(a),m=vo(a)==="y",{width:S,height:v}=i.floating;let A,R;g==="top"||g==="bottom"?(A=g,R=b===(await(l.isRTL==null?void 0:l.isRTL(u.floating))?"start":"end")?"left":"right"):(R=g,A=b==="end"?"top":"bottom");const x=v-p.top-p.bottom,T=S-p.left-p.right,C=yo(v-p[A],x),N=yo(S-p[R],T),_=!t.middlewareData.shift;let O=C,z=N;if((n=t.middlewareData.shift)!=null&&n.enabled.x&&(z=T),(r=t.middlewareData.shift)!=null&&r.enabled.y&&(O=x),_&&!b){const M=Kn(p.left,0),H=Kn(p.right,0),q=Kn(p.top,0),P=Kn(p.bottom,0);m?z=S-2*(M!==0||H!==0?M+H:Kn(p.left,p.right)):O=v-2*(q!==0||P!==0?q+P:Kn(p.top,p.bottom))}await c({...t,availableWidth:z,availableHeight:O});const I=await l.getDimensions(u.floating);return S!==I.width||v!==I.height?{reset:{rects:!0}}:{}}}};function mf(){return typeof window<"u"}function Cl(e){return sB(e)?(e.nodeName||"").toLowerCase():"#document"}function Zn(e){var t;return(e==null||(t=e.ownerDocument)==null?void 0:t.defaultView)||window}function Zr(e){var t;return(t=(sB(e)?e.ownerDocument:e.document)||window.document)==null?void 0:t.documentElement}function sB(e){return mf()?e instanceof Node||e instanceof Zn(e).Node:!1}function Dr(e){return mf()?e instanceof Element||e instanceof Zn(e).Element:!1}function Xr(e){return mf()?e instanceof HTMLElement||e instanceof Zn(e).HTMLElement:!1}function jR(e){return!mf()||typeof ShadowRoot>"u"?!1:e instanceof ShadowRoot||e instanceof Zn(e).ShadowRoot}function mu(e){const{overflow:t,overflowX:n,overflowY:r,display:a}=Ir(e);return/auto|scroll|overlay|hidden|clip/.test(t+r+n)&&!["inline","contents"].includes(a)}function mV(e){return["table","td","th"].includes(Cl(e))}function bf(e){return[":popover-open",":modal"].some(t=>{try{return e.matches(t)}catch{return!1}})}function Wk(e){const t=Yk(),n=Dr(e)?Ir(e):e;return["transform","translate","scale","rotate","perspective"].some(r=>n[r]?n[r]!=="none":!1)||(n.containerType?n.containerType!=="normal":!1)||!t&&(n.backdropFilter?n.backdropFilter!=="none":!1)||!t&&(n.filter?n.filter!=="none":!1)||["transform","translate","scale","rotate","perspective","filter"].some(r=>(n.willChange||"").includes(r))||["paint","layout","strict","content"].some(r=>(n.contain||"").includes(r))}function bV(e){let t=So(e);for(;Xr(t)&&!ml(t);){if(Wk(t))return t;if(bf(t))return null;t=So(t)}return null}function Yk(){return typeof CSS>"u"||!CSS.supports?!1:CSS.supports("-webkit-backdrop-filter","none")}function ml(e){return["html","body","#document"].includes(Cl(e))}function Ir(e){return Zn(e).getComputedStyle(e)}function yf(e){return Dr(e)?{scrollLeft:e.scrollLeft,scrollTop:e.scrollTop}:{scrollLeft:e.scrollX,scrollTop:e.scrollY}}function So(e){if(Cl(e)==="html")return e;const t=e.assignedSlot||e.parentNode||jR(e)&&e.host||Zr(e);return jR(t)?t.host:t}function uB(e){const t=So(e);return ml(t)?e.ownerDocument?e.ownerDocument.body:e.body:Xr(t)&&mu(t)?t:uB(t)}function tu(e,t,n){var r;t===void 0&&(t=[]),n===void 0&&(n=!0);const a=uB(e),i=a===((r=e.ownerDocument)==null?void 0:r.body),l=Zn(a);if(i){const u=Rx(l);return t.concat(l,l.visualViewport||[],mu(a)?a:[],u&&n?tu(u):[])}return t.concat(a,tu(a,[],n))}function Rx(e){return e.parent&&Object.getPrototypeOf(e.parent)?e.frameElement:null}function cB(e){const t=Ir(e);let n=parseFloat(t.width)||0,r=parseFloat(t.height)||0;const a=Xr(e),i=a?e.offsetWidth:n,l=a?e.offsetHeight:r,u=Id(n)!==i||Id(r)!==l;return u&&(n=i,r=l),{width:n,height:r,$:u}}function Kk(e){return Dr(e)?e:e.contextElement}function fl(e){const t=Kk(e);if(!Xr(t))return Kr(1);const n=t.getBoundingClientRect(),{width:r,height:a,$:i}=cB(t);let l=(i?Id(n.width):n.width)/r,u=(i?Id(n.height):n.height)/a;return(!l||!Number.isFinite(l))&&(l=1),(!u||!Number.isFinite(u))&&(u=1),{x:l,y:u}}const yV=Kr(0);function dB(e){const t=Zn(e);return!Yk()||!t.visualViewport?yV:{x:t.visualViewport.offsetLeft,y:t.visualViewport.offsetTop}}function vV(e,t,n){return t===void 0&&(t=!1),!n||t&&n!==Zn(e)?!1:t}function oi(e,t,n,r){t===void 0&&(t=!1),n===void 0&&(n=!1);const a=e.getBoundingClientRect(),i=Kk(e);let l=Kr(1);t&&(r?Dr(r)&&(l=fl(r)):l=fl(e));const u=vV(i,n,r)?dB(i):Kr(0);let c=(a.left+u.x)/l.x,f=(a.top+u.y)/l.y,p=a.width/l.x,g=a.height/l.y;if(i){const b=Zn(i),m=r&&Dr(r)?Zn(r):r;let S=b,v=Rx(S);for(;v&&r&&m!==S;){const A=fl(v),R=v.getBoundingClientRect(),x=Ir(v),T=R.left+(v.clientLeft+parseFloat(x.paddingLeft))*A.x,C=R.top+(v.clientTop+parseFloat(x.paddingTop))*A.y;c*=A.x,f*=A.y,p*=A.x,g*=A.y,c+=T,f+=C,S=Zn(v),v=Rx(S)}}return Md({width:p,height:g,x:c,y:f})}function Xk(e,t){const n=yf(e).scrollLeft;return t?t.left+n:oi(Zr(e)).left+n}function fB(e,t,n){n===void 0&&(n=!1);const r=e.getBoundingClientRect(),a=r.left+t.scrollLeft-(n?0:Xk(e,r)),i=r.top+t.scrollTop;return{x:a,y:i}}function SV(e){let{elements:t,rect:n,offsetParent:r,strategy:a}=e;const i=a==="fixed",l=Zr(r),u=t?bf(t.floating):!1;if(r===l||u&&i)return n;let c={scrollLeft:0,scrollTop:0},f=Kr(1);const p=Kr(0),g=Xr(r);if((g||!g&&!i)&&((Cl(r)!=="body"||mu(l))&&(c=yf(r)),Xr(r))){const m=oi(r);f=fl(r),p.x=m.x+r.clientLeft,p.y=m.y+r.clientTop}const b=l&&!g&&!i?fB(l,c,!0):Kr(0);return{width:n.width*f.x,height:n.height*f.y,x:n.x*f.x-c.scrollLeft*f.x+p.x+b.x,y:n.y*f.y-c.scrollTop*f.y+p.y+b.y}}function EV(e){return Array.from(e.getClientRects())}function wV(e){const t=Zr(e),n=yf(e),r=e.ownerDocument.body,a=Kn(t.scrollWidth,t.clientWidth,r.scrollWidth,r.clientWidth),i=Kn(t.scrollHeight,t.clientHeight,r.scrollHeight,r.clientHeight);let l=-n.scrollLeft+Xk(e);const u=-n.scrollTop;return Ir(r).direction==="rtl"&&(l+=Kn(t.clientWidth,r.clientWidth)-a),{width:a,height:i,x:l,y:u}}function xV(e,t){const n=Zn(e),r=Zr(e),a=n.visualViewport;let i=r.clientWidth,l=r.clientHeight,u=0,c=0;if(a){i=a.width,l=a.height;const f=Yk();(!f||f&&t==="fixed")&&(u=a.offsetLeft,c=a.offsetTop)}return{width:i,height:l,x:u,y:c}}function kV(e,t){const n=oi(e,!0,t==="fixed"),r=n.top+e.clientTop,a=n.left+e.clientLeft,i=Xr(e)?fl(e):Kr(1),l=e.clientWidth*i.x,u=e.clientHeight*i.y,c=a*i.x,f=r*i.y;return{width:l,height:u,x:c,y:f}}function GR(e,t,n){let r;if(t==="viewport")r=xV(e,n);else if(t==="document")r=wV(Zr(e));else if(Dr(t))r=kV(t,n);else{const a=dB(e);r={x:t.x-a.x,y:t.y-a.y,width:t.width,height:t.height}}return Md(r)}function pB(e,t){const n=So(e);return n===t||!Dr(n)||ml(n)?!1:Ir(n).position==="fixed"||pB(n,t)}function AV(e,t){const n=t.get(e);if(n)return n;let r=tu(e,[],!1).filter(u=>Dr(u)&&Cl(u)!=="body"),a=null;const i=Ir(e).position==="fixed";let l=i?So(e):e;for(;Dr(l)&&!ml(l);){const u=Ir(l),c=Wk(l);!c&&u.position==="fixed"&&(a=null),(i?!c&&!a:!c&&u.position==="static"&&!!a&&["absolute","fixed"].includes(a.position)||mu(l)&&!c&&pB(e,l))?r=r.filter(p=>p!==l):a=u,l=So(l)}return t.set(e,r),r}function TV(e){let{element:t,boundary:n,rootBoundary:r,strategy:a}=e;const l=[...n==="clippingAncestors"?bf(t)?[]:AV(t,this._c):[].concat(n),r],u=l[0],c=l.reduce((f,p)=>{const g=GR(t,p,a);return f.top=Kn(g.top,f.top),f.right=yo(g.right,f.right),f.bottom=yo(g.bottom,f.bottom),f.left=Kn(g.left,f.left),f},GR(t,u,a));return{width:c.right-c.left,height:c.bottom-c.top,x:c.left,y:c.top}}function _V(e){const{width:t,height:n}=cB(e);return{width:t,height:n}}function RV(e,t,n){const r=Xr(t),a=Zr(t),i=n==="fixed",l=oi(e,!0,i,t);let u={scrollLeft:0,scrollTop:0};const c=Kr(0);if(r||!r&&!i)if((Cl(t)!=="body"||mu(a))&&(u=yf(t)),r){const b=oi(t,!0,i,t);c.x=b.x+t.clientLeft,c.y=b.y+t.clientTop}else a&&(c.x=Xk(a));const f=a&&!r&&!i?fB(a,u):Kr(0),p=l.left+u.scrollLeft-c.x-f.x,g=l.top+u.scrollTop-c.y-f.y;return{x:p,y:g,width:l.width,height:l.height}}function Sh(e){return Ir(e).position==="static"}function HR(e,t){if(!Xr(e)||Ir(e).position==="fixed")return null;if(t)return t(e);let n=e.offsetParent;return Zr(e)===n&&(n=n.ownerDocument.body),n}function gB(e,t){const n=Zn(e);if(bf(e))return n;if(!Xr(e)){let a=So(e);for(;a&&!ml(a);){if(Dr(a)&&!Sh(a))return a;a=So(a)}return n}let r=HR(e,t);for(;r&&mV(r)&&Sh(r);)r=HR(r,t);return r&&ml(r)&&Sh(r)&&!Wk(r)?n:r||bV(e)||n}const CV=async function(e){const t=this.getOffsetParent||gB,n=this.getDimensions,r=await n(e.floating);return{reference:RV(e.reference,await t(e.floating),e.strategy),floating:{x:0,y:0,width:r.width,height:r.height}}};function NV(e){return Ir(e).direction==="rtl"}const OV={convertOffsetParentRelativeRectToViewportRelativeRect:SV,getDocumentElement:Zr,getClippingRect:TV,getOffsetParent:gB,getElementRects:CV,getClientRects:EV,getDimensions:_V,getScale:fl,isElement:Dr,isRTL:NV};function hB(e,t){return e.x===t.x&&e.y===t.y&&e.width===t.width&&e.height===t.height}function DV(e,t){let n=null,r;const a=Zr(e);function i(){var u;clearTimeout(r),(u=n)==null||u.disconnect(),n=null}function l(u,c){u===void 0&&(u=!1),c===void 0&&(c=1),i();const f=e.getBoundingClientRect(),{left:p,top:g,width:b,height:m}=f;if(u||t(),!b||!m)return;const S=Hc(g),v=Hc(a.clientWidth-(p+b)),A=Hc(a.clientHeight-(g+m)),R=Hc(p),T={rootMargin:-S+"px "+-v+"px "+-A+"px "+-R+"px",threshold:Kn(0,yo(1,c))||1};let C=!0;function N(_){const O=_[0].intersectionRatio;if(O!==c){if(!C)return l();O?l(!1,O):r=setTimeout(()=>{l(!1,1e-7)},1e3)}O===1&&!hB(f,e.getBoundingClientRect())&&l(),C=!1}try{n=new IntersectionObserver(N,{...T,root:a.ownerDocument})}catch{n=new IntersectionObserver(N,T)}n.observe(e)}return l(!0),i}function IV(e,t,n,r){r===void 0&&(r={});const{ancestorScroll:a=!0,ancestorResize:i=!0,elementResize:l=typeof ResizeObserver=="function",layoutShift:u=typeof IntersectionObserver=="function",animationFrame:c=!1}=r,f=Kk(e),p=a||i?[...f?tu(f):[],...tu(t)]:[];p.forEach(R=>{a&&R.addEventListener("scroll",n,{passive:!0}),i&&R.addEventListener("resize",n)});const g=f&&u?DV(f,n):null;let b=-1,m=null;l&&(m=new ResizeObserver(R=>{let[x]=R;x&&x.target===f&&m&&(m.unobserve(t),cancelAnimationFrame(b),b=requestAnimationFrame(()=>{var T;(T=m)==null||T.observe(t)})),n()}),f&&!c&&m.observe(f),m.observe(t));let S,v=c?oi(e):null;c&&A();function A(){const R=oi(e);v&&!hB(v,R)&&n(),v=R,S=requestAnimationFrame(A)}return n(),()=>{var R;p.forEach(x=>{a&&x.removeEventListener("scroll",n),i&&x.removeEventListener("resize",n)}),g==null||g(),(R=m)==null||R.disconnect(),m=null,c&&cancelAnimationFrame(S)}}const LV=fV,MV=pV,FV=uV,zV=hV,PV=cV,$R=sV,BV=gV,UV=(e,t,n)=>{const r=new Map,a={platform:OV,...n},i={...a.platform,_c:r};return lV(e,t,{...a,platform:i})};var bd=typeof document<"u"?k.useLayoutEffect:k.useEffect;function Fd(e,t){if(e===t)return!0;if(typeof e!=typeof t)return!1;if(typeof e=="function"&&e.toString()===t.toString())return!0;let n,r,a;if(e&&t&&typeof e=="object"){if(Array.isArray(e)){if(n=e.length,n!==t.length)return!1;for(r=n;r--!==0;)if(!Fd(e[r],t[r]))return!1;return!0}if(a=Object.keys(e),n=a.length,n!==Object.keys(t).length)return!1;for(r=n;r--!==0;)if(!{}.hasOwnProperty.call(t,a[r]))return!1;for(r=n;r--!==0;){const i=a[r];if(!(i==="_owner"&&e.$$typeof)&&!Fd(e[i],t[i]))return!1}return!0}return e!==e&&t!==t}function mB(e){return typeof window>"u"?1:(e.ownerDocument.defaultView||window).devicePixelRatio||1}function qR(e,t){const n=mB(e);return Math.round(t*n)/n}function Eh(e){const t=k.useRef(e);return bd(()=>{t.current=e}),t}function jV(e){e===void 0&&(e={});const{placement:t="bottom",strategy:n="absolute",middleware:r=[],platform:a,elements:{reference:i,floating:l}={},transform:u=!0,whileElementsMounted:c,open:f}=e,[p,g]=k.useState({x:0,y:0,strategy:n,placement:t,middlewareData:{},isPositioned:!1}),[b,m]=k.useState(r);Fd(b,r)||m(r);const[S,v]=k.useState(null),[A,R]=k.useState(null),x=k.useCallback(B=>{B!==_.current&&(_.current=B,v(B))},[]),T=k.useCallback(B=>{B!==O.current&&(O.current=B,R(B))},[]),C=i||S,N=l||A,_=k.useRef(null),O=k.useRef(null),z=k.useRef(p),I=c!=null,M=Eh(c),H=Eh(a),q=Eh(f),P=k.useCallback(()=>{if(!_.current||!O.current)return;const B={placement:t,strategy:n,middleware:b};H.current&&(B.platform=H.current),UV(_.current,O.current,B).then(X=>{const D={...X,isPositioned:q.current!==!1};W.current&&!Fd(z.current,D)&&(z.current=D,gu.flushSync(()=>{g(D)}))})},[b,t,n,H,q]);bd(()=>{f===!1&&z.current.isPositioned&&(z.current.isPositioned=!1,g(B=>({...B,isPositioned:!1})))},[f]);const W=k.useRef(!1);bd(()=>(W.current=!0,()=>{W.current=!1}),[]),bd(()=>{if(C&&(_.current=C),N&&(O.current=N),C&&N){if(M.current)return M.current(C,N,P);P()}},[C,N,P,M,I]);const Z=k.useMemo(()=>({reference:_,floating:O,setReference:x,setFloating:T}),[x,T]),j=k.useMemo(()=>({reference:C,floating:N}),[C,N]),G=k.useMemo(()=>{const B={position:n,left:0,top:0};if(!j.floating)return B;const X=qR(j.floating,p.x),D=qR(j.floating,p.y);return u?{...B,transform:"translate("+X+"px, "+D+"px)",...mB(j.floating)>=1.5&&{willChange:"transform"}}:{position:n,left:X,top:D}},[n,u,j.floating,p.x,p.y]);return k.useMemo(()=>({...p,update:P,refs:Z,elements:j,floatingStyles:G}),[p,P,Z,j,G])}const GV=e=>{function t(n){return{}.hasOwnProperty.call(n,"current")}return{name:"arrow",options:e,fn(n){const{element:r,padding:a}=typeof e=="function"?e(n):e;return r&&t(r)?r.current!=null?$R({element:r.current,padding:a}).fn(n):{}:r?$R({element:r,padding:a}).fn(n):{}}}},HV=(e,t)=>({...LV(e),options:[e,t]}),$V=(e,t)=>({...MV(e),options:[e,t]}),qV=(e,t)=>({...BV(e),options:[e,t]}),VV=(e,t)=>({...FV(e),options:[e,t]}),WV=(e,t)=>({...zV(e),options:[e,t]}),YV=(e,t)=>({...PV(e),options:[e,t]}),KV=(e,t)=>({...GV(e),options:[e,t]});var XV="Arrow",bB=k.forwardRef((e,t)=>{const{children:n,width:r=10,height:a=5,...i}=e;return w.jsx(Xe.svg,{...i,ref:t,width:r,height:a,viewBox:"0 0 30 10",preserveAspectRatio:"none",children:e.asChild?n:w.jsx("polygon",{points:"0,0 30,0 15,10"})})});bB.displayName=XV;var ZV=bB;function yB(e){const[t,n]=k.useState(void 0);return wn(()=>{if(e){n({width:e.offsetWidth,height:e.offsetHeight});const r=new ResizeObserver(a=>{if(!Array.isArray(a)||!a.length)return;const i=a[0];let l,u;if("borderBoxSize"in i){const c=i.borderBoxSize,f=Array.isArray(c)?c[0]:c;l=f.inlineSize,u=f.blockSize}else l=e.offsetWidth,u=e.offsetHeight;n({width:l,height:u})});return r.observe(e,{box:"border-box"}),()=>r.unobserve(e)}else n(void 0)},[e]),t}var Zk="Popper",[vB,Nl]=mr(Zk),[QV,SB]=vB(Zk),EB=e=>{const{__scopePopper:t,children:n}=e,[r,a]=k.useState(null);return w.jsx(QV,{scope:t,anchor:r,onAnchorChange:a,children:n})};EB.displayName=Zk;var wB="PopperAnchor",xB=k.forwardRef((e,t)=>{const{__scopePopper:n,virtualRef:r,...a}=e,i=SB(wB,n),l=k.useRef(null),u=ft(t,l);return k.useEffect(()=>{i.onAnchorChange((r==null?void 0:r.current)||l.current)}),r?null:w.jsx(Xe.div,{...a,ref:u})});xB.displayName=wB;var Qk="PopperContent",[JV,eW]=vB(Qk),kB=k.forwardRef((e,t)=>{var re,le,Ae,ae,we,xe;const{__scopePopper:n,side:r="bottom",sideOffset:a=0,align:i="center",alignOffset:l=0,arrowPadding:u=0,avoidCollisions:c=!0,collisionBoundary:f=[],collisionPadding:p=0,sticky:g="partial",hideWhenDetached:b=!1,updatePositionStrategy:m="optimized",onPlaced:S,...v}=e,A=SB(Qk,n),[R,x]=k.useState(null),T=ft(t,Ie=>x(Ie)),[C,N]=k.useState(null),_=yB(C),O=(_==null?void 0:_.width)??0,z=(_==null?void 0:_.height)??0,I=r+(i!=="center"?"-"+i:""),M=typeof p=="number"?p:{top:0,right:0,bottom:0,left:0,...p},H=Array.isArray(f)?f:[f],q=H.length>0,P={padding:M,boundary:H.filter(nW),altBoundary:q},{refs:W,floatingStyles:Z,placement:j,isPositioned:G,middlewareData:B}=jV({strategy:"fixed",placement:I,whileElementsMounted:(...Ie)=>IV(...Ie,{animationFrame:m==="always"}),elements:{reference:A.anchor},middleware:[HV({mainAxis:a+z,alignmentAxis:l}),c&&$V({mainAxis:!0,crossAxis:!1,limiter:g==="partial"?qV():void 0,...P}),c&&VV({...P}),WV({...P,apply:({elements:Ie,rects:Ce,availableWidth:Ee,availableHeight:J})=>{const{width:fe,height:ke}=Ce.reference,me=Ie.floating.style;me.setProperty("--radix-popper-available-width",`${Ee}px`),me.setProperty("--radix-popper-available-height",`${J}px`),me.setProperty("--radix-popper-anchor-width",`${fe}px`),me.setProperty("--radix-popper-anchor-height",`${ke}px`)}}),C&&KV({element:C,padding:u}),rW({arrowWidth:O,arrowHeight:z}),b&&YV({strategy:"referenceHidden",...P})]}),[X,D]=_B(j),V=pn(S);wn(()=>{G&&(V==null||V())},[G,V]);const U=(re=B.arrow)==null?void 0:re.x,L=(le=B.arrow)==null?void 0:le.y,Y=((Ae=B.arrow)==null?void 0:Ae.centerOffset)!==0,[Q,se]=k.useState();return wn(()=>{R&&se(window.getComputedStyle(R).zIndex)},[R]),w.jsx("div",{ref:W.setFloating,"data-radix-popper-content-wrapper":"",style:{...Z,transform:G?Z.transform:"translate(0, -200%)",minWidth:"max-content",zIndex:Q,"--radix-popper-transform-origin":[(ae=B.transformOrigin)==null?void 0:ae.x,(we=B.transformOrigin)==null?void 0:we.y].join(" "),...((xe=B.hide)==null?void 0:xe.referenceHidden)&&{visibility:"hidden",pointerEvents:"none"}},dir:e.dir,children:w.jsx(JV,{scope:n,placedSide:X,onArrowChange:N,arrowX:U,arrowY:L,shouldHideArrow:Y,children:w.jsx(Xe.div,{"data-side":X,"data-align":D,...v,ref:T,style:{...v.style,animation:G?void 0:"none"}})})})});kB.displayName=Qk;var AB="PopperArrow",tW={top:"bottom",right:"left",bottom:"top",left:"right"},TB=k.forwardRef(function(t,n){const{__scopePopper:r,...a}=t,i=eW(AB,r),l=tW[i.placedSide];return w.jsx("span",{ref:i.onArrowChange,style:{position:"absolute",left:i.arrowX,top:i.arrowY,[l]:0,transformOrigin:{top:"",right:"0 0",bottom:"center 0",left:"100% 0"}[i.placedSide],transform:{top:"translateY(100%)",right:"translateY(50%) rotate(90deg) translateX(-50%)",bottom:"rotate(180deg)",left:"translateY(50%) rotate(-90deg) translateX(50%)"}[i.placedSide],visibility:i.shouldHideArrow?"hidden":void 0},children:w.jsx(ZV,{...a,ref:n,style:{...a.style,display:"block"}})})});TB.displayName=AB;function nW(e){return e!==null}var rW=e=>({name:"transformOrigin",options:e,fn(t){var A,R,x;const{placement:n,rects:r,middlewareData:a}=t,l=((A=a.arrow)==null?void 0:A.centerOffset)!==0,u=l?0:e.arrowWidth,c=l?0:e.arrowHeight,[f,p]=_B(n),g={start:"0%",center:"50%",end:"100%"}[p],b=(((R=a.arrow)==null?void 0:R.x)??0)+u/2,m=(((x=a.arrow)==null?void 0:x.y)??0)+c/2;let S="",v="";return f==="bottom"?(S=l?g:`${b}px`,v=`${-c}px`):f==="top"?(S=l?g:`${b}px`,v=`${r.floating.height+c}px`):f==="right"?(S=`${-c}px`,v=l?g:`${m}px`):f==="left"&&(S=`${r.floating.width+c}px`,v=l?g:`${m}px`),{data:{x:S,y:v}}}});function _B(e){const[t,n="center"]=e.split("-");return[t,n]}var Jk=EB,vf=xB,e0=kB,t0=TB,aW="VisuallyHidden",n0=k.forwardRef((e,t)=>w.jsx(Xe.span,{...e,ref:t,style:{position:"absolute",border:0,width:1,height:1,padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",wordWrap:"normal",...e.style}}));n0.displayName=aW;var oW=n0,[Sf,Jye]=mr("Tooltip",[Nl]),Ef=Nl(),RB="TooltipProvider",iW=700,Cx="tooltip.open",[lW,r0]=Sf(RB),CB=e=>{const{__scopeTooltip:t,delayDuration:n=iW,skipDelayDuration:r=300,disableHoverableContent:a=!1,children:i}=e,[l,u]=k.useState(!0),c=k.useRef(!1),f=k.useRef(0);return k.useEffect(()=>{const p=f.current;return()=>window.clearTimeout(p)},[]),w.jsx(lW,{scope:t,isOpenDelayed:l,delayDuration:n,onOpen:k.useCallback(()=>{window.clearTimeout(f.current),u(!1)},[]),onClose:k.useCallback(()=>{window.clearTimeout(f.current),f.current=window.setTimeout(()=>u(!0),r)},[r]),isPointerInTransitRef:c,onPointerInTransitChange:k.useCallback(p=>{c.current=p},[]),disableHoverableContent:a,children:i})};CB.displayName=RB;var wf="Tooltip",[sW,xf]=Sf(wf),NB=e=>{const{__scopeTooltip:t,children:n,open:r,defaultOpen:a=!1,onOpenChange:i,disableHoverableContent:l,delayDuration:u}=e,c=r0(wf,e.__scopeTooltip),f=Ef(t),[p,g]=k.useState(null),b=En(),m=k.useRef(0),S=l??c.disableHoverableContent,v=u??c.delayDuration,A=k.useRef(!1),[R=!1,x]=Oa({prop:r,defaultProp:a,onChange:O=>{O?(c.onOpen(),document.dispatchEvent(new CustomEvent(Cx))):c.onClose(),i==null||i(O)}}),T=k.useMemo(()=>R?A.current?"delayed-open":"instant-open":"closed",[R]),C=k.useCallback(()=>{window.clearTimeout(m.current),m.current=0,A.current=!1,x(!0)},[x]),N=k.useCallback(()=>{window.clearTimeout(m.current),m.current=0,x(!1)},[x]),_=k.useCallback(()=>{window.clearTimeout(m.current),m.current=window.setTimeout(()=>{A.current=!0,x(!0),m.current=0},v)},[v,x]);return k.useEffect(()=>()=>{m.current&&(window.clearTimeout(m.current),m.current=0)},[]),w.jsx(Jk,{...f,children:w.jsx(sW,{scope:t,contentId:b,open:R,stateAttribute:T,trigger:p,onTriggerChange:g,onTriggerEnter:k.useCallback(()=>{c.isOpenDelayed?_():C()},[c.isOpenDelayed,_,C]),onTriggerLeave:k.useCallback(()=>{S?N():(window.clearTimeout(m.current),m.current=0)},[N,S]),onOpen:C,onClose:N,disableHoverableContent:S,children:n})})};NB.displayName=wf;var Nx="TooltipTrigger",OB=k.forwardRef((e,t)=>{const{__scopeTooltip:n,...r}=e,a=xf(Nx,n),i=r0(Nx,n),l=Ef(n),u=k.useRef(null),c=ft(t,u,a.onTriggerChange),f=k.useRef(!1),p=k.useRef(!1),g=k.useCallback(()=>f.current=!1,[]);return k.useEffect(()=>()=>document.removeEventListener("pointerup",g),[g]),w.jsx(vf,{asChild:!0,...l,children:w.jsx(Xe.button,{"aria-describedby":a.open?a.contentId:void 0,"data-state":a.stateAttribute,...r,ref:c,onPointerMove:Ye(e.onPointerMove,b=>{b.pointerType!=="touch"&&!p.current&&!i.isPointerInTransitRef.current&&(a.onTriggerEnter(),p.current=!0)}),onPointerLeave:Ye(e.onPointerLeave,()=>{a.onTriggerLeave(),p.current=!1}),onPointerDown:Ye(e.onPointerDown,()=>{f.current=!0,document.addEventListener("pointerup",g,{once:!0})}),onFocus:Ye(e.onFocus,()=>{f.current||a.onOpen()}),onBlur:Ye(e.onBlur,a.onClose),onClick:Ye(e.onClick,a.onClose)})})});OB.displayName=Nx;var uW="TooltipPortal",[eve,cW]=Sf(uW,{forceMount:void 0}),bl="TooltipContent",DB=k.forwardRef((e,t)=>{const n=cW(bl,e.__scopeTooltip),{forceMount:r=n.forceMount,side:a="top",...i}=e,l=xf(bl,e.__scopeTooltip);return w.jsx(Jn,{present:r||l.open,children:l.disableHoverableContent?w.jsx(IB,{side:a,...i,ref:t}):w.jsx(dW,{side:a,...i,ref:t})})}),dW=k.forwardRef((e,t)=>{const n=xf(bl,e.__scopeTooltip),r=r0(bl,e.__scopeTooltip),a=k.useRef(null),i=ft(t,a),[l,u]=k.useState(null),{trigger:c,onClose:f}=n,p=a.current,{onPointerInTransitChange:g}=r,b=k.useCallback(()=>{u(null),g(!1)},[g]),m=k.useCallback((S,v)=>{const A=S.currentTarget,R={x:S.clientX,y:S.clientY},x=hW(R,A.getBoundingClientRect()),T=mW(R,x),C=bW(v.getBoundingClientRect()),N=vW([...T,...C]);u(N),g(!0)},[g]);return k.useEffect(()=>()=>b(),[b]),k.useEffect(()=>{if(c&&p){const S=A=>m(A,p),v=A=>m(A,c);return c.addEventListener("pointerleave",S),p.addEventListener("pointerleave",v),()=>{c.removeEventListener("pointerleave",S),p.removeEventListener("pointerleave",v)}}},[c,p,m,b]),k.useEffect(()=>{if(l){const S=v=>{const A=v.target,R={x:v.clientX,y:v.clientY},x=(c==null?void 0:c.contains(A))||(p==null?void 0:p.contains(A)),T=!yW(R,l);x?b():T&&(b(),f())};return document.addEventListener("pointermove",S),()=>document.removeEventListener("pointermove",S)}},[c,p,l,f,b]),w.jsx(IB,{...e,ref:i})}),[fW,pW]=Sf(wf,{isInside:!1}),IB=k.forwardRef((e,t)=>{const{__scopeTooltip:n,children:r,"aria-label":a,onEscapeKeyDown:i,onPointerDownOutside:l,...u}=e,c=xf(bl,n),f=Ef(n),{onClose:p}=c;return k.useEffect(()=>(document.addEventListener(Cx,p),()=>document.removeEventListener(Cx,p)),[p]),k.useEffect(()=>{if(c.trigger){const g=b=>{const m=b.target;m!=null&&m.contains(c.trigger)&&p()};return window.addEventListener("scroll",g,{capture:!0}),()=>window.removeEventListener("scroll",g,{capture:!0})}},[c.trigger,p]),w.jsx(hu,{asChild:!0,disableOutsidePointerEvents:!1,onEscapeKeyDown:i,onPointerDownOutside:l,onFocusOutside:g=>g.preventDefault(),onDismiss:p,children:w.jsxs(e0,{"data-state":c.stateAttribute,...f,...u,ref:t,style:{...u.style,"--radix-tooltip-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-tooltip-content-available-width":"var(--radix-popper-available-width)","--radix-tooltip-content-available-height":"var(--radix-popper-available-height)","--radix-tooltip-trigger-width":"var(--radix-popper-anchor-width)","--radix-tooltip-trigger-height":"var(--radix-popper-anchor-height)"},children:[w.jsx(Dk,{children:r}),w.jsx(fW,{scope:n,isInside:!0,children:w.jsx(oW,{id:c.contentId,role:"tooltip",children:a||r})})]})})});DB.displayName=bl;var LB="TooltipArrow",gW=k.forwardRef((e,t)=>{const{__scopeTooltip:n,...r}=e,a=Ef(n);return pW(LB,n).isInside?null:w.jsx(t0,{...a,...r,ref:t})});gW.displayName=LB;function hW(e,t){const n=Math.abs(t.top-e.y),r=Math.abs(t.bottom-e.y),a=Math.abs(t.right-e.x),i=Math.abs(t.left-e.x);switch(Math.min(n,r,a,i)){case i:return"left";case a:return"right";case n:return"top";case r:return"bottom";default:throw new Error("unreachable")}}function mW(e,t,n=5){const r=[];switch(t){case"top":r.push({x:e.x-n,y:e.y+n},{x:e.x+n,y:e.y+n});break;case"bottom":r.push({x:e.x-n,y:e.y-n},{x:e.x+n,y:e.y-n});break;case"left":r.push({x:e.x+n,y:e.y-n},{x:e.x+n,y:e.y+n});break;case"right":r.push({x:e.x-n,y:e.y-n},{x:e.x-n,y:e.y+n});break}return r}function bW(e){const{top:t,right:n,bottom:r,left:a}=e;return[{x:a,y:t},{x:n,y:t},{x:n,y:r},{x:a,y:r}]}function yW(e,t){const{x:n,y:r}=e;let a=!1;for(let i=0,l=t.length-1;i<t.length;l=i++){const u=t[i].x,c=t[i].y,f=t[l].x,p=t[l].y;c>r!=p>r&&n<(f-u)*(r-c)/(p-c)+u&&(a=!a)}return a}function vW(e){const t=e.slice();return t.sort((n,r)=>n.x<r.x?-1:n.x>r.x?1:n.y<r.y?-1:n.y>r.y?1:0),SW(t)}function SW(e){if(e.length<=1)return e.slice();const t=[];for(let r=0;r<e.length;r++){const a=e[r];for(;t.length>=2;){const i=t[t.length-1],l=t[t.length-2];if((i.x-l.x)*(a.y-l.y)>=(i.y-l.y)*(a.x-l.x))t.pop();else break}t.push(a)}t.pop();const n=[];for(let r=e.length-1;r>=0;r--){const a=e[r];for(;n.length>=2;){const i=n[n.length-1],l=n[n.length-2];if((i.x-l.x)*(a.y-l.y)>=(i.y-l.y)*(a.x-l.x))n.pop();else break}n.push(a)}return n.pop(),t.length===1&&n.length===1&&t[0].x===n[0].x&&t[0].y===n[0].y?t:t.concat(n)}var EW=CB,wW=NB,xW=OB,MB=DB;const FB=EW,zB=wW,PB=xW,kW=e=>typeof e!="string"?e:e.split("\\n").map((t,n)=>w.jsxs(k.Fragment,{children:[t,n<e.split("\\n").length-1&&w.jsx("br",{})]},n)),a0=k.forwardRef(({className:e,sideOffset:t=4,children:n,...r},a)=>w.jsx(MB,{ref:a,sideOffset:t,className:Me("bg-popover text-popover-foreground animate-in fade-in-0 zoom-in-95 data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=closed]:zoom-out-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 mx-1 max-w-sm overflow-hidden rounded-md border px-3 py-2 text-sm shadow-md",e),...r,children:typeof n=="string"?kW(n):n}));a0.displayName=MB.displayName;const zd=Nz("inline-flex items-center justify-center gap-2 whitespace-nowrap rounded-md text-sm font-medium ring-offset-background transition-colors focus-visible:outline-none focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2 disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0",{variants:{variant:{default:"bg-primary text-primary-foreground hover:bg-primary/90",destructive:"bg-destructive text-destructive-foreground hover:bg-destructive/90",outline:"border border-input bg-background hover:bg-accent hover:text-accent-foreground",secondary:"bg-secondary text-secondary-foreground hover:bg-secondary/80",ghost:"hover:bg-accent hover:text-accent-foreground",link:"text-primary underline-offset-4 hover:underline"},size:{default:"h-10 px-4 py-2",sm:"h-9 rounded-md px-3",lg:"h-11 rounded-md px-8",icon:"size-8"}},defaultVariants:{variant:"default",size:"default"}}),Lt=k.forwardRef(({className:e,variant:t,tooltip:n,size:r,side:a="right",asChild:i=!1,...l},u)=>{const c=i?bo:"button";return n?w.jsx(FB,{children:w.jsxs(zB,{children:[w.jsx(PB,{asChild:!0,children:w.jsx(c,{className:Me(zd({variant:t,size:r,className:e}),"cursor-pointer"),ref:u,...l})}),w.jsx(a0,{side:a,children:n})]})}):w.jsx(c,{className:Me(zd({variant:t,size:r,className:e}),"cursor-pointer"),ref:u,...l})});Lt.displayName="Button";const AW=Z7,TW=Q7,BB=k.forwardRef(({className:e,...t},n)=>w.jsx(tB,{className:Me("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/80",e),...t,ref:n}));BB.displayName=tB.displayName;const UB=k.forwardRef(({className:e,...t},n)=>w.jsxs(TW,{children:[w.jsx(BB,{}),w.jsx(nB,{ref:n,className:Me("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-top-[48%] fixed top-[50%] left-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border p-6 shadow-lg duration-200 sm:rounded-lg",e),...t})]}));UB.displayName=nB.displayName;const jB=({className:e,...t})=>w.jsx("div",{className:Me("flex flex-col space-y-2 text-center sm:text-left",e),...t});jB.displayName="AlertDialogHeader";const GB=k.forwardRef(({className:e,...t},n)=>w.jsx(oB,{ref:n,className:Me("text-lg font-semibold",e),...t}));GB.displayName=oB.displayName;const HB=k.forwardRef(({className:e,...t},n)=>w.jsx(iB,{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));HB.displayName=iB.displayName;const _W=k.forwardRef(({className:e,...t},n)=>w.jsx(rB,{ref:n,className:Me(zd(),e),...t}));_W.displayName=rB.displayName;const RW=k.forwardRef(({className:e,...t},n)=>w.jsx(aB,{ref:n,className:Me(zd({variant:"outline"}),"mt-2 sm:mt-0",e),...t}));RW.displayName=aB.displayName;const Eo=k.forwardRef(({className:e,type:t,...n},r)=>w.jsx("input",{type:t,className:Me("border-input file:text-foreground placeholder:text-muted-foreground focus-visible:ring-ring flex h-9 rounded-md border bg-transparent px-3 py-1 text-base shadow-sm transition-colors file:border-0 file:bg-transparent file:text-sm file:font-medium focus-visible:ring-1 focus-visible:outline-none disabled:cursor-not-allowed disabled:opacity-50 md:text-sm [&::-webkit-inner-spin-button]:opacity-100 [&::-webkit-outer-spin-button]:opacity-100",e),ref:r,...n}));Eo.displayName="Input";var CW=e=>{switch(e){case"success":return DW;case"info":return LW;case"warning":return IW;case"error":return MW;default:return null}},NW=Array(12).fill(0),OW=({visible:e,className:t})=>ye.createElement("div",{className:["sonner-loading-wrapper",t].filter(Boolean).join(" "),"data-visible":e},ye.createElement("div",{className:"sonner-spinner"},NW.map((n,r)=>ye.createElement("div",{className:"sonner-loading-bar",key:`spinner-bar-${r}`})))),DW=ye.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},ye.createElement("path",{fillRule:"evenodd",d:"M10 18a8 8 0 100-16 8 8 0 000 16zm3.857-9.809a.75.75 0 00-1.214-.882l-3.483 4.79-1.88-1.88a.75.75 0 10-1.06 1.061l2.5 2.5a.75.75 0 001.137-.089l4-5.5z",clipRule:"evenodd"})),IW=ye.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 24 24",fill:"currentColor",height:"20",width:"20"},ye.createElement("path",{fillRule:"evenodd",d:"M9.401 3.003c1.155-2 4.043-2 5.197 0l7.355 12.748c1.154 2-.29 4.5-2.599 4.5H4.645c-2.309 0-3.752-2.5-2.598-4.5L9.4 3.003zM12 8.25a.75.75 0 01.75.75v3.75a.75.75 0 01-1.5 0V9a.75.75 0 01.75-.75zm0 8.25a.75.75 0 100-1.5.75.75 0 000 1.5z",clipRule:"evenodd"})),LW=ye.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},ye.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-7-4a1 1 0 11-2 0 1 1 0 012 0zM9 9a.75.75 0 000 1.5h.253a.25.25 0 01.244.304l-.459 2.066A1.75 1.75 0 0010.747 15H11a.75.75 0 000-1.5h-.253a.25.25 0 01-.244-.304l.459-2.066A1.75 1.75 0 009.253 9H9z",clipRule:"evenodd"})),MW=ye.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",viewBox:"0 0 20 20",fill:"currentColor",height:"20",width:"20"},ye.createElement("path",{fillRule:"evenodd",d:"M18 10a8 8 0 11-16 0 8 8 0 0116 0zm-8-5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z",clipRule:"evenodd"})),FW=ye.createElement("svg",{xmlns:"http://www.w3.org/2000/svg",width:"12",height:"12",viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:"1.5",strokeLinecap:"round",strokeLinejoin:"round"},ye.createElement("line",{x1:"18",y1:"6",x2:"6",y2:"18"}),ye.createElement("line",{x1:"6",y1:"6",x2:"18",y2:"18"})),zW=()=>{let[e,t]=ye.useState(document.hidden);return ye.useEffect(()=>{let n=()=>{t(document.hidden)};return document.addEventListener("visibilitychange",n),()=>window.removeEventListener("visibilitychange",n)},[]),e},Ox=1,PW=class{constructor(){this.subscribe=e=>(this.subscribers.push(e),()=>{let t=this.subscribers.indexOf(e);this.subscribers.splice(t,1)}),this.publish=e=>{this.subscribers.forEach(t=>t(e))},this.addToast=e=>{this.publish(e),this.toasts=[...this.toasts,e]},this.create=e=>{var t;let{message:n,...r}=e,a=typeof(e==null?void 0:e.id)=="number"||((t=e.id)==null?void 0:t.length)>0?e.id:Ox++,i=this.toasts.find(u=>u.id===a),l=e.dismissible===void 0?!0:e.dismissible;return this.dismissedToasts.has(a)&&this.dismissedToasts.delete(a),i?this.toasts=this.toasts.map(u=>u.id===a?(this.publish({...u,...e,id:a,title:n}),{...u,...e,id:a,dismissible:l,title:n}):u):this.addToast({title:n,...r,dismissible:l,id:a}),a},this.dismiss=e=>(this.dismissedToasts.add(e),e||this.toasts.forEach(t=>{this.subscribers.forEach(n=>n({id:t.id,dismiss:!0}))}),this.subscribers.forEach(t=>t({id:e,dismiss:!0})),e),this.message=(e,t)=>this.create({...t,message:e}),this.error=(e,t)=>this.create({...t,message:e,type:"error"}),this.success=(e,t)=>this.create({...t,type:"success",message:e}),this.info=(e,t)=>this.create({...t,type:"info",message:e}),this.warning=(e,t)=>this.create({...t,type:"warning",message:e}),this.loading=(e,t)=>this.create({...t,type:"loading",message:e}),this.promise=(e,t)=>{if(!t)return;let n;t.loading!==void 0&&(n=this.create({...t,promise:e,type:"loading",message:t.loading,description:typeof t.description!="function"?t.description:void 0}));let r=e instanceof Promise?e:e(),a=n!==void 0,i,l=r.then(async c=>{if(i=["resolve",c],ye.isValidElement(c))a=!1,this.create({id:n,type:"default",message:c});else if(UW(c)&&!c.ok){a=!1;let f=typeof t.error=="function"?await t.error(`HTTP error! status: ${c.status}`):t.error,p=typeof t.description=="function"?await t.description(`HTTP error! status: ${c.status}`):t.description;this.create({id:n,type:"error",message:f,description:p})}else if(t.success!==void 0){a=!1;let f=typeof t.success=="function"?await t.success(c):t.success,p=typeof t.description=="function"?await t.description(c):t.description;this.create({id:n,type:"success",message:f,description:p})}}).catch(async c=>{if(i=["reject",c],t.error!==void 0){a=!1;let f=typeof t.error=="function"?await t.error(c):t.error,p=typeof t.description=="function"?await t.description(c):t.description;this.create({id:n,type:"error",message:f,description:p})}}).finally(()=>{var c;a&&(this.dismiss(n),n=void 0),(c=t.finally)==null||c.call(t)}),u=()=>new Promise((c,f)=>l.then(()=>i[0]==="reject"?f(i[1]):c(i[1])).catch(f));return typeof n!="string"&&typeof n!="number"?{unwrap:u}:Object.assign(n,{unwrap:u})},this.custom=(e,t)=>{let n=(t==null?void 0:t.id)||Ox++;return this.create({jsx:e(n),id:n,...t}),n},this.getActiveToasts=()=>this.toasts.filter(e=>!this.dismissedToasts.has(e.id)),this.subscribers=[],this.toasts=[],this.dismissedToasts=new Set}},Fn=new PW,BW=(e,t)=>{let n=(t==null?void 0:t.id)||Ox++;return Fn.addToast({title:e,...t,id:n}),n},UW=e=>e&&typeof e=="object"&&"ok"in e&&typeof e.ok=="boolean"&&"status"in e&&typeof e.status=="number",jW=BW,GW=()=>Fn.toasts,HW=()=>Fn.getActiveToasts(),vn=Object.assign(jW,{success:Fn.success,info:Fn.info,warning:Fn.warning,error:Fn.error,custom:Fn.custom,message:Fn.message,promise:Fn.promise,dismiss:Fn.dismiss,loading:Fn.loading},{getHistory:GW,getToasts:HW});function $W(e,{insertAt:t}={}){if(typeof document>"u")return;let n=document.head||document.getElementsByTagName("head")[0],r=document.createElement("style");r.type="text/css",t==="top"&&n.firstChild?n.insertBefore(r,n.firstChild):n.appendChild(r),r.styleSheet?r.styleSheet.cssText=e:r.appendChild(document.createTextNode(e))}$W(`:where(html[dir="ltr"]),:where([data-sonner-toaster][dir="ltr"]){--toast-icon-margin-start: -3px;--toast-icon-margin-end: 4px;--toast-svg-margin-start: -1px;--toast-svg-margin-end: 0px;--toast-button-margin-start: auto;--toast-button-margin-end: 0;--toast-close-button-start: 0;--toast-close-button-end: unset;--toast-close-button-transform: translate(-35%, -35%)}:where(html[dir="rtl"]),:where([data-sonner-toaster][dir="rtl"]){--toast-icon-margin-start: 4px;--toast-icon-margin-end: -3px;--toast-svg-margin-start: 0px;--toast-svg-margin-end: -1px;--toast-button-margin-start: 0;--toast-button-margin-end: auto;--toast-close-button-start: unset;--toast-close-button-end: 0;--toast-close-button-transform: translate(35%, -35%)}:where([data-sonner-toaster]){position:fixed;width:var(--width);font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,Apple Color Emoji,Segoe UI Emoji,Segoe UI Symbol,Noto Color Emoji;--gray1: hsl(0, 0%, 99%);--gray2: hsl(0, 0%, 97.3%);--gray3: hsl(0, 0%, 95.1%);--gray4: hsl(0, 0%, 93%);--gray5: hsl(0, 0%, 90.9%);--gray6: hsl(0, 0%, 88.7%);--gray7: hsl(0, 0%, 85.8%);--gray8: hsl(0, 0%, 78%);--gray9: hsl(0, 0%, 56.1%);--gray10: hsl(0, 0%, 52.3%);--gray11: hsl(0, 0%, 43.5%);--gray12: hsl(0, 0%, 9%);--border-radius: 8px;box-sizing:border-box;padding:0;margin:0;list-style:none;outline:none;z-index:999999999;transition:transform .4s ease}:where([data-sonner-toaster][data-lifted="true"]){transform:translateY(-10px)}@media (hover: none) and (pointer: coarse){:where([data-sonner-toaster][data-lifted="true"]){transform:none}}:where([data-sonner-toaster][data-x-position="right"]){right:var(--offset-right)}:where([data-sonner-toaster][data-x-position="left"]){left:var(--offset-left)}:where([data-sonner-toaster][data-x-position="center"]){left:50%;transform:translate(-50%)}:where([data-sonner-toaster][data-y-position="top"]){top:var(--offset-top)}:where([data-sonner-toaster][data-y-position="bottom"]){bottom:var(--offset-bottom)}:where([data-sonner-toast]){--y: translateY(100%);--lift-amount: calc(var(--lift) * var(--gap));z-index:var(--z-index);position:absolute;opacity:0;transform:var(--y);filter:blur(0);touch-action:none;transition:transform .4s,opacity .4s,height .4s,box-shadow .2s;box-sizing:border-box;outline:none;overflow-wrap:anywhere}:where([data-sonner-toast][data-styled="true"]){padding:16px;background:var(--normal-bg);border:1px solid var(--normal-border);color:var(--normal-text);border-radius:var(--border-radius);box-shadow:0 4px 12px #0000001a;width:var(--width);font-size:13px;display:flex;align-items:center;gap:6px}:where([data-sonner-toast]:focus-visible){box-shadow:0 4px 12px #0000001a,0 0 0 2px #0003}:where([data-sonner-toast][data-y-position="top"]){top:0;--y: translateY(-100%);--lift: 1;--lift-amount: calc(1 * var(--gap))}:where([data-sonner-toast][data-y-position="bottom"]){bottom:0;--y: translateY(100%);--lift: -1;--lift-amount: calc(var(--lift) * var(--gap))}:where([data-sonner-toast]) :where([data-description]){font-weight:400;line-height:1.4;color:inherit}:where([data-sonner-toast]) :where([data-title]){font-weight:500;line-height:1.5;color:inherit}:where([data-sonner-toast]) :where([data-icon]){display:flex;height:16px;width:16px;position:relative;justify-content:flex-start;align-items:center;flex-shrink:0;margin-left:var(--toast-icon-margin-start);margin-right:var(--toast-icon-margin-end)}:where([data-sonner-toast][data-promise="true"]) :where([data-icon])>svg{opacity:0;transform:scale(.8);transform-origin:center;animation:sonner-fade-in .3s ease forwards}:where([data-sonner-toast]) :where([data-icon])>*{flex-shrink:0}:where([data-sonner-toast]) :where([data-icon]) svg{margin-left:var(--toast-svg-margin-start);margin-right:var(--toast-svg-margin-end)}:where([data-sonner-toast]) :where([data-content]){display:flex;flex-direction:column;gap:2px}[data-sonner-toast][data-styled=true] [data-button]{border-radius:4px;padding-left:8px;padding-right:8px;height:24px;font-size:12px;color:var(--normal-bg);background:var(--normal-text);margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end);border:none;cursor:pointer;outline:none;display:flex;align-items:center;flex-shrink:0;transition:opacity .4s,box-shadow .2s}:where([data-sonner-toast]) :where([data-button]):focus-visible{box-shadow:0 0 0 2px #0006}:where([data-sonner-toast]) :where([data-button]):first-of-type{margin-left:var(--toast-button-margin-start);margin-right:var(--toast-button-margin-end)}:where([data-sonner-toast]) :where([data-cancel]){color:var(--normal-text);background:rgba(0,0,0,.08)}:where([data-sonner-toast][data-theme="dark"]) :where([data-cancel]){background:rgba(255,255,255,.3)}:where([data-sonner-toast]) :where([data-close-button]){position:absolute;left:var(--toast-close-button-start);right:var(--toast-close-button-end);top:0;height:20px;width:20px;display:flex;justify-content:center;align-items:center;padding:0;color:var(--gray12);border:1px solid var(--gray4);transform:var(--toast-close-button-transform);border-radius:50%;cursor:pointer;z-index:1;transition:opacity .1s,background .2s,border-color .2s}[data-sonner-toast] [data-close-button]{background:var(--gray1)}:where([data-sonner-toast]) :where([data-close-button]):focus-visible{box-shadow:0 4px 12px #0000001a,0 0 0 2px #0003}:where([data-sonner-toast]) :where([data-disabled="true"]){cursor:not-allowed}:where([data-sonner-toast]):hover :where([data-close-button]):hover{background:var(--gray2);border-color:var(--gray5)}:where([data-sonner-toast][data-swiping="true"]):before{content:"";position:absolute;left:-50%;right:-50%;height:100%;z-index:-1}:where([data-sonner-toast][data-y-position="top"][data-swiping="true"]):before{bottom:50%;transform:scaleY(3) translateY(50%)}:where([data-sonner-toast][data-y-position="bottom"][data-swiping="true"]):before{top:50%;transform:scaleY(3) translateY(-50%)}:where([data-sonner-toast][data-swiping="false"][data-removed="true"]):before{content:"";position:absolute;inset:0;transform:scaleY(2)}:where([data-sonner-toast]):after{content:"";position:absolute;left:0;height:calc(var(--gap) + 1px);bottom:100%;width:100%}:where([data-sonner-toast][data-mounted="true"]){--y: translateY(0);opacity:1}:where([data-sonner-toast][data-expanded="false"][data-front="false"]){--scale: var(--toasts-before) * .05 + 1;--y: translateY(calc(var(--lift-amount) * var(--toasts-before))) scale(calc(-1 * var(--scale)));height:var(--front-toast-height)}:where([data-sonner-toast])>*{transition:opacity .4s}:where([data-sonner-toast][data-expanded="false"][data-front="false"][data-styled="true"])>*{opacity:0}:where([data-sonner-toast][data-visible="false"]){opacity:0;pointer-events:none}:where([data-sonner-toast][data-mounted="true"][data-expanded="true"]){--y: translateY(calc(var(--lift) * var(--offset)));height:var(--initial-height)}:where([data-sonner-toast][data-removed="true"][data-front="true"][data-swipe-out="false"]){--y: translateY(calc(var(--lift) * -100%));opacity:0}:where([data-sonner-toast][data-removed="true"][data-front="false"][data-swipe-out="false"][data-expanded="true"]){--y: translateY(calc(var(--lift) * var(--offset) + var(--lift) * -100%));opacity:0}:where([data-sonner-toast][data-removed="true"][data-front="false"][data-swipe-out="false"][data-expanded="false"]){--y: translateY(40%);opacity:0;transition:transform .5s,opacity .2s}:where([data-sonner-toast][data-removed="true"][data-front="false"]):before{height:calc(var(--initial-height) + 20%)}[data-sonner-toast][data-swiping=true]{transform:var(--y) translateY(var(--swipe-amount-y, 0px)) translate(var(--swipe-amount-x, 0px));transition:none}[data-sonner-toast][data-swiped=true]{user-select:none}[data-sonner-toast][data-swipe-out=true][data-y-position=bottom],[data-sonner-toast][data-swipe-out=true][data-y-position=top]{animation-duration:.2s;animation-timing-function:ease-out;animation-fill-mode:forwards}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=left]{animation-name:swipe-out-left}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=right]{animation-name:swipe-out-right}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=up]{animation-name:swipe-out-up}[data-sonner-toast][data-swipe-out=true][data-swipe-direction=down]{animation-name:swipe-out-down}@keyframes swipe-out-left{0%{transform:var(--y) translate(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translate(calc(var(--swipe-amount-x) - 100%));opacity:0}}@keyframes swipe-out-right{0%{transform:var(--y) translate(var(--swipe-amount-x));opacity:1}to{transform:var(--y) translate(calc(var(--swipe-amount-x) + 100%));opacity:0}}@keyframes swipe-out-up{0%{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) - 100%));opacity:0}}@keyframes swipe-out-down{0%{transform:var(--y) translateY(var(--swipe-amount-y));opacity:1}to{transform:var(--y) translateY(calc(var(--swipe-amount-y) + 100%));opacity:0}}@media (max-width: 600px){[data-sonner-toaster]{position:fixed;right:var(--mobile-offset-right);left:var(--mobile-offset-left);width:100%}[data-sonner-toaster][dir=rtl]{left:calc(var(--mobile-offset-left) * -1)}[data-sonner-toaster] [data-sonner-toast]{left:0;right:0;width:calc(100% - var(--mobile-offset-left) * 2)}[data-sonner-toaster][data-x-position=left]{left:var(--mobile-offset-left)}[data-sonner-toaster][data-y-position=bottom]{bottom:var(--mobile-offset-bottom)}[data-sonner-toaster][data-y-position=top]{top:var(--mobile-offset-top)}[data-sonner-toaster][data-x-position=center]{left:var(--mobile-offset-left);right:var(--mobile-offset-right);transform:none}}[data-sonner-toaster][data-theme=light]{--normal-bg: #fff;--normal-border: var(--gray4);--normal-text: var(--gray12);--success-bg: hsl(143, 85%, 96%);--success-border: hsl(145, 92%, 91%);--success-text: hsl(140, 100%, 27%);--info-bg: hsl(208, 100%, 97%);--info-border: hsl(221, 91%, 91%);--info-text: hsl(210, 92%, 45%);--warning-bg: hsl(49, 100%, 97%);--warning-border: hsl(49, 91%, 91%);--warning-text: hsl(31, 92%, 45%);--error-bg: hsl(359, 100%, 97%);--error-border: hsl(359, 100%, 94%);--error-text: hsl(360, 100%, 45%)}[data-sonner-toaster][data-theme=light] [data-sonner-toast][data-invert=true]{--normal-bg: #000;--normal-border: hsl(0, 0%, 20%);--normal-text: var(--gray1)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast][data-invert=true]{--normal-bg: #fff;--normal-border: var(--gray3);--normal-text: var(--gray12)}[data-sonner-toaster][data-theme=dark]{--normal-bg: #000;--normal-bg-hover: hsl(0, 0%, 12%);--normal-border: hsl(0, 0%, 20%);--normal-border-hover: hsl(0, 0%, 25%);--normal-text: var(--gray1);--success-bg: hsl(150, 100%, 6%);--success-border: hsl(147, 100%, 12%);--success-text: hsl(150, 86%, 65%);--info-bg: hsl(215, 100%, 6%);--info-border: hsl(223, 100%, 12%);--info-text: hsl(216, 87%, 65%);--warning-bg: hsl(64, 100%, 6%);--warning-border: hsl(60, 100%, 12%);--warning-text: hsl(46, 87%, 65%);--error-bg: hsl(358, 76%, 10%);--error-border: hsl(357, 89%, 16%);--error-text: hsl(358, 100%, 81%)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast] [data-close-button]{background:var(--normal-bg);border-color:var(--normal-border);color:var(--normal-text)}[data-sonner-toaster][data-theme=dark] [data-sonner-toast] [data-close-button]:hover{background:var(--normal-bg-hover);border-color:var(--normal-border-hover)}[data-rich-colors=true][data-sonner-toast][data-type=success],[data-rich-colors=true][data-sonner-toast][data-type=success] [data-close-button]{background:var(--success-bg);border-color:var(--success-border);color:var(--success-text)}[data-rich-colors=true][data-sonner-toast][data-type=info],[data-rich-colors=true][data-sonner-toast][data-type=info] [data-close-button]{background:var(--info-bg);border-color:var(--info-border);color:var(--info-text)}[data-rich-colors=true][data-sonner-toast][data-type=warning],[data-rich-colors=true][data-sonner-toast][data-type=warning] [data-close-button]{background:var(--warning-bg);border-color:var(--warning-border);color:var(--warning-text)}[data-rich-colors=true][data-sonner-toast][data-type=error],[data-rich-colors=true][data-sonner-toast][data-type=error] [data-close-button]{background:var(--error-bg);border-color:var(--error-border);color:var(--error-text)}.sonner-loading-wrapper{--size: 16px;height:var(--size);width:var(--size);position:absolute;inset:0;z-index:10}.sonner-loading-wrapper[data-visible=false]{transform-origin:center;animation:sonner-fade-out .2s ease forwards}.sonner-spinner{position:relative;top:50%;left:50%;height:var(--size);width:var(--size)}.sonner-loading-bar{animation:sonner-spin 1.2s linear infinite;background:var(--gray11);border-radius:6px;height:8%;left:-10%;position:absolute;top:-3.9%;width:24%}.sonner-loading-bar:nth-child(1){animation-delay:-1.2s;transform:rotate(.0001deg) translate(146%)}.sonner-loading-bar:nth-child(2){animation-delay:-1.1s;transform:rotate(30deg) translate(146%)}.sonner-loading-bar:nth-child(3){animation-delay:-1s;transform:rotate(60deg) translate(146%)}.sonner-loading-bar:nth-child(4){animation-delay:-.9s;transform:rotate(90deg) translate(146%)}.sonner-loading-bar:nth-child(5){animation-delay:-.8s;transform:rotate(120deg) translate(146%)}.sonner-loading-bar:nth-child(6){animation-delay:-.7s;transform:rotate(150deg) translate(146%)}.sonner-loading-bar:nth-child(7){animation-delay:-.6s;transform:rotate(180deg) translate(146%)}.sonner-loading-bar:nth-child(8){animation-delay:-.5s;transform:rotate(210deg) translate(146%)}.sonner-loading-bar:nth-child(9){animation-delay:-.4s;transform:rotate(240deg) translate(146%)}.sonner-loading-bar:nth-child(10){animation-delay:-.3s;transform:rotate(270deg) translate(146%)}.sonner-loading-bar:nth-child(11){animation-delay:-.2s;transform:rotate(300deg) translate(146%)}.sonner-loading-bar:nth-child(12){animation-delay:-.1s;transform:rotate(330deg) translate(146%)}@keyframes sonner-fade-in{0%{opacity:0;transform:scale(.8)}to{opacity:1;transform:scale(1)}}@keyframes sonner-fade-out{0%{opacity:1;transform:scale(1)}to{opacity:0;transform:scale(.8)}}@keyframes sonner-spin{0%{opacity:1}to{opacity:.15}}@media (prefers-reduced-motion){[data-sonner-toast],[data-sonner-toast]>*,.sonner-loading-bar{transition:none!important;animation:none!important}}.sonner-loader{position:absolute;top:50%;left:50%;transform:translate(-50%,-50%);transform-origin:center;transition:opacity .2s,transform .2s}.sonner-loader[data-visible=false]{opacity:0;transform:scale(.8) translate(-50%,-50%)}
`);function $c(e){return e.label!==void 0}var qW=3,VW="32px",WW="16px",VR=4e3,YW=356,KW=14,XW=20,ZW=200;function Ar(...e){return e.filter(Boolean).join(" ")}function QW(e){let[t,n]=e.split("-"),r=[];return t&&r.push(t),n&&r.push(n),r}var JW=e=>{var t,n,r,a,i,l,u,c,f,p,g;let{invert:b,toast:m,unstyled:S,interacting:v,setHeights:A,visibleToasts:R,heights:x,index:T,toasts:C,expanded:N,removeToast:_,defaultRichColors:O,closeButton:z,style:I,cancelButtonStyle:M,actionButtonStyle:H,className:q="",descriptionClassName:P="",duration:W,position:Z,gap:j,loadingIcon:G,expandByDefault:B,classNames:X,icons:D,closeButtonAriaLabel:V="Close toast",pauseWhenPageIsHidden:U}=e,[L,Y]=ye.useState(null),[Q,se]=ye.useState(null),[re,le]=ye.useState(!1),[Ae,ae]=ye.useState(!1),[we,xe]=ye.useState(!1),[Ie,Ce]=ye.useState(!1),[Ee,J]=ye.useState(!1),[fe,ke]=ye.useState(0),[me,ve]=ye.useState(0),ie=ye.useRef(m.duration||W||VR),ze=ye.useRef(null),Pe=ye.useRef(null),he=T===0,Ne=T+1<=R,ee=m.type,ce=m.dismissible!==!1,Re=m.className||"",Fe=m.descriptionClassName||"",qe=ye.useMemo(()=>x.findIndex(Ke=>Ke.toastId===m.id)||0,[x,m.id]),mt=ye.useMemo(()=>{var Ke;return(Ke=m.closeButton)!=null?Ke:z},[m.closeButton,z]),St=ye.useMemo(()=>m.duration||W||VR,[m.duration,W]),pt=ye.useRef(0),Je=ye.useRef(0),wt=ye.useRef(0),rt=ye.useRef(null),[bt,Bt]=Z.split("-"),sn=ye.useMemo(()=>x.reduce((Ke,gt,_t)=>_t>=qe?Ke:Ke+gt.height,0),[x,qe]),Mt=zW(),er=m.invert||b,zr=ee==="loading";Je.current=ye.useMemo(()=>qe*j+sn,[qe,sn]),ye.useEffect(()=>{ie.current=St},[St]),ye.useEffect(()=>{le(!0)},[]),ye.useEffect(()=>{let Ke=Pe.current;if(Ke){let gt=Ke.getBoundingClientRect().height;return ve(gt),A(_t=>[{toastId:m.id,height:gt,position:m.position},..._t]),()=>A(_t=>_t.filter(Rn=>Rn.toastId!==m.id))}},[A,m.id]),ye.useLayoutEffect(()=>{if(!re)return;let Ke=Pe.current,gt=Ke.style.height;Ke.style.height="auto";let _t=Ke.getBoundingClientRect().height;Ke.style.height=gt,ve(_t),A(Rn=>Rn.find(kn=>kn.toastId===m.id)?Rn.map(kn=>kn.toastId===m.id?{...kn,height:_t}:kn):[{toastId:m.id,height:_t,position:m.position},...Rn])},[re,m.title,m.description,A,m.id]);let Kt=ye.useCallback(()=>{ae(!0),ke(Je.current),A(Ke=>Ke.filter(gt=>gt.toastId!==m.id)),setTimeout(()=>{_(m)},ZW)},[m,_,A,Je]);ye.useEffect(()=>{if(m.promise&&ee==="loading"||m.duration===1/0||m.type==="loading")return;let Ke;return N||v||U&&Mt?(()=>{if(wt.current<pt.current){let gt=new Date().getTime()-pt.current;ie.current=ie.current-gt}wt.current=new Date().getTime()})():ie.current!==1/0&&(pt.current=new Date().getTime(),Ke=setTimeout(()=>{var gt;(gt=m.onAutoClose)==null||gt.call(m,m),Kt()},ie.current)),()=>clearTimeout(Ke)},[N,v,m,ee,U,Mt,Kt]),ye.useEffect(()=>{m.delete&&Kt()},[Kt,m.delete]);function na(){var Ke,gt,_t;return D!=null&&D.loading?ye.createElement("div",{className:Ar(X==null?void 0:X.loader,(Ke=m==null?void 0:m.classNames)==null?void 0:Ke.loader,"sonner-loader"),"data-visible":ee==="loading"},D.loading):G?ye.createElement("div",{className:Ar(X==null?void 0:X.loader,(gt=m==null?void 0:m.classNames)==null?void 0:gt.loader,"sonner-loader"),"data-visible":ee==="loading"},G):ye.createElement(OW,{className:Ar(X==null?void 0:X.loader,(_t=m==null?void 0:m.classNames)==null?void 0:_t.loader),visible:ee==="loading"})}return ye.createElement("li",{tabIndex:0,ref:Pe,className:Ar(q,Re,X==null?void 0:X.toast,(t=m==null?void 0:m.classNames)==null?void 0:t.toast,X==null?void 0:X.default,X==null?void 0:X[ee],(n=m==null?void 0:m.classNames)==null?void 0:n[ee]),"data-sonner-toast":"","data-rich-colors":(r=m.richColors)!=null?r:O,"data-styled":!(m.jsx||m.unstyled||S),"data-mounted":re,"data-promise":!!m.promise,"data-swiped":Ee,"data-removed":Ae,"data-visible":Ne,"data-y-position":bt,"data-x-position":Bt,"data-index":T,"data-front":he,"data-swiping":we,"data-dismissible":ce,"data-type":ee,"data-invert":er,"data-swipe-out":Ie,"data-swipe-direction":Q,"data-expanded":!!(N||B&&re),style:{"--index":T,"--toasts-before":T,"--z-index":C.length-T,"--offset":`${Ae?fe:Je.current}px`,"--initial-height":B?"auto":`${me}px`,...I,...m.style},onDragEnd:()=>{xe(!1),Y(null),rt.current=null},onPointerDown:Ke=>{zr||!ce||(ze.current=new Date,ke(Je.current),Ke.target.setPointerCapture(Ke.pointerId),Ke.target.tagName!=="BUTTON"&&(xe(!0),rt.current={x:Ke.clientX,y:Ke.clientY}))},onPointerUp:()=>{var Ke,gt,_t,Rn;if(Ie||!ce)return;rt.current=null;let kn=Number(((Ke=Pe.current)==null?void 0:Ke.style.getPropertyValue("--swipe-amount-x").replace("px",""))||0),Cn=Number(((gt=Pe.current)==null?void 0:gt.style.getPropertyValue("--swipe-amount-y").replace("px",""))||0),ra=new Date().getTime()-((_t=ze.current)==null?void 0:_t.getTime()),Nn=L==="x"?kn:Cn,Sr=Math.abs(Nn)/ra;if(Math.abs(Nn)>=XW||Sr>.11){ke(Je.current),(Rn=m.onDismiss)==null||Rn.call(m,m),se(L==="x"?kn>0?"right":"left":Cn>0?"down":"up"),Kt(),Ce(!0),J(!1);return}xe(!1),Y(null)},onPointerMove:Ke=>{var gt,_t,Rn,kn;if(!rt.current||!ce||((gt=window.getSelection())==null?void 0:gt.toString().length)>0)return;let Cn=Ke.clientY-rt.current.y,ra=Ke.clientX-rt.current.x,Nn=(_t=e.swipeDirections)!=null?_t:QW(Z);!L&&(Math.abs(ra)>1||Math.abs(Cn)>1)&&Y(Math.abs(ra)>Math.abs(Cn)?"x":"y");let Sr={x:0,y:0};L==="y"?(Nn.includes("top")||Nn.includes("bottom"))&&(Nn.includes("top")&&Cn<0||Nn.includes("bottom")&&Cn>0)&&(Sr.y=Cn):L==="x"&&(Nn.includes("left")||Nn.includes("right"))&&(Nn.includes("left")&&ra<0||Nn.includes("right")&&ra>0)&&(Sr.x=ra),(Math.abs(Sr.x)>0||Math.abs(Sr.y)>0)&&J(!0),(Rn=Pe.current)==null||Rn.style.setProperty("--swipe-amount-x",`${Sr.x}px`),(kn=Pe.current)==null||kn.style.setProperty("--swipe-amount-y",`${Sr.y}px`)}},mt&&!m.jsx?ye.createElement("button",{"aria-label":V,"data-disabled":zr,"data-close-button":!0,onClick:zr||!ce?()=>{}:()=>{var Ke;Kt(),(Ke=m.onDismiss)==null||Ke.call(m,m)},className:Ar(X==null?void 0:X.closeButton,(a=m==null?void 0:m.classNames)==null?void 0:a.closeButton)},(i=D==null?void 0:D.close)!=null?i:FW):null,m.jsx||k.isValidElement(m.title)?m.jsx?m.jsx:typeof m.title=="function"?m.title():m.title:ye.createElement(ye.Fragment,null,ee||m.icon||m.promise?ye.createElement("div",{"data-icon":"",className:Ar(X==null?void 0:X.icon,(l=m==null?void 0:m.classNames)==null?void 0:l.icon)},m.promise||m.type==="loading"&&!m.icon?m.icon||na():null,m.type!=="loading"?m.icon||(D==null?void 0:D[ee])||CW(ee):null):null,ye.createElement("div",{"data-content":"",className:Ar(X==null?void 0:X.content,(u=m==null?void 0:m.classNames)==null?void 0:u.content)},ye.createElement("div",{"data-title":"",className:Ar(X==null?void 0:X.title,(c=m==null?void 0:m.classNames)==null?void 0:c.title)},typeof m.title=="function"?m.title():m.title),m.description?ye.createElement("div",{"data-description":"",className:Ar(P,Fe,X==null?void 0:X.description,(f=m==null?void 0:m.classNames)==null?void 0:f.description)},typeof m.description=="function"?m.description():m.description):null),k.isValidElement(m.cancel)?m.cancel:m.cancel&&$c(m.cancel)?ye.createElement("button",{"data-button":!0,"data-cancel":!0,style:m.cancelButtonStyle||M,onClick:Ke=>{var gt,_t;$c(m.cancel)&&ce&&((_t=(gt=m.cancel).onClick)==null||_t.call(gt,Ke),Kt())},className:Ar(X==null?void 0:X.cancelButton,(p=m==null?void 0:m.classNames)==null?void 0:p.cancelButton)},m.cancel.label):null,k.isValidElement(m.action)?m.action:m.action&&$c(m.action)?ye.createElement("button",{"data-button":!0,"data-action":!0,style:m.actionButtonStyle||H,onClick:Ke=>{var gt,_t;$c(m.action)&&((_t=(gt=m.action).onClick)==null||_t.call(gt,Ke),!Ke.defaultPrevented&&Kt())},className:Ar(X==null?void 0:X.actionButton,(g=m==null?void 0:m.classNames)==null?void 0:g.actionButton)},m.action.label):null))};function WR(){if(typeof window>"u"||typeof document>"u")return"ltr";let e=document.documentElement.getAttribute("dir");return e==="auto"||!e?window.getComputedStyle(document.documentElement).direction:e}function eY(e,t){let n={};return[e,t].forEach((r,a)=>{let i=a===1,l=i?"--mobile-offset":"--offset",u=i?WW:VW;function c(f){["top","right","bottom","left"].forEach(p=>{n[`${l}-${p}`]=typeof f=="number"?`${f}px`:f})}typeof r=="number"||typeof r=="string"?c(r):typeof r=="object"?["top","right","bottom","left"].forEach(f=>{r[f]===void 0?n[`${l}-${f}`]=u:n[`${l}-${f}`]=typeof r[f]=="number"?`${r[f]}px`:r[f]}):c(u)}),n}var tY=k.forwardRef(function(e,t){let{invert:n,position:r="bottom-right",hotkey:a=["altKey","KeyT"],expand:i,closeButton:l,className:u,offset:c,mobileOffset:f,theme:p="light",richColors:g,duration:b,style:m,visibleToasts:S=qW,toastOptions:v,dir:A=WR(),gap:R=KW,loadingIcon:x,icons:T,containerAriaLabel:C="Notifications",pauseWhenPageIsHidden:N}=e,[_,O]=ye.useState([]),z=ye.useMemo(()=>Array.from(new Set([r].concat(_.filter(U=>U.position).map(U=>U.position)))),[_,r]),[I,M]=ye.useState([]),[H,q]=ye.useState(!1),[P,W]=ye.useState(!1),[Z,j]=ye.useState(p!=="system"?p:typeof window<"u"&&window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light"),G=ye.useRef(null),B=a.join("+").replace(/Key/g,"").replace(/Digit/g,""),X=ye.useRef(null),D=ye.useRef(!1),V=ye.useCallback(U=>{O(L=>{var Y;return(Y=L.find(Q=>Q.id===U.id))!=null&&Y.delete||Fn.dismiss(U.id),L.filter(({id:Q})=>Q!==U.id)})},[]);return ye.useEffect(()=>Fn.subscribe(U=>{if(U.dismiss){O(L=>L.map(Y=>Y.id===U.id?{...Y,delete:!0}:Y));return}setTimeout(()=>{pP.flushSync(()=>{O(L=>{let Y=L.findIndex(Q=>Q.id===U.id);return Y!==-1?[...L.slice(0,Y),{...L[Y],...U},...L.slice(Y+1)]:[U,...L]})})})}),[]),ye.useEffect(()=>{if(p!=="system"){j(p);return}if(p==="system"&&(window.matchMedia&&window.matchMedia("(prefers-color-scheme: dark)").matches?j("dark"):j("light")),typeof window>"u")return;let U=window.matchMedia("(prefers-color-scheme: dark)");try{U.addEventListener("change",({matches:L})=>{j(L?"dark":"light")})}catch{U.addListener(({matches:Y})=>{try{j(Y?"dark":"light")}catch(Q){console.error(Q)}})}},[p]),ye.useEffect(()=>{_.length<=1&&q(!1)},[_]),ye.useEffect(()=>{let U=L=>{var Y,Q;a.every(se=>L[se]||L.code===se)&&(q(!0),(Y=G.current)==null||Y.focus()),L.code==="Escape"&&(document.activeElement===G.current||(Q=G.current)!=null&&Q.contains(document.activeElement))&&q(!1)};return document.addEventListener("keydown",U),()=>document.removeEventListener("keydown",U)},[a]),ye.useEffect(()=>{if(G.current)return()=>{X.current&&(X.current.focus({preventScroll:!0}),X.current=null,D.current=!1)}},[G.current]),ye.createElement("section",{ref:t,"aria-label":`${C} ${B}`,tabIndex:-1,"aria-live":"polite","aria-relevant":"additions text","aria-atomic":"false",suppressHydrationWarning:!0},z.map((U,L)=>{var Y;let[Q,se]=U.split("-");return _.length?ye.createElement("ol",{key:U,dir:A==="auto"?WR():A,tabIndex:-1,ref:G,className:u,"data-sonner-toaster":!0,"data-theme":Z,"data-y-position":Q,"data-lifted":H&&_.length>1&&!i,"data-x-position":se,style:{"--front-toast-height":`${((Y=I[0])==null?void 0:Y.height)||0}px`,"--width":`${YW}px`,"--gap":`${R}px`,...m,...eY(c,f)},onBlur:re=>{D.current&&!re.currentTarget.contains(re.relatedTarget)&&(D.current=!1,X.current&&(X.current.focus({preventScroll:!0}),X.current=null))},onFocus:re=>{re.target instanceof HTMLElement&&re.target.dataset.dismissible==="false"||D.current||(D.current=!0,X.current=re.relatedTarget)},onMouseEnter:()=>q(!0),onMouseMove:()=>q(!0),onMouseLeave:()=>{P||q(!1)},onDragEnd:()=>q(!1),onPointerDown:re=>{re.target instanceof HTMLElement&&re.target.dataset.dismissible==="false"||W(!0)},onPointerUp:()=>W(!1)},_.filter(re=>!re.position&&L===0||re.position===U).map((re,le)=>{var Ae,ae;return ye.createElement(JW,{key:re.id,icons:T,index:le,toast:re,defaultRichColors:g,duration:(Ae=v==null?void 0:v.duration)!=null?Ae:b,className:v==null?void 0:v.className,descriptionClassName:v==null?void 0:v.descriptionClassName,invert:n,visibleToasts:S,closeButton:(ae=v==null?void 0:v.closeButton)!=null?ae:l,interacting:P,position:U,style:v==null?void 0:v.style,unstyled:v==null?void 0:v.unstyled,classNames:v==null?void 0:v.classNames,cancelButtonStyle:v==null?void 0:v.cancelButtonStyle,actionButtonStyle:v==null?void 0:v.actionButtonStyle,removeToast:V,toasts:_.filter(we=>we.position==re.position),heights:I.filter(we=>we.position==re.position),setHeights:M,expandByDefault:i,gap:R,loadingIcon:x,expanded:H,pauseWhenPageIsHidden:N,swipeDirections:e.swipeDirections})})):null}))});const nY=()=>{const[e,t]=k.useState(!0),n=We.use.apiKey(),[r,a]=k.useState(""),i=Pn.use.message();k.useEffect(()=>{a(n||"")},[n,e]),k.useEffect(()=>{i&&(i.includes(oP)||i.includes(iP))&&t(!0)},[i,t]);const l=k.useCallback(async()=>{if(We.setState({apiKey:r||null}),await Pn.getState().check()){t(!1);return}vn.error("API Key is invalid")},[r]),u=k.useCallback(c=>{a(c.target.value)},[a]);return w.jsx(AW,{open:e,onOpenChange:t,children:w.jsxs(UB,{children:[w.jsxs(jB,{children:[w.jsx(GB,{children:"API Key is required"}),w.jsx(HB,{children:"Please enter your API key"})]}),w.jsxs("form",{className:"flex gap-2",onSubmit:c=>c.preventDefault(),children:[w.jsx(Eo,{type:"password",value:r,onChange:u,placeholder:"Enter your API key",className:"max-h-full w-full min-w-0",autoComplete:"off"}),w.jsx(Lt,{onClick:l,variant:"outline",size:"sm",children:"Save"})]})]})})};var o0="Popover",[$B,tve]=mr(o0,[Nl]),bu=Nl(),[rY,wo]=$B(o0),qB=e=>{const{__scopePopover:t,children:n,open:r,defaultOpen:a,onOpenChange:i,modal:l=!1}=e,u=bu(t),c=k.useRef(null),[f,p]=k.useState(!1),[g=!1,b]=Oa({prop:r,defaultProp:a,onChange:i});return w.jsx(Jk,{...u,children:w.jsx(rY,{scope:t,contentId:En(),triggerRef:c,open:g,onOpenChange:b,onOpenToggle:k.useCallback(()=>b(m=>!m),[b]),hasCustomAnchor:f,onCustomAnchorAdd:k.useCallback(()=>p(!0),[]),onCustomAnchorRemove:k.useCallback(()=>p(!1),[]),modal:l,children:n})})};qB.displayName=o0;var VB="PopoverAnchor",aY=k.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=wo(VB,n),i=bu(n),{onCustomAnchorAdd:l,onCustomAnchorRemove:u}=a;return k.useEffect(()=>(l(),()=>u()),[l,u]),w.jsx(vf,{...i,...r,ref:t})});aY.displayName=VB;var WB="PopoverTrigger",YB=k.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=wo(WB,n),i=bu(n),l=ft(t,a.triggerRef),u=w.jsx(Xe.button,{type:"button","aria-haspopup":"dialog","aria-expanded":a.open,"aria-controls":a.contentId,"data-state":JB(a.open),...r,ref:l,onClick:Ye(e.onClick,a.onOpenToggle)});return a.hasCustomAnchor?u:w.jsx(vf,{asChild:!0,...i,children:u})});YB.displayName=WB;var i0="PopoverPortal",[oY,iY]=$B(i0,{forceMount:void 0}),KB=e=>{const{__scopePopover:t,forceMount:n,children:r,container:a}=e,i=wo(i0,t);return w.jsx(oY,{scope:t,forceMount:n,children:w.jsx(Jn,{present:n||i.open,children:w.jsx(df,{asChild:!0,container:a,children:r})})})};KB.displayName=i0;var yl="PopoverContent",XB=k.forwardRef((e,t)=>{const n=iY(yl,e.__scopePopover),{forceMount:r=n.forceMount,...a}=e,i=wo(yl,e.__scopePopover);return w.jsx(Jn,{present:r||i.open,children:i.modal?w.jsx(lY,{...a,ref:t}):w.jsx(sY,{...a,ref:t})})});XB.displayName=yl;var lY=k.forwardRef((e,t)=>{const n=wo(yl,e.__scopePopover),r=k.useRef(null),a=ft(t,r),i=k.useRef(!1);return k.useEffect(()=>{const l=r.current;if(l)return Lk(l)},[]),w.jsx(pf,{as:bo,allowPinchZoom:!0,children:w.jsx(ZB,{...e,ref:a,trapFocus:n.open,disableOutsidePointerEvents:!0,onCloseAutoFocus:Ye(e.onCloseAutoFocus,l=>{var u;l.preventDefault(),i.current||(u=n.triggerRef.current)==null||u.focus()}),onPointerDownOutside:Ye(e.onPointerDownOutside,l=>{const u=l.detail.originalEvent,c=u.button===0&&u.ctrlKey===!0,f=u.button===2||c;i.current=f},{checkForDefaultPrevented:!1}),onFocusOutside:Ye(e.onFocusOutside,l=>l.preventDefault(),{checkForDefaultPrevented:!1})})})}),sY=k.forwardRef((e,t)=>{const n=wo(yl,e.__scopePopover),r=k.useRef(!1),a=k.useRef(!1);return w.jsx(ZB,{...e,ref:t,trapFocus:!1,disableOutsidePointerEvents:!1,onCloseAutoFocus:i=>{var l,u;(l=e.onCloseAutoFocus)==null||l.call(e,i),i.defaultPrevented||(r.current||(u=n.triggerRef.current)==null||u.focus(),i.preventDefault()),r.current=!1,a.current=!1},onInteractOutside:i=>{var c,f;(c=e.onInteractOutside)==null||c.call(e,i),i.defaultPrevented||(r.current=!0,i.detail.originalEvent.type==="pointerdown"&&(a.current=!0));const l=i.target;((f=n.triggerRef.current)==null?void 0:f.contains(l))&&i.preventDefault(),i.detail.originalEvent.type==="focusin"&&a.current&&i.preventDefault()}})}),ZB=k.forwardRef((e,t)=>{const{__scopePopover:n,trapFocus:r,onOpenAutoFocus:a,onCloseAutoFocus:i,disableOutsidePointerEvents:l,onEscapeKeyDown:u,onPointerDownOutside:c,onFocusOutside:f,onInteractOutside:p,...g}=e,b=wo(yl,n),m=bu(n);return Ik(),w.jsx(cf,{asChild:!0,loop:!0,trapped:r,onMountAutoFocus:a,onUnmountAutoFocus:i,children:w.jsx(hu,{asChild:!0,disableOutsidePointerEvents:l,onInteractOutside:p,onEscapeKeyDown:u,onPointerDownOutside:c,onFocusOutside:f,onDismiss:()=>b.onOpenChange(!1),children:w.jsx(e0,{"data-state":JB(b.open),role:"dialog",id:b.contentId,...m,...g,ref:t,style:{...g.style,"--radix-popover-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-popover-content-available-width":"var(--radix-popper-available-width)","--radix-popover-content-available-height":"var(--radix-popper-available-height)","--radix-popover-trigger-width":"var(--radix-popper-anchor-width)","--radix-popover-trigger-height":"var(--radix-popper-anchor-height)"}})})})}),QB="PopoverClose",uY=k.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=wo(QB,n);return w.jsx(Xe.button,{type:"button",...r,ref:t,onClick:Ye(e.onClick,()=>a.onOpenChange(!1))})});uY.displayName=QB;var cY="PopoverArrow",dY=k.forwardRef((e,t)=>{const{__scopePopover:n,...r}=e,a=bu(n);return w.jsx(t0,{...a,...r,ref:t})});dY.displayName=cY;function JB(e){return e?"open":"closed"}var fY=qB,pY=YB,gY=KB,eU=XB;const kf=fY,Af=pY,yu=k.forwardRef(({className:e,align:t="center",sideOffset:n=4,...r},a)=>w.jsx(gY,{children:w.jsx(eU,{ref:a,align:t,sideOffset:n,className:Me("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 z-50 rounded-md border p-4 shadow-md outline-none",e),...r})}));yu.displayName=eU.displayName;const hY=({status:e})=>e?w.jsxs("div",{className:"min-w-[300px] space-y-3 text-sm",children:[w.jsxs("div",{className:"space-y-1",children:[w.jsx("h4",{className:"font-medium",children:"Storage Info"}),w.jsxs("div",{className:"text-muted-foreground grid grid-cols-2 gap-1",children:[w.jsx("span",{children:"Working Directory:"}),w.jsx("span",{className:"truncate",children:e.working_directory}),w.jsx("span",{children:"Input Directory:"}),w.jsx("span",{className:"truncate",children:e.input_directory})]})]}),w.jsxs("div",{className:"space-y-1",children:[w.jsx("h4",{className:"font-medium",children:"LLM Configuration"}),w.jsxs("div",{className:"text-muted-foreground grid grid-cols-2 gap-1",children:[w.jsx("span",{children:"LLM Binding:"}),w.jsx("span",{children:e.configuration.llm_binding}),w.jsx("span",{children:"LLM Binding Host:"}),w.jsx("span",{children:e.configuration.llm_binding_host}),w.jsx("span",{children:"LLM Model:"}),w.jsx("span",{children:e.configuration.llm_model}),w.jsx("span",{children:"Max Tokens:"}),w.jsx("span",{children:e.configuration.max_tokens})]})]}),w.jsxs("div",{className:"space-y-1",children:[w.jsx("h4",{className:"font-medium",children:"Embedding Configuration"}),w.jsxs("div",{className:"text-muted-foreground grid grid-cols-2 gap-1",children:[w.jsx("span",{children:"Embedding Binding:"}),w.jsx("span",{children:e.configuration.embedding_binding}),w.jsx("span",{children:"Embedding Binding Host:"}),w.jsx("span",{children:e.configuration.embedding_binding_host}),w.jsx("span",{children:"Embedding Model:"}),w.jsx("span",{children:e.configuration.embedding_model})]})]}),w.jsxs("div",{className:"space-y-1",children:[w.jsx("h4",{className:"font-medium",children:"Storage Configuration"}),w.jsxs("div",{className:"text-muted-foreground grid grid-cols-2 gap-1",children:[w.jsx("span",{children:"KV Storage:"}),w.jsx("span",{children:e.configuration.kv_storage}),w.jsx("span",{children:"Doc Status Storage:"}),w.jsx("span",{children:e.configuration.doc_status_storage}),w.jsx("span",{children:"Graph Storage:"}),w.jsx("span",{children:e.configuration.graph_storage}),w.jsx("span",{children:"Vector Storage:"}),w.jsx("span",{children:e.configuration.vector_storage})]})]})]}):w.jsx("div",{className:"text-muted-foreground text-sm",children:"Status information unavailable"}),mY=()=>{const e=Pn.use.health(),t=Pn.use.lastCheckTime(),n=Pn.use.status(),[r,a]=k.useState(!1);return k.useEffect(()=>{a(!0);const i=setTimeout(()=>a(!1),300);return()=>clearTimeout(i)},[t]),w.jsx("div",{className:"fixed right-4 bottom-4 flex items-center gap-2 opacity-80 select-none",children:w.jsxs(kf,{children:[w.jsx(Af,{asChild:!0,children:w.jsxs("div",{className:"flex cursor-help items-center gap-2",children:[w.jsx("div",{className:Me("h-3 w-3 rounded-full transition-all duration-300","shadow-[0_0_8px_rgba(0,0,0,0.2)]",e?"bg-green-500":"bg-red-500",r&&"scale-125",r&&e&&"shadow-[0_0_12px_rgba(34,197,94,0.4)]",r&&!e&&"shadow-[0_0_12px_rgba(239,68,68,0.4)]")}),w.jsx("span",{className:"text-muted-foreground text-xs",children:e?"Connected":"Disconnected"})]})}),w.jsx(yu,{className:"w-auto",side:"top",align:"end",children:w.jsx(hY,{status:n})})]})})},l0=()=>{const e=k.useContext(Cz);if(e===void 0)throw new Error("useTheme must be used within a ThemeProvider");return e};function bY(){const{theme:e,setTheme:t}=l0(),n=k.useCallback(()=>t("light"),[t]),r=k.useCallback(()=>t("dark"),[t]);return e==="dark"?w.jsx(Lt,{onClick:n,variant:Yr,tooltip:"Switch to light theme",size:"icon",side:"bottom",children:w.jsx(Kq,{})}):w.jsx(Lt,{onClick:r,variant:Yr,tooltip:"Switch to dark theme",size:"icon",side:"bottom",children:w.jsx(u8,{})})}function tU(e){const t=e+"CollectionProvider",[n,r]=mr(t),[a,i]=n(t,{collectionRef:{current:null},itemMap:new Map}),l=m=>{const{scope:S,children:v}=m,A=ye.useRef(null),R=ye.useRef(new Map).current;return w.jsx(a,{scope:S,itemMap:R,collectionRef:A,children:v})};l.displayName=t;const u=e+"CollectionSlot",c=ye.forwardRef((m,S)=>{const{scope:v,children:A}=m,R=i(u,v),x=ft(S,R.collectionRef);return w.jsx(bo,{ref:x,children:A})});c.displayName=u;const f=e+"CollectionItemSlot",p="data-radix-collection-item",g=ye.forwardRef((m,S)=>{const{scope:v,children:A,...R}=m,x=ye.useRef(null),T=ft(S,x),C=i(f,v);return ye.useEffect(()=>(C.itemMap.set(x,{ref:x,...R}),()=>void C.itemMap.delete(x))),w.jsx(bo,{[p]:"",ref:T,children:A})});g.displayName=f;function b(m){const S=i(e+"CollectionConsumer",m);return ye.useCallback(()=>{const A=S.collectionRef.current;if(!A)return[];const R=Array.from(A.querySelectorAll(`[${p}]`));return Array.from(S.itemMap.values()).sort((C,N)=>R.indexOf(C.ref.current)-R.indexOf(N.ref.current))},[S.collectionRef,S.itemMap])}return[{Provider:l,Slot:c,ItemSlot:g},b,r]}var yY=k.createContext(void 0);function Tf(e){const t=k.useContext(yY);return e||t||"ltr"}var wh="rovingFocusGroup.onEntryFocus",vY={bubbles:!1,cancelable:!0},_f="RovingFocusGroup",[Dx,nU,SY]=tU(_f),[EY,rU]=mr(_f,[SY]),[wY,xY]=EY(_f),aU=k.forwardRef((e,t)=>w.jsx(Dx.Provider,{scope:e.__scopeRovingFocusGroup,children:w.jsx(Dx.Slot,{scope:e.__scopeRovingFocusGroup,children:w.jsx(kY,{...e,ref:t})})}));aU.displayName=_f;var kY=k.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,orientation:r,loop:a=!1,dir:i,currentTabStopId:l,defaultCurrentTabStopId:u,onCurrentTabStopIdChange:c,onEntryFocus:f,preventScrollOnEntryFocus:p=!1,...g}=e,b=k.useRef(null),m=ft(t,b),S=Tf(i),[v=null,A]=Oa({prop:l,defaultProp:u,onChange:c}),[R,x]=k.useState(!1),T=pn(f),C=nU(n),N=k.useRef(!1),[_,O]=k.useState(0);return k.useEffect(()=>{const z=b.current;if(z)return z.addEventListener(wh,T),()=>z.removeEventListener(wh,T)},[T]),w.jsx(wY,{scope:n,orientation:r,dir:S,loop:a,currentTabStopId:v,onItemFocus:k.useCallback(z=>A(z),[A]),onItemShiftTab:k.useCallback(()=>x(!0),[]),onFocusableItemAdd:k.useCallback(()=>O(z=>z+1),[]),onFocusableItemRemove:k.useCallback(()=>O(z=>z-1),[]),children:w.jsx(Xe.div,{tabIndex:R||_===0?-1:0,"data-orientation":r,...g,ref:m,style:{outline:"none",...e.style},onMouseDown:Ye(e.onMouseDown,()=>{N.current=!0}),onFocus:Ye(e.onFocus,z=>{const I=!N.current;if(z.target===z.currentTarget&&I&&!R){const M=new CustomEvent(wh,vY);if(z.currentTarget.dispatchEvent(M),!M.defaultPrevented){const H=C().filter(j=>j.focusable),q=H.find(j=>j.active),P=H.find(j=>j.id===v),Z=[q,P,...H].filter(Boolean).map(j=>j.ref.current);lU(Z,p)}}N.current=!1}),onBlur:Ye(e.onBlur,()=>x(!1))})})}),oU="RovingFocusGroupItem",iU=k.forwardRef((e,t)=>{const{__scopeRovingFocusGroup:n,focusable:r=!0,active:a=!1,tabStopId:i,...l}=e,u=En(),c=i||u,f=xY(oU,n),p=f.currentTabStopId===c,g=nU(n),{onFocusableItemAdd:b,onFocusableItemRemove:m}=f;return k.useEffect(()=>{if(r)return b(),()=>m()},[r,b,m]),w.jsx(Dx.ItemSlot,{scope:n,id:c,focusable:r,active:a,children:w.jsx(Xe.span,{tabIndex:p?0:-1,"data-orientation":f.orientation,...l,ref:t,onMouseDown:Ye(e.onMouseDown,S=>{r?f.onItemFocus(c):S.preventDefault()}),onFocus:Ye(e.onFocus,()=>f.onItemFocus(c)),onKeyDown:Ye(e.onKeyDown,S=>{if(S.key==="Tab"&&S.shiftKey){f.onItemShiftTab();return}if(S.target!==S.currentTarget)return;const v=_Y(S,f.orientation,f.dir);if(v!==void 0){if(S.metaKey||S.ctrlKey||S.altKey||S.shiftKey)return;S.preventDefault();let R=g().filter(x=>x.focusable).map(x=>x.ref.current);if(v==="last")R.reverse();else if(v==="prev"||v==="next"){v==="prev"&&R.reverse();const x=R.indexOf(S.currentTarget);R=f.loop?RY(R,x+1):R.slice(x+1)}setTimeout(()=>lU(R))}})})})});iU.displayName=oU;var AY={ArrowLeft:"prev",ArrowUp:"prev",ArrowRight:"next",ArrowDown:"next",PageUp:"first",Home:"first",PageDown:"last",End:"last"};function TY(e,t){return t!=="rtl"?e:e==="ArrowLeft"?"ArrowRight":e==="ArrowRight"?"ArrowLeft":e}function _Y(e,t,n){const r=TY(e.key,n);if(!(t==="vertical"&&["ArrowLeft","ArrowRight"].includes(r))&&!(t==="horizontal"&&["ArrowUp","ArrowDown"].includes(r)))return AY[r]}function lU(e,t=!1){const n=document.activeElement;for(const r of e)if(r===n||(r.focus({preventScroll:t}),document.activeElement!==n))return}function RY(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var CY=aU,NY=iU,s0="Tabs",[OY,nve]=mr(s0,[rU]),sU=rU(),[DY,u0]=OY(s0),uU=k.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,onValueChange:a,defaultValue:i,orientation:l="horizontal",dir:u,activationMode:c="automatic",...f}=e,p=Tf(u),[g,b]=Oa({prop:r,onChange:a,defaultProp:i});return w.jsx(DY,{scope:n,baseId:En(),value:g,onValueChange:b,orientation:l,dir:p,activationMode:c,children:w.jsx(Xe.div,{dir:p,"data-orientation":l,...f,ref:t})})});uU.displayName=s0;var cU="TabsList",dU=k.forwardRef((e,t)=>{const{__scopeTabs:n,loop:r=!0,...a}=e,i=u0(cU,n),l=sU(n);return w.jsx(CY,{asChild:!0,...l,orientation:i.orientation,dir:i.dir,loop:r,children:w.jsx(Xe.div,{role:"tablist","aria-orientation":i.orientation,...a,ref:t})})});dU.displayName=cU;var fU="TabsTrigger",pU=k.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,disabled:a=!1,...i}=e,l=u0(fU,n),u=sU(n),c=mU(l.baseId,r),f=bU(l.baseId,r),p=r===l.value;return w.jsx(NY,{asChild:!0,...u,focusable:!a,active:p,children:w.jsx(Xe.button,{type:"button",role:"tab","aria-selected":p,"aria-controls":f,"data-state":p?"active":"inactive","data-disabled":a?"":void 0,disabled:a,id:c,...i,ref:t,onMouseDown:Ye(e.onMouseDown,g=>{!a&&g.button===0&&g.ctrlKey===!1?l.onValueChange(r):g.preventDefault()}),onKeyDown:Ye(e.onKeyDown,g=>{[" ","Enter"].includes(g.key)&&l.onValueChange(r)}),onFocus:Ye(e.onFocus,()=>{const g=l.activationMode!=="manual";!p&&!a&&g&&l.onValueChange(r)})})})});pU.displayName=fU;var gU="TabsContent",hU=k.forwardRef((e,t)=>{const{__scopeTabs:n,value:r,forceMount:a,children:i,...l}=e,u=u0(gU,n),c=mU(u.baseId,r),f=bU(u.baseId,r),p=r===u.value,g=k.useRef(p);return k.useEffect(()=>{const b=requestAnimationFrame(()=>g.current=!1);return()=>cancelAnimationFrame(b)},[]),w.jsx(Jn,{present:a||p,children:({present:b})=>w.jsx(Xe.div,{"data-state":p?"active":"inactive","data-orientation":u.orientation,role:"tabpanel","aria-labelledby":c,hidden:!b,id:f,tabIndex:0,...l,ref:t,style:{...e.style,animationDuration:g.current?"0s":void 0},children:b&&i})})});hU.displayName=gU;function mU(e,t){return`${e}-trigger-${t}`}function bU(e,t){return`${e}-content-${t}`}var IY=uU,yU=dU,vU=pU,SU=hU;const LY=IY,EU=k.forwardRef(({className:e,...t},n)=>w.jsx(yU,{ref:n,className:Me("bg-muted text-muted-foreground inline-flex h-10 items-center justify-center rounded-md p-1",e),...t}));EU.displayName=yU.displayName;const wU=k.forwardRef(({className:e,...t},n)=>w.jsx(vU,{ref:n,className:Me("ring-offset-background focus-visible:ring-ring data-[state=active]:bg-background data-[state=active]:text-foreground inline-flex items-center justify-center rounded-sm px-3 py-1.5 text-sm font-medium whitespace-nowrap transition-all focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none disabled:pointer-events-none disabled:opacity-50 data-[state=active]:shadow-sm",e),...t}));wU.displayName=vU.displayName;const Vs=k.forwardRef(({className:e,...t},n)=>w.jsx(SU,{ref:n,className:Me("ring-offset-background focus-visible:ring-ring mt-2 focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none",e),...t}));Vs.displayName=SU.displayName;function qc({value:e,currentTab:t,children:n}){return w.jsx(wU,{value:e,className:Me("cursor-pointer px-2 py-1 transition-all",t===e?"!bg-emerald-400 !text-zinc-50":"hover:bg-background/60"),children:n})}function MY(){const e=We.use.currentTab();return w.jsx("div",{className:"flex h-8 self-center",children:w.jsxs(EU,{className:"h-full gap-2",children:[w.jsx(qc,{value:"documents",currentTab:e,children:"Documents"}),w.jsx(qc,{value:"knowledge-graph",currentTab:e,children:"Knowledge Graph"}),w.jsx(qc,{value:"retrieval",currentTab:e,children:"Retrieval"}),w.jsx(qc,{value:"api",currentTab:e,children:"API"})]})})}function FY(){return w.jsxs("header",{className:"border-border/40 bg-background/95 supports-[backdrop-filter]:bg-background/60 sticky top-0 z-50 flex h-10 w-full border-b px-4 backdrop-blur",children:[w.jsxs("a",{href:"/",className:"mr-6 flex items-center gap-2",children:[w.jsx(p8,{className:"size-4 text-emerald-400","aria-hidden":"true"}),w.jsx("span",{className:"font-bold md:inline-block",children:sR.name})]}),w.jsx("div",{className:"flex h-10 flex-1 justify-center",children:w.jsx(MY,{})}),w.jsxs("nav",{className:"flex items-center",children:[w.jsx(Lt,{variant:"ghost",size:"icon",side:"bottom",tooltip:"Project Repository",children:w.jsx("a",{href:sR.github,target:"_blank",rel:"noopener noreferrer",children:w.jsx(Pq,{className:"size-4","aria-hidden":"true"})})}),w.jsx(bY,{})]})]})}var Vc={exports:{}},YR;function zY(){if(YR)return Vc.exports;YR=1;var e=typeof Reflect=="object"?Reflect:null,t=e&&typeof e.apply=="function"?e.apply:function(N,_,O){return Function.prototype.apply.call(N,_,O)},n;e&&typeof e.ownKeys=="function"?n=e.ownKeys:Object.getOwnPropertySymbols?n=function(N){return Object.getOwnPropertyNames(N).concat(Object.getOwnPropertySymbols(N))}:n=function(N){return Object.getOwnPropertyNames(N)};function r(C){console&&console.warn&&console.warn(C)}var a=Number.isNaN||function(N){return N!==N};function i(){i.init.call(this)}Vc.exports=i,Vc.exports.once=R,i.EventEmitter=i,i.prototype._events=void 0,i.prototype._eventsCount=0,i.prototype._maxListeners=void 0;var l=10;function u(C){if(typeof C!="function")throw new TypeError('The "listener" argument must be of type Function. Received type '+typeof C)}Object.defineProperty(i,"defaultMaxListeners",{enumerable:!0,get:function(){return l},set:function(C){if(typeof C!="number"||C<0||a(C))throw new RangeError('The value of "defaultMaxListeners" is out of range. It must be a non-negative number. Received '+C+".");l=C}}),i.init=function(){(this._events===void 0||this._events===Object.getPrototypeOf(this)._events)&&(this._events=Object.create(null),this._eventsCount=0),this._maxListeners=this._maxListeners||void 0},i.prototype.setMaxListeners=function(N){if(typeof N!="number"||N<0||a(N))throw new RangeError('The value of "n" is out of range. It must be a non-negative number. Received '+N+".");return this._maxListeners=N,this};function c(C){return C._maxListeners===void 0?i.defaultMaxListeners:C._maxListeners}i.prototype.getMaxListeners=function(){return c(this)},i.prototype.emit=function(N){for(var _=[],O=1;O<arguments.length;O++)_.push(arguments[O]);var z=N==="error",I=this._events;if(I!==void 0)z=z&&I.error===void 0;else if(!z)return!1;if(z){var M;if(_.length>0&&(M=_[0]),M instanceof Error)throw M;var H=new Error("Unhandled error."+(M?" ("+M.message+")":""));throw H.context=M,H}var q=I[N];if(q===void 0)return!1;if(typeof q=="function")t(q,this,_);else for(var P=q.length,W=S(q,P),O=0;O<P;++O)t(W[O],this,_);return!0};function f(C,N,_,O){var z,I,M;if(u(_),I=C._events,I===void 0?(I=C._events=Object.create(null),C._eventsCount=0):(I.newListener!==void 0&&(C.emit("newListener",N,_.listener?_.listener:_),I=C._events),M=I[N]),M===void 0)M=I[N]=_,++C._eventsCount;else if(typeof M=="function"?M=I[N]=O?[_,M]:[M,_]:O?M.unshift(_):M.push(_),z=c(C),z>0&&M.length>z&&!M.warned){M.warned=!0;var H=new Error("Possible EventEmitter memory leak detected. "+M.length+" "+String(N)+" listeners added. Use emitter.setMaxListeners() to increase limit");H.name="MaxListenersExceededWarning",H.emitter=C,H.type=N,H.count=M.length,r(H)}return C}i.prototype.addListener=function(N,_){return f(this,N,_,!1)},i.prototype.on=i.prototype.addListener,i.prototype.prependListener=function(N,_){return f(this,N,_,!0)};function p(){if(!this.fired)return this.target.removeListener(this.type,this.wrapFn),this.fired=!0,arguments.length===0?this.listener.call(this.target):this.listener.apply(this.target,arguments)}function g(C,N,_){var O={fired:!1,wrapFn:void 0,target:C,type:N,listener:_},z=p.bind(O);return z.listener=_,O.wrapFn=z,z}i.prototype.once=function(N,_){return u(_),this.on(N,g(this,N,_)),this},i.prototype.prependOnceListener=function(N,_){return u(_),this.prependListener(N,g(this,N,_)),this},i.prototype.removeListener=function(N,_){var O,z,I,M,H;if(u(_),z=this._events,z===void 0)return this;if(O=z[N],O===void 0)return this;if(O===_||O.listener===_)--this._eventsCount===0?this._events=Object.create(null):(delete z[N],z.removeListener&&this.emit("removeListener",N,O.listener||_));else if(typeof O!="function"){for(I=-1,M=O.length-1;M>=0;M--)if(O[M]===_||O[M].listener===_){H=O[M].listener,I=M;break}if(I<0)return this;I===0?O.shift():v(O,I),O.length===1&&(z[N]=O[0]),z.removeListener!==void 0&&this.emit("removeListener",N,H||_)}return this},i.prototype.off=i.prototype.removeListener,i.prototype.removeAllListeners=function(N){var _,O,z;if(O=this._events,O===void 0)return this;if(O.removeListener===void 0)return arguments.length===0?(this._events=Object.create(null),this._eventsCount=0):O[N]!==void 0&&(--this._eventsCount===0?this._events=Object.create(null):delete O[N]),this;if(arguments.length===0){var I=Object.keys(O),M;for(z=0;z<I.length;++z)M=I[z],M!=="removeListener"&&this.removeAllListeners(M);return this.removeAllListeners("removeListener"),this._events=Object.create(null),this._eventsCount=0,this}if(_=O[N],typeof _=="function")this.removeListener(N,_);else if(_!==void 0)for(z=_.length-1;z>=0;z--)this.removeListener(N,_[z]);return this};function b(C,N,_){var O=C._events;if(O===void 0)return[];var z=O[N];return z===void 0?[]:typeof z=="function"?_?[z.listener||z]:[z]:_?A(z):S(z,z.length)}i.prototype.listeners=function(N){return b(this,N,!0)},i.prototype.rawListeners=function(N){return b(this,N,!1)},i.listenerCount=function(C,N){return typeof C.listenerCount=="function"?C.listenerCount(N):m.call(C,N)},i.prototype.listenerCount=m;function m(C){var N=this._events;if(N!==void 0){var _=N[C];if(typeof _=="function")return 1;if(_!==void 0)return _.length}return 0}i.prototype.eventNames=function(){return this._eventsCount>0?n(this._events):[]};function S(C,N){for(var _=new Array(N),O=0;O<N;++O)_[O]=C[O];return _}function v(C,N){for(;N+1<C.length;N++)C[N]=C[N+1];C.pop()}function A(C){for(var N=new Array(C.length),_=0;_<N.length;++_)N[_]=C[_].listener||C[_];return N}function R(C,N){return new Promise(function(_,O){function z(M){C.removeListener(N,I),O(M)}function I(){typeof C.removeListener=="function"&&C.removeListener("error",z),_([].slice.call(arguments))}T(C,N,I,{once:!0}),N!=="error"&&x(C,z,{once:!0})})}function x(C,N,_){typeof C.on=="function"&&T(C,"error",N,_)}function T(C,N,_,O){if(typeof C.on=="function")O.once?C.once(N,_):C.on(N,_);else if(typeof C.addEventListener=="function")C.addEventListener(N,function z(I){O.once&&C.removeEventListener(N,z),_(I)});else throw new TypeError('The "emitter" argument must be of type EventEmitter. Received type '+typeof C)}return Vc.exports}var xU=zY();function PY(){const e=arguments[0];for(let t=1,n=arguments.length;t<n;t++)if(arguments[t])for(const r in arguments[t])e[r]=arguments[t][r];return e}let Qt=PY;typeof Object.assign=="function"&&(Qt=Object.assign);function hr(e,t,n,r){const a=e._nodes.get(t);let i=null;return a&&(r==="mixed"?i=a.out&&a.out[n]||a.undirected&&a.undirected[n]:r==="directed"?i=a.out&&a.out[n]:i=a.undirected&&a.undirected[n]),i}function gn(e){return typeof e=="object"&&e!==null}function kU(e){let t;for(t in e)return!1;return!0}function pr(e,t,n){Object.defineProperty(e,t,{enumerable:!1,configurable:!1,writable:!0,value:n})}function Tr(e,t,n){const r={enumerable:!0,configurable:!0};typeof n=="function"?r.get=n:(r.value=n,r.writable=!1),Object.defineProperty(e,t,r)}function KR(e){return!(!gn(e)||e.attributes&&!Array.isArray(e.attributes))}function BY(){let e=Math.floor(Math.random()*256)&255;return()=>e++}function Na(){const e=arguments;let t=null,n=-1;return{[Symbol.iterator](){return this},next(){let r=null;do{if(t===null){if(n++,n>=e.length)return{done:!0};t=e[n][Symbol.iterator]()}if(r=t.next(),r.done){t=null;continue}break}while(!0);return r}}}function Ol(){return{[Symbol.iterator](){return this},next(){return{done:!0}}}}class c0 extends Error{constructor(t){super(),this.name="GraphError",this.message=t}}class Le extends c0{constructor(t){super(t),this.name="InvalidArgumentsGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,Le.prototype.constructor)}}class De extends c0{constructor(t){super(t),this.name="NotFoundGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,De.prototype.constructor)}}class Ze extends c0{constructor(t){super(t),this.name="UsageGraphError",typeof Error.captureStackTrace=="function"&&Error.captureStackTrace(this,Ze.prototype.constructor)}}function AU(e,t){this.key=e,this.attributes=t,this.clear()}AU.prototype.clear=function(){this.inDegree=0,this.outDegree=0,this.undirectedDegree=0,this.undirectedLoops=0,this.directedLoops=0,this.in={},this.out={},this.undirected={}};function TU(e,t){this.key=e,this.attributes=t,this.clear()}TU.prototype.clear=function(){this.inDegree=0,this.outDegree=0,this.directedLoops=0,this.in={},this.out={}};function _U(e,t){this.key=e,this.attributes=t,this.clear()}_U.prototype.clear=function(){this.undirectedDegree=0,this.undirectedLoops=0,this.undirected={}};function Dl(e,t,n,r,a){this.key=t,this.attributes=a,this.undirected=e,this.source=n,this.target=r}Dl.prototype.attach=function(){let e="out",t="in";this.undirected&&(e=t="undirected");const n=this.source.key,r=this.target.key;this.source[e][r]=this,!(this.undirected&&n===r)&&(this.target[t][n]=this)};Dl.prototype.attachMulti=function(){let e="out",t="in";const n=this.source.key,r=this.target.key;this.undirected&&(e=t="undirected");const a=this.source[e],i=a[r];if(typeof i>"u"){a[r]=this,this.undirected&&n===r||(this.target[t][n]=this);return}i.previous=this,this.next=i,a[r]=this,this.target[t][n]=this};Dl.prototype.detach=function(){const e=this.source.key,t=this.target.key;let n="out",r="in";this.undirected&&(n=r="undirected"),delete this.source[n][t],delete this.target[r][e]};Dl.prototype.detachMulti=function(){const e=this.source.key,t=this.target.key;let n="out",r="in";this.undirected&&(n=r="undirected"),this.previous===void 0?this.next===void 0?(delete this.source[n][t],delete this.target[r][e]):(this.next.previous=void 0,this.source[n][t]=this.next,this.target[r][e]=this.next):(this.previous.next=this.next,this.next!==void 0&&(this.next.previous=this.previous))};const RU=0,CU=1,UY=2,NU=3;function Ma(e,t,n,r,a,i,l){let u,c,f,p;if(r=""+r,n===RU){if(u=e._nodes.get(r),!u)throw new De(`Graph.${t}: could not find the "${r}" node in the graph.`);f=a,p=i}else if(n===NU){if(a=""+a,c=e._edges.get(a),!c)throw new De(`Graph.${t}: could not find the "${a}" edge in the graph.`);const g=c.source.key,b=c.target.key;if(r===g)u=c.target;else if(r===b)u=c.source;else throw new De(`Graph.${t}: the "${r}" node is not attached to the "${a}" edge (${g}, ${b}).`);f=i,p=l}else{if(c=e._edges.get(r),!c)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`);n===CU?u=c.source:u=c.target,f=a,p=i}return[u,f,p]}function jY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);return l.attributes[u]}}function GY(e,t,n){e.prototype[t]=function(r,a){const[i]=Ma(this,t,n,r,a);return i.attributes}}function HY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);return l.attributes.hasOwnProperty(u)}}function $Y(e,t,n){e.prototype[t]=function(r,a,i,l){const[u,c,f]=Ma(this,t,n,r,a,i,l);return u.attributes[c]=f,this.emit("nodeAttributesUpdated",{key:u.key,type:"set",attributes:u.attributes,name:c}),this}}function qY(e,t,n){e.prototype[t]=function(r,a,i,l){const[u,c,f]=Ma(this,t,n,r,a,i,l);if(typeof f!="function")throw new Le(`Graph.${t}: updater should be a function.`);const p=u.attributes,g=f(p[c]);return p[c]=g,this.emit("nodeAttributesUpdated",{key:u.key,type:"set",attributes:u.attributes,name:c}),this}}function VY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);return delete l.attributes[u],this.emit("nodeAttributesUpdated",{key:l.key,type:"remove",attributes:l.attributes,name:u}),this}}function WY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);if(!gn(u))throw new Le(`Graph.${t}: provided attributes are not a plain object.`);return l.attributes=u,this.emit("nodeAttributesUpdated",{key:l.key,type:"replace",attributes:l.attributes}),this}}function YY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);if(!gn(u))throw new Le(`Graph.${t}: provided attributes are not a plain object.`);return Qt(l.attributes,u),this.emit("nodeAttributesUpdated",{key:l.key,type:"merge",attributes:l.attributes,data:u}),this}}function KY(e,t,n){e.prototype[t]=function(r,a,i){const[l,u]=Ma(this,t,n,r,a,i);if(typeof u!="function")throw new Le(`Graph.${t}: provided updater is not a function.`);return l.attributes=u(l.attributes),this.emit("nodeAttributesUpdated",{key:l.key,type:"update",attributes:l.attributes}),this}}const XY=[{name:e=>`get${e}Attribute`,attacher:jY},{name:e=>`get${e}Attributes`,attacher:GY},{name:e=>`has${e}Attribute`,attacher:HY},{name:e=>`set${e}Attribute`,attacher:$Y},{name:e=>`update${e}Attribute`,attacher:qY},{name:e=>`remove${e}Attribute`,attacher:VY},{name:e=>`replace${e}Attributes`,attacher:WY},{name:e=>`merge${e}Attributes`,attacher:YY},{name:e=>`update${e}Attributes`,attacher:KY}];function ZY(e){XY.forEach(function({name:t,attacher:n}){n(e,t("Node"),RU),n(e,t("Source"),CU),n(e,t("Target"),UY),n(e,t("Opposite"),NU)})}function QY(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return i.attributes[a]}}function JY(e,t,n){e.prototype[t]=function(r){let a;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>1){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const i=""+r,l=""+arguments[1];if(a=hr(this,i,l,n),!a)throw new De(`Graph.${t}: could not find an edge for the given path ("${i}" - "${l}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,a=this._edges.get(r),!a)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return a.attributes}}function eK(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return i.attributes.hasOwnProperty(a)}}function tK(e,t,n){e.prototype[t]=function(r,a,i){let l;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>3){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const u=""+r,c=""+a;if(a=arguments[2],i=arguments[3],l=hr(this,u,c,n),!l)throw new De(`Graph.${t}: could not find an edge for the given path ("${u}" - "${c}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,l=this._edges.get(r),!l)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return l.attributes[a]=i,this.emit("edgeAttributesUpdated",{key:l.key,type:"set",attributes:l.attributes,name:a}),this}}function nK(e,t,n){e.prototype[t]=function(r,a,i){let l;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>3){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const u=""+r,c=""+a;if(a=arguments[2],i=arguments[3],l=hr(this,u,c,n),!l)throw new De(`Graph.${t}: could not find an edge for the given path ("${u}" - "${c}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,l=this._edges.get(r),!l)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(typeof i!="function")throw new Le(`Graph.${t}: updater should be a function.`);return l.attributes[a]=i(l.attributes[a]),this.emit("edgeAttributesUpdated",{key:l.key,type:"set",attributes:l.attributes,name:a}),this}}function rK(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}return delete i.attributes[a],this.emit("edgeAttributesUpdated",{key:i.key,type:"remove",attributes:i.attributes,name:a}),this}}function aK(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(!gn(a))throw new Le(`Graph.${t}: provided attributes are not a plain object.`);return i.attributes=a,this.emit("edgeAttributesUpdated",{key:i.key,type:"replace",attributes:i.attributes}),this}}function oK(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(!gn(a))throw new Le(`Graph.${t}: provided attributes are not a plain object.`);return Qt(i.attributes,a),this.emit("edgeAttributesUpdated",{key:i.key,type:"merge",attributes:i.attributes,data:a}),this}}function iK(e,t,n){e.prototype[t]=function(r,a){let i;if(this.type!=="mixed"&&n!=="mixed"&&n!==this.type)throw new Ze(`Graph.${t}: cannot find this type of edges in your ${this.type} graph.`);if(arguments.length>2){if(this.multi)throw new Ze(`Graph.${t}: cannot use a {source,target} combo when asking about an edge's attributes in a MultiGraph since we cannot infer the one you want information about.`);const l=""+r,u=""+a;if(a=arguments[2],i=hr(this,l,u,n),!i)throw new De(`Graph.${t}: could not find an edge for the given path ("${l}" - "${u}").`)}else{if(n!=="mixed")throw new Ze(`Graph.${t}: calling this method with only a key (vs. a source and target) does not make sense since an edge with this key could have the other type.`);if(r=""+r,i=this._edges.get(r),!i)throw new De(`Graph.${t}: could not find the "${r}" edge in the graph.`)}if(typeof a!="function")throw new Le(`Graph.${t}: provided updater is not a function.`);return i.attributes=a(i.attributes),this.emit("edgeAttributesUpdated",{key:i.key,type:"update",attributes:i.attributes}),this}}const lK=[{name:e=>`get${e}Attribute`,attacher:QY},{name:e=>`get${e}Attributes`,attacher:JY},{name:e=>`has${e}Attribute`,attacher:eK},{name:e=>`set${e}Attribute`,attacher:tK},{name:e=>`update${e}Attribute`,attacher:nK},{name:e=>`remove${e}Attribute`,attacher:rK},{name:e=>`replace${e}Attributes`,attacher:aK},{name:e=>`merge${e}Attributes`,attacher:oK},{name:e=>`update${e}Attributes`,attacher:iK}];function sK(e){lK.forEach(function({name:t,attacher:n}){n(e,t("Edge"),"mixed"),n(e,t("DirectedEdge"),"directed"),n(e,t("UndirectedEdge"),"undirected")})}const uK=[{name:"edges",type:"mixed"},{name:"inEdges",type:"directed",direction:"in"},{name:"outEdges",type:"directed",direction:"out"},{name:"inboundEdges",type:"mixed",direction:"in"},{name:"outboundEdges",type:"mixed",direction:"out"},{name:"directedEdges",type:"directed"},{name:"undirectedEdges",type:"undirected"}];function cK(e,t,n,r){let a=!1;for(const i in t){if(i===r)continue;const l=t[i];if(a=n(l.key,l.attributes,l.source.key,l.target.key,l.source.attributes,l.target.attributes,l.undirected),e&&a)return l.key}}function dK(e,t,n,r){let a,i,l,u=!1;for(const c in t)if(c!==r){a=t[c];do{if(i=a.source,l=a.target,u=n(a.key,a.attributes,i.key,l.key,i.attributes,l.attributes,a.undirected),e&&u)return a.key;a=a.next}while(a!==void 0)}}function xh(e,t){const n=Object.keys(e),r=n.length;let a,i=0;return{[Symbol.iterator](){return this},next(){do if(a)a=a.next;else{if(i>=r)return{done:!0};const l=n[i++];if(l===t){a=void 0;continue}a=e[l]}while(!a);return{done:!1,value:{edge:a.key,attributes:a.attributes,source:a.source.key,target:a.target.key,sourceAttributes:a.source.attributes,targetAttributes:a.target.attributes,undirected:a.undirected}}}}}function fK(e,t,n,r){const a=t[n];if(!a)return;const i=a.source,l=a.target;if(r(a.key,a.attributes,i.key,l.key,i.attributes,l.attributes,a.undirected)&&e)return a.key}function pK(e,t,n,r){let a=t[n];if(!a)return;let i=!1;do{if(i=r(a.key,a.attributes,a.source.key,a.target.key,a.source.attributes,a.target.attributes,a.undirected),e&&i)return a.key;a=a.next}while(a!==void 0)}function kh(e,t){let n=e[t];if(n.next!==void 0)return{[Symbol.iterator](){return this},next(){if(!n)return{done:!0};const a={edge:n.key,attributes:n.attributes,source:n.source.key,target:n.target.key,sourceAttributes:n.source.attributes,targetAttributes:n.target.attributes,undirected:n.undirected};return n=n.next,{done:!1,value:a}}};let r=!1;return{[Symbol.iterator](){return this},next(){return r===!0?{done:!0}:(r=!0,{done:!1,value:{edge:n.key,attributes:n.attributes,source:n.source.key,target:n.target.key,sourceAttributes:n.source.attributes,targetAttributes:n.target.attributes,undirected:n.undirected}})}}}function gK(e,t){if(e.size===0)return[];if(t==="mixed"||t===e.type)return Array.from(e._edges.keys());const n=t==="undirected"?e.undirectedSize:e.directedSize,r=new Array(n),a=t==="undirected",i=e._edges.values();let l=0,u,c;for(;u=i.next(),u.done!==!0;)c=u.value,c.undirected===a&&(r[l++]=c.key);return r}function OU(e,t,n,r){if(t.size===0)return;const a=n!=="mixed"&&n!==t.type,i=n==="undirected";let l,u,c=!1;const f=t._edges.values();for(;l=f.next(),l.done!==!0;){if(u=l.value,a&&u.undirected!==i)continue;const{key:p,attributes:g,source:b,target:m}=u;if(c=r(p,g,b.key,m.key,b.attributes,m.attributes,u.undirected),e&&c)return p}}function hK(e,t){if(e.size===0)return Ol();const n=t!=="mixed"&&t!==e.type,r=t==="undirected",a=e._edges.values();return{[Symbol.iterator](){return this},next(){let i,l;for(;;){if(i=a.next(),i.done)return i;if(l=i.value,!(n&&l.undirected!==r))break}return{value:{edge:l.key,attributes:l.attributes,source:l.source.key,target:l.target.key,sourceAttributes:l.source.attributes,targetAttributes:l.target.attributes,undirected:l.undirected},done:!1}}}}function d0(e,t,n,r,a,i){const l=t?dK:cK;let u;if(n!=="undirected"&&(r!=="out"&&(u=l(e,a.in,i),e&&u)||r!=="in"&&(u=l(e,a.out,i,r?void 0:a.key),e&&u))||n!=="directed"&&(u=l(e,a.undirected,i),e&&u))return u}function mK(e,t,n,r){const a=[];return d0(!1,e,t,n,r,function(i){a.push(i)}),a}function bK(e,t,n){let r=Ol();return e!=="undirected"&&(t!=="out"&&typeof n.in<"u"&&(r=Na(r,xh(n.in))),t!=="in"&&typeof n.out<"u"&&(r=Na(r,xh(n.out,t?void 0:n.key)))),e!=="directed"&&typeof n.undirected<"u"&&(r=Na(r,xh(n.undirected))),r}function f0(e,t,n,r,a,i,l){const u=n?pK:fK;let c;if(t!=="undirected"&&(typeof a.in<"u"&&r!=="out"&&(c=u(e,a.in,i,l),e&&c)||typeof a.out<"u"&&r!=="in"&&(r||a.key!==i)&&(c=u(e,a.out,i,l),e&&c))||t!=="directed"&&typeof a.undirected<"u"&&(c=u(e,a.undirected,i,l),e&&c))return c}function yK(e,t,n,r,a){const i=[];return f0(!1,e,t,n,r,a,function(l){i.push(l)}),i}function vK(e,t,n,r){let a=Ol();return e!=="undirected"&&(typeof n.in<"u"&&t!=="out"&&r in n.in&&(a=Na(a,kh(n.in,r))),typeof n.out<"u"&&t!=="in"&&r in n.out&&(t||n.key!==r)&&(a=Na(a,kh(n.out,r)))),e!=="directed"&&typeof n.undirected<"u"&&r in n.undirected&&(a=Na(a,kh(n.undirected,r))),a}function SK(e,t){const{name:n,type:r,direction:a}=t;e.prototype[n]=function(i,l){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return[];if(!arguments.length)return gK(this,r);if(arguments.length===1){i=""+i;const u=this._nodes.get(i);if(typeof u>"u")throw new De(`Graph.${n}: could not find the "${i}" node in the graph.`);return mK(this.multi,r==="mixed"?this.type:r,a,u)}if(arguments.length===2){i=""+i,l=""+l;const u=this._nodes.get(i);if(!u)throw new De(`Graph.${n}:  could not find the "${i}" source node in the graph.`);if(!this._nodes.has(l))throw new De(`Graph.${n}:  could not find the "${l}" target node in the graph.`);return yK(r,this.multi,a,u,l)}throw new Le(`Graph.${n}: too many arguments (expecting 0, 1 or 2 and got ${arguments.length}).`)}}function EK(e,t){const{name:n,type:r,direction:a}=t,i="forEach"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[i]=function(f,p,g){if(!(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)){if(arguments.length===1)return g=f,OU(!1,this,r,g);if(arguments.length===2){f=""+f,g=p;const b=this._nodes.get(f);if(typeof b>"u")throw new De(`Graph.${i}: could not find the "${f}" node in the graph.`);return d0(!1,this.multi,r==="mixed"?this.type:r,a,b,g)}if(arguments.length===3){f=""+f,p=""+p;const b=this._nodes.get(f);if(!b)throw new De(`Graph.${i}:  could not find the "${f}" source node in the graph.`);if(!this._nodes.has(p))throw new De(`Graph.${i}:  could not find the "${p}" target node in the graph.`);return f0(!1,r,this.multi,a,b,p,g)}throw new Le(`Graph.${i}: too many arguments (expecting 1, 2 or 3 and got ${arguments.length}).`)}};const l="map"+n[0].toUpperCase()+n.slice(1);e.prototype[l]=function(){const f=Array.prototype.slice.call(arguments),p=f.pop();let g;if(f.length===0){let b=0;r!=="directed"&&(b+=this.undirectedSize),r!=="undirected"&&(b+=this.directedSize),g=new Array(b);let m=0;f.push((S,v,A,R,x,T,C)=>{g[m++]=p(S,v,A,R,x,T,C)})}else g=[],f.push((b,m,S,v,A,R,x)=>{g.push(p(b,m,S,v,A,R,x))});return this[i].apply(this,f),g};const u="filter"+n[0].toUpperCase()+n.slice(1);e.prototype[u]=function(){const f=Array.prototype.slice.call(arguments),p=f.pop(),g=[];return f.push((b,m,S,v,A,R,x)=>{p(b,m,S,v,A,R,x)&&g.push(b)}),this[i].apply(this,f),g};const c="reduce"+n[0].toUpperCase()+n.slice(1);e.prototype[c]=function(){let f=Array.prototype.slice.call(arguments);if(f.length<2||f.length>4)throw new Le(`Graph.${c}: invalid number of arguments (expecting 2, 3 or 4 and got ${f.length}).`);if(typeof f[f.length-1]=="function"&&typeof f[f.length-2]!="function")throw new Le(`Graph.${c}: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.`);let p,g;f.length===2?(p=f[0],g=f[1],f=[]):f.length===3?(p=f[1],g=f[2],f=[f[0]]):f.length===4&&(p=f[2],g=f[3],f=[f[0],f[1]]);let b=g;return f.push((m,S,v,A,R,x,T)=>{b=p(b,m,S,v,A,R,x,T)}),this[i].apply(this,f),b}}function wK(e,t){const{name:n,type:r,direction:a}=t,i="find"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[i]=function(c,f,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return!1;if(arguments.length===1)return p=c,OU(!0,this,r,p);if(arguments.length===2){c=""+c,p=f;const g=this._nodes.get(c);if(typeof g>"u")throw new De(`Graph.${i}: could not find the "${c}" node in the graph.`);return d0(!0,this.multi,r==="mixed"?this.type:r,a,g,p)}if(arguments.length===3){c=""+c,f=""+f;const g=this._nodes.get(c);if(!g)throw new De(`Graph.${i}:  could not find the "${c}" source node in the graph.`);if(!this._nodes.has(f))throw new De(`Graph.${i}:  could not find the "${f}" target node in the graph.`);return f0(!0,r,this.multi,a,g,f,p)}throw new Le(`Graph.${i}: too many arguments (expecting 1, 2 or 3 and got ${arguments.length}).`)};const l="some"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[l]=function(){const c=Array.prototype.slice.call(arguments),f=c.pop();return c.push((g,b,m,S,v,A,R)=>f(g,b,m,S,v,A,R)),!!this[i].apply(this,c)};const u="every"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[u]=function(){const c=Array.prototype.slice.call(arguments),f=c.pop();return c.push((g,b,m,S,v,A,R)=>!f(g,b,m,S,v,A,R)),!this[i].apply(this,c)}}function xK(e,t){const{name:n,type:r,direction:a}=t,i=n.slice(0,-1)+"Entries";e.prototype[i]=function(l,u){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return Ol();if(!arguments.length)return hK(this,r);if(arguments.length===1){l=""+l;const c=this._nodes.get(l);if(!c)throw new De(`Graph.${i}: could not find the "${l}" node in the graph.`);return bK(r,a,c)}if(arguments.length===2){l=""+l,u=""+u;const c=this._nodes.get(l);if(!c)throw new De(`Graph.${i}:  could not find the "${l}" source node in the graph.`);if(!this._nodes.has(u))throw new De(`Graph.${i}:  could not find the "${u}" target node in the graph.`);return vK(r,a,c,u)}throw new Le(`Graph.${i}: too many arguments (expecting 0, 1 or 2 and got ${arguments.length}).`)}}function kK(e){uK.forEach(t=>{SK(e,t),EK(e,t),wK(e,t),xK(e,t)})}const AK=[{name:"neighbors",type:"mixed"},{name:"inNeighbors",type:"directed",direction:"in"},{name:"outNeighbors",type:"directed",direction:"out"},{name:"inboundNeighbors",type:"mixed",direction:"in"},{name:"outboundNeighbors",type:"mixed",direction:"out"},{name:"directedNeighbors",type:"directed"},{name:"undirectedNeighbors",type:"undirected"}];function Rf(){this.A=null,this.B=null}Rf.prototype.wrap=function(e){this.A===null?this.A=e:this.B===null&&(this.B=e)};Rf.prototype.has=function(e){return this.A!==null&&e in this.A||this.B!==null&&e in this.B};function Fs(e,t,n,r,a){for(const i in r){const l=r[i],u=l.source,c=l.target,f=u===n?c:u;if(t&&t.has(f.key))continue;const p=a(f.key,f.attributes);if(e&&p)return f.key}}function p0(e,t,n,r,a){if(t!=="mixed"){if(t==="undirected")return Fs(e,null,r,r.undirected,a);if(typeof n=="string")return Fs(e,null,r,r[n],a)}const i=new Rf;let l;if(t!=="undirected"){if(n!=="out"){if(l=Fs(e,null,r,r.in,a),e&&l)return l;i.wrap(r.in)}if(n!=="in"){if(l=Fs(e,i,r,r.out,a),e&&l)return l;i.wrap(r.out)}}if(t!=="directed"&&(l=Fs(e,i,r,r.undirected,a),e&&l))return l}function TK(e,t,n){if(e!=="mixed"){if(e==="undirected")return Object.keys(n.undirected);if(typeof t=="string")return Object.keys(n[t])}const r=[];return p0(!1,e,t,n,function(a){r.push(a)}),r}function zs(e,t,n){const r=Object.keys(n),a=r.length;let i=0;return{[Symbol.iterator](){return this},next(){let l=null;do{if(i>=a)return e&&e.wrap(n),{done:!0};const u=n[r[i++]],c=u.source,f=u.target;if(l=c===t?f:c,e&&e.has(l.key)){l=null;continue}}while(l===null);return{done:!1,value:{neighbor:l.key,attributes:l.attributes}}}}}function _K(e,t,n){if(e!=="mixed"){if(e==="undirected")return zs(null,n,n.undirected);if(typeof t=="string")return zs(null,n,n[t])}let r=Ol();const a=new Rf;return e!=="undirected"&&(t!=="out"&&(r=Na(r,zs(a,n,n.in))),t!=="in"&&(r=Na(r,zs(a,n,n.out)))),e!=="directed"&&(r=Na(r,zs(a,n,n.undirected))),r}function RK(e,t){const{name:n,type:r,direction:a}=t;e.prototype[n]=function(i){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return[];i=""+i;const l=this._nodes.get(i);if(typeof l>"u")throw new De(`Graph.${n}: could not find the "${i}" node in the graph.`);return TK(r==="mixed"?this.type:r,a,l)}}function CK(e,t){const{name:n,type:r,direction:a}=t,i="forEach"+n[0].toUpperCase()+n.slice(1,-1);e.prototype[i]=function(f,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return;f=""+f;const g=this._nodes.get(f);if(typeof g>"u")throw new De(`Graph.${i}: could not find the "${f}" node in the graph.`);p0(!1,r==="mixed"?this.type:r,a,g,p)};const l="map"+n[0].toUpperCase()+n.slice(1);e.prototype[l]=function(f,p){const g=[];return this[i](f,(b,m)=>{g.push(p(b,m))}),g};const u="filter"+n[0].toUpperCase()+n.slice(1);e.prototype[u]=function(f,p){const g=[];return this[i](f,(b,m)=>{p(b,m)&&g.push(b)}),g};const c="reduce"+n[0].toUpperCase()+n.slice(1);e.prototype[c]=function(f,p,g){if(arguments.length<3)throw new Le(`Graph.${c}: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.`);let b=g;return this[i](f,(m,S)=>{b=p(b,m,S)}),b}}function NK(e,t){const{name:n,type:r,direction:a}=t,i=n[0].toUpperCase()+n.slice(1,-1),l="find"+i;e.prototype[l]=function(f,p){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return;f=""+f;const g=this._nodes.get(f);if(typeof g>"u")throw new De(`Graph.${l}: could not find the "${f}" node in the graph.`);return p0(!0,r==="mixed"?this.type:r,a,g,p)};const u="some"+i;e.prototype[u]=function(f,p){return!!this[l](f,p)};const c="every"+i;e.prototype[c]=function(f,p){return!this[l](f,(b,m)=>!p(b,m))}}function OK(e,t){const{name:n,type:r,direction:a}=t,i=n.slice(0,-1)+"Entries";e.prototype[i]=function(l){if(r!=="mixed"&&this.type!=="mixed"&&r!==this.type)return Ol();l=""+l;const u=this._nodes.get(l);if(typeof u>"u")throw new De(`Graph.${i}: could not find the "${l}" node in the graph.`);return _K(r==="mixed"?this.type:r,a,u)}}function DK(e){AK.forEach(t=>{RK(e,t),CK(e,t),NK(e,t),OK(e,t)})}function Wc(e,t,n,r,a){const i=r._nodes.values(),l=r.type;let u,c,f,p,g,b;for(;u=i.next(),u.done!==!0;){let m=!1;if(c=u.value,l!=="undirected"){p=c.out;for(f in p){g=p[f];do b=g.target,m=!0,a(c.key,b.key,c.attributes,b.attributes,g.key,g.attributes,g.undirected),g=g.next;while(g)}}if(l!=="directed"){p=c.undirected;for(f in p)if(!(t&&c.key>f)){g=p[f];do b=g.target,b.key!==f&&(b=g.source),m=!0,a(c.key,b.key,c.attributes,b.attributes,g.key,g.attributes,g.undirected),g=g.next;while(g)}}n&&!m&&a(c.key,null,c.attributes,null,null,null,null)}}function IK(e,t){const n={key:e};return kU(t.attributes)||(n.attributes=Qt({},t.attributes)),n}function LK(e,t,n){const r={key:t,source:n.source.key,target:n.target.key};return kU(n.attributes)||(r.attributes=Qt({},n.attributes)),e==="mixed"&&n.undirected&&(r.undirected=!0),r}function MK(e){if(!gn(e))throw new Le('Graph.import: invalid serialized node. A serialized node should be a plain object with at least a "key" property.');if(!("key"in e))throw new Le("Graph.import: serialized node is missing its key.");if("attributes"in e&&(!gn(e.attributes)||e.attributes===null))throw new Le("Graph.import: invalid attributes. Attributes should be a plain object, null or omitted.")}function FK(e){if(!gn(e))throw new Le('Graph.import: invalid serialized edge. A serialized edge should be a plain object with at least a "source" & "target" property.');if(!("source"in e))throw new Le("Graph.import: serialized edge is missing its source.");if(!("target"in e))throw new Le("Graph.import: serialized edge is missing its target.");if("attributes"in e&&(!gn(e.attributes)||e.attributes===null))throw new Le("Graph.import: invalid attributes. Attributes should be a plain object, null or omitted.");if("undirected"in e&&typeof e.undirected!="boolean")throw new Le("Graph.import: invalid undirectedness information. Undirected should be boolean or omitted.")}const zK=BY(),PK=new Set(["directed","undirected","mixed"]),XR=new Set(["domain","_events","_eventsCount","_maxListeners"]),BK=[{name:e=>`${e}Edge`,generateKey:!0},{name:e=>`${e}DirectedEdge`,generateKey:!0,type:"directed"},{name:e=>`${e}UndirectedEdge`,generateKey:!0,type:"undirected"},{name:e=>`${e}EdgeWithKey`},{name:e=>`${e}DirectedEdgeWithKey`,type:"directed"},{name:e=>`${e}UndirectedEdgeWithKey`,type:"undirected"}],UK={allowSelfLoops:!0,multi:!1,type:"mixed"};function jK(e,t,n){if(n&&!gn(n))throw new Le(`Graph.addNode: invalid attributes. Expecting an object but got "${n}"`);if(t=""+t,n=n||{},e._nodes.has(t))throw new Ze(`Graph.addNode: the "${t}" node already exist in the graph.`);const r=new e.NodeDataClass(t,n);return e._nodes.set(t,r),e.emit("nodeAdded",{key:t,attributes:n}),r}function ZR(e,t,n){const r=new e.NodeDataClass(t,n);return e._nodes.set(t,r),e.emit("nodeAdded",{key:t,attributes:n}),r}function DU(e,t,n,r,a,i,l,u){if(!r&&e.type==="undirected")throw new Ze(`Graph.${t}: you cannot add a directed edge to an undirected graph. Use the #.addEdge or #.addUndirectedEdge instead.`);if(r&&e.type==="directed")throw new Ze(`Graph.${t}: you cannot add an undirected edge to a directed graph. Use the #.addEdge or #.addDirectedEdge instead.`);if(u&&!gn(u))throw new Le(`Graph.${t}: invalid attributes. Expecting an object but got "${u}"`);if(i=""+i,l=""+l,u=u||{},!e.allowSelfLoops&&i===l)throw new Ze(`Graph.${t}: source & target are the same ("${i}"), thus creating a loop explicitly forbidden by this graph 'allowSelfLoops' option set to false.`);const c=e._nodes.get(i),f=e._nodes.get(l);if(!c)throw new De(`Graph.${t}: source node "${i}" not found.`);if(!f)throw new De(`Graph.${t}: target node "${l}" not found.`);const p={key:null,undirected:r,source:i,target:l,attributes:u};if(n)a=e._edgeKeyGenerator();else if(a=""+a,e._edges.has(a))throw new Ze(`Graph.${t}: the "${a}" edge already exists in the graph.`);if(!e.multi&&(r?typeof c.undirected[l]<"u":typeof c.out[l]<"u"))throw new Ze(`Graph.${t}: an edge linking "${i}" to "${l}" already exists. If you really want to add multiple edges linking those nodes, you should create a multi graph by using the 'multi' option.`);const g=new Dl(r,a,c,f,u);e._edges.set(a,g);const b=i===l;return r?(c.undirectedDegree++,f.undirectedDegree++,b&&(c.undirectedLoops++,e._undirectedSelfLoopCount++)):(c.outDegree++,f.inDegree++,b&&(c.directedLoops++,e._directedSelfLoopCount++)),e.multi?g.attachMulti():g.attach(),r?e._undirectedSize++:e._directedSize++,p.key=a,e.emit("edgeAdded",p),a}function GK(e,t,n,r,a,i,l,u,c){if(!r&&e.type==="undirected")throw new Ze(`Graph.${t}: you cannot merge/update a directed edge to an undirected graph. Use the #.mergeEdge/#.updateEdge or #.addUndirectedEdge instead.`);if(r&&e.type==="directed")throw new Ze(`Graph.${t}: you cannot merge/update an undirected edge to a directed graph. Use the #.mergeEdge/#.updateEdge or #.addDirectedEdge instead.`);if(u){if(c){if(typeof u!="function")throw new Le(`Graph.${t}: invalid updater function. Expecting a function but got "${u}"`)}else if(!gn(u))throw new Le(`Graph.${t}: invalid attributes. Expecting an object but got "${u}"`)}i=""+i,l=""+l;let f;if(c&&(f=u,u=void 0),!e.allowSelfLoops&&i===l)throw new Ze(`Graph.${t}: source & target are the same ("${i}"), thus creating a loop explicitly forbidden by this graph 'allowSelfLoops' option set to false.`);let p=e._nodes.get(i),g=e._nodes.get(l),b,m;if(!n&&(b=e._edges.get(a),b)){if((b.source.key!==i||b.target.key!==l)&&(!r||b.source.key!==l||b.target.key!==i))throw new Ze(`Graph.${t}: inconsistency detected when attempting to merge the "${a}" edge with "${i}" source & "${l}" target vs. ("${b.source.key}", "${b.target.key}").`);m=b}if(!m&&!e.multi&&p&&(m=r?p.undirected[l]:p.out[l]),m){const x=[m.key,!1,!1,!1];if(c?!f:!u)return x;if(c){const T=m.attributes;m.attributes=f(T),e.emit("edgeAttributesUpdated",{type:"replace",key:m.key,attributes:m.attributes})}else Qt(m.attributes,u),e.emit("edgeAttributesUpdated",{type:"merge",key:m.key,attributes:m.attributes,data:u});return x}u=u||{},c&&f&&(u=f(u));const S={key:null,undirected:r,source:i,target:l,attributes:u};if(n)a=e._edgeKeyGenerator();else if(a=""+a,e._edges.has(a))throw new Ze(`Graph.${t}: the "${a}" edge already exists in the graph.`);let v=!1,A=!1;p||(p=ZR(e,i,{}),v=!0,i===l&&(g=p,A=!0)),g||(g=ZR(e,l,{}),A=!0),b=new Dl(r,a,p,g,u),e._edges.set(a,b);const R=i===l;return r?(p.undirectedDegree++,g.undirectedDegree++,R&&(p.undirectedLoops++,e._undirectedSelfLoopCount++)):(p.outDegree++,g.inDegree++,R&&(p.directedLoops++,e._directedSelfLoopCount++)),e.multi?b.attachMulti():b.attach(),r?e._undirectedSize++:e._directedSize++,S.key=a,e.emit("edgeAdded",S),[a,!0,v,A]}function Qi(e,t){e._edges.delete(t.key);const{source:n,target:r,attributes:a}=t,i=t.undirected,l=n===r;i?(n.undirectedDegree--,r.undirectedDegree--,l&&(n.undirectedLoops--,e._undirectedSelfLoopCount--)):(n.outDegree--,r.inDegree--,l&&(n.directedLoops--,e._directedSelfLoopCount--)),e.multi?t.detachMulti():t.detach(),i?e._undirectedSize--:e._directedSize--,e.emit("edgeDropped",{key:t.key,attributes:a,source:n.key,target:r.key,undirected:i})}class Tt extends xU.EventEmitter{constructor(t){if(super(),t=Qt({},UK,t),typeof t.multi!="boolean")throw new Le(`Graph.constructor: invalid 'multi' option. Expecting a boolean but got "${t.multi}".`);if(!PK.has(t.type))throw new Le(`Graph.constructor: invalid 'type' option. Should be one of "mixed", "directed" or "undirected" but got "${t.type}".`);if(typeof t.allowSelfLoops!="boolean")throw new Le(`Graph.constructor: invalid 'allowSelfLoops' option. Expecting a boolean but got "${t.allowSelfLoops}".`);const n=t.type==="mixed"?AU:t.type==="directed"?TU:_U;pr(this,"NodeDataClass",n);const r="geid_"+zK()+"_";let a=0;const i=()=>{let l;do l=r+a++;while(this._edges.has(l));return l};pr(this,"_attributes",{}),pr(this,"_nodes",new Map),pr(this,"_edges",new Map),pr(this,"_directedSize",0),pr(this,"_undirectedSize",0),pr(this,"_directedSelfLoopCount",0),pr(this,"_undirectedSelfLoopCount",0),pr(this,"_edgeKeyGenerator",i),pr(this,"_options",t),XR.forEach(l=>pr(this,l,this[l])),Tr(this,"order",()=>this._nodes.size),Tr(this,"size",()=>this._edges.size),Tr(this,"directedSize",()=>this._directedSize),Tr(this,"undirectedSize",()=>this._undirectedSize),Tr(this,"selfLoopCount",()=>this._directedSelfLoopCount+this._undirectedSelfLoopCount),Tr(this,"directedSelfLoopCount",()=>this._directedSelfLoopCount),Tr(this,"undirectedSelfLoopCount",()=>this._undirectedSelfLoopCount),Tr(this,"multi",this._options.multi),Tr(this,"type",this._options.type),Tr(this,"allowSelfLoops",this._options.allowSelfLoops),Tr(this,"implementation",()=>"graphology")}_resetInstanceCounters(){this._directedSize=0,this._undirectedSize=0,this._directedSelfLoopCount=0,this._undirectedSelfLoopCount=0}hasNode(t){return this._nodes.has(""+t)}hasDirectedEdge(t,n){if(this.type==="undirected")return!1;if(arguments.length===1){const r=""+t,a=this._edges.get(r);return!!a&&!a.undirected}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?r.out.hasOwnProperty(n):!1}throw new Le(`Graph.hasDirectedEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}hasUndirectedEdge(t,n){if(this.type==="directed")return!1;if(arguments.length===1){const r=""+t,a=this._edges.get(r);return!!a&&a.undirected}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?r.undirected.hasOwnProperty(n):!1}throw new Le(`Graph.hasDirectedEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}hasEdge(t,n){if(arguments.length===1){const r=""+t;return this._edges.has(r)}else if(arguments.length===2){t=""+t,n=""+n;const r=this._nodes.get(t);return r?typeof r.out<"u"&&r.out.hasOwnProperty(n)||typeof r.undirected<"u"&&r.undirected.hasOwnProperty(n):!1}throw new Le(`Graph.hasEdge: invalid arity (${arguments.length}, instead of 1 or 2). You can either ask for an edge id or for the existence of an edge between a source & a target.`)}directedEdge(t,n){if(this.type==="undirected")return;if(t=""+t,n=""+n,this.multi)throw new Ze("Graph.directedEdge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.directedEdges instead.");const r=this._nodes.get(t);if(!r)throw new De(`Graph.directedEdge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new De(`Graph.directedEdge: could not find the "${n}" target node in the graph.`);const a=r.out&&r.out[n]||void 0;if(a)return a.key}undirectedEdge(t,n){if(this.type==="directed")return;if(t=""+t,n=""+n,this.multi)throw new Ze("Graph.undirectedEdge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.undirectedEdges instead.");const r=this._nodes.get(t);if(!r)throw new De(`Graph.undirectedEdge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new De(`Graph.undirectedEdge: could not find the "${n}" target node in the graph.`);const a=r.undirected&&r.undirected[n]||void 0;if(a)return a.key}edge(t,n){if(this.multi)throw new Ze("Graph.edge: this method is irrelevant with multigraphs since there might be multiple edges between source & target. See #.edges instead.");t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.edge: could not find the "${t}" source node in the graph.`);if(!this._nodes.has(n))throw new De(`Graph.edge: could not find the "${n}" target node in the graph.`);const a=r.out&&r.out[n]||r.undirected&&r.undirected[n]||void 0;if(a)return a.key}areDirectedNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areDirectedNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.in||n in r.out}areOutNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areOutNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.out}areInNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areInNeighbors: could not find the "${t}" node in the graph.`);return this.type==="undirected"?!1:n in r.in}areUndirectedNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areUndirectedNeighbors: could not find the "${t}" node in the graph.`);return this.type==="directed"?!1:n in r.undirected}areNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&(n in r.in||n in r.out)||this.type!=="directed"&&n in r.undirected}areInboundNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areInboundNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&n in r.in||this.type!=="directed"&&n in r.undirected}areOutboundNeighbors(t,n){t=""+t,n=""+n;const r=this._nodes.get(t);if(!r)throw new De(`Graph.areOutboundNeighbors: could not find the "${t}" node in the graph.`);return this.type!=="undirected"&&n in r.out||this.type!=="directed"&&n in r.undirected}inDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.inDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree}outDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.outDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.outDegree}directedDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.directedDegree: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree+n.outDegree}undirectedDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.undirectedDegree: could not find the "${t}" node in the graph.`);return this.type==="directed"?0:n.undirectedDegree}inboundDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.inboundDegree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.inDegree),r}outboundDegree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.outboundDegree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.outDegree),r}degree(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.degree: could not find the "${t}" node in the graph.`);let r=0;return this.type!=="directed"&&(r+=n.undirectedDegree),this.type!=="undirected"&&(r+=n.inDegree+n.outDegree),r}inDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.inDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree-n.directedLoops}outDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.outDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.outDegree-n.directedLoops}directedDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.directedDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="undirected"?0:n.inDegree+n.outDegree-n.directedLoops*2}undirectedDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.undirectedDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);return this.type==="directed"?0:n.undirectedDegree-n.undirectedLoops*2}inboundDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.inboundDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.inDegree,a+=n.directedLoops),r-a}outboundDegreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.outboundDegreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.outDegree,a+=n.directedLoops),r-a}degreeWithoutSelfLoops(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.degreeWithoutSelfLoops: could not find the "${t}" node in the graph.`);let r=0,a=0;return this.type!=="directed"&&(r+=n.undirectedDegree,a+=n.undirectedLoops*2),this.type!=="undirected"&&(r+=n.inDegree+n.outDegree,a+=n.directedLoops*2),r-a}source(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.source: could not find the "${t}" edge in the graph.`);return n.source.key}target(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.target: could not find the "${t}" edge in the graph.`);return n.target.key}extremities(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.extremities: could not find the "${t}" edge in the graph.`);return[n.source.key,n.target.key]}opposite(t,n){t=""+t,n=""+n;const r=this._edges.get(n);if(!r)throw new De(`Graph.opposite: could not find the "${n}" edge in the graph.`);const a=r.source.key,i=r.target.key;if(t===a)return i;if(t===i)return a;throw new De(`Graph.opposite: the "${t}" node is not attached to the "${n}" edge (${a}, ${i}).`)}hasExtremity(t,n){t=""+t,n=""+n;const r=this._edges.get(t);if(!r)throw new De(`Graph.hasExtremity: could not find the "${t}" edge in the graph.`);return r.source.key===n||r.target.key===n}isUndirected(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.isUndirected: could not find the "${t}" edge in the graph.`);return n.undirected}isDirected(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.isDirected: could not find the "${t}" edge in the graph.`);return!n.undirected}isSelfLoop(t){t=""+t;const n=this._edges.get(t);if(!n)throw new De(`Graph.isSelfLoop: could not find the "${t}" edge in the graph.`);return n.source===n.target}addNode(t,n){return jK(this,t,n).key}mergeNode(t,n){if(n&&!gn(n))throw new Le(`Graph.mergeNode: invalid attributes. Expecting an object but got "${n}"`);t=""+t,n=n||{};let r=this._nodes.get(t);return r?(n&&(Qt(r.attributes,n),this.emit("nodeAttributesUpdated",{type:"merge",key:t,attributes:r.attributes,data:n})),[t,!1]):(r=new this.NodeDataClass(t,n),this._nodes.set(t,r),this.emit("nodeAdded",{key:t,attributes:n}),[t,!0])}updateNode(t,n){if(n&&typeof n!="function")throw new Le(`Graph.updateNode: invalid updater function. Expecting a function but got "${n}"`);t=""+t;let r=this._nodes.get(t);if(r){if(n){const i=r.attributes;r.attributes=n(i),this.emit("nodeAttributesUpdated",{type:"replace",key:t,attributes:r.attributes})}return[t,!1]}const a=n?n({}):{};return r=new this.NodeDataClass(t,a),this._nodes.set(t,r),this.emit("nodeAdded",{key:t,attributes:a}),[t,!0]}dropNode(t){t=""+t;const n=this._nodes.get(t);if(!n)throw new De(`Graph.dropNode: could not find the "${t}" node in the graph.`);let r;if(this.type!=="undirected"){for(const a in n.out){r=n.out[a];do Qi(this,r),r=r.next;while(r)}for(const a in n.in){r=n.in[a];do Qi(this,r),r=r.next;while(r)}}if(this.type!=="directed")for(const a in n.undirected){r=n.undirected[a];do Qi(this,r),r=r.next;while(r)}this._nodes.delete(t),this.emit("nodeDropped",{key:t,attributes:n.attributes})}dropEdge(t){let n;if(arguments.length>1){const r=""+arguments[0],a=""+arguments[1];if(n=hr(this,r,a,this.type),!n)throw new De(`Graph.dropEdge: could not find the "${r}" -> "${a}" edge in the graph.`)}else if(t=""+t,n=this._edges.get(t),!n)throw new De(`Graph.dropEdge: could not find the "${t}" edge in the graph.`);return Qi(this,n),this}dropDirectedEdge(t,n){if(arguments.length<2)throw new Ze("Graph.dropDirectedEdge: it does not make sense to try and drop a directed edge by key. What if the edge with this key is undirected? Use #.dropEdge for this purpose instead.");if(this.multi)throw new Ze("Graph.dropDirectedEdge: cannot use a {source,target} combo when dropping an edge in a MultiGraph since we cannot infer the one you want to delete as there could be multiple ones.");t=""+t,n=""+n;const r=hr(this,t,n,"directed");if(!r)throw new De(`Graph.dropDirectedEdge: could not find a "${t}" -> "${n}" edge in the graph.`);return Qi(this,r),this}dropUndirectedEdge(t,n){if(arguments.length<2)throw new Ze("Graph.dropUndirectedEdge: it does not make sense to drop a directed edge by key. What if the edge with this key is undirected? Use #.dropEdge for this purpose instead.");if(this.multi)throw new Ze("Graph.dropUndirectedEdge: cannot use a {source,target} combo when dropping an edge in a MultiGraph since we cannot infer the one you want to delete as there could be multiple ones.");const r=hr(this,t,n,"undirected");if(!r)throw new De(`Graph.dropUndirectedEdge: could not find a "${t}" -> "${n}" edge in the graph.`);return Qi(this,r),this}clear(){this._edges.clear(),this._nodes.clear(),this._resetInstanceCounters(),this.emit("cleared")}clearEdges(){const t=this._nodes.values();let n;for(;n=t.next(),n.done!==!0;)n.value.clear();this._edges.clear(),this._resetInstanceCounters(),this.emit("edgesCleared")}getAttribute(t){return this._attributes[t]}getAttributes(){return this._attributes}hasAttribute(t){return this._attributes.hasOwnProperty(t)}setAttribute(t,n){return this._attributes[t]=n,this.emit("attributesUpdated",{type:"set",attributes:this._attributes,name:t}),this}updateAttribute(t,n){if(typeof n!="function")throw new Le("Graph.updateAttribute: updater should be a function.");const r=this._attributes[t];return this._attributes[t]=n(r),this.emit("attributesUpdated",{type:"set",attributes:this._attributes,name:t}),this}removeAttribute(t){return delete this._attributes[t],this.emit("attributesUpdated",{type:"remove",attributes:this._attributes,name:t}),this}replaceAttributes(t){if(!gn(t))throw new Le("Graph.replaceAttributes: provided attributes are not a plain object.");return this._attributes=t,this.emit("attributesUpdated",{type:"replace",attributes:this._attributes}),this}mergeAttributes(t){if(!gn(t))throw new Le("Graph.mergeAttributes: provided attributes are not a plain object.");return Qt(this._attributes,t),this.emit("attributesUpdated",{type:"merge",attributes:this._attributes,data:t}),this}updateAttributes(t){if(typeof t!="function")throw new Le("Graph.updateAttributes: provided updater is not a function.");return this._attributes=t(this._attributes),this.emit("attributesUpdated",{type:"update",attributes:this._attributes}),this}updateEachNodeAttributes(t,n){if(typeof t!="function")throw new Le("Graph.updateEachNodeAttributes: expecting an updater function.");if(n&&!KR(n))throw new Le("Graph.updateEachNodeAttributes: invalid hints. Expecting an object having the following shape: {attributes?: [string]}");const r=this._nodes.values();let a,i;for(;a=r.next(),a.done!==!0;)i=a.value,i.attributes=t(i.key,i.attributes);this.emit("eachNodeAttributesUpdated",{hints:n||null})}updateEachEdgeAttributes(t,n){if(typeof t!="function")throw new Le("Graph.updateEachEdgeAttributes: expecting an updater function.");if(n&&!KR(n))throw new Le("Graph.updateEachEdgeAttributes: invalid hints. Expecting an object having the following shape: {attributes?: [string]}");const r=this._edges.values();let a,i,l,u;for(;a=r.next(),a.done!==!0;)i=a.value,l=i.source,u=i.target,i.attributes=t(i.key,i.attributes,l.key,u.key,l.attributes,u.attributes,i.undirected);this.emit("eachEdgeAttributesUpdated",{hints:n||null})}forEachAdjacencyEntry(t){if(typeof t!="function")throw new Le("Graph.forEachAdjacencyEntry: expecting a callback.");Wc(!1,!1,!1,this,t)}forEachAdjacencyEntryWithOrphans(t){if(typeof t!="function")throw new Le("Graph.forEachAdjacencyEntryWithOrphans: expecting a callback.");Wc(!1,!1,!0,this,t)}forEachAssymetricAdjacencyEntry(t){if(typeof t!="function")throw new Le("Graph.forEachAssymetricAdjacencyEntry: expecting a callback.");Wc(!1,!0,!1,this,t)}forEachAssymetricAdjacencyEntryWithOrphans(t){if(typeof t!="function")throw new Le("Graph.forEachAssymetricAdjacencyEntryWithOrphans: expecting a callback.");Wc(!1,!0,!0,this,t)}nodes(){return Array.from(this._nodes.keys())}forEachNode(t){if(typeof t!="function")throw new Le("Graph.forEachNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)a=r.value,t(a.key,a.attributes)}findNode(t){if(typeof t!="function")throw new Le("Graph.findNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,t(a.key,a.attributes))return a.key}mapNodes(t){if(typeof t!="function")throw new Le("Graph.mapNode: expecting a callback.");const n=this._nodes.values();let r,a;const i=new Array(this.order);let l=0;for(;r=n.next(),r.done!==!0;)a=r.value,i[l++]=t(a.key,a.attributes);return i}someNode(t){if(typeof t!="function")throw new Le("Graph.someNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,t(a.key,a.attributes))return!0;return!1}everyNode(t){if(typeof t!="function")throw new Le("Graph.everyNode: expecting a callback.");const n=this._nodes.values();let r,a;for(;r=n.next(),r.done!==!0;)if(a=r.value,!t(a.key,a.attributes))return!1;return!0}filterNodes(t){if(typeof t!="function")throw new Le("Graph.filterNodes: expecting a callback.");const n=this._nodes.values();let r,a;const i=[];for(;r=n.next(),r.done!==!0;)a=r.value,t(a.key,a.attributes)&&i.push(a.key);return i}reduceNodes(t,n){if(typeof t!="function")throw new Le("Graph.reduceNodes: expecting a callback.");if(arguments.length<2)throw new Le("Graph.reduceNodes: missing initial value. You must provide it because the callback takes more than one argument and we cannot infer the initial value from the first iteration, as you could with a simple array.");let r=n;const a=this._nodes.values();let i,l;for(;i=a.next(),i.done!==!0;)l=i.value,r=t(r,l.key,l.attributes);return r}nodeEntries(){const t=this._nodes.values();return{[Symbol.iterator](){return this},next(){const n=t.next();if(n.done)return n;const r=n.value;return{value:{node:r.key,attributes:r.attributes},done:!1}}}}export(){const t=new Array(this._nodes.size);let n=0;this._nodes.forEach((a,i)=>{t[n++]=IK(i,a)});const r=new Array(this._edges.size);return n=0,this._edges.forEach((a,i)=>{r[n++]=LK(this.type,i,a)}),{options:{type:this.type,multi:this.multi,allowSelfLoops:this.allowSelfLoops},attributes:this.getAttributes(),nodes:t,edges:r}}import(t,n=!1){if(t instanceof Tt)return t.forEachNode((c,f)=>{n?this.mergeNode(c,f):this.addNode(c,f)}),t.forEachEdge((c,f,p,g,b,m,S)=>{n?S?this.mergeUndirectedEdgeWithKey(c,p,g,f):this.mergeDirectedEdgeWithKey(c,p,g,f):S?this.addUndirectedEdgeWithKey(c,p,g,f):this.addDirectedEdgeWithKey(c,p,g,f)}),this;if(!gn(t))throw new Le("Graph.import: invalid argument. Expecting a serialized graph or, alternatively, a Graph instance.");if(t.attributes){if(!gn(t.attributes))throw new Le("Graph.import: invalid attributes. Expecting a plain object.");n?this.mergeAttributes(t.attributes):this.replaceAttributes(t.attributes)}let r,a,i,l,u;if(t.nodes){if(i=t.nodes,!Array.isArray(i))throw new Le("Graph.import: invalid nodes. Expecting an array.");for(r=0,a=i.length;r<a;r++){l=i[r],MK(l);const{key:c,attributes:f}=l;n?this.mergeNode(c,f):this.addNode(c,f)}}if(t.edges){let c=!1;if(this.type==="undirected"&&(c=!0),i=t.edges,!Array.isArray(i))throw new Le("Graph.import: invalid edges. Expecting an array.");for(r=0,a=i.length;r<a;r++){u=i[r],FK(u);const{source:f,target:p,attributes:g,undirected:b=c}=u;let m;"key"in u?(m=n?b?this.mergeUndirectedEdgeWithKey:this.mergeDirectedEdgeWithKey:b?this.addUndirectedEdgeWithKey:this.addDirectedEdgeWithKey,m.call(this,u.key,f,p,g)):(m=n?b?this.mergeUndirectedEdge:this.mergeDirectedEdge:b?this.addUndirectedEdge:this.addDirectedEdge,m.call(this,f,p,g))}}return this}nullCopy(t){const n=new Tt(Qt({},this._options,t));return n.replaceAttributes(Qt({},this.getAttributes())),n}emptyCopy(t){const n=this.nullCopy(t);return this._nodes.forEach((r,a)=>{const i=Qt({},r.attributes);r=new n.NodeDataClass(a,i),n._nodes.set(a,r)}),n}copy(t){if(t=t||{},typeof t.type=="string"&&t.type!==this.type&&t.type!=="mixed")throw new Ze(`Graph.copy: cannot create an incompatible copy from "${this.type}" type to "${t.type}" because this would mean losing information about the current graph.`);if(typeof t.multi=="boolean"&&t.multi!==this.multi&&t.multi!==!0)throw new Ze("Graph.copy: cannot create an incompatible copy by downgrading a multi graph to a simple one because this would mean losing information about the current graph.");if(typeof t.allowSelfLoops=="boolean"&&t.allowSelfLoops!==this.allowSelfLoops&&t.allowSelfLoops!==!0)throw new Ze("Graph.copy: cannot create an incompatible copy from a graph allowing self loops to one that does not because this would mean losing information about the current graph.");const n=this.emptyCopy(t),r=this._edges.values();let a,i;for(;a=r.next(),a.done!==!0;)i=a.value,DU(n,"copy",!1,i.undirected,i.key,i.source.key,i.target.key,Qt({},i.attributes));return n}toJSON(){return this.export()}toString(){return"[object Graph]"}inspect(){const t={};this._nodes.forEach((i,l)=>{t[l]=i.attributes});const n={},r={};this._edges.forEach((i,l)=>{const u=i.undirected?"--":"->";let c="",f=i.source.key,p=i.target.key,g;i.undirected&&f>p&&(g=f,f=p,p=g);const b=`(${f})${u}(${p})`;l.startsWith("geid_")?this.multi&&(typeof r[b]>"u"?r[b]=0:r[b]++,c+=`${r[b]}. `):c+=`[${l}]: `,c+=b,n[c]=i.attributes});const a={};for(const i in this)this.hasOwnProperty(i)&&!XR.has(i)&&typeof this[i]!="function"&&typeof i!="symbol"&&(a[i]=this[i]);return a.attributes=this._attributes,a.nodes=t,a.edges=n,pr(a,"constructor",this.constructor),a}}typeof Symbol<"u"&&(Tt.prototype[Symbol.for("nodejs.util.inspect.custom")]=Tt.prototype.inspect);BK.forEach(e=>{["add","merge","update"].forEach(t=>{const n=e.name(t),r=t==="add"?DU:GK;e.generateKey?Tt.prototype[n]=function(a,i,l){return r(this,n,!0,(e.type||this.type)==="undirected",null,a,i,l,t==="update")}:Tt.prototype[n]=function(a,i,l,u){return r(this,n,!1,(e.type||this.type)==="undirected",a,i,l,u,t==="update")}})});ZY(Tt);sK(Tt);kK(Tt);DK(Tt);class nu extends Tt{constructor(t){const n=Qt({type:"directed"},t);if("multi"in n&&n.multi!==!1)throw new Le("DirectedGraph.from: inconsistent indication that the graph should be multi in given options!");if(n.type!=="directed")throw new Le('DirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class IU extends Tt{constructor(t){const n=Qt({type:"undirected"},t);if("multi"in n&&n.multi!==!1)throw new Le("UndirectedGraph.from: inconsistent indication that the graph should be multi in given options!");if(n.type!=="undirected")throw new Le('UndirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class LU extends Tt{constructor(t){const n=Qt({multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Le("MultiGraph.from: inconsistent indication that the graph should be simple in given options!");super(n)}}class MU extends Tt{constructor(t){const n=Qt({type:"directed",multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Le("MultiDirectedGraph.from: inconsistent indication that the graph should be simple in given options!");if(n.type!=="directed")throw new Le('MultiDirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}class FU extends Tt{constructor(t){const n=Qt({type:"undirected",multi:!0},t);if("multi"in n&&n.multi!==!0)throw new Le("MultiUndirectedGraph.from: inconsistent indication that the graph should be simple in given options!");if(n.type!=="undirected")throw new Le('MultiUndirectedGraph.from: inconsistent "'+n.type+'" type in given options!');super(n)}}function Il(e){e.from=function(t,n){const r=Qt({},t.options,n),a=new e(r);return a.import(t),a}}Il(Tt);Il(nu);Il(IU);Il(LU);Il(MU);Il(FU);Tt.Graph=Tt;Tt.DirectedGraph=nu;Tt.UndirectedGraph=IU;Tt.MultiGraph=LU;Tt.MultiDirectedGraph=MU;Tt.MultiUndirectedGraph=FU;Tt.InvalidArgumentsGraphError=Le;Tt.NotFoundGraphError=De;Tt.UsageGraphError=Ze;function HK(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return String(e)}function Ys(e){var t=HK(e,"string");return typeof t=="symbol"?t:t+""}function on(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function QR(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,Ys(r.key),r)}}function ln(e,t,n){return t&&QR(e.prototype,t),n&&QR(e,n),Object.defineProperty(e,"prototype",{writable:!1}),e}function vl(e){return vl=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},vl(e)}function zU(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(zU=function(){return!!e})()}function $K(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function qK(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return $K(e)}function Bn(e,t,n){return t=vl(t),qK(e,zU()?Reflect.construct(t,n||[],vl(e).constructor):t.apply(e,n))}function Ix(e,t){return Ix=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},Ix(e,t)}function Un(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Ix(e,t)}function VK(e){if(Array.isArray(e))return e}function WK(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r,a,i,l,u=[],c=!0,f=!1;try{if(i=(n=n.call(e)).next,t===0){if(Object(n)!==n)return;c=!1}else for(;!(c=(r=i.call(n)).done)&&(u.push(r.value),u.length!==t);c=!0);}catch(p){f=!0,a=p}finally{try{if(!c&&n.return!=null&&(l=n.return(),Object(l)!==l))return}finally{if(f)throw a}}return u}}function Lx(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function PU(e,t){if(e){if(typeof e=="string")return Lx(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Lx(e,t):void 0}}function YK(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Sl(e,t){return VK(e)||WK(e,t)||PU(e,t)||YK()}var Ah={black:"#000000",silver:"#C0C0C0",gray:"#808080",grey:"#808080",white:"#FFFFFF",maroon:"#800000",red:"#FF0000",purple:"#800080",fuchsia:"#FF00FF",green:"#008000",lime:"#00FF00",olive:"#808000",yellow:"#FFFF00",navy:"#000080",blue:"#0000FF",teal:"#008080",aqua:"#00FFFF",darkblue:"#00008B",mediumblue:"#0000CD",darkgreen:"#006400",darkcyan:"#008B8B",deepskyblue:"#00BFFF",darkturquoise:"#00CED1",mediumspringgreen:"#00FA9A",springgreen:"#00FF7F",cyan:"#00FFFF",midnightblue:"#191970",dodgerblue:"#1E90FF",lightseagreen:"#20B2AA",forestgreen:"#228B22",seagreen:"#2E8B57",darkslategray:"#2F4F4F",darkslategrey:"#2F4F4F",limegreen:"#32CD32",mediumseagreen:"#3CB371",turquoise:"#40E0D0",royalblue:"#4169E1",steelblue:"#4682B4",darkslateblue:"#483D8B",mediumturquoise:"#48D1CC",indigo:"#4B0082",darkolivegreen:"#556B2F",cadetblue:"#5F9EA0",cornflowerblue:"#6495ED",rebeccapurple:"#663399",mediumaquamarine:"#66CDAA",dimgray:"#696969",dimgrey:"#696969",slateblue:"#6A5ACD",olivedrab:"#6B8E23",slategray:"#708090",slategrey:"#708090",lightslategray:"#778899",lightslategrey:"#778899",mediumslateblue:"#7B68EE",lawngreen:"#7CFC00",chartreuse:"#7FFF00",aquamarine:"#7FFFD4",skyblue:"#87CEEB",lightskyblue:"#87CEFA",blueviolet:"#8A2BE2",darkred:"#8B0000",darkmagenta:"#8B008B",saddlebrown:"#8B4513",darkseagreen:"#8FBC8F",lightgreen:"#90EE90",mediumpurple:"#9370DB",darkviolet:"#9400D3",palegreen:"#98FB98",darkorchid:"#9932CC",yellowgreen:"#9ACD32",sienna:"#A0522D",brown:"#A52A2A",darkgray:"#A9A9A9",darkgrey:"#A9A9A9",lightblue:"#ADD8E6",greenyellow:"#ADFF2F",paleturquoise:"#AFEEEE",lightsteelblue:"#B0C4DE",powderblue:"#B0E0E6",firebrick:"#B22222",darkgoldenrod:"#B8860B",mediumorchid:"#BA55D3",rosybrown:"#BC8F8F",darkkhaki:"#BDB76B",mediumvioletred:"#C71585",indianred:"#CD5C5C",peru:"#CD853F",chocolate:"#D2691E",tan:"#D2B48C",lightgray:"#D3D3D3",lightgrey:"#D3D3D3",thistle:"#D8BFD8",orchid:"#DA70D6",goldenrod:"#DAA520",palevioletred:"#DB7093",crimson:"#DC143C",gainsboro:"#DCDCDC",plum:"#DDA0DD",burlywood:"#DEB887",lightcyan:"#E0FFFF",lavender:"#E6E6FA",darksalmon:"#E9967A",violet:"#EE82EE",palegoldenrod:"#EEE8AA",lightcoral:"#F08080",khaki:"#F0E68C",aliceblue:"#F0F8FF",honeydew:"#F0FFF0",azure:"#F0FFFF",sandybrown:"#F4A460",wheat:"#F5DEB3",beige:"#F5F5DC",whitesmoke:"#F5F5F5",mintcream:"#F5FFFA",ghostwhite:"#F8F8FF",salmon:"#FA8072",antiquewhite:"#FAEBD7",linen:"#FAF0E6",lightgoldenrodyellow:"#FAFAD2",oldlace:"#FDF5E6",magenta:"#FF00FF",deeppink:"#FF1493",orangered:"#FF4500",tomato:"#FF6347",hotpink:"#FF69B4",coral:"#FF7F50",darkorange:"#FF8C00",lightsalmon:"#FFA07A",orange:"#FFA500",lightpink:"#FFB6C1",pink:"#FFC0CB",gold:"#FFD700",peachpuff:"#FFDAB9",navajowhite:"#FFDEAD",moccasin:"#FFE4B5",bisque:"#FFE4C4",mistyrose:"#FFE4E1",blanchedalmond:"#FFEBCD",papayawhip:"#FFEFD5",lavenderblush:"#FFF0F5",seashell:"#FFF5EE",cornsilk:"#FFF8DC",lemonchiffon:"#FFFACD",floralwhite:"#FFFAF0",snow:"#FFFAFA",lightyellow:"#FFFFE0",ivory:"#FFFFF0"},BU=new Int8Array(4),yd=new Int32Array(BU.buffer,0,1),UU=new Float32Array(BU.buffer,0,1),KK=/^\s*rgba?\s*\(/,XK=/^\s*rgba?\s*\(\s*([0-9]*)\s*,\s*([0-9]*)\s*,\s*([0-9]*)(?:\s*,\s*(.*)?)?\)\s*$/;function ZK(e){var t=0,n=0,r=0,a=1;if(e[0]==="#")e.length===4?(t=parseInt(e.charAt(1)+e.charAt(1),16),n=parseInt(e.charAt(2)+e.charAt(2),16),r=parseInt(e.charAt(3)+e.charAt(3),16)):(t=parseInt(e.charAt(1)+e.charAt(2),16),n=parseInt(e.charAt(3)+e.charAt(4),16),r=parseInt(e.charAt(5)+e.charAt(6),16)),e.length===9&&(a=parseInt(e.charAt(7)+e.charAt(8),16)/255);else if(KK.test(e)){var i=e.match(XK);i&&(t=+i[1],n=+i[2],r=+i[3],i[4]&&(a=+i[4]))}return{r:t,g:n,b:r,a}}var pl={};for(var Yc in Ah)pl[Yc]=Qr(Ah[Yc]),pl[Ah[Yc]]=pl[Yc];function jU(e,t,n,r,a){return yd[0]=r<<24|n<<16|t<<8|e,yd[0]=yd[0]&4278190079,UU[0]}function Qr(e){if(e=e.toLowerCase(),typeof pl[e]<"u")return pl[e];var t=ZK(e),n=t.r,r=t.g,a=t.b,i=t.a;i=i*255|0;var l=jU(n,r,a,i);return pl[e]=l,l}function QK(e,t){UU[0]=Qr(e);var n=yd[0],r=n&255,a=n>>8&255,i=n>>16&255,l=n>>24&255;return[r,a,i,l]}var Th={};function GU(e){if(typeof Th[e]<"u")return Th[e];var t=(e&16711680)>>>16,n=(e&65280)>>>8,r=e&255,a=255,i=jU(t,n,r,a);return Th[e]=i,i}function JR(e,t,n,r){return n+(t<<8)+(e<<16)}function eC(e,t,n,r,a,i){var l=Math.floor(n/i*a),u=Math.floor(e.drawingBufferHeight/i-r/i*a),c=new Uint8Array(4);e.bindFramebuffer(e.FRAMEBUFFER,t),e.readPixels(l,u,1,1,e.RGBA,e.UNSIGNED_BYTE,c);var f=Sl(c,4),p=f[0],g=f[1],b=f[2],m=f[3];return[p,g,b,m]}function _e(e,t,n){return(t=Ys(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function tC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Be(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?tC(Object(n),!0).forEach(function(r){_e(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):tC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function JK(e,t){for(;!{}.hasOwnProperty.call(e,t)&&(e=vl(e))!==null;);return e}function Mx(){return Mx=typeof Reflect<"u"&&Reflect.get?Reflect.get.bind():function(e,t,n){var r=JK(e,t);if(r){var a=Object.getOwnPropertyDescriptor(r,t);return a.get?a.get.call(arguments.length<3?e:n):a.value}},Mx.apply(null,arguments)}function HU(e,t,n,r){var a=Mx(vl(e.prototype),t,n);return typeof a=="function"?function(i){return a.apply(n,i)}:a}function eX(e){return e.normalized?1:e.size}function _h(e){var t=0;return e.forEach(function(n){return t+=eX(n)}),t}function $U(e,t,n){var r=e==="VERTEX"?t.VERTEX_SHADER:t.FRAGMENT_SHADER,a=t.createShader(r);if(a===null)throw new Error("loadShader: error while creating the shader");t.shaderSource(a,n),t.compileShader(a);var i=t.getShaderParameter(a,t.COMPILE_STATUS);if(!i){var l=t.getShaderInfoLog(a);throw t.deleteShader(a),new Error(`loadShader: error while compiling the shader:
`.concat(l,`
`).concat(n))}return a}function tX(e,t){return $U("VERTEX",e,t)}function nX(e,t){return $U("FRAGMENT",e,t)}function rX(e,t){var n=e.createProgram();if(n===null)throw new Error("loadProgram: error while creating the program.");var r,a;for(r=0,a=t.length;r<a;r++)e.attachShader(n,t[r]);e.linkProgram(n);var i=e.getProgramParameter(n,e.LINK_STATUS);if(!i)throw e.deleteProgram(n),new Error("loadProgram: error while linking the program.");return n}function nC(e){var t=e.gl,n=e.buffer,r=e.program,a=e.vertexShader,i=e.fragmentShader;t.deleteShader(a),t.deleteShader(i),t.deleteProgram(r),t.deleteBuffer(n)}function rC(e){return e%1===0?e.toFixed(1):e.toString()}var aC=`#define PICKING_MODE
`,aX=_e(_e(_e(_e(_e(_e(_e(_e({},WebGL2RenderingContext.BOOL,1),WebGL2RenderingContext.BYTE,1),WebGL2RenderingContext.UNSIGNED_BYTE,1),WebGL2RenderingContext.SHORT,2),WebGL2RenderingContext.UNSIGNED_SHORT,2),WebGL2RenderingContext.INT,4),WebGL2RenderingContext.UNSIGNED_INT,4),WebGL2RenderingContext.FLOAT,4),qU=function(){function e(t,n,r){on(this,e),_e(this,"array",new Float32Array),_e(this,"constantArray",new Float32Array),_e(this,"capacity",0),_e(this,"verticesCount",0);var a=this.getDefinition();if(this.VERTICES=a.VERTICES,this.VERTEX_SHADER_SOURCE=a.VERTEX_SHADER_SOURCE,this.FRAGMENT_SHADER_SOURCE=a.FRAGMENT_SHADER_SOURCE,this.UNIFORMS=a.UNIFORMS,this.ATTRIBUTES=a.ATTRIBUTES,this.METHOD=a.METHOD,this.CONSTANT_ATTRIBUTES="CONSTANT_ATTRIBUTES"in a?a.CONSTANT_ATTRIBUTES:[],this.CONSTANT_DATA="CONSTANT_DATA"in a?a.CONSTANT_DATA:[],this.isInstanced="CONSTANT_ATTRIBUTES"in a,this.ATTRIBUTES_ITEMS_COUNT=_h(this.ATTRIBUTES),this.STRIDE=this.VERTICES*this.ATTRIBUTES_ITEMS_COUNT,this.renderer=r,this.normalProgram=this.getProgramInfo("normal",t,a.VERTEX_SHADER_SOURCE,a.FRAGMENT_SHADER_SOURCE,null),this.pickProgram=n?this.getProgramInfo("pick",t,aC+a.VERTEX_SHADER_SOURCE,aC+a.FRAGMENT_SHADER_SOURCE,n):null,this.isInstanced){var i=_h(this.CONSTANT_ATTRIBUTES);if(this.CONSTANT_DATA.length!==this.VERTICES)throw new Error("Program: error while getting constant data (expected ".concat(this.VERTICES," items, received ").concat(this.CONSTANT_DATA.length," instead)"));this.constantArray=new Float32Array(this.CONSTANT_DATA.length*i);for(var l=0;l<this.CONSTANT_DATA.length;l++){var u=this.CONSTANT_DATA[l];if(u.length!==i)throw new Error("Program: error while getting constant data (one vector has ".concat(u.length," items instead of ").concat(i,")"));for(var c=0;c<u.length;c++)this.constantArray[l*i+c]=u[c]}this.STRIDE=this.ATTRIBUTES_ITEMS_COUNT}}return ln(e,[{key:"kill",value:function(){nC(this.normalProgram),this.pickProgram&&(nC(this.pickProgram),this.pickProgram=null)}},{key:"getProgramInfo",value:function(n,r,a,i,l){var u=this.getDefinition(),c=r.createBuffer();if(c===null)throw new Error("Program: error while creating the WebGL buffer.");var f=tX(r,a),p=nX(r,i),g=rX(r,[f,p]),b={};u.UNIFORMS.forEach(function(v){var A=r.getUniformLocation(g,v);A&&(b[v]=A)});var m={};u.ATTRIBUTES.forEach(function(v){m[v.name]=r.getAttribLocation(g,v.name)});var S;if("CONSTANT_ATTRIBUTES"in u&&(u.CONSTANT_ATTRIBUTES.forEach(function(v){m[v.name]=r.getAttribLocation(g,v.name)}),S=r.createBuffer(),S===null))throw new Error("Program: error while creating the WebGL constant buffer.");return{name:n,program:g,gl:r,frameBuffer:l,buffer:c,constantBuffer:S||{},uniformLocations:b,attributeLocations:m,isPicking:n==="pick",vertexShader:f,fragmentShader:p}}},{key:"bindProgram",value:function(n){var r=this,a=0,i=n.gl,l=n.buffer;this.isInstanced?(i.bindBuffer(i.ARRAY_BUFFER,n.constantBuffer),a=0,this.CONSTANT_ATTRIBUTES.forEach(function(u){return a+=r.bindAttribute(u,n,a,!1)}),i.bufferData(i.ARRAY_BUFFER,this.constantArray,i.STATIC_DRAW),i.bindBuffer(i.ARRAY_BUFFER,n.buffer),a=0,this.ATTRIBUTES.forEach(function(u){return a+=r.bindAttribute(u,n,a,!0)}),i.bufferData(i.ARRAY_BUFFER,this.array,i.DYNAMIC_DRAW)):(i.bindBuffer(i.ARRAY_BUFFER,l),a=0,this.ATTRIBUTES.forEach(function(u){return a+=r.bindAttribute(u,n,a)}),i.bufferData(i.ARRAY_BUFFER,this.array,i.DYNAMIC_DRAW)),i.bindBuffer(i.ARRAY_BUFFER,null)}},{key:"unbindProgram",value:function(n){var r=this;this.isInstanced?(this.CONSTANT_ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n,!1)}),this.ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n,!0)})):this.ATTRIBUTES.forEach(function(a){return r.unbindAttribute(a,n)})}},{key:"bindAttribute",value:function(n,r,a,i){var l=aX[n.type];if(typeof l!="number")throw new Error('Program.bind: yet unsupported attribute type "'.concat(n.type,'"'));var u=r.attributeLocations[n.name],c=r.gl;if(u!==-1){c.enableVertexAttribArray(u);var f=this.isInstanced?(i?this.ATTRIBUTES_ITEMS_COUNT:_h(this.CONSTANT_ATTRIBUTES))*Float32Array.BYTES_PER_ELEMENT:this.ATTRIBUTES_ITEMS_COUNT*Float32Array.BYTES_PER_ELEMENT;if(c.vertexAttribPointer(u,n.size,n.type,n.normalized||!1,f,a),this.isInstanced&&i)if(c instanceof WebGL2RenderingContext)c.vertexAttribDivisor(u,1);else{var p=c.getExtension("ANGLE_instanced_arrays");p&&p.vertexAttribDivisorANGLE(u,1)}}return n.size*l}},{key:"unbindAttribute",value:function(n,r,a){var i=r.attributeLocations[n.name],l=r.gl;if(i!==-1&&(l.disableVertexAttribArray(i),this.isInstanced&&a))if(l instanceof WebGL2RenderingContext)l.vertexAttribDivisor(i,0);else{var u=l.getExtension("ANGLE_instanced_arrays");u&&u.vertexAttribDivisorANGLE(i,0)}}},{key:"reallocate",value:function(n){n!==this.capacity&&(this.capacity=n,this.verticesCount=this.VERTICES*n,this.array=new Float32Array(this.isInstanced?this.capacity*this.ATTRIBUTES_ITEMS_COUNT:this.verticesCount*this.ATTRIBUTES_ITEMS_COUNT))}},{key:"hasNothingToRender",value:function(){return this.verticesCount===0}},{key:"renderProgram",value:function(n,r){var a=r.gl,i=r.program;a.enable(a.BLEND),a.useProgram(i),this.setUniforms(n,r),this.drawWebGL(this.METHOD,r)}},{key:"render",value:function(n){this.hasNothingToRender()||(this.pickProgram&&(this.pickProgram.gl.viewport(0,0,n.width*n.pixelRatio/n.downSizingRatio,n.height*n.pixelRatio/n.downSizingRatio),this.bindProgram(this.pickProgram),this.renderProgram(Be(Be({},n),{},{pixelRatio:n.pixelRatio/n.downSizingRatio}),this.pickProgram),this.unbindProgram(this.pickProgram)),this.normalProgram.gl.viewport(0,0,n.width*n.pixelRatio,n.height*n.pixelRatio),this.bindProgram(this.normalProgram),this.renderProgram(n,this.normalProgram),this.unbindProgram(this.normalProgram))}},{key:"drawWebGL",value:function(n,r){var a=r.gl,i=r.frameBuffer;if(a.bindFramebuffer(a.FRAMEBUFFER,i),!this.isInstanced)a.drawArrays(n,0,this.verticesCount);else if(a instanceof WebGL2RenderingContext)a.drawArraysInstanced(n,0,this.VERTICES,this.capacity);else{var l=a.getExtension("ANGLE_instanced_arrays");l&&l.drawArraysInstancedANGLE(n,0,this.VERTICES,this.capacity)}}}])}(),g0=function(e){function t(){return on(this,t),Bn(this,t,arguments)}return Un(t,e),ln(t,[{key:"kill",value:function(){HU(t,"kill",this)([])}},{key:"process",value:function(r,a,i){var l=a*this.STRIDE;if(i.hidden){for(var u=l+this.STRIDE;l<u;l++)this.array[l]=0;return}return this.processVisibleItem(GU(r),l,i)}}])}(qU),vu=function(e){function t(){var n;on(this,t);for(var r=arguments.length,a=new Array(r),i=0;i<r;i++)a[i]=arguments[i];return n=Bn(this,t,[].concat(a)),_e(n,"drawLabel",void 0),n}return Un(t,e),ln(t,[{key:"kill",value:function(){HU(t,"kill",this)([])}},{key:"process",value:function(r,a,i,l,u){var c=a*this.STRIDE;if(u.hidden||i.hidden||l.hidden){for(var f=c+this.STRIDE;c<f;c++)this.array[c]=0;return}return this.processVisibleItem(GU(r),c,i,l,u)}}])}(qU);function VU(e,t){return function(){function n(r,a,i){on(this,n),_e(this,"drawLabel",t),this.programs=e.map(function(l){return new l(r,a,i)})}return ln(n,[{key:"reallocate",value:function(a){this.programs.forEach(function(i){return i.reallocate(a)})}},{key:"process",value:function(a,i,l,u,c){this.programs.forEach(function(f){return f.process(a,i,l,u,c)})}},{key:"render",value:function(a){this.programs.forEach(function(i){return i.render(a)})}},{key:"kill",value:function(){this.programs.forEach(function(a){return a.kill()})}}])}()}function oX(e,t,n,r,a){var i=a.edgeLabelSize,l=a.edgeLabelFont,u=a.edgeLabelWeight,c=a.edgeLabelColor.attribute?t[a.edgeLabelColor.attribute]||a.edgeLabelColor.color||"#000":a.edgeLabelColor.color,f=t.label;if(f){e.fillStyle=c,e.font="".concat(u," ").concat(i,"px ").concat(l);var p=n.size,g=r.size,b=n.x,m=n.y,S=r.x,v=r.y,A=(b+S)/2,R=(m+v)/2,x=S-b,T=v-m,C=Math.sqrt(x*x+T*T);if(!(C<p+g)){b+=x*p/C,m+=T*p/C,S-=x*g/C,v-=T*g/C,A=(b+S)/2,R=(m+v)/2,x=S-b,T=v-m,C=Math.sqrt(x*x+T*T);var N=e.measureText(f).width;if(N>C){var _="…";for(f=f+_,N=e.measureText(f).width;N>C&&f.length>1;)f=f.slice(0,-2)+_,N=e.measureText(f).width;if(f.length<4)return}var O;x>0?T>0?O=Math.acos(x/C):O=Math.asin(T/C):T>0?O=Math.acos(x/C)+Math.PI:O=Math.asin(x/C)+Math.PI/2,e.save(),e.translate(A,R),e.rotate(O),e.fillText(f,-N/2,t.size/2+i),e.restore()}}}function WU(e,t,n){if(t.label){var r=n.labelSize,a=n.labelFont,i=n.labelWeight,l=n.labelColor.attribute?t[n.labelColor.attribute]||n.labelColor.color||"#000":n.labelColor.color;e.fillStyle=l,e.font="".concat(i," ").concat(r,"px ").concat(a),e.fillText(t.label,t.x+t.size+3,t.y+r/3)}}function iX(e,t,n){var r=n.labelSize,a=n.labelFont,i=n.labelWeight;e.font="".concat(i," ").concat(r,"px ").concat(a),e.fillStyle="#FFF",e.shadowOffsetX=0,e.shadowOffsetY=0,e.shadowBlur=8,e.shadowColor="#000";var l=2;if(typeof t.label=="string"){var u=e.measureText(t.label).width,c=Math.round(u+5),f=Math.round(r+2*l),p=Math.max(t.size,r/2)+l,g=Math.asin(f/2/p),b=Math.sqrt(Math.abs(Math.pow(p,2)-Math.pow(f/2,2)));e.beginPath(),e.moveTo(t.x+b,t.y+f/2),e.lineTo(t.x+p+c,t.y+f/2),e.lineTo(t.x+p+c,t.y-f/2),e.lineTo(t.x+b,t.y-f/2),e.arc(t.x,t.y,p,g,-g),e.closePath(),e.fill()}else e.beginPath(),e.arc(t.x,t.y,t.size+l,0,Math.PI*2),e.closePath(),e.fill();e.shadowOffsetX=0,e.shadowOffsetY=0,e.shadowBlur=0,WU(e,t,n)}var lX=`
precision highp float;

varying vec4 v_color;
varying vec2 v_diffVector;
varying float v_radius;

uniform float u_correctionRatio;

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float border = u_correctionRatio * 2.0;
  float dist = length(v_diffVector) - v_radius + border;

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > border)
    gl_FragColor = transparent;
  else
    gl_FragColor = v_color;

  #else
  float t = 0.0;
  if (dist > border)
    t = 1.0;
  else if (dist > 0.0)
    t = dist / border;

  gl_FragColor = mix(v_color, transparent, t);
  #endif
}
`,sX=lX,uX=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_position;
attribute float a_size;
attribute float a_angle;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;

varying vec4 v_color;
varying vec2 v_diffVector;
varying float v_radius;
varying float v_border;

const float bias = 255.0 / 254.0;

void main() {
  float size = a_size * u_correctionRatio / u_sizeRatio * 4.0;
  vec2 diffVector = size * vec2(cos(a_angle), sin(a_angle));
  vec2 position = a_position + diffVector;
  gl_Position = vec4(
    (u_matrix * vec3(position, 1)).xy,
    0,
    1
  );

  v_diffVector = diffVector;
  v_radius = size / 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,cX=uX,YU=WebGLRenderingContext,oC=YU.UNSIGNED_BYTE,Rh=YU.FLOAT,dX=["u_sizeRatio","u_correctionRatio","u_matrix"],Su=function(e){function t(){return on(this,t),Bn(this,t,arguments)}return Un(t,e),ln(t,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:cX,FRAGMENT_SHADER_SOURCE:sX,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:dX,ATTRIBUTES:[{name:"a_position",size:2,type:Rh},{name:"a_size",size:1,type:Rh},{name:"a_color",size:4,type:oC,normalized:!0},{name:"a_id",size:4,type:oC,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_angle",size:1,type:Rh}],CONSTANT_DATA:[[t.ANGLE_1],[t.ANGLE_2],[t.ANGLE_3]]}}},{key:"processVisibleItem",value:function(r,a,i){var l=this.array,u=Qr(i.color);l[a++]=i.x,l[a++]=i.y,l[a++]=i.size,l[a++]=u,l[a++]=r}},{key:"setUniforms",value:function(r,a){var i=a.gl,l=a.uniformLocations,u=l.u_sizeRatio,c=l.u_correctionRatio,f=l.u_matrix;i.uniform1f(c,r.correctionRatio),i.uniform1f(u,r.sizeRatio),i.uniformMatrix3fv(f,!1,r.matrix)}}])}(g0);_e(Su,"ANGLE_1",0);_e(Su,"ANGLE_2",2*Math.PI/3);_e(Su,"ANGLE_3",4*Math.PI/3);var fX=`
precision mediump float;

varying vec4 v_color;

void main(void) {
  gl_FragColor = v_color;
}
`,pX=fX,gX=`
attribute vec2 a_position;
attribute vec2 a_normal;
attribute float a_radius;
attribute vec3 a_barycentric;

#ifdef PICKING_MODE
attribute vec4 a_id;
#else
attribute vec4 a_color;
#endif

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_widenessToThicknessRatio;

varying vec4 v_color;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  float normalLength = length(a_normal);
  vec2 unitNormal = a_normal / normalLength;

  // These first computations are taken from edge.vert.glsl and
  // edge.clamped.vert.glsl. Please read it to get better comments on what's
  // happening:
  float pixelsThickness = max(normalLength / u_sizeRatio, minThickness);
  float webGLThickness = pixelsThickness * u_correctionRatio;
  float webGLNodeRadius = a_radius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  float webGLArrowHeadThickness = webGLThickness * u_widenessToThicknessRatio;

  float da = a_barycentric.x;
  float db = a_barycentric.y;
  float dc = a_barycentric.z;

  vec2 delta = vec2(
      da * (webGLNodeRadius * unitNormal.y)
    + db * ((webGLNodeRadius + webGLArrowHeadLength) * unitNormal.y + webGLArrowHeadThickness * unitNormal.x)
    + dc * ((webGLNodeRadius + webGLArrowHeadLength) * unitNormal.y - webGLArrowHeadThickness * unitNormal.x),

      da * (-webGLNodeRadius * unitNormal.x)
    + db * (-(webGLNodeRadius + webGLArrowHeadLength) * unitNormal.x + webGLArrowHeadThickness * unitNormal.y)
    + dc * (-(webGLNodeRadius + webGLArrowHeadLength) * unitNormal.x - webGLArrowHeadThickness * unitNormal.y)
  );

  vec2 position = (u_matrix * vec3(a_position + delta, 1)).xy;

  gl_Position = vec4(position, 0, 1);

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,hX=gX,KU=WebGLRenderingContext,iC=KU.UNSIGNED_BYTE,Kc=KU.FLOAT,mX=["u_matrix","u_sizeRatio","u_correctionRatio","u_minEdgeThickness","u_lengthToThicknessRatio","u_widenessToThicknessRatio"],Eu={extremity:"target",lengthToThicknessRatio:2.5,widenessToThicknessRatio:2};function Pd(e){var t=Be(Be({},Eu),e||{});return function(n){function r(){return on(this,r),Bn(this,r,arguments)}return Un(r,n),ln(r,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:hX,FRAGMENT_SHADER_SOURCE:pX,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:mX,ATTRIBUTES:[{name:"a_position",size:2,type:Kc},{name:"a_normal",size:2,type:Kc},{name:"a_radius",size:1,type:Kc},{name:"a_color",size:4,type:iC,normalized:!0},{name:"a_id",size:4,type:iC,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_barycentric",size:3,type:Kc}],CONSTANT_DATA:[[1,0,0],[0,1,0],[0,0,1]]}}},{key:"processVisibleItem",value:function(i,l,u,c,f){if(t.extremity==="source"){var p=[c,u];u=p[0],c=p[1]}var g=f.size||1,b=c.size||1,m=u.x,S=u.y,v=c.x,A=c.y,R=Qr(f.color),x=v-m,T=A-S,C=x*x+T*T,N=0,_=0;C&&(C=1/Math.sqrt(C),N=-T*C*g,_=x*C*g);var O=this.array;O[l++]=v,O[l++]=A,O[l++]=-N,O[l++]=-_,O[l++]=b,O[l++]=R,O[l++]=i}},{key:"setUniforms",value:function(i,l){var u=l.gl,c=l.uniformLocations,f=c.u_matrix,p=c.u_sizeRatio,g=c.u_correctionRatio,b=c.u_minEdgeThickness,m=c.u_lengthToThicknessRatio,S=c.u_widenessToThicknessRatio;u.uniformMatrix3fv(f,!1,i.matrix),u.uniform1f(p,i.sizeRatio),u.uniform1f(g,i.correctionRatio),u.uniform1f(b,i.minEdgeThickness),u.uniform1f(m,t.lengthToThicknessRatio),u.uniform1f(S,t.widenessToThicknessRatio)}}])}(vu)}Pd();var bX=`
precision mediump float;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  // We only handle antialiasing for normal mode:
  #ifdef PICKING_MODE
  gl_FragColor = v_color;
  #else
  float dist = length(v_normal) * v_thickness;

  float t = smoothstep(
    v_thickness - v_feather,
    v_thickness,
    dist
  );

  gl_FragColor = mix(v_color, transparent, t);
  #endif
}
`,h0=bX,yX=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;
attribute float a_radius;
attribute float a_radiusCoef;

uniform mat3 u_matrix;
uniform float u_zoomRatio;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  float radius = a_radius * a_radiusCoef;
  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // These first computations are taken from edge.vert.glsl. Please read it to
  // get better comments on what's happening:
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here, we move the point to leave space for the arrow head:
  float direction = sign(radius);
  float webGLNodeRadius = direction * radius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;

  vec2 compensationVector = vec2(-direction * unitNormal.y, direction * unitNormal.x) * (webGLNodeRadius + webGLArrowHeadLength);

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness + compensationVector, 1)).xy, 0, 1);

  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,vX=yX,XU=WebGLRenderingContext,lC=XU.UNSIGNED_BYTE,Ko=XU.FLOAT,SX=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness","u_lengthToThicknessRatio"],EX={lengthToThicknessRatio:Eu.lengthToThicknessRatio};function ZU(e){var t=Be(Be({},EX),{});return function(n){function r(){return on(this,r),Bn(this,r,arguments)}return Un(r,n),ln(r,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:vX,FRAGMENT_SHADER_SOURCE:h0,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:SX,ATTRIBUTES:[{name:"a_positionStart",size:2,type:Ko},{name:"a_positionEnd",size:2,type:Ko},{name:"a_normal",size:2,type:Ko},{name:"a_color",size:4,type:lC,normalized:!0},{name:"a_id",size:4,type:lC,normalized:!0},{name:"a_radius",size:1,type:Ko}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:Ko},{name:"a_normalCoef",size:1,type:Ko},{name:"a_radiusCoef",size:1,type:Ko}],CONSTANT_DATA:[[0,1,0],[0,-1,0],[1,1,1],[1,1,1],[0,-1,0],[1,-1,-1]]}}},{key:"processVisibleItem",value:function(i,l,u,c,f){var p=f.size||1,g=u.x,b=u.y,m=c.x,S=c.y,v=Qr(f.color),A=m-g,R=S-b,x=c.size||1,T=A*A+R*R,C=0,N=0;T&&(T=1/Math.sqrt(T),C=-R*T*p,N=A*T*p);var _=this.array;_[l++]=g,_[l++]=b,_[l++]=m,_[l++]=S,_[l++]=C,_[l++]=N,_[l++]=v,_[l++]=i,_[l++]=x}},{key:"setUniforms",value:function(i,l){var u=l.gl,c=l.uniformLocations,f=c.u_matrix,p=c.u_zoomRatio,g=c.u_feather,b=c.u_pixelRatio,m=c.u_correctionRatio,S=c.u_sizeRatio,v=c.u_minEdgeThickness,A=c.u_lengthToThicknessRatio;u.uniformMatrix3fv(f,!1,i.matrix),u.uniform1f(p,i.zoomRatio),u.uniform1f(S,i.sizeRatio),u.uniform1f(m,i.correctionRatio),u.uniform1f(b,i.pixelRatio),u.uniform1f(g,i.antiAliasingFeather),u.uniform1f(v,i.minEdgeThickness),u.uniform1f(A,t.lengthToThicknessRatio)}}])}(vu)}ZU();function wX(e){return VU([ZU(),Pd(e)])}var xX=wX(),QU=xX,kX=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_zoomRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // We require edges to be at least "minThickness" pixels thick *on screen*
  // (so we need to compensate the size ratio):
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);

  // Then, we need to retrieve the normalized thickness of the edge in the WebGL
  // referential (in a ([0, 1], [0, 1]) space), using our "magic" correction
  // ratio:
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness, 1)).xy, 0, 1);

  // For the fragment shader though, we need a thickness that takes the "magic"
  // correction ratio into account (as in webGLThickness), but so that the
  // antialiasing effect does not depend on the zoom level. So here's yet
  // another thickness version:
  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,AX=kX,JU=WebGLRenderingContext,sC=JU.UNSIGNED_BYTE,Ps=JU.FLOAT,TX=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness"],_X=function(e){function t(){return on(this,t),Bn(this,t,arguments)}return Un(t,e),ln(t,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:AX,FRAGMENT_SHADER_SOURCE:h0,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:TX,ATTRIBUTES:[{name:"a_positionStart",size:2,type:Ps},{name:"a_positionEnd",size:2,type:Ps},{name:"a_normal",size:2,type:Ps},{name:"a_color",size:4,type:sC,normalized:!0},{name:"a_id",size:4,type:sC,normalized:!0}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:Ps},{name:"a_normalCoef",size:1,type:Ps}],CONSTANT_DATA:[[0,1],[0,-1],[1,1],[1,1],[0,-1],[1,-1]]}}},{key:"processVisibleItem",value:function(r,a,i,l,u){var c=u.size||1,f=i.x,p=i.y,g=l.x,b=l.y,m=Qr(u.color),S=g-f,v=b-p,A=S*S+v*v,R=0,x=0;A&&(A=1/Math.sqrt(A),R=-v*A*c,x=S*A*c);var T=this.array;T[a++]=f,T[a++]=p,T[a++]=g,T[a++]=b,T[a++]=R,T[a++]=x,T[a++]=m,T[a++]=r}},{key:"setUniforms",value:function(r,a){var i=a.gl,l=a.uniformLocations,u=l.u_matrix,c=l.u_zoomRatio,f=l.u_feather,p=l.u_pixelRatio,g=l.u_correctionRatio,b=l.u_sizeRatio,m=l.u_minEdgeThickness;i.uniformMatrix3fv(u,!1,r.matrix),i.uniform1f(c,r.zoomRatio),i.uniform1f(b,r.sizeRatio),i.uniform1f(g,r.correctionRatio),i.uniform1f(p,r.pixelRatio),i.uniform1f(f,r.antiAliasingFeather),i.uniform1f(m,r.minEdgeThickness)}}])}(vu),m0=function(e){function t(){var n;return on(this,t),n=Bn(this,t),n.rawEmitter=n,n}return Un(t,e),ln(t)}(xU.EventEmitter),Ch,uC;function Jr(){return uC||(uC=1,Ch=function(t){return t!==null&&typeof t=="object"&&typeof t.addUndirectedEdgeWithKey=="function"&&typeof t.dropNode=="function"&&typeof t.multi=="boolean"}),Ch}var RX=Jr();const CX=an(RX);var NX=function(t){return t},OX=function(t){return t*t},DX=function(t){return t*(2-t)},IX=function(t){return(t*=2)<1?.5*t*t:-.5*(--t*(t-2)-1)},LX=function(t){return t*t*t},MX=function(t){return--t*t*t+1},FX=function(t){return(t*=2)<1?.5*t*t*t:.5*((t-=2)*t*t+2)},e3={linear:NX,quadraticIn:OX,quadraticOut:DX,quadraticInOut:IX,cubicIn:LX,cubicOut:MX,cubicInOut:FX},t3={easing:"quadraticInOut",duration:150};function zX(e,t,n,r){var a=Object.assign({},t3,n),i=typeof a.easing=="function"?a.easing:e3[a.easing],l=Date.now(),u={};for(var c in t){var f=t[c];u[c]={};for(var p in f)u[c][p]=e.getNodeAttribute(c,p)}var g=null,b=function(){g=null;var S=(Date.now()-l)/a.duration;if(S>=1){for(var v in t){var A=t[v];for(var R in A)e.setNodeAttribute(v,R,A[R])}return}S=i(S);for(var x in t){var T=t[x],C=u[x];for(var N in T)e.setNodeAttribute(x,N,T[N]*S+C[N]*(1-S))}g=requestAnimationFrame(b)};return b(),function(){g&&cancelAnimationFrame(g)}}function _r(){return Float32Array.of(1,0,0,0,1,0,0,0,1)}function Xc(e,t,n){return e[0]=t,e[4]=typeof n=="number"?n:t,e}function cC(e,t){var n=Math.sin(t),r=Math.cos(t);return e[0]=r,e[1]=n,e[3]=-n,e[4]=r,e}function dC(e,t,n){return e[6]=t,e[7]=n,e}function io(e,t){var n=e[0],r=e[1],a=e[2],i=e[3],l=e[4],u=e[5],c=e[6],f=e[7],p=e[8],g=t[0],b=t[1],m=t[2],S=t[3],v=t[4],A=t[5],R=t[6],x=t[7],T=t[8];return e[0]=g*n+b*i+m*c,e[1]=g*r+b*l+m*f,e[2]=g*a+b*u+m*p,e[3]=S*n+v*i+A*c,e[4]=S*r+v*l+A*f,e[5]=S*a+v*u+A*p,e[6]=R*n+x*i+T*c,e[7]=R*r+x*l+T*f,e[8]=R*a+x*u+T*p,e}function Fx(e,t){var n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:1,r=e[0],a=e[1],i=e[3],l=e[4],u=e[6],c=e[7],f=t.x,p=t.y;return{x:f*r+p*i+u*n,y:f*a+p*l+c*n}}function PX(e,t){var n=e.height/e.width,r=t.height/t.width;return n<1&&r>1||n>1&&r<1?1:Math.min(Math.max(r,1/r),Math.max(1/n,n))}function Bs(e,t,n,r,a){var i=e.angle,l=e.ratio,u=e.x,c=e.y,f=t.width,p=t.height,g=_r(),b=Math.min(f,p)-2*r,m=PX(t,n);return a?(io(g,dC(_r(),u,c)),io(g,Xc(_r(),l)),io(g,cC(_r(),i)),io(g,Xc(_r(),f/b/2/m,p/b/2/m))):(io(g,Xc(_r(),2*(b/f)*m,2*(b/p)*m)),io(g,cC(_r(),-i)),io(g,Xc(_r(),1/l)),io(g,dC(_r(),-u,-c))),g}function BX(e,t,n){var r=Fx(e,{x:Math.cos(t.angle),y:Math.sin(t.angle)},0),a=r.x,i=r.y;return 1/Math.sqrt(Math.pow(a,2)+Math.pow(i,2))/n.width}function UX(e){if(!e.order)return{x:[0,1],y:[0,1]};var t=1/0,n=-1/0,r=1/0,a=-1/0;return e.forEachNode(function(i,l){var u=l.x,c=l.y;u<t&&(t=u),u>n&&(n=u),c<r&&(r=c),c>a&&(a=c)}),{x:[t,n],y:[r,a]}}function jX(e){if(!CX(e))throw new Error("Sigma: invalid graph instance.");e.forEachNode(function(t,n){if(!Number.isFinite(n.x)||!Number.isFinite(n.y))throw new Error("Sigma: Coordinates of node ".concat(t," are invalid. A node must have a numeric 'x' and 'y' attribute."))})}function GX(e,t,n){var r=document.createElement(e);if(t)for(var a in t)r.style[a]=t[a];if(n)for(var i in n)r.setAttribute(i,n[i]);return r}function fC(){return typeof window.devicePixelRatio<"u"?window.devicePixelRatio:1}function pC(e,t,n){return n.sort(function(r,a){var i=t(r)||0,l=t(a)||0;return i<l?-1:i>l?1:0})}function gC(e){var t=Sl(e.x,2),n=t[0],r=t[1],a=Sl(e.y,2),i=a[0],l=a[1],u=Math.max(r-n,l-i),c=(r+n)/2,f=(l+i)/2;(u===0||Math.abs(u)===1/0||isNaN(u))&&(u=1),isNaN(c)&&(c=0),isNaN(f)&&(f=0);var p=function(b){return{x:.5+(b.x-c)/u,y:.5+(b.y-f)/u}};return p.applyTo=function(g){g.x=.5+(g.x-c)/u,g.y=.5+(g.y-f)/u},p.inverse=function(g){return{x:c+u*(g.x-.5),y:f+u*(g.y-.5)}},p.ratio=u,p}function zx(e){"@babel/helpers - typeof";return zx=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},zx(e)}function hC(e,t){var n=t.size;if(n!==0){var r=e.length;e.length+=n;var a=0;t.forEach(function(i){e[r+a]=i,a++})}}function Nh(e){e=e||{};for(var t=0,n=arguments.length<=1?0:arguments.length-1;t<n;t++){var r=t+1<1||arguments.length<=t+1?void 0:arguments[t+1];r&&Object.assign(e,r)}return e}var b0={hideEdgesOnMove:!1,hideLabelsOnMove:!1,renderLabels:!0,renderEdgeLabels:!1,enableEdgeEvents:!1,defaultNodeColor:"#999",defaultNodeType:"circle",defaultEdgeColor:"#ccc",defaultEdgeType:"line",labelFont:"Arial",labelSize:14,labelWeight:"normal",labelColor:{color:"#000"},edgeLabelFont:"Arial",edgeLabelSize:14,edgeLabelWeight:"normal",edgeLabelColor:{attribute:"color"},stagePadding:30,defaultDrawEdgeLabel:oX,defaultDrawNodeLabel:WU,defaultDrawNodeHover:iX,minEdgeThickness:1.7,antiAliasingFeather:1,dragTimeout:100,draggedEventsTolerance:3,inertiaDuration:200,inertiaRatio:3,zoomDuration:250,zoomingRatio:1.7,doubleClickTimeout:300,doubleClickZoomingRatio:2.2,doubleClickZoomingDuration:200,tapMoveTolerance:10,zoomToSizeRatioFunction:Math.sqrt,itemSizesReference:"screen",autoRescale:!0,autoCenter:!0,labelDensity:1,labelGridCellSize:100,labelRenderedSizeThreshold:6,nodeReducer:null,edgeReducer:null,zIndex:!1,minCameraRatio:null,maxCameraRatio:null,enableCameraZooming:!0,enableCameraPanning:!0,enableCameraRotation:!0,cameraPanBoundaries:null,allowInvalidContainer:!1,nodeProgramClasses:{},nodeHoverProgramClasses:{},edgeProgramClasses:{}},HX={circle:Su},$X={arrow:QU,line:_X};function Oh(e){if(typeof e.labelDensity!="number"||e.labelDensity<0)throw new Error("Settings: invalid `labelDensity`. Expecting a positive number.");var t=e.minCameraRatio,n=e.maxCameraRatio;if(typeof t=="number"&&typeof n=="number"&&n<t)throw new Error("Settings: invalid camera ratio boundaries. Expecting `maxCameraRatio` to be greater than `minCameraRatio`.")}function qX(e){var t=Nh({},b0,e);return t.nodeProgramClasses=Nh({},HX,t.nodeProgramClasses),t.edgeProgramClasses=Nh({},$X,t.edgeProgramClasses),t}var Zc=1.5,mC=function(e){function t(){var n;return on(this,t),n=Bn(this,t),_e(n,"x",.5),_e(n,"y",.5),_e(n,"angle",0),_e(n,"ratio",1),_e(n,"minRatio",null),_e(n,"maxRatio",null),_e(n,"enabledZooming",!0),_e(n,"enabledPanning",!0),_e(n,"enabledRotation",!0),_e(n,"clean",null),_e(n,"nextFrame",null),_e(n,"previousState",null),_e(n,"enabled",!0),n.previousState=n.getState(),n}return Un(t,e),ln(t,[{key:"enable",value:function(){return this.enabled=!0,this}},{key:"disable",value:function(){return this.enabled=!1,this}},{key:"getState",value:function(){return{x:this.x,y:this.y,angle:this.angle,ratio:this.ratio}}},{key:"hasState",value:function(r){return this.x===r.x&&this.y===r.y&&this.ratio===r.ratio&&this.angle===r.angle}},{key:"getPreviousState",value:function(){var r=this.previousState;return r?{x:r.x,y:r.y,angle:r.angle,ratio:r.ratio}:null}},{key:"getBoundedRatio",value:function(r){var a=r;return typeof this.minRatio=="number"&&(a=Math.max(a,this.minRatio)),typeof this.maxRatio=="number"&&(a=Math.min(a,this.maxRatio)),a}},{key:"validateState",value:function(r){var a={};return this.enabledPanning&&typeof r.x=="number"&&(a.x=r.x),this.enabledPanning&&typeof r.y=="number"&&(a.y=r.y),this.enabledZooming&&typeof r.ratio=="number"&&(a.ratio=this.getBoundedRatio(r.ratio)),this.enabledRotation&&typeof r.angle=="number"&&(a.angle=r.angle),this.clean?this.clean(Be(Be({},this.getState()),a)):a}},{key:"isAnimated",value:function(){return!!this.nextFrame}},{key:"setState",value:function(r){if(!this.enabled)return this;this.previousState=this.getState();var a=this.validateState(r);return typeof a.x=="number"&&(this.x=a.x),typeof a.y=="number"&&(this.y=a.y),typeof a.ratio=="number"&&(this.ratio=a.ratio),typeof a.angle=="number"&&(this.angle=a.angle),this.hasState(this.previousState)||this.emit("updated",this.getState()),this}},{key:"updateState",value:function(r){return this.setState(r(this.getState())),this}},{key:"animate",value:function(r){var a=this,i=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},l=arguments.length>2?arguments[2]:void 0;if(!l)return new Promise(function(m){return a.animate(r,i,m)});if(this.enabled){var u=Be(Be({},t3),i),c=this.validateState(r),f=typeof u.easing=="function"?u.easing:e3[u.easing],p=Date.now(),g=this.getState(),b=function(){var S=(Date.now()-p)/u.duration;if(S>=1){a.nextFrame=null,a.setState(c),a.animationCallback&&(a.animationCallback.call(null),a.animationCallback=void 0);return}var v=f(S),A={};typeof c.x=="number"&&(A.x=g.x+(c.x-g.x)*v),typeof c.y=="number"&&(A.y=g.y+(c.y-g.y)*v),a.enabledRotation&&typeof c.angle=="number"&&(A.angle=g.angle+(c.angle-g.angle)*v),typeof c.ratio=="number"&&(A.ratio=g.ratio+(c.ratio-g.ratio)*v),a.setState(A),a.nextFrame=requestAnimationFrame(b)};this.nextFrame?(cancelAnimationFrame(this.nextFrame),this.animationCallback&&this.animationCallback.call(null),this.nextFrame=requestAnimationFrame(b)):b(),this.animationCallback=l}}},{key:"animatedZoom",value:function(r){return r?typeof r=="number"?this.animate({ratio:this.ratio/r}):this.animate({ratio:this.ratio/(r.factor||Zc)},r):this.animate({ratio:this.ratio/Zc})}},{key:"animatedUnzoom",value:function(r){return r?typeof r=="number"?this.animate({ratio:this.ratio*r}):this.animate({ratio:this.ratio*(r.factor||Zc)},r):this.animate({ratio:this.ratio*Zc})}},{key:"animatedReset",value:function(r){return this.animate({x:.5,y:.5,ratio:1,angle:0},r)}},{key:"copy",value:function(){return t.from(this.getState())}}],[{key:"from",value:function(r){var a=new t;return a.setState(r)}}])}(m0);function Cr(e,t){var n=t.getBoundingClientRect();return{x:e.clientX-n.left,y:e.clientY-n.top}}function Aa(e,t){var n=Be(Be({},Cr(e,t)),{},{sigmaDefaultPrevented:!1,preventSigmaDefault:function(){n.sigmaDefaultPrevented=!0},original:e});return n}function Us(e){var t="x"in e?e:Be(Be({},e.touches[0]||e.previousTouches[0]),{},{original:e.original,sigmaDefaultPrevented:e.sigmaDefaultPrevented,preventSigmaDefault:function(){e.sigmaDefaultPrevented=!0,t.sigmaDefaultPrevented=!0}});return t}function VX(e,t){return Be(Be({},Aa(e,t)),{},{delta:n3(e)})}var WX=2;function vd(e){for(var t=[],n=0,r=Math.min(e.length,WX);n<r;n++)t.push(e[n]);return t}function js(e,t,n){var r={touches:vd(e.touches).map(function(a){return Cr(a,n)}),previousTouches:t.map(function(a){return Cr(a,n)}),sigmaDefaultPrevented:!1,preventSigmaDefault:function(){r.sigmaDefaultPrevented=!0},original:e};return r}function n3(e){if(typeof e.deltaY<"u")return e.deltaY*-3/360;if(typeof e.detail<"u")return e.detail/-9;throw new Error("Captor: could not extract delta from event.")}var r3=function(e){function t(n,r){var a;return on(this,t),a=Bn(this,t),a.container=n,a.renderer=r,a}return Un(t,e),ln(t)}(m0),YX=["doubleClickTimeout","doubleClickZoomingDuration","doubleClickZoomingRatio","dragTimeout","draggedEventsTolerance","inertiaDuration","inertiaRatio","zoomDuration","zoomingRatio"],KX=YX.reduce(function(e,t){return Be(Be({},e),{},_e({},t,b0[t]))},{}),XX=function(e){function t(n,r){var a;return on(this,t),a=Bn(this,t,[n,r]),_e(a,"enabled",!0),_e(a,"draggedEvents",0),_e(a,"downStartTime",null),_e(a,"lastMouseX",null),_e(a,"lastMouseY",null),_e(a,"isMouseDown",!1),_e(a,"isMoving",!1),_e(a,"movingTimeout",null),_e(a,"startCameraState",null),_e(a,"clicks",0),_e(a,"doubleClickTimeout",null),_e(a,"currentWheelDirection",0),_e(a,"settings",KX),a.handleClick=a.handleClick.bind(a),a.handleRightClick=a.handleRightClick.bind(a),a.handleDown=a.handleDown.bind(a),a.handleUp=a.handleUp.bind(a),a.handleMove=a.handleMove.bind(a),a.handleWheel=a.handleWheel.bind(a),a.handleLeave=a.handleLeave.bind(a),a.handleEnter=a.handleEnter.bind(a),n.addEventListener("click",a.handleClick,{capture:!1}),n.addEventListener("contextmenu",a.handleRightClick,{capture:!1}),n.addEventListener("mousedown",a.handleDown,{capture:!1}),n.addEventListener("wheel",a.handleWheel,{capture:!1}),n.addEventListener("mouseleave",a.handleLeave,{capture:!1}),n.addEventListener("mouseenter",a.handleEnter,{capture:!1}),document.addEventListener("mousemove",a.handleMove,{capture:!1}),document.addEventListener("mouseup",a.handleUp,{capture:!1}),a}return Un(t,e),ln(t,[{key:"kill",value:function(){var r=this.container;r.removeEventListener("click",this.handleClick),r.removeEventListener("contextmenu",this.handleRightClick),r.removeEventListener("mousedown",this.handleDown),r.removeEventListener("wheel",this.handleWheel),r.removeEventListener("mouseleave",this.handleLeave),r.removeEventListener("mouseenter",this.handleEnter),document.removeEventListener("mousemove",this.handleMove),document.removeEventListener("mouseup",this.handleUp)}},{key:"handleClick",value:function(r){var a=this;if(this.enabled){if(this.clicks++,this.clicks===2)return this.clicks=0,typeof this.doubleClickTimeout=="number"&&(clearTimeout(this.doubleClickTimeout),this.doubleClickTimeout=null),this.handleDoubleClick(r);setTimeout(function(){a.clicks=0,a.doubleClickTimeout=null},this.settings.doubleClickTimeout),this.draggedEvents<this.settings.draggedEventsTolerance&&this.emit("click",Aa(r,this.container))}}},{key:"handleRightClick",value:function(r){this.enabled&&this.emit("rightClick",Aa(r,this.container))}},{key:"handleDoubleClick",value:function(r){if(this.enabled){r.preventDefault(),r.stopPropagation();var a=Aa(r,this.container);if(this.emit("doubleClick",a),!a.sigmaDefaultPrevented){var i=this.renderer.getCamera(),l=i.getBoundedRatio(i.getState().ratio/this.settings.doubleClickZoomingRatio);i.animate(this.renderer.getViewportZoomedState(Cr(r,this.container),l),{easing:"quadraticInOut",duration:this.settings.doubleClickZoomingDuration})}}}},{key:"handleDown",value:function(r){if(this.enabled){if(r.button===0){this.startCameraState=this.renderer.getCamera().getState();var a=Cr(r,this.container),i=a.x,l=a.y;this.lastMouseX=i,this.lastMouseY=l,this.draggedEvents=0,this.downStartTime=Date.now(),this.isMouseDown=!0}this.emit("mousedown",Aa(r,this.container))}}},{key:"handleUp",value:function(r){var a=this;if(!(!this.enabled||!this.isMouseDown)){var i=this.renderer.getCamera();this.isMouseDown=!1,typeof this.movingTimeout=="number"&&(clearTimeout(this.movingTimeout),this.movingTimeout=null);var l=Cr(r,this.container),u=l.x,c=l.y,f=i.getState(),p=i.getPreviousState()||{x:0,y:0};this.isMoving?i.animate({x:f.x+this.settings.inertiaRatio*(f.x-p.x),y:f.y+this.settings.inertiaRatio*(f.y-p.y)},{duration:this.settings.inertiaDuration,easing:"quadraticOut"}):(this.lastMouseX!==u||this.lastMouseY!==c)&&i.setState({x:f.x,y:f.y}),this.isMoving=!1,setTimeout(function(){var g=a.draggedEvents>0;a.draggedEvents=0,g&&a.renderer.getSetting("hideEdgesOnMove")&&a.renderer.refresh()},0),this.emit("mouseup",Aa(r,this.container))}}},{key:"handleMove",value:function(r){var a=this;if(this.enabled){var i=Aa(r,this.container);if(this.emit("mousemovebody",i),(r.target===this.container||r.composedPath()[0]===this.container)&&this.emit("mousemove",i),!i.sigmaDefaultPrevented&&this.isMouseDown){this.isMoving=!0,this.draggedEvents++,typeof this.movingTimeout=="number"&&clearTimeout(this.movingTimeout),this.movingTimeout=window.setTimeout(function(){a.movingTimeout=null,a.isMoving=!1},this.settings.dragTimeout);var l=this.renderer.getCamera(),u=Cr(r,this.container),c=u.x,f=u.y,p=this.renderer.viewportToFramedGraph({x:this.lastMouseX,y:this.lastMouseY}),g=this.renderer.viewportToFramedGraph({x:c,y:f}),b=p.x-g.x,m=p.y-g.y,S=l.getState(),v=S.x+b,A=S.y+m;l.setState({x:v,y:A}),this.lastMouseX=c,this.lastMouseY=f,r.preventDefault(),r.stopPropagation()}}}},{key:"handleLeave",value:function(r){this.emit("mouseleave",Aa(r,this.container))}},{key:"handleEnter",value:function(r){this.emit("mouseenter",Aa(r,this.container))}},{key:"handleWheel",value:function(r){var a=this,i=this.renderer.getCamera();if(!(!this.enabled||!i.enabledZooming)){var l=n3(r);if(l){var u=VX(r,this.container);if(this.emit("wheel",u),u.sigmaDefaultPrevented){r.preventDefault(),r.stopPropagation();return}var c=i.getState().ratio,f=l>0?1/this.settings.zoomingRatio:this.settings.zoomingRatio,p=i.getBoundedRatio(c*f),g=l>0?1:-1,b=Date.now();c!==p&&(r.preventDefault(),r.stopPropagation(),!(this.currentWheelDirection===g&&this.lastWheelTriggerTime&&b-this.lastWheelTriggerTime<this.settings.zoomDuration/5)&&(i.animate(this.renderer.getViewportZoomedState(Cr(r,this.container),p),{easing:"quadraticOut",duration:this.settings.zoomDuration},function(){a.currentWheelDirection=0}),this.currentWheelDirection=g,this.lastWheelTriggerTime=b))}}}},{key:"setSettings",value:function(r){this.settings=r}}])}(r3),ZX=["dragTimeout","inertiaDuration","inertiaRatio","doubleClickTimeout","doubleClickZoomingRatio","doubleClickZoomingDuration","tapMoveTolerance"],QX=ZX.reduce(function(e,t){return Be(Be({},e),{},_e({},t,b0[t]))},{}),JX=function(e){function t(n,r){var a;return on(this,t),a=Bn(this,t,[n,r]),_e(a,"enabled",!0),_e(a,"isMoving",!1),_e(a,"hasMoved",!1),_e(a,"touchMode",0),_e(a,"startTouchesPositions",[]),_e(a,"lastTouches",[]),_e(a,"lastTap",null),_e(a,"settings",QX),a.handleStart=a.handleStart.bind(a),a.handleLeave=a.handleLeave.bind(a),a.handleMove=a.handleMove.bind(a),n.addEventListener("touchstart",a.handleStart,{capture:!1}),n.addEventListener("touchcancel",a.handleLeave,{capture:!1}),document.addEventListener("touchend",a.handleLeave,{capture:!1,passive:!1}),document.addEventListener("touchmove",a.handleMove,{capture:!1,passive:!1}),a}return Un(t,e),ln(t,[{key:"kill",value:function(){var r=this.container;r.removeEventListener("touchstart",this.handleStart),r.removeEventListener("touchcancel",this.handleLeave),document.removeEventListener("touchend",this.handleLeave),document.removeEventListener("touchmove",this.handleMove)}},{key:"getDimensions",value:function(){return{width:this.container.offsetWidth,height:this.container.offsetHeight}}},{key:"handleStart",value:function(r){var a=this;if(this.enabled){r.preventDefault();var i=vd(r.touches);if(this.touchMode=i.length,this.startCameraState=this.renderer.getCamera().getState(),this.startTouchesPositions=i.map(function(m){return Cr(m,a.container)}),this.touchMode===2){var l=Sl(this.startTouchesPositions,2),u=l[0],c=u.x,f=u.y,p=l[1],g=p.x,b=p.y;this.startTouchesAngle=Math.atan2(b-f,g-c),this.startTouchesDistance=Math.sqrt(Math.pow(g-c,2)+Math.pow(b-f,2))}this.emit("touchdown",js(r,this.lastTouches,this.container)),this.lastTouches=i,this.lastTouchesPositions=this.startTouchesPositions}}},{key:"handleLeave",value:function(r){if(!(!this.enabled||!this.startTouchesPositions.length)){switch(r.cancelable&&r.preventDefault(),this.movingTimeout&&(this.isMoving=!1,clearTimeout(this.movingTimeout)),this.touchMode){case 2:if(r.touches.length===1){this.handleStart(r),r.preventDefault();break}case 1:if(this.isMoving){var a=this.renderer.getCamera(),i=a.getState(),l=a.getPreviousState()||{x:0,y:0};a.animate({x:i.x+this.settings.inertiaRatio*(i.x-l.x),y:i.y+this.settings.inertiaRatio*(i.y-l.y)},{duration:this.settings.inertiaDuration,easing:"quadraticOut"})}this.hasMoved=!1,this.isMoving=!1,this.touchMode=0;break}if(this.emit("touchup",js(r,this.lastTouches,this.container)),!r.touches.length){var u=Cr(this.lastTouches[0],this.container),c=this.startTouchesPositions[0],f=Math.pow(u.x-c.x,2)+Math.pow(u.y-c.y,2);if(!r.touches.length&&f<Math.pow(this.settings.tapMoveTolerance,2))if(this.lastTap&&Date.now()-this.lastTap.time<this.settings.doubleClickTimeout){var p=js(r,this.lastTouches,this.container);if(this.emit("doubletap",p),this.lastTap=null,!p.sigmaDefaultPrevented){var g=this.renderer.getCamera(),b=g.getBoundedRatio(g.getState().ratio/this.settings.doubleClickZoomingRatio);g.animate(this.renderer.getViewportZoomedState(u,b),{easing:"quadraticInOut",duration:this.settings.doubleClickZoomingDuration})}}else{var m=js(r,this.lastTouches,this.container);this.emit("tap",m),this.lastTap={time:Date.now(),position:m.touches[0]||m.previousTouches[0]}}}this.lastTouches=vd(r.touches),this.startTouchesPositions=[]}}},{key:"handleMove",value:function(r){var a=this;if(!(!this.enabled||!this.startTouchesPositions.length)){r.preventDefault();var i=vd(r.touches),l=i.map(function(V){return Cr(V,a.container)}),u=this.lastTouches;this.lastTouches=i,this.lastTouchesPositions=l;var c=js(r,u,this.container);if(this.emit("touchmove",c),!c.sigmaDefaultPrevented&&(this.hasMoved||(this.hasMoved=l.some(function(V,U){var L=a.startTouchesPositions[U];return L&&(V.x!==L.x||V.y!==L.y)})),!!this.hasMoved)){this.isMoving=!0,this.movingTimeout&&clearTimeout(this.movingTimeout),this.movingTimeout=window.setTimeout(function(){a.isMoving=!1},this.settings.dragTimeout);var f=this.renderer.getCamera(),p=this.startCameraState,g=this.renderer.getSetting("stagePadding");switch(this.touchMode){case 1:{var b=this.renderer.viewportToFramedGraph((this.startTouchesPositions||[])[0]),m=b.x,S=b.y,v=this.renderer.viewportToFramedGraph(l[0]),A=v.x,R=v.y;f.setState({x:p.x+m-A,y:p.y+S-R});break}case 2:{var x={x:.5,y:.5,angle:0,ratio:1},T=l[0],C=T.x,N=T.y,_=l[1],O=_.x,z=_.y,I=Math.atan2(z-N,O-C)-this.startTouchesAngle,M=Math.hypot(z-N,O-C)/this.startTouchesDistance,H=f.getBoundedRatio(p.ratio/M);x.ratio=H,x.angle=p.angle+I;var q=this.getDimensions(),P=this.renderer.viewportToFramedGraph((this.startTouchesPositions||[])[0],{cameraState:p}),W=Math.min(q.width,q.height)-2*g,Z=W/q.width,j=W/q.height,G=H/W,B=C-W/2/Z,X=N-W/2/j,D=[B*Math.cos(-x.angle)-X*Math.sin(-x.angle),X*Math.cos(-x.angle)+B*Math.sin(-x.angle)];B=D[0],X=D[1],x.x=P.x-B*G,x.y=P.y+X*G,f.setState(x);break}}}}}},{key:"setSettings",value:function(r){this.settings=r}}])}(r3);function eZ(e){if(Array.isArray(e))return Lx(e)}function tZ(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function nZ(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function bC(e){return eZ(e)||tZ(e)||PU(e)||nZ()}function rZ(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.includes(r))continue;n[r]=e[r]}return n}function Dh(e,t){if(e==null)return{};var n,r,a=rZ(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(r=0;r<i.length;r++)n=i[r],t.includes(n)||{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}var yC=function(){function e(t,n){on(this,e),this.key=t,this.size=n}return ln(e,null,[{key:"compare",value:function(n,r){return n.size>r.size?-1:n.size<r.size||n.key>r.key?1:-1}}])}(),vC=function(){function e(){on(this,e),_e(this,"width",0),_e(this,"height",0),_e(this,"cellSize",0),_e(this,"columns",0),_e(this,"rows",0),_e(this,"cells",{})}return ln(e,[{key:"resizeAndClear",value:function(n,r){this.width=n.width,this.height=n.height,this.cellSize=r,this.columns=Math.ceil(n.width/r),this.rows=Math.ceil(n.height/r),this.cells={}}},{key:"getIndex",value:function(n){var r=Math.floor(n.x/this.cellSize),a=Math.floor(n.y/this.cellSize);return a*this.columns+r}},{key:"add",value:function(n,r,a){var i=new yC(n,r),l=this.getIndex(a),u=this.cells[l];u||(u=[],this.cells[l]=u),u.push(i)}},{key:"organize",value:function(){for(var n in this.cells){var r=this.cells[n];r.sort(yC.compare)}}},{key:"getLabelsToDisplay",value:function(n,r){var a=this.cellSize*this.cellSize,i=a/n/n,l=i*r/a,u=Math.ceil(l),c=[];for(var f in this.cells)for(var p=this.cells[f],g=0;g<Math.min(u,p.length);g++)c.push(p[g].key);return c}}])}();function aZ(e){var t=e.graph,n=e.hoveredNode,r=e.highlightedNodes,a=e.displayedNodeLabels,i=[];return t.forEachEdge(function(l,u,c,f){(c===n||f===n||r.has(c)||r.has(f)||a.has(c)&&a.has(f))&&i.push(l)}),i}var oZ=150,iZ=50,Ca=Object.prototype.hasOwnProperty;function lZ(e,t,n){if(!Ca.call(n,"x")||!Ca.call(n,"y"))throw new Error('Sigma: could not find a valid position (x, y) for node "'.concat(t,'". All your nodes must have a number "x" and "y". Maybe your forgot to apply a layout or your "nodeReducer" is not returning the correct data?'));return n.color||(n.color=e.defaultNodeColor),!n.label&&n.label!==""&&(n.label=null),n.label!==void 0&&n.label!==null?n.label=""+n.label:n.label=null,n.size||(n.size=2),Ca.call(n,"hidden")||(n.hidden=!1),Ca.call(n,"highlighted")||(n.highlighted=!1),Ca.call(n,"forceLabel")||(n.forceLabel=!1),(!n.type||n.type==="")&&(n.type=e.defaultNodeType),n.zIndex||(n.zIndex=0),n}function sZ(e,t,n){return n.color||(n.color=e.defaultEdgeColor),n.label||(n.label=""),n.size||(n.size=.5),Ca.call(n,"hidden")||(n.hidden=!1),Ca.call(n,"forceLabel")||(n.forceLabel=!1),(!n.type||n.type==="")&&(n.type=e.defaultEdgeType),n.zIndex||(n.zIndex=0),n}var uZ=function(e){function t(n,r){var a,i=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};if(on(this,t),a=Bn(this,t),_e(a,"elements",{}),_e(a,"canvasContexts",{}),_e(a,"webGLContexts",{}),_e(a,"pickingLayers",new Set),_e(a,"textures",{}),_e(a,"frameBuffers",{}),_e(a,"activeListeners",{}),_e(a,"labelGrid",new vC),_e(a,"nodeDataCache",{}),_e(a,"edgeDataCache",{}),_e(a,"nodeProgramIndex",{}),_e(a,"edgeProgramIndex",{}),_e(a,"nodesWithForcedLabels",new Set),_e(a,"edgesWithForcedLabels",new Set),_e(a,"nodeExtent",{x:[0,1],y:[0,1]}),_e(a,"nodeZExtent",[1/0,-1/0]),_e(a,"edgeZExtent",[1/0,-1/0]),_e(a,"matrix",_r()),_e(a,"invMatrix",_r()),_e(a,"correctionRatio",1),_e(a,"customBBox",null),_e(a,"normalizationFunction",gC({x:[0,1],y:[0,1]})),_e(a,"graphToViewportRatio",1),_e(a,"itemIDsIndex",{}),_e(a,"nodeIndices",{}),_e(a,"edgeIndices",{}),_e(a,"width",0),_e(a,"height",0),_e(a,"pixelRatio",fC()),_e(a,"pickingDownSizingRatio",2*a.pixelRatio),_e(a,"displayedNodeLabels",new Set),_e(a,"displayedEdgeLabels",new Set),_e(a,"highlightedNodes",new Set),_e(a,"hoveredNode",null),_e(a,"hoveredEdge",null),_e(a,"renderFrame",null),_e(a,"renderHighlightedNodesFrame",null),_e(a,"needToProcess",!1),_e(a,"checkEdgesEventsFrame",null),_e(a,"nodePrograms",{}),_e(a,"nodeHoverPrograms",{}),_e(a,"edgePrograms",{}),a.settings=qX(i),Oh(a.settings),jX(n),!(r instanceof HTMLElement))throw new Error("Sigma: container should be an html element.");a.graph=n,a.container=r,a.createWebGLContext("edges",{picking:i.enableEdgeEvents}),a.createCanvasContext("edgeLabels"),a.createWebGLContext("nodes",{picking:!0}),a.createCanvasContext("labels"),a.createCanvasContext("hovers"),a.createWebGLContext("hoverNodes"),a.createCanvasContext("mouse",{style:{touchAction:"none",userSelect:"none"}}),a.resize();for(var l in a.settings.nodeProgramClasses)a.registerNodeProgram(l,a.settings.nodeProgramClasses[l],a.settings.nodeHoverProgramClasses[l]);for(var u in a.settings.edgeProgramClasses)a.registerEdgeProgram(u,a.settings.edgeProgramClasses[u]);return a.camera=new mC,a.bindCameraHandlers(),a.mouseCaptor=new XX(a.elements.mouse,a),a.mouseCaptor.setSettings(a.settings),a.touchCaptor=new JX(a.elements.mouse,a),a.touchCaptor.setSettings(a.settings),a.bindEventHandlers(),a.bindGraphHandlers(),a.handleSettingsUpdate(),a.refresh(),a}return Un(t,e),ln(t,[{key:"registerNodeProgram",value:function(r,a,i){return this.nodePrograms[r]&&this.nodePrograms[r].kill(),this.nodeHoverPrograms[r]&&this.nodeHoverPrograms[r].kill(),this.nodePrograms[r]=new a(this.webGLContexts.nodes,this.frameBuffers.nodes,this),this.nodeHoverPrograms[r]=new(i||a)(this.webGLContexts.hoverNodes,null,this),this}},{key:"registerEdgeProgram",value:function(r,a){return this.edgePrograms[r]&&this.edgePrograms[r].kill(),this.edgePrograms[r]=new a(this.webGLContexts.edges,this.frameBuffers.edges,this),this}},{key:"unregisterNodeProgram",value:function(r){if(this.nodePrograms[r]){var a=this.nodePrograms,i=a[r],l=Dh(a,[r].map(Ys));i.kill(),this.nodePrograms=l}if(this.nodeHoverPrograms[r]){var u=this.nodeHoverPrograms,c=u[r],f=Dh(u,[r].map(Ys));c.kill(),this.nodePrograms=f}return this}},{key:"unregisterEdgeProgram",value:function(r){if(this.edgePrograms[r]){var a=this.edgePrograms,i=a[r],l=Dh(a,[r].map(Ys));i.kill(),this.edgePrograms=l}return this}},{key:"resetWebGLTexture",value:function(r){var a=this.webGLContexts[r],i=this.frameBuffers[r],l=this.textures[r];l&&a.deleteTexture(l);var u=a.createTexture();return a.bindFramebuffer(a.FRAMEBUFFER,i),a.bindTexture(a.TEXTURE_2D,u),a.texImage2D(a.TEXTURE_2D,0,a.RGBA,this.width,this.height,0,a.RGBA,a.UNSIGNED_BYTE,null),a.framebufferTexture2D(a.FRAMEBUFFER,a.COLOR_ATTACHMENT0,a.TEXTURE_2D,u,0),this.textures[r]=u,this}},{key:"bindCameraHandlers",value:function(){var r=this;return this.activeListeners.camera=function(){r.scheduleRender()},this.camera.on("updated",this.activeListeners.camera),this}},{key:"unbindCameraHandlers",value:function(){return this.camera.removeListener("updated",this.activeListeners.camera),this}},{key:"getNodeAtPosition",value:function(r){var a=r.x,i=r.y,l=eC(this.webGLContexts.nodes,this.frameBuffers.nodes,a,i,this.pixelRatio,this.pickingDownSizingRatio),u=JR.apply(void 0,bC(l)),c=this.itemIDsIndex[u];return c&&c.type==="node"?c.id:null}},{key:"bindEventHandlers",value:function(){var r=this;this.activeListeners.handleResize=function(){r.scheduleRefresh()},window.addEventListener("resize",this.activeListeners.handleResize),this.activeListeners.handleMove=function(i){var l=Us(i),u={event:l,preventSigmaDefault:function(){l.preventSigmaDefault()}},c=r.getNodeAtPosition(l);if(c&&r.hoveredNode!==c&&!r.nodeDataCache[c].hidden){r.hoveredNode&&r.emit("leaveNode",Be(Be({},u),{},{node:r.hoveredNode})),r.hoveredNode=c,r.emit("enterNode",Be(Be({},u),{},{node:c})),r.scheduleHighlightedNodesRender();return}if(r.hoveredNode&&r.getNodeAtPosition(l)!==r.hoveredNode){var f=r.hoveredNode;r.hoveredNode=null,r.emit("leaveNode",Be(Be({},u),{},{node:f})),r.scheduleHighlightedNodesRender();return}if(r.settings.enableEdgeEvents){var p=r.hoveredNode?null:r.getEdgeAtPoint(u.event.x,u.event.y);p!==r.hoveredEdge&&(r.hoveredEdge&&r.emit("leaveEdge",Be(Be({},u),{},{edge:r.hoveredEdge})),p&&r.emit("enterEdge",Be(Be({},u),{},{edge:p})),r.hoveredEdge=p)}},this.activeListeners.handleMoveBody=function(i){var l=Us(i);r.emit("moveBody",{event:l,preventSigmaDefault:function(){l.preventSigmaDefault()}})},this.activeListeners.handleLeave=function(i){var l=Us(i),u={event:l,preventSigmaDefault:function(){l.preventSigmaDefault()}};r.hoveredNode&&(r.emit("leaveNode",Be(Be({},u),{},{node:r.hoveredNode})),r.scheduleHighlightedNodesRender()),r.settings.enableEdgeEvents&&r.hoveredEdge&&(r.emit("leaveEdge",Be(Be({},u),{},{edge:r.hoveredEdge})),r.scheduleHighlightedNodesRender()),r.emit("leaveStage",Be({},u))},this.activeListeners.handleEnter=function(i){var l=Us(i),u={event:l,preventSigmaDefault:function(){l.preventSigmaDefault()}};r.emit("enterStage",Be({},u))};var a=function(l){return function(u){var c=Us(u),f={event:c,preventSigmaDefault:function(){c.preventSigmaDefault()}},p=r.getNodeAtPosition(c);if(p)return r.emit("".concat(l,"Node"),Be(Be({},f),{},{node:p}));if(r.settings.enableEdgeEvents){var g=r.getEdgeAtPoint(c.x,c.y);if(g)return r.emit("".concat(l,"Edge"),Be(Be({},f),{},{edge:g}))}return r.emit("".concat(l,"Stage"),f)}};return this.activeListeners.handleClick=a("click"),this.activeListeners.handleRightClick=a("rightClick"),this.activeListeners.handleDoubleClick=a("doubleClick"),this.activeListeners.handleWheel=a("wheel"),this.activeListeners.handleDown=a("down"),this.activeListeners.handleUp=a("up"),this.mouseCaptor.on("mousemove",this.activeListeners.handleMove),this.mouseCaptor.on("mousemovebody",this.activeListeners.handleMoveBody),this.mouseCaptor.on("click",this.activeListeners.handleClick),this.mouseCaptor.on("rightClick",this.activeListeners.handleRightClick),this.mouseCaptor.on("doubleClick",this.activeListeners.handleDoubleClick),this.mouseCaptor.on("wheel",this.activeListeners.handleWheel),this.mouseCaptor.on("mousedown",this.activeListeners.handleDown),this.mouseCaptor.on("mouseup",this.activeListeners.handleUp),this.mouseCaptor.on("mouseleave",this.activeListeners.handleLeave),this.mouseCaptor.on("mouseenter",this.activeListeners.handleEnter),this.touchCaptor.on("touchdown",this.activeListeners.handleDown),this.touchCaptor.on("touchdown",this.activeListeners.handleMove),this.touchCaptor.on("touchup",this.activeListeners.handleUp),this.touchCaptor.on("touchmove",this.activeListeners.handleMove),this.touchCaptor.on("tap",this.activeListeners.handleClick),this.touchCaptor.on("doubletap",this.activeListeners.handleDoubleClick),this.touchCaptor.on("touchmove",this.activeListeners.handleMoveBody),this}},{key:"bindGraphHandlers",value:function(){var r=this,a=this.graph,i=new Set(["x","y","zIndex","type"]);return this.activeListeners.eachNodeAttributesUpdatedGraphUpdate=function(l){var u,c=(u=l.hints)===null||u===void 0?void 0:u.attributes;r.graph.forEachNode(function(p){return r.updateNode(p)});var f=!c||c.some(function(p){return i.has(p)});r.refresh({partialGraph:{nodes:a.nodes()},skipIndexation:!f,schedule:!0})},this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate=function(l){var u,c=(u=l.hints)===null||u===void 0?void 0:u.attributes;r.graph.forEachEdge(function(p){return r.updateEdge(p)});var f=c&&["zIndex","type"].some(function(p){return c==null?void 0:c.includes(p)});r.refresh({partialGraph:{edges:a.edges()},skipIndexation:!f,schedule:!0})},this.activeListeners.addNodeGraphUpdate=function(l){var u=l.key;r.addNode(u),r.refresh({partialGraph:{nodes:[u]},skipIndexation:!1,schedule:!0})},this.activeListeners.updateNodeGraphUpdate=function(l){var u=l.key;r.refresh({partialGraph:{nodes:[u]},skipIndexation:!1,schedule:!0})},this.activeListeners.dropNodeGraphUpdate=function(l){var u=l.key;r.removeNode(u),r.refresh({schedule:!0})},this.activeListeners.addEdgeGraphUpdate=function(l){var u=l.key;r.addEdge(u),r.refresh({partialGraph:{edges:[u]},schedule:!0})},this.activeListeners.updateEdgeGraphUpdate=function(l){var u=l.key;r.refresh({partialGraph:{edges:[u]},skipIndexation:!1,schedule:!0})},this.activeListeners.dropEdgeGraphUpdate=function(l){var u=l.key;r.removeEdge(u),r.refresh({schedule:!0})},this.activeListeners.clearEdgesGraphUpdate=function(){r.clearEdgeState(),r.clearEdgeIndices(),r.refresh({schedule:!0})},this.activeListeners.clearGraphUpdate=function(){r.clearEdgeState(),r.clearNodeState(),r.clearEdgeIndices(),r.clearNodeIndices(),r.refresh({schedule:!0})},a.on("nodeAdded",this.activeListeners.addNodeGraphUpdate),a.on("nodeDropped",this.activeListeners.dropNodeGraphUpdate),a.on("nodeAttributesUpdated",this.activeListeners.updateNodeGraphUpdate),a.on("eachNodeAttributesUpdated",this.activeListeners.eachNodeAttributesUpdatedGraphUpdate),a.on("edgeAdded",this.activeListeners.addEdgeGraphUpdate),a.on("edgeDropped",this.activeListeners.dropEdgeGraphUpdate),a.on("edgeAttributesUpdated",this.activeListeners.updateEdgeGraphUpdate),a.on("eachEdgeAttributesUpdated",this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate),a.on("edgesCleared",this.activeListeners.clearEdgesGraphUpdate),a.on("cleared",this.activeListeners.clearGraphUpdate),this}},{key:"unbindGraphHandlers",value:function(){var r=this.graph;r.removeListener("nodeAdded",this.activeListeners.addNodeGraphUpdate),r.removeListener("nodeDropped",this.activeListeners.dropNodeGraphUpdate),r.removeListener("nodeAttributesUpdated",this.activeListeners.updateNodeGraphUpdate),r.removeListener("eachNodeAttributesUpdated",this.activeListeners.eachNodeAttributesUpdatedGraphUpdate),r.removeListener("edgeAdded",this.activeListeners.addEdgeGraphUpdate),r.removeListener("edgeDropped",this.activeListeners.dropEdgeGraphUpdate),r.removeListener("edgeAttributesUpdated",this.activeListeners.updateEdgeGraphUpdate),r.removeListener("eachEdgeAttributesUpdated",this.activeListeners.eachEdgeAttributesUpdatedGraphUpdate),r.removeListener("edgesCleared",this.activeListeners.clearEdgesGraphUpdate),r.removeListener("cleared",this.activeListeners.clearGraphUpdate)}},{key:"getEdgeAtPoint",value:function(r,a){var i=eC(this.webGLContexts.edges,this.frameBuffers.edges,r,a,this.pixelRatio,this.pickingDownSizingRatio),l=JR.apply(void 0,bC(i)),u=this.itemIDsIndex[l];return u&&u.type==="edge"?u.id:null}},{key:"process",value:function(){var r=this;this.emit("beforeProcess");var a=this.graph,i=this.settings,l=this.getDimensions();if(this.nodeExtent=UX(this.graph),!this.settings.autoRescale){var u=l.width,c=l.height,f=this.nodeExtent,p=f.x,g=f.y;this.nodeExtent={x:[(p[0]+p[1])/2-u/2,(p[0]+p[1])/2+u/2],y:[(g[0]+g[1])/2-c/2,(g[0]+g[1])/2+c/2]}}this.normalizationFunction=gC(this.customBBox||this.nodeExtent);var b=new mC,m=Bs(b.getState(),l,this.getGraphDimensions(),this.getStagePadding());this.labelGrid.resizeAndClear(l,i.labelGridCellSize);for(var S={},v={},A={},R={},x=1,T=a.nodes(),C=0,N=T.length;C<N;C++){var _=T[C],O=this.nodeDataCache[_],z=a.getNodeAttributes(_);O.x=z.x,O.y=z.y,this.normalizationFunction.applyTo(O),typeof O.label=="string"&&!O.hidden&&this.labelGrid.add(_,O.size,this.framedGraphToViewport(O,{matrix:m})),S[O.type]=(S[O.type]||0)+1}this.labelGrid.organize();for(var I in this.nodePrograms){if(!Ca.call(this.nodePrograms,I))throw new Error('Sigma: could not find a suitable program for node type "'.concat(I,'"!'));this.nodePrograms[I].reallocate(S[I]||0),S[I]=0}this.settings.zIndex&&this.nodeZExtent[0]!==this.nodeZExtent[1]&&(T=pC(this.nodeZExtent,function(Q){return r.nodeDataCache[Q].zIndex},T));for(var M=0,H=T.length;M<H;M++){var q=T[M];v[q]=x,R[v[q]]={type:"node",id:q},x++;var P=this.nodeDataCache[q];this.addNodeToProgram(q,v[q],S[P.type]++)}for(var W={},Z=a.edges(),j=0,G=Z.length;j<G;j++){var B=Z[j],X=this.edgeDataCache[B];W[X.type]=(W[X.type]||0)+1}this.settings.zIndex&&this.edgeZExtent[0]!==this.edgeZExtent[1]&&(Z=pC(this.edgeZExtent,function(Q){return r.edgeDataCache[Q].zIndex},Z));for(var D in this.edgePrograms){if(!Ca.call(this.edgePrograms,D))throw new Error('Sigma: could not find a suitable program for edge type "'.concat(D,'"!'));this.edgePrograms[D].reallocate(W[D]||0),W[D]=0}for(var V=0,U=Z.length;V<U;V++){var L=Z[V];A[L]=x,R[A[L]]={type:"edge",id:L},x++;var Y=this.edgeDataCache[L];this.addEdgeToProgram(L,A[L],W[Y.type]++)}return this.itemIDsIndex=R,this.nodeIndices=v,this.edgeIndices=A,this.emit("afterProcess"),this}},{key:"handleSettingsUpdate",value:function(r){var a=this,i=this.settings;if(this.camera.minRatio=i.minCameraRatio,this.camera.maxRatio=i.maxCameraRatio,this.camera.enabledZooming=i.enableCameraZooming,this.camera.enabledPanning=i.enableCameraPanning,this.camera.enabledRotation=i.enableCameraRotation,i.cameraPanBoundaries?this.camera.clean=function(p){return a.cleanCameraState(p,i.cameraPanBoundaries&&zx(i.cameraPanBoundaries)==="object"?i.cameraPanBoundaries:{})}:this.camera.clean=null,this.camera.setState(this.camera.validateState(this.camera.getState())),r){if(r.edgeProgramClasses!==i.edgeProgramClasses){for(var l in i.edgeProgramClasses)i.edgeProgramClasses[l]!==r.edgeProgramClasses[l]&&this.registerEdgeProgram(l,i.edgeProgramClasses[l]);for(var u in r.edgeProgramClasses)i.edgeProgramClasses[u]||this.unregisterEdgeProgram(u)}if(r.nodeProgramClasses!==i.nodeProgramClasses||r.nodeHoverProgramClasses!==i.nodeHoverProgramClasses){for(var c in i.nodeProgramClasses)(i.nodeProgramClasses[c]!==r.nodeProgramClasses[c]||i.nodeHoverProgramClasses[c]!==r.nodeHoverProgramClasses[c])&&this.registerNodeProgram(c,i.nodeProgramClasses[c],i.nodeHoverProgramClasses[c]);for(var f in r.nodeProgramClasses)i.nodeProgramClasses[f]||this.unregisterNodeProgram(f)}}return this.mouseCaptor.setSettings(this.settings),this.touchCaptor.setSettings(this.settings),this}},{key:"cleanCameraState",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=a.tolerance,l=i===void 0?0:i,u=a.boundaries,c=Be({},r),f=u||this.nodeExtent,p=Sl(f.x,2),g=p[0],b=p[1],m=Sl(f.y,2),S=m[0],v=m[1],A=[this.graphToViewport({x:g,y:S},{cameraState:r}),this.graphToViewport({x:b,y:S},{cameraState:r}),this.graphToViewport({x:g,y:v},{cameraState:r}),this.graphToViewport({x:b,y:v},{cameraState:r})],R=1/0,x=-1/0,T=1/0,C=-1/0;A.forEach(function(W){var Z=W.x,j=W.y;R=Math.min(R,Z),x=Math.max(x,Z),T=Math.min(T,j),C=Math.max(C,j)});var N=x-R,_=C-T,O=this.getDimensions(),z=O.width,I=O.height,M=0,H=0;if(N>=z?x<z-l?M=x-(z-l):R>l&&(M=R-l):x>z+l?M=x-(z+l):R<-l&&(M=R+l),_>=I?C<I-l?H=C-(I-l):T>l&&(H=T-l):C>I+l?H=C-(I+l):T<-l&&(H=T+l),M||H){var q=this.viewportToFramedGraph({x:0,y:0},{cameraState:r}),P=this.viewportToFramedGraph({x:M,y:H},{cameraState:r});M=P.x-q.x,H=P.y-q.y,c.x+=M,c.y+=H}return c}},{key:"renderLabels",value:function(){if(!this.settings.renderLabels)return this;var r=this.camera.getState(),a=this.labelGrid.getLabelsToDisplay(r.ratio,this.settings.labelDensity);hC(a,this.nodesWithForcedLabels),this.displayedNodeLabels=new Set;for(var i=this.canvasContexts.labels,l=0,u=a.length;l<u;l++){var c=a[l],f=this.nodeDataCache[c];if(!this.displayedNodeLabels.has(c)&&!f.hidden){var p=this.framedGraphToViewport(f),g=p.x,b=p.y,m=this.scaleSize(f.size);if(!(!f.forceLabel&&m<this.settings.labelRenderedSizeThreshold)&&!(g<-150||g>this.width+oZ||b<-50||b>this.height+iZ)){this.displayedNodeLabels.add(c);var S=this.settings.defaultDrawNodeLabel,v=this.nodePrograms[f.type],A=(v==null?void 0:v.drawLabel)||S;A(i,Be(Be({key:c},f),{},{size:m,x:g,y:b}),this.settings)}}}return this}},{key:"renderEdgeLabels",value:function(){if(!this.settings.renderEdgeLabels)return this;var r=this.canvasContexts.edgeLabels;r.clearRect(0,0,this.width,this.height);var a=aZ({graph:this.graph,hoveredNode:this.hoveredNode,displayedNodeLabels:this.displayedNodeLabels,highlightedNodes:this.highlightedNodes});hC(a,this.edgesWithForcedLabels);for(var i=new Set,l=0,u=a.length;l<u;l++){var c=a[l],f=this.graph.extremities(c),p=this.nodeDataCache[f[0]],g=this.nodeDataCache[f[1]],b=this.edgeDataCache[c];if(!i.has(c)&&!(b.hidden||p.hidden||g.hidden)){var m=this.settings.defaultDrawEdgeLabel,S=this.edgePrograms[b.type],v=(S==null?void 0:S.drawLabel)||m;v(r,Be(Be({key:c},b),{},{size:this.scaleSize(b.size)}),Be(Be(Be({key:f[0]},p),this.framedGraphToViewport(p)),{},{size:this.scaleSize(p.size)}),Be(Be(Be({key:f[1]},g),this.framedGraphToViewport(g)),{},{size:this.scaleSize(g.size)}),this.settings),i.add(c)}}return this.displayedEdgeLabels=i,this}},{key:"renderHighlightedNodes",value:function(){var r=this,a=this.canvasContexts.hovers;a.clearRect(0,0,this.width,this.height);var i=function(m){var S=r.nodeDataCache[m],v=r.framedGraphToViewport(S),A=v.x,R=v.y,x=r.scaleSize(S.size),T=r.settings.defaultDrawNodeHover,C=r.nodePrograms[S.type],N=(C==null?void 0:C.drawHover)||T;N(a,Be(Be({key:m},S),{},{size:x,x:A,y:R}),r.settings)},l=[];this.hoveredNode&&!this.nodeDataCache[this.hoveredNode].hidden&&l.push(this.hoveredNode),this.highlightedNodes.forEach(function(b){b!==r.hoveredNode&&l.push(b)}),l.forEach(function(b){return i(b)});var u={};l.forEach(function(b){var m=r.nodeDataCache[b].type;u[m]=(u[m]||0)+1});for(var c in this.nodeHoverPrograms)this.nodeHoverPrograms[c].reallocate(u[c]||0),u[c]=0;l.forEach(function(b){var m=r.nodeDataCache[b];r.nodeHoverPrograms[m.type].process(0,u[m.type]++,m)}),this.webGLContexts.hoverNodes.clear(this.webGLContexts.hoverNodes.COLOR_BUFFER_BIT);var f=this.getRenderParams();for(var p in this.nodeHoverPrograms){var g=this.nodeHoverPrograms[p];g.render(f)}}},{key:"scheduleHighlightedNodesRender",value:function(){var r=this;this.renderHighlightedNodesFrame||this.renderFrame||(this.renderHighlightedNodesFrame=requestAnimationFrame(function(){r.renderHighlightedNodesFrame=null,r.renderHighlightedNodes(),r.renderEdgeLabels()}))}},{key:"render",value:function(){var r=this;this.emit("beforeRender");var a=function(){return r.emit("afterRender"),r};if(this.renderFrame&&(cancelAnimationFrame(this.renderFrame),this.renderFrame=null),this.resize(),this.needToProcess&&this.process(),this.needToProcess=!1,this.clear(),this.pickingLayers.forEach(function(A){return r.resetWebGLTexture(A)}),!this.graph.order)return a();var i=this.mouseCaptor,l=this.camera.isAnimated()||i.isMoving||i.draggedEvents||i.currentWheelDirection,u=this.camera.getState(),c=this.getDimensions(),f=this.getGraphDimensions(),p=this.getStagePadding();this.matrix=Bs(u,c,f,p),this.invMatrix=Bs(u,c,f,p,!0),this.correctionRatio=BX(this.matrix,u,c),this.graphToViewportRatio=this.getGraphToViewportRatio();var g=this.getRenderParams();for(var b in this.nodePrograms){var m=this.nodePrograms[b];m.render(g)}if(!this.settings.hideEdgesOnMove||!l)for(var S in this.edgePrograms){var v=this.edgePrograms[S];v.render(g)}return this.settings.hideLabelsOnMove&&l||(this.renderLabels(),this.renderEdgeLabels(),this.renderHighlightedNodes()),a()}},{key:"addNode",value:function(r){var a=Object.assign({},this.graph.getNodeAttributes(r));this.settings.nodeReducer&&(a=this.settings.nodeReducer(r,a));var i=lZ(this.settings,r,a);this.nodeDataCache[r]=i,this.nodesWithForcedLabels.delete(r),i.forceLabel&&!i.hidden&&this.nodesWithForcedLabels.add(r),this.highlightedNodes.delete(r),i.highlighted&&!i.hidden&&this.highlightedNodes.add(r),this.settings.zIndex&&(i.zIndex<this.nodeZExtent[0]&&(this.nodeZExtent[0]=i.zIndex),i.zIndex>this.nodeZExtent[1]&&(this.nodeZExtent[1]=i.zIndex))}},{key:"updateNode",value:function(r){this.addNode(r);var a=this.nodeDataCache[r];this.normalizationFunction.applyTo(a)}},{key:"removeNode",value:function(r){delete this.nodeDataCache[r],delete this.nodeProgramIndex[r],this.highlightedNodes.delete(r),this.hoveredNode===r&&(this.hoveredNode=null),this.nodesWithForcedLabels.delete(r)}},{key:"addEdge",value:function(r){var a=Object.assign({},this.graph.getEdgeAttributes(r));this.settings.edgeReducer&&(a=this.settings.edgeReducer(r,a));var i=sZ(this.settings,r,a);this.edgeDataCache[r]=i,this.edgesWithForcedLabels.delete(r),i.forceLabel&&!i.hidden&&this.edgesWithForcedLabels.add(r),this.settings.zIndex&&(i.zIndex<this.edgeZExtent[0]&&(this.edgeZExtent[0]=i.zIndex),i.zIndex>this.edgeZExtent[1]&&(this.edgeZExtent[1]=i.zIndex))}},{key:"updateEdge",value:function(r){this.addEdge(r)}},{key:"removeEdge",value:function(r){delete this.edgeDataCache[r],delete this.edgeProgramIndex[r],this.hoveredEdge===r&&(this.hoveredEdge=null),this.edgesWithForcedLabels.delete(r)}},{key:"clearNodeIndices",value:function(){this.labelGrid=new vC,this.nodeExtent={x:[0,1],y:[0,1]},this.nodeDataCache={},this.edgeProgramIndex={},this.nodesWithForcedLabels=new Set,this.nodeZExtent=[1/0,-1/0]}},{key:"clearEdgeIndices",value:function(){this.edgeDataCache={},this.edgeProgramIndex={},this.edgesWithForcedLabels=new Set,this.edgeZExtent=[1/0,-1/0]}},{key:"clearIndices",value:function(){this.clearEdgeIndices(),this.clearNodeIndices()}},{key:"clearNodeState",value:function(){this.displayedNodeLabels=new Set,this.highlightedNodes=new Set,this.hoveredNode=null}},{key:"clearEdgeState",value:function(){this.displayedEdgeLabels=new Set,this.highlightedNodes=new Set,this.hoveredEdge=null}},{key:"clearState",value:function(){this.clearEdgeState(),this.clearNodeState()}},{key:"addNodeToProgram",value:function(r,a,i){var l=this.nodeDataCache[r],u=this.nodePrograms[l.type];if(!u)throw new Error('Sigma: could not find a suitable program for node type "'.concat(l.type,'"!'));u.process(a,i,l),this.nodeProgramIndex[r]=i}},{key:"addEdgeToProgram",value:function(r,a,i){var l=this.edgeDataCache[r],u=this.edgePrograms[l.type];if(!u)throw new Error('Sigma: could not find a suitable program for edge type "'.concat(l.type,'"!'));var c=this.graph.extremities(r),f=this.nodeDataCache[c[0]],p=this.nodeDataCache[c[1]];u.process(a,i,f,p,l),this.edgeProgramIndex[r]=i}},{key:"getRenderParams",value:function(){return{matrix:this.matrix,invMatrix:this.invMatrix,width:this.width,height:this.height,pixelRatio:this.pixelRatio,zoomRatio:this.camera.ratio,cameraAngle:this.camera.angle,sizeRatio:1/this.scaleSize(),correctionRatio:this.correctionRatio,downSizingRatio:this.pickingDownSizingRatio,minEdgeThickness:this.settings.minEdgeThickness,antiAliasingFeather:this.settings.antiAliasingFeather}}},{key:"getStagePadding",value:function(){var r=this.settings,a=r.stagePadding,i=r.autoRescale;return i&&a||0}},{key:"createLayer",value:function(r,a){var i=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{};if(this.elements[r])throw new Error('Sigma: a layer named "'.concat(r,'" already exists'));var l=GX(a,{position:"absolute"},{class:"sigma-".concat(r)});return i.style&&Object.assign(l.style,i.style),this.elements[r]=l,"beforeLayer"in i&&i.beforeLayer?this.elements[i.beforeLayer].before(l):"afterLayer"in i&&i.afterLayer?this.elements[i.afterLayer].after(l):this.container.appendChild(l),l}},{key:"createCanvas",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.createLayer(r,"canvas",a)}},{key:"createCanvasContext",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=this.createCanvas(r,a),l={preserveDrawingBuffer:!1,antialias:!1};return this.canvasContexts[r]=i.getContext("2d",l),this}},{key:"createWebGLContext",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=(a==null?void 0:a.canvas)||this.createCanvas(r,a);a.hidden&&i.remove();var l=Be({preserveDrawingBuffer:!1,antialias:!1},a),u;u=i.getContext("webgl2",l),u||(u=i.getContext("webgl",l)),u||(u=i.getContext("experimental-webgl",l));var c=u;if(this.webGLContexts[r]=c,c.blendFunc(c.ONE,c.ONE_MINUS_SRC_ALPHA),a.picking){this.pickingLayers.add(r);var f=c.createFramebuffer();if(!f)throw new Error("Sigma: cannot create a new frame buffer for layer ".concat(r));this.frameBuffers[r]=f}return c}},{key:"killLayer",value:function(r){var a=this.elements[r];if(!a)throw new Error("Sigma: cannot kill layer ".concat(r,", which does not exist"));if(this.webGLContexts[r]){var i,l=this.webGLContexts[r];(i=l.getExtension("WEBGL_lose_context"))===null||i===void 0||i.loseContext(),delete this.webGLContexts[r]}else this.canvasContexts[r]&&delete this.canvasContexts[r];return a.remove(),delete this.elements[r],this}},{key:"getCamera",value:function(){return this.camera}},{key:"setCamera",value:function(r){this.unbindCameraHandlers(),this.camera=r,this.bindCameraHandlers()}},{key:"getContainer",value:function(){return this.container}},{key:"getGraph",value:function(){return this.graph}},{key:"setGraph",value:function(r){r!==this.graph&&(this.hoveredNode&&!r.hasNode(this.hoveredNode)&&(this.hoveredNode=null),this.hoveredEdge&&!r.hasEdge(this.hoveredEdge)&&(this.hoveredEdge=null),this.unbindGraphHandlers(),this.checkEdgesEventsFrame!==null&&(cancelAnimationFrame(this.checkEdgesEventsFrame),this.checkEdgesEventsFrame=null),this.graph=r,this.bindGraphHandlers(),this.refresh())}},{key:"getMouseCaptor",value:function(){return this.mouseCaptor}},{key:"getTouchCaptor",value:function(){return this.touchCaptor}},{key:"getDimensions",value:function(){return{width:this.width,height:this.height}}},{key:"getGraphDimensions",value:function(){var r=this.customBBox||this.nodeExtent;return{width:r.x[1]-r.x[0]||1,height:r.y[1]-r.y[0]||1}}},{key:"getNodeDisplayData",value:function(r){var a=this.nodeDataCache[r];return a?Object.assign({},a):void 0}},{key:"getEdgeDisplayData",value:function(r){var a=this.edgeDataCache[r];return a?Object.assign({},a):void 0}},{key:"getNodeDisplayedLabels",value:function(){return new Set(this.displayedNodeLabels)}},{key:"getEdgeDisplayedLabels",value:function(){return new Set(this.displayedEdgeLabels)}},{key:"getSettings",value:function(){return Be({},this.settings)}},{key:"getSetting",value:function(r){return this.settings[r]}},{key:"setSetting",value:function(r,a){var i=Be({},this.settings);return this.settings[r]=a,Oh(this.settings),this.handleSettingsUpdate(i),this.scheduleRefresh(),this}},{key:"updateSetting",value:function(r,a){return this.setSetting(r,a(this.settings[r])),this}},{key:"setSettings",value:function(r){var a=Be({},this.settings);return this.settings=Be(Be({},this.settings),r),Oh(this.settings),this.handleSettingsUpdate(a),this.scheduleRefresh(),this}},{key:"resize",value:function(r){var a=this.width,i=this.height;if(this.width=this.container.offsetWidth,this.height=this.container.offsetHeight,this.pixelRatio=fC(),this.width===0)if(this.settings.allowInvalidContainer)this.width=1;else throw new Error("Sigma: Container has no width. You can set the allowInvalidContainer setting to true to stop seeing this error.");if(this.height===0)if(this.settings.allowInvalidContainer)this.height=1;else throw new Error("Sigma: Container has no height. You can set the allowInvalidContainer setting to true to stop seeing this error.");if(!r&&a===this.width&&i===this.height)return this;for(var l in this.elements){var u=this.elements[l];u.style.width=this.width+"px",u.style.height=this.height+"px"}for(var c in this.canvasContexts)this.elements[c].setAttribute("width",this.width*this.pixelRatio+"px"),this.elements[c].setAttribute("height",this.height*this.pixelRatio+"px"),this.pixelRatio!==1&&this.canvasContexts[c].scale(this.pixelRatio,this.pixelRatio);for(var f in this.webGLContexts){this.elements[f].setAttribute("width",this.width*this.pixelRatio+"px"),this.elements[f].setAttribute("height",this.height*this.pixelRatio+"px");var p=this.webGLContexts[f];if(p.viewport(0,0,this.width*this.pixelRatio,this.height*this.pixelRatio),this.pickingLayers.has(f)){var g=this.textures[f];g&&p.deleteTexture(g)}}return this.emit("resize"),this}},{key:"clear",value:function(){return this.emit("beforeClear"),this.webGLContexts.nodes.bindFramebuffer(WebGLRenderingContext.FRAMEBUFFER,null),this.webGLContexts.nodes.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.webGLContexts.edges.bindFramebuffer(WebGLRenderingContext.FRAMEBUFFER,null),this.webGLContexts.edges.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.webGLContexts.hoverNodes.clear(WebGLRenderingContext.COLOR_BUFFER_BIT),this.canvasContexts.labels.clearRect(0,0,this.width,this.height),this.canvasContexts.hovers.clearRect(0,0,this.width,this.height),this.canvasContexts.edgeLabels.clearRect(0,0,this.width,this.height),this.emit("afterClear"),this}},{key:"refresh",value:function(r){var a=this,i=(r==null?void 0:r.skipIndexation)!==void 0?r==null?void 0:r.skipIndexation:!1,l=(r==null?void 0:r.schedule)!==void 0?r.schedule:!1,u=!r||!r.partialGraph;if(u)this.clearEdgeIndices(),this.clearNodeIndices(),this.graph.forEachNode(function(C){return a.addNode(C)}),this.graph.forEachEdge(function(C){return a.addEdge(C)});else{for(var c,f,p=((c=r.partialGraph)===null||c===void 0?void 0:c.nodes)||[],g=0,b=(p==null?void 0:p.length)||0;g<b;g++){var m=p[g];if(this.updateNode(m),i){var S=this.nodeProgramIndex[m];if(S===void 0)throw new Error('Sigma: node "'.concat(m,`" can't be repaint`));this.addNodeToProgram(m,this.nodeIndices[m],S)}}for(var v=(r==null||(f=r.partialGraph)===null||f===void 0?void 0:f.edges)||[],A=0,R=v.length;A<R;A++){var x=v[A];if(this.updateEdge(x),i){var T=this.edgeProgramIndex[x];if(T===void 0)throw new Error('Sigma: edge "'.concat(x,`" can't be repaint`));this.addEdgeToProgram(x,this.edgeIndices[x],T)}}}return(u||!i)&&(this.needToProcess=!0),l?this.scheduleRender():this.render(),this}},{key:"scheduleRender",value:function(){var r=this;return this.renderFrame||(this.renderFrame=requestAnimationFrame(function(){r.render()})),this}},{key:"scheduleRefresh",value:function(r){return this.refresh(Be(Be({},r),{},{schedule:!0}))}},{key:"getViewportZoomedState",value:function(r,a){var i=this.camera.getState(),l=i.ratio,u=i.angle,c=i.x,f=i.y,p=this.settings,g=p.minCameraRatio,b=p.maxCameraRatio;typeof b=="number"&&(a=Math.min(a,b)),typeof g=="number"&&(a=Math.max(a,g));var m=a/l,S={x:this.width/2,y:this.height/2},v=this.viewportToFramedGraph(r),A=this.viewportToFramedGraph(S);return{angle:u,x:(v.x-A.x)*(1-m)+c,y:(v.y-A.y)*(1-m)+f,ratio:a}}},{key:"viewRectangle",value:function(){var r=this.viewportToFramedGraph({x:0,y:0}),a=this.viewportToFramedGraph({x:this.width,y:0}),i=this.viewportToFramedGraph({x:0,y:this.height});return{x1:r.x,y1:r.y,x2:a.x,y2:a.y,height:a.y-i.y}}},{key:"framedGraphToViewport",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=!!a.cameraState||!!a.viewportDimensions||!!a.graphDimensions,l=a.matrix?a.matrix:i?Bs(a.cameraState||this.camera.getState(),a.viewportDimensions||this.getDimensions(),a.graphDimensions||this.getGraphDimensions(),a.padding||this.getStagePadding()):this.matrix,u=Fx(l,r);return{x:(1+u.x)*this.width/2,y:(1-u.y)*this.height/2}}},{key:"viewportToFramedGraph",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},i=!!a.cameraState||!!a.viewportDimensions||!a.graphDimensions,l=a.matrix?a.matrix:i?Bs(a.cameraState||this.camera.getState(),a.viewportDimensions||this.getDimensions(),a.graphDimensions||this.getGraphDimensions(),a.padding||this.getStagePadding(),!0):this.invMatrix,u=Fx(l,{x:r.x/this.width*2-1,y:1-r.y/this.height*2});return isNaN(u.x)&&(u.x=0),isNaN(u.y)&&(u.y=0),u}},{key:"viewportToGraph",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.normalizationFunction.inverse(this.viewportToFramedGraph(r,a))}},{key:"graphToViewport",value:function(r){var a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};return this.framedGraphToViewport(this.normalizationFunction(r),a)}},{key:"getGraphToViewportRatio",value:function(){var r={x:0,y:0},a={x:1,y:1},i=Math.sqrt(Math.pow(r.x-a.x,2)+Math.pow(r.y-a.y,2)),l=this.graphToViewport(r),u=this.graphToViewport(a),c=Math.sqrt(Math.pow(l.x-u.x,2)+Math.pow(l.y-u.y,2));return c/i}},{key:"getBBox",value:function(){return this.nodeExtent}},{key:"getCustomBBox",value:function(){return this.customBBox}},{key:"setCustomBBox",value:function(r){return this.customBBox=r,this.scheduleRender(),this}},{key:"kill",value:function(){this.emit("kill"),this.removeAllListeners(),this.unbindCameraHandlers(),window.removeEventListener("resize",this.activeListeners.handleResize),this.mouseCaptor.kill(),this.touchCaptor.kill(),this.unbindGraphHandlers(),this.clearIndices(),this.clearState(),this.nodeDataCache={},this.edgeDataCache={},this.highlightedNodes.clear(),this.renderFrame&&(cancelAnimationFrame(this.renderFrame),this.renderFrame=null),this.renderHighlightedNodesFrame&&(cancelAnimationFrame(this.renderHighlightedNodesFrame),this.renderHighlightedNodesFrame=null);for(var r=this.container;r.firstChild;)r.removeChild(r.firstChild);this.canvasContexts={},this.webGLContexts={},this.elements={};for(var a in this.nodePrograms)this.nodePrograms[a].kill();for(var i in this.nodeHoverPrograms)this.nodeHoverPrograms[i].kill();for(var l in this.edgePrograms)this.edgePrograms[l].kill();this.nodePrograms={},this.nodeHoverPrograms={},this.edgePrograms={};for(var u in this.elements)this.killLayer(u)}},{key:"scaleSize",value:function(){var r=arguments.length>0&&arguments[0]!==void 0?arguments[0]:1,a=arguments.length>1&&arguments[1]!==void 0?arguments[1]:this.camera.ratio;return r/this.settings.zoomToSizeRatioFunction(a)*(this.getSetting("itemSizesReference")==="positions"?a*this.graphToViewportRatio:1)}},{key:"getCanvases",value:function(){var r={};for(var a in this.elements)this.elements[a]instanceof HTMLCanvasElement&&(r[a]=this.elements[a]);return r}}])}(m0);const a3=k.createContext(null),cZ=a3.Provider;function y0(){const e=k.useContext(a3);if(e==null)throw new Error("No context provided: useSigmaContext() can only be used in a descendant of <SigmaContainer>");return e}function br(){return y0().sigma}function o3(){const{sigma:e}=y0();return k.useCallback(t=>{e&&Object.keys(t).forEach(n=>{e.setSetting(n,t[n])})},[e])}function Cf(e){return new Set(Object.keys(e))}const SC=Cf({clickNode:!0,rightClickNode:!0,downNode:!0,enterNode:!0,leaveNode:!0,doubleClickNode:!0,wheelNode:!0,clickEdge:!0,rightClickEdge:!0,downEdge:!0,enterEdge:!0,leaveEdge:!0,doubleClickEdge:!0,wheelEdge:!0,clickStage:!0,rightClickStage:!0,downStage:!0,doubleClickStage:!0,wheelStage:!0,beforeRender:!0,afterRender:!0,kill:!0,upStage:!0,upEdge:!0,upNode:!0,enterStage:!0,leaveStage:!0,resize:!0,afterClear:!0,afterProcess:!0,beforeClear:!0,beforeProcess:!0,moveBody:!0}),EC=Cf({click:!0,rightClick:!0,doubleClick:!0,mouseup:!0,mousedown:!0,mousemove:!0,mousemovebody:!0,mouseleave:!0,mouseenter:!0,wheel:!0}),wC=Cf({touchup:!0,touchdown:!0,touchmove:!0,touchmovebody:!0,tap:!0,doubletap:!0}),xC=Cf({updated:!0});function i3(){const e=br(),t=o3(),[n,r]=k.useState({});return k.useEffect(()=>{if(!e||!n)return;const a=n,i=Object.keys(a);return i.forEach(l=>{const u=a[l];SC.has(l)&&e.on(l,u),EC.has(l)&&e.getMouseCaptor().on(l,u),wC.has(l)&&e.getTouchCaptor().on(l,u),xC.has(l)&&e.getCamera().on(l,u)}),()=>{e&&i.forEach(l=>{const u=a[l];SC.has(l)&&e.off(l,u),EC.has(l)&&e.getMouseCaptor().off(l,u),wC.has(l)&&e.getTouchCaptor().off(l,u),xC.has(l)&&e.getCamera().off(l,u)})}},[e,n,t]),r}function dZ(){const e=br();return k.useCallback((t,n=!0)=>{e&&t&&(n&&e.getGraph().order>0&&e.getGraph().clear(),e.getGraph().import(t),e.refresh())},[e])}function wu(e,t){if(e===t)return!0;if(typeof e=="object"&&e!=null&&typeof t=="object"&&t!=null){if(Object.keys(e).length!=Object.keys(t).length)return!1;for(const n in e)if(!Object.hasOwn(t,n)||!wu(e[n],t[n]))return!1;return!0}return!1}function l3(e){const t=br(),[n,r]=k.useState(e||{});k.useEffect(()=>{r(f=>wu(f,e||{})?f:e||{})},[e]);const a=k.useCallback(f=>{t.getCamera().animatedZoom(Object.assign(Object.assign({},n),f))},[t,n]),i=k.useCallback(f=>{t.getCamera().animatedUnzoom(Object.assign(Object.assign({},n),f))},[t,n]),l=k.useCallback(f=>{t.getCamera().animatedReset(Object.assign(Object.assign({},n),f))},[t,n]),u=k.useCallback((f,p)=>{t.getCamera().animate(f,Object.assign(Object.assign({},n),p))},[t,n]),c=k.useCallback((f,p)=>{const g=t.getNodeDisplayData(f);g?t.getCamera().animate(g,Object.assign(Object.assign({},n),p)):console.warn(`Node ${f} not found`)},[t,n]);return{zoomIn:a,zoomOut:i,reset:l,goto:u,gotoNode:c}}function fZ(e){const t=y0(),[n,r]=k.useState(!1),[a,i]=k.useState(t.container),l=k.useCallback(()=>r(u=>!u),[]);return k.useEffect(()=>(document.addEventListener("fullscreenchange",l),()=>document.removeEventListener("fullscreenchange",l)),[l]),k.useEffect(()=>{i(t.container)},[e,t.container]),{toggle:k.useCallback(()=>{var u;u=a,document.fullscreenElement!==u?u.requestFullscreen():document.exitFullscreen&&document.exitFullscreen()},[a]),isFullScreen:n}}const pZ=k.forwardRef(({graph:e,id:t,className:n,style:r,settings:a={},children:i},l)=>{const u=k.useRef(null),c=k.useRef(null),f={className:`react-sigma ${n||""}`,id:t,style:r},[p,g]=k.useState(null),[b,m]=k.useState(a);k.useEffect(()=>{m(A=>wu(A,a)?A:a)},[a]),k.useEffect(()=>{g(A=>{let R=null;if(c.current!==null){let x=new Tt;e&&(x=typeof e=="function"?new e:e);let T=null;A&&(T=A.getCamera().getState(),A.kill()),R=new uZ(x,c.current,b),T&&R.getCamera().setState(T)}return R})},[c,e,b]),k.useImperativeHandle(l,()=>p,[p]);const S=k.useMemo(()=>p&&u.current?{sigma:p,container:u.current}:null,[p,u]),v=S!==null?ye.createElement(cZ,{value:S},i):null;return ye.createElement("div",Object.assign({},f,{ref:u}),ye.createElement("div",{className:"sigma-container",ref:c}),v)});var gZ=`
precision mediump float;

varying vec4 v_color;
varying float v_border;

const float radius = 0.5;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  vec2 m = gl_PointCoord - vec2(0.5, 0.5);
  float dist = radius - length(m);

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > v_border)
    gl_FragColor = v_color;
  else
    gl_FragColor = transparent;

  #else
  float t = 0.0;
  if (dist > v_border)
    t = 1.0;
  else if (dist > 0.0)
    t = dist / v_border;

  gl_FragColor = mix(transparent, v_color, t);
  #endif
}
`,hZ=gZ,mZ=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_position;
attribute float a_size;

uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform mat3 u_matrix;

varying vec4 v_color;
varying float v_border;

const float bias = 255.0 / 254.0;

void main() {
  gl_Position = vec4(
    (u_matrix * vec3(a_position, 1)).xy,
    0,
    1
  );

  // Multiply the point size twice:
  //  - x SCALING_RATIO to correct the canvas scaling
  //  - x 2 to correct the formulae
  gl_PointSize = a_size / u_sizeRatio * u_pixelRatio * 2.0;

  v_border = (0.5 / a_size) * u_sizeRatio;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,bZ=mZ,s3=WebGLRenderingContext,kC=s3.UNSIGNED_BYTE,AC=s3.FLOAT,yZ=["u_sizeRatio","u_pixelRatio","u_matrix"],vZ=function(e){function t(){return on(this,t),Bn(this,t,arguments)}return Un(t,e),ln(t,[{key:"getDefinition",value:function(){return{VERTICES:1,VERTEX_SHADER_SOURCE:bZ,FRAGMENT_SHADER_SOURCE:hZ,METHOD:WebGLRenderingContext.POINTS,UNIFORMS:yZ,ATTRIBUTES:[{name:"a_position",size:2,type:AC},{name:"a_size",size:1,type:AC},{name:"a_color",size:4,type:kC,normalized:!0},{name:"a_id",size:4,type:kC,normalized:!0}]}}},{key:"processVisibleItem",value:function(r,a,i){var l=this.array;l[a++]=i.x,l[a++]=i.y,l[a++]=i.size,l[a++]=Qr(i.color),l[a++]=r}},{key:"setUniforms",value:function(r,a){var i=r.sizeRatio,l=r.pixelRatio,u=r.matrix,c=a.gl,f=a.uniformLocations,p=f.u_sizeRatio,g=f.u_pixelRatio,b=f.u_matrix;c.uniform1f(g,l),c.uniform1f(p,i),c.uniformMatrix3fv(b,!1,u)}}])}(g0),SZ=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute vec2 a_normal;
attribute float a_normalCoef;
attribute vec2 a_positionStart;
attribute vec2 a_positionEnd;
attribute float a_positionCoef;
attribute float a_sourceRadius;
attribute float a_targetRadius;
attribute float a_sourceRadiusCoef;
attribute float a_targetRadiusCoef;

uniform mat3 u_matrix;
uniform float u_zoomRatio;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform float u_correctionRatio;
uniform float u_minEdgeThickness;
uniform float u_lengthToThicknessRatio;
uniform float u_feather;

varying vec4 v_color;
varying vec2 v_normal;
varying float v_thickness;
varying float v_feather;

const float bias = 255.0 / 254.0;

void main() {
  float minThickness = u_minEdgeThickness;

  vec2 normal = a_normal * a_normalCoef;
  vec2 position = a_positionStart * (1.0 - a_positionCoef) + a_positionEnd * a_positionCoef;

  float normalLength = length(normal);
  vec2 unitNormal = normal / normalLength;

  // These first computations are taken from edge.vert.glsl. Please read it to
  // get better comments on what's happening:
  float pixelsThickness = max(normalLength, minThickness * u_sizeRatio);
  float webGLThickness = pixelsThickness * u_correctionRatio / u_sizeRatio;

  // Here, we move the point to leave space for the arrow heads:
  // Source arrow head
  float sourceRadius = a_sourceRadius * a_sourceRadiusCoef;
  float sourceDirection = sign(sourceRadius);
  float webGLSourceRadius = sourceDirection * sourceRadius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLSourceArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  vec2 sourceCompensationVector =
    vec2(-sourceDirection * unitNormal.y, sourceDirection * unitNormal.x)
    * (webGLSourceRadius + webGLSourceArrowHeadLength);
    
  // Target arrow head
  float targetRadius = a_targetRadius * a_targetRadiusCoef;
  float targetDirection = sign(targetRadius);
  float webGLTargetRadius = targetDirection * targetRadius * 2.0 * u_correctionRatio / u_sizeRatio;
  float webGLTargetArrowHeadLength = webGLThickness * u_lengthToThicknessRatio * 2.0;
  vec2 targetCompensationVector =
  vec2(-targetDirection * unitNormal.y, targetDirection * unitNormal.x)
    * (webGLTargetRadius + webGLTargetArrowHeadLength);

  // Here is the proper position of the vertex
  gl_Position = vec4((u_matrix * vec3(position + unitNormal * webGLThickness + sourceCompensationVector + targetCompensationVector, 1)).xy, 0, 1);

  v_thickness = webGLThickness / u_zoomRatio;

  v_normal = unitNormal;

  v_feather = u_feather * u_correctionRatio / u_zoomRatio / u_pixelRatio * 2.0;

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`,EZ=SZ,u3=WebGLRenderingContext,TC=u3.UNSIGNED_BYTE,wa=u3.FLOAT,wZ=["u_matrix","u_zoomRatio","u_sizeRatio","u_correctionRatio","u_pixelRatio","u_feather","u_minEdgeThickness","u_lengthToThicknessRatio"],xZ={lengthToThicknessRatio:Eu.lengthToThicknessRatio};function c3(e){var t=Be(Be({},xZ),{});return function(n){function r(){return on(this,r),Bn(this,r,arguments)}return Un(r,n),ln(r,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:EZ,FRAGMENT_SHADER_SOURCE:h0,METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:wZ,ATTRIBUTES:[{name:"a_positionStart",size:2,type:wa},{name:"a_positionEnd",size:2,type:wa},{name:"a_normal",size:2,type:wa},{name:"a_color",size:4,type:TC,normalized:!0},{name:"a_id",size:4,type:TC,normalized:!0},{name:"a_sourceRadius",size:1,type:wa},{name:"a_targetRadius",size:1,type:wa}],CONSTANT_ATTRIBUTES:[{name:"a_positionCoef",size:1,type:wa},{name:"a_normalCoef",size:1,type:wa},{name:"a_sourceRadiusCoef",size:1,type:wa},{name:"a_targetRadiusCoef",size:1,type:wa}],CONSTANT_DATA:[[0,1,-1,0],[0,-1,1,0],[1,1,0,1],[1,1,0,1],[0,-1,1,0],[1,-1,0,-1]]}}},{key:"processVisibleItem",value:function(i,l,u,c,f){var p=f.size||1,g=u.x,b=u.y,m=c.x,S=c.y,v=Qr(f.color),A=m-g,R=S-b,x=u.size||1,T=c.size||1,C=A*A+R*R,N=0,_=0;C&&(C=1/Math.sqrt(C),N=-R*C*p,_=A*C*p);var O=this.array;O[l++]=g,O[l++]=b,O[l++]=m,O[l++]=S,O[l++]=N,O[l++]=_,O[l++]=v,O[l++]=i,O[l++]=x,O[l++]=T}},{key:"setUniforms",value:function(i,l){var u=l.gl,c=l.uniformLocations,f=c.u_matrix,p=c.u_zoomRatio,g=c.u_feather,b=c.u_pixelRatio,m=c.u_correctionRatio,S=c.u_sizeRatio,v=c.u_minEdgeThickness,A=c.u_lengthToThicknessRatio;u.uniformMatrix3fv(f,!1,i.matrix),u.uniform1f(p,i.zoomRatio),u.uniform1f(S,i.sizeRatio),u.uniform1f(m,i.correctionRatio),u.uniform1f(b,i.pixelRatio),u.uniform1f(g,i.antiAliasingFeather),u.uniform1f(v,i.minEdgeThickness),u.uniform1f(A,t.lengthToThicknessRatio)}}])}(vu)}c3();function kZ(e){return VU([c3(),Pd(e),Pd(Be(Be({},e),{},{extremity:"source"}))])}kZ();function AZ(e){if(Array.isArray(e))return e}function TZ(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r,a,i,l,u=[],c=!0,f=!1;try{if(i=(n=n.call(e)).next,t!==0)for(;!(c=(r=i.call(n)).done)&&(u.push(r.value),u.length!==t);c=!0);}catch(p){f=!0,a=p}finally{try{if(!c&&n.return!=null&&(l=n.return(),Object(l)!==l))return}finally{if(f)throw a}}return u}}function Px(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function d3(e,t){if(e){if(typeof e=="string")return Px(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Px(e,t):void 0}}function _Z(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function RZ(e,t){return AZ(e)||TZ(e,t)||d3(e,t)||_Z()}function CZ(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function NZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function f3(e){var t=NZ(e,"string");return typeof t=="symbol"?t:t+""}function OZ(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,f3(r.key),r)}}function DZ(e,t,n){return t&&OZ(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e}function Bd(e){return Bd=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},Bd(e)}function p3(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(p3=function(){return!!e})()}function Bx(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function IZ(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return Bx(e)}function LZ(e,t,n){return t=Bd(t),IZ(e,p3()?Reflect.construct(t,n||[],Bd(e).constructor):t.apply(e,n))}function Ux(e,t){return Ux=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},Ux(e,t)}function MZ(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&Ux(e,t)}function al(e,t,n){return(t=f3(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function FZ(e){if(Array.isArray(e))return Px(e)}function zZ(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function PZ(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Ih(e){return FZ(e)||zZ(e)||d3(e)||PZ()}function _C(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function RC(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?_C(Object(n),!0).forEach(function(r){al(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):_C(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}var BZ="relative",UZ={drawLabel:void 0,drawHover:void 0,borders:[{size:{value:.1},color:{attribute:"borderColor"}},{size:{fill:!0},color:{attribute:"color"}}]},jZ="#000000";function GZ(e){var t=e.borders,n=rC(t.filter(function(a){var i=a.size;return"fill"in i}).length),r=`
precision highp float;

varying vec2 v_diffVector;
varying float v_radius;

#ifdef PICKING_MODE
varying vec4 v_color;
#else
// For normal mode, we use the border colors defined in the program:
`.concat(t.flatMap(function(a,i){var l=a.size;return"attribute"in l?["varying float v_borderSize_".concat(i+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(a,i){var l=a.color;return"attribute"in l?["varying vec4 v_borderColor_".concat(i+1,";")]:"value"in l?["uniform vec4 u_borderColor_".concat(i+1,";")]:[]}).join(`
`),`
#endif

uniform float u_correctionRatio;

const float bias = 255.0 / 254.0;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float dist = length(v_diffVector);
  float aaBorder = 2.0 * u_correctionRatio;
  float v_borderSize_0 = v_radius;
  vec4 v_borderColor_0 = transparent;

  // No antialiasing for picking mode:
  #ifdef PICKING_MODE
  if (dist > v_radius)
    gl_FragColor = transparent;
  else {
    gl_FragColor = v_color;
    gl_FragColor.a *= bias;
  }
  #else
  // Sizes:
`).concat(t.flatMap(function(a,i){var l=a.size;if("fill"in l)return[];l=l;var u="attribute"in l?"v_borderSize_".concat(i+1):rC(l.value),c=(l.mode||BZ)==="pixels"?"u_correctionRatio":"v_radius";return["  float borderSize_".concat(i+1," = ").concat(c," * ").concat(u,";")]}).join(`
`),`
  // Now, let's split the remaining space between "fill" borders:
  float fillBorderSize = (v_radius - (`).concat(t.flatMap(function(a,i){var l=a.size;return"fill"in l?[]:["borderSize_".concat(i+1)]}).join(" + "),") ) / ").concat(n,`;
`).concat(t.flatMap(function(a,i){var l=a.size;return"fill"in l?["  float borderSize_".concat(i+1," = fillBorderSize;")]:[]}).join(`
`),`

  // Finally, normalize all border sizes, to start from the full size and to end with the smallest:
  float adjustedBorderSize_0 = v_radius;
`).concat(t.map(function(a,i){return"  float adjustedBorderSize_".concat(i+1," = adjustedBorderSize_").concat(i," - borderSize_").concat(i+1,";")}).join(`
`),`

  // Colors:
  vec4 borderColor_0 = transparent;
`).concat(t.map(function(a,i){var l=a.color,u=[];return"attribute"in l?u.push("  vec4 borderColor_".concat(i+1," = v_borderColor_").concat(i+1,";")):"transparent"in l?u.push("  vec4 borderColor_".concat(i+1," = vec4(0.0, 0.0, 0.0, 0.0);")):u.push("  vec4 borderColor_".concat(i+1," = u_borderColor_").concat(i+1,";")),u.push("  borderColor_".concat(i+1,".a *= bias;")),u.push("  if (borderSize_".concat(i+1," <= 1.0 * u_correctionRatio) { borderColor_").concat(i+1," = borderColor_").concat(i,"; }")),u.join(`
`)}).join(`
`),`
  if (dist > adjustedBorderSize_0) {
    gl_FragColor = borderColor_0;
  } else `).concat(t.map(function(a,i){return"if (dist > adjustedBorderSize_".concat(i,` - aaBorder) {
    gl_FragColor = mix(borderColor_`).concat(i+1,", borderColor_").concat(i,", (dist - adjustedBorderSize_").concat(i,` + aaBorder) / aaBorder);
  } else if (dist > adjustedBorderSize_`).concat(i+1,`) {
    gl_FragColor = borderColor_`).concat(i+1,`;
  } else `)}).join(""),` { /* Nothing to add here */ }
  #endif
}
`);return r}function HZ(e){var t=e.borders,n=`
attribute vec2 a_position;
attribute float a_size;
attribute float a_angle;

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_correctionRatio;

varying vec2 v_diffVector;
varying float v_radius;

#ifdef PICKING_MODE
attribute vec4 a_id;
varying vec4 v_color;
#else
`.concat(t.flatMap(function(r,a){var i=r.size;return"attribute"in i?["attribute float a_borderSize_".concat(a+1,";"),"varying float v_borderSize_".concat(a+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(r,a){var i=r.color;return"attribute"in i?["attribute vec4 a_borderColor_".concat(a+1,";"),"varying vec4 v_borderColor_".concat(a+1,";")]:[]}).join(`
`),`
#endif

const float bias = 255.0 / 254.0;
const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main() {
  float size = a_size * u_correctionRatio / u_sizeRatio * 4.0;
  vec2 diffVector = size * vec2(cos(a_angle), sin(a_angle));
  vec2 position = a_position + diffVector;
  gl_Position = vec4(
    (u_matrix * vec3(position, 1)).xy,
    0,
    1
  );

  v_radius = size / 2.0;
  v_diffVector = diffVector;

  #ifdef PICKING_MODE
  v_color = a_id;
  #else
`).concat(t.flatMap(function(r,a){var i=r.size;return"attribute"in i?["  v_borderSize_".concat(a+1," = a_borderSize_").concat(a+1,";")]:[]}).join(`
`),`
`).concat(t.flatMap(function(r,a){var i=r.color;return"attribute"in i?["  v_borderColor_".concat(a+1," = a_borderColor_").concat(a+1,";")]:[]}).join(`
`),`
  #endif
}
`);return n}var g3=WebGLRenderingContext,CC=g3.UNSIGNED_BYTE,Qc=g3.FLOAT;function $Z(e){var t,n=RC(RC({},UZ),{}),r=n.borders,a=n.drawLabel,i=n.drawHover,l=["u_sizeRatio","u_correctionRatio","u_matrix"].concat(Ih(r.flatMap(function(u,c){var f=u.color;return"value"in f?["u_borderColor_".concat(c+1)]:[]})));return t=function(u){MZ(c,u);function c(){var f;CZ(this,c);for(var p=arguments.length,g=new Array(p),b=0;b<p;b++)g[b]=arguments[b];return f=LZ(this,c,[].concat(g)),al(Bx(f),"drawLabel",a),al(Bx(f),"drawHover",i),f}return DZ(c,[{key:"getDefinition",value:function(){return{VERTICES:3,VERTEX_SHADER_SOURCE:HZ(n),FRAGMENT_SHADER_SOURCE:GZ(n),METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:l,ATTRIBUTES:[{name:"a_position",size:2,type:Qc},{name:"a_id",size:4,type:CC,normalized:!0},{name:"a_size",size:1,type:Qc}].concat(Ih(r.flatMap(function(p,g){var b=p.color;return"attribute"in b?[{name:"a_borderColor_".concat(g+1),size:4,type:CC,normalized:!0}]:[]})),Ih(r.flatMap(function(p,g){var b=p.size;return"attribute"in b?[{name:"a_borderSize_".concat(g+1),size:1,type:Qc}]:[]}))),CONSTANT_ATTRIBUTES:[{name:"a_angle",size:1,type:Qc}],CONSTANT_DATA:[[c.ANGLE_1],[c.ANGLE_2],[c.ANGLE_3]]}}},{key:"processVisibleItem",value:function(p,g,b){var m=this.array;m[g++]=b.x,m[g++]=b.y,m[g++]=p,m[g++]=b.size,r.forEach(function(S){var v=S.color;"attribute"in v&&(m[g++]=Qr(b[v.attribute]||v.defaultValue||jZ))}),r.forEach(function(S){var v=S.size;"attribute"in v&&(m[g++]=b[v.attribute]||v.defaultValue)})}},{key:"setUniforms",value:function(p,g){var b=g.gl,m=g.uniformLocations,S=m.u_sizeRatio,v=m.u_correctionRatio,A=m.u_matrix;b.uniform1f(v,p.correctionRatio),b.uniform1f(S,p.sizeRatio),b.uniformMatrix3fv(A,!1,p.matrix),r.forEach(function(R,x){var T=R.color;if("value"in T){var C=m["u_borderColor_".concat(x+1)],N=QK(T.value),_=RZ(N,4),O=_[0],z=_[1],I=_[2],M=_[3];b.uniform4f(C,O/255,z/255,I/255,M/255)}})}}]),c}(g0),al(t,"ANGLE_1",0),al(t,"ANGLE_2",2*Math.PI/3),al(t,"ANGLE_3",4*Math.PI/3),t}var qZ=$Z();function VZ(e,t){if(typeof e!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function h3(e){var t=VZ(e,"string");return typeof t=="symbol"?t:t+""}function m3(e,t,n){return(t=h3(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function NC(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Ud(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?NC(Object(n),!0).forEach(function(r){m3(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):NC(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function WZ(e,t){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}function YZ(e,t){for(var n=0;n<t.length;n++){var r=t[n];r.enumerable=r.enumerable||!1,r.configurable=!0,"value"in r&&(r.writable=!0),Object.defineProperty(e,h3(r.key),r)}}function KZ(e,t,n){return t&&YZ(e.prototype,t),Object.defineProperty(e,"prototype",{writable:!1}),e}function jd(e){return jd=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(t){return t.__proto__||Object.getPrototypeOf(t)},jd(e)}function b3(){try{var e=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(b3=function(){return!!e})()}function y3(e){if(e===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return e}function XZ(e,t){if(t&&(typeof t=="object"||typeof t=="function"))return t;if(t!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return y3(e)}function ZZ(e,t,n){return t=jd(t),XZ(e,b3()?Reflect.construct(t,n||[],jd(e).constructor):t.apply(e,n))}function jx(e,t){return jx=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(n,r){return n.__proto__=r,n},jx(e,t)}function QZ(e,t){if(typeof t!="function"&&t!==null)throw new TypeError("Super expression must either be null or a function");e.prototype=Object.create(t&&t.prototype,{constructor:{value:e,writable:!0,configurable:!0}}),Object.defineProperty(e,"prototype",{writable:!1}),t&&jx(e,t)}function Gx(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function JZ(e){if(Array.isArray(e))return Gx(e)}function eQ(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function tQ(e,t){if(e){if(typeof e=="string")return Gx(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Gx(e,t):void 0}}function nQ(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Lh(e){return JZ(e)||eQ(e)||tQ(e)||nQ()}function v3(e,t,n,r){var a=Math.pow(1-e,2)*t.x+2*(1-e)*e*n.x+Math.pow(e,2)*r.x,i=Math.pow(1-e,2)*t.y+2*(1-e)*e*n.y+Math.pow(e,2)*r.y;return{x:a,y:i}}function rQ(e,t,n){for(var r=20,a=0,i=e,l=0;l<r;l++){var u=v3((l+1)/r,e,t,n);a+=Math.sqrt(Math.pow(i.x-u.x,2)+Math.pow(i.y-u.y,2)),i=u}return a}function aQ(e){var t=e.curvatureAttribute,n=e.defaultCurvature,r=e.keepLabelUpright,a=r===void 0?!0:r;return function(i,l,u,c,f){var p=f.edgeLabelSize,g=l[t]||n,b=f.edgeLabelFont,m=f.edgeLabelWeight,S=f.edgeLabelColor.attribute?l[f.edgeLabelColor.attribute]||f.edgeLabelColor.color||"#000":f.edgeLabelColor.color,v=l.label;if(v){i.fillStyle=S,i.font="".concat(m," ").concat(p,"px ").concat(b);var A=!a||u.x<c.x,R=A?u.x:c.x,x=A?u.y:c.y,T=A?c.x:u.x,C=A?c.y:u.y,N=(R+T)/2,_=(x+C)/2,O=T-R,z=C-x,I=Math.sqrt(Math.pow(O,2)+Math.pow(z,2)),M=A?1:-1,H=N+z*g*M,q=_-O*g*M,P=l.size*.7+5,W={x:q-x,y:-(H-R)},Z=Math.sqrt(Math.pow(W.x,2)+Math.pow(W.y,2)),j={x:C-q,y:-(T-H)},G=Math.sqrt(Math.pow(j.x,2)+Math.pow(j.y,2));R+=P*W.x/Z,x+=P*W.y/Z,T+=P*j.x/G,C+=P*j.y/G,H+=P*z/I,q-=P*O/I;var B={x:H,y:q},X={x:R,y:x},D={x:T,y:C},V=rQ(X,B,D);if(!(V<u.size+c.size)){var U=i.measureText(v).width,L=V-u.size-c.size;if(U>L){var Y="…";for(v=v+Y,U=i.measureText(v).width;U>L&&v.length>1;)v=v.slice(0,-2)+Y,U=i.measureText(v).width;if(v.length<4)return}for(var Q={},se=0,re=v.length;se<re;se++){var le=v[se];Q[le]||(Q[le]=i.measureText(le).width*(1+g*.35))}for(var Ae=.5-U/V/2,ae=0,we=v.length;ae<we;ae++){var xe=v[ae],Ie=v3(Ae,X,B,D),Ce=2*(1-Ae)*(H-R)+2*Ae*(T-H),Ee=2*(1-Ae)*(q-x)+2*Ae*(C-q),J=Math.atan2(Ee,Ce);i.save(),i.translate(Ie.x,Ie.y),i.rotate(J),i.fillText(xe,0,0),i.restore(),Ae+=Q[xe]/V}}}}}function oQ(e){var t=e.arrowHead,n=(t==null?void 0:t.extremity)==="target"||(t==null?void 0:t.extremity)==="both",r=(t==null?void 0:t.extremity)==="source"||(t==null?void 0:t.extremity)==="both",a=`
precision highp float;

varying vec4 v_color;
varying float v_thickness;
varying float v_feather;
varying vec2 v_cpA;
varying vec2 v_cpB;
varying vec2 v_cpC;
`.concat(n?`
varying float v_targetSize;
varying vec2 v_targetPoint;`:"",`
`).concat(r?`
varying float v_sourceSize;
varying vec2 v_sourcePoint;`:"",`
`).concat(t?`
uniform float u_lengthToThicknessRatio;
uniform float u_widenessToThicknessRatio;`:"",`

float det(vec2 a, vec2 b) {
  return a.x * b.y - b.x * a.y;
}

vec2 getDistanceVector(vec2 b0, vec2 b1, vec2 b2) {
  float a = det(b0, b2), b = 2.0 * det(b1, b0), d = 2.0 * det(b2, b1);
  float f = b * d - a * a;
  vec2 d21 = b2 - b1, d10 = b1 - b0, d20 = b2 - b0;
  vec2 gf = 2.0 * (b * d21 + d * d10 + a * d20);
  gf = vec2(gf.y, -gf.x);
  vec2 pp = -f * gf / dot(gf, gf);
  vec2 d0p = b0 - pp;
  float ap = det(d0p, d20), bp = 2.0 * det(d10, d0p);
  float t = clamp((ap + bp) / (2.0 * a + b + d), 0.0, 1.0);
  return mix(mix(b0, b1, t), mix(b1, b2, t), t);
}

float distToQuadraticBezierCurve(vec2 p, vec2 b0, vec2 b1, vec2 b2) {
  return length(getDistanceVector(b0 - p, b1 - p, b2 - p));
}

const vec4 transparent = vec4(0.0, 0.0, 0.0, 0.0);

void main(void) {
  float dist = distToQuadraticBezierCurve(gl_FragCoord.xy, v_cpA, v_cpB, v_cpC);
  float thickness = v_thickness;
`).concat(n?`
  float distToTarget = length(gl_FragCoord.xy - v_targetPoint);
  float targetArrowLength = v_targetSize + thickness * u_lengthToThicknessRatio;
  if (distToTarget < targetArrowLength) {
    thickness = (distToTarget - v_targetSize) / (targetArrowLength - v_targetSize) * u_widenessToThicknessRatio * thickness;
  }`:"",`
`).concat(r?`
  float distToSource = length(gl_FragCoord.xy - v_sourcePoint);
  float sourceArrowLength = v_sourceSize + thickness * u_lengthToThicknessRatio;
  if (distToSource < sourceArrowLength) {
    thickness = (distToSource - v_sourceSize) / (sourceArrowLength - v_sourceSize) * u_widenessToThicknessRatio * thickness;
  }`:"",`

  float halfThickness = thickness / 2.0;
  if (dist < halfThickness) {
    #ifdef PICKING_MODE
    gl_FragColor = v_color;
    #else
    float t = smoothstep(
      halfThickness - v_feather,
      halfThickness,
      dist
    );

    gl_FragColor = mix(v_color, transparent, t);
    #endif
  } else {
    gl_FragColor = transparent;
  }
}
`);return a}function iQ(e){var t=e.arrowHead,n=(t==null?void 0:t.extremity)==="target"||(t==null?void 0:t.extremity)==="both",r=(t==null?void 0:t.extremity)==="source"||(t==null?void 0:t.extremity)==="both",a=`
attribute vec4 a_id;
attribute vec4 a_color;
attribute float a_direction;
attribute float a_thickness;
attribute vec2 a_source;
attribute vec2 a_target;
attribute float a_current;
attribute float a_curvature;
`.concat(n?`attribute float a_targetSize;
`:"",`
`).concat(r?`attribute float a_sourceSize;
`:"",`

uniform mat3 u_matrix;
uniform float u_sizeRatio;
uniform float u_pixelRatio;
uniform vec2 u_dimensions;
uniform float u_minEdgeThickness;
uniform float u_feather;

varying vec4 v_color;
varying float v_thickness;
varying float v_feather;
varying vec2 v_cpA;
varying vec2 v_cpB;
varying vec2 v_cpC;
`).concat(n?`
varying float v_targetSize;
varying vec2 v_targetPoint;`:"",`
`).concat(r?`
varying float v_sourceSize;
varying vec2 v_sourcePoint;`:"",`
`).concat(t?`
uniform float u_widenessToThicknessRatio;`:"",`

const float bias = 255.0 / 254.0;
const float epsilon = 0.7;

vec2 clipspaceToViewport(vec2 pos, vec2 dimensions) {
  return vec2(
    (pos.x + 1.0) * dimensions.x / 2.0,
    (pos.y + 1.0) * dimensions.y / 2.0
  );
}

vec2 viewportToClipspace(vec2 pos, vec2 dimensions) {
  return vec2(
    pos.x / dimensions.x * 2.0 - 1.0,
    pos.y / dimensions.y * 2.0 - 1.0
  );
}

void main() {
  float minThickness = u_minEdgeThickness;

  // Selecting the correct position
  // Branchless "position = a_source if a_current == 1.0 else a_target"
  vec2 position = a_source * max(0.0, a_current) + a_target * max(0.0, 1.0 - a_current);
  position = (u_matrix * vec3(position, 1)).xy;

  vec2 source = (u_matrix * vec3(a_source, 1)).xy;
  vec2 target = (u_matrix * vec3(a_target, 1)).xy;

  vec2 viewportPosition = clipspaceToViewport(position, u_dimensions);
  vec2 viewportSource = clipspaceToViewport(source, u_dimensions);
  vec2 viewportTarget = clipspaceToViewport(target, u_dimensions);

  vec2 delta = viewportTarget.xy - viewportSource.xy;
  float len = length(delta);
  vec2 normal = vec2(-delta.y, delta.x) * a_direction;
  vec2 unitNormal = normal / len;
  float boundingBoxThickness = len * a_curvature;

  float curveThickness = max(minThickness, a_thickness / u_sizeRatio);
  v_thickness = curveThickness * u_pixelRatio;
  v_feather = u_feather;

  v_cpA = viewportSource;
  v_cpB = 0.5 * (viewportSource + viewportTarget) + unitNormal * a_direction * boundingBoxThickness;
  v_cpC = viewportTarget;

  vec2 viewportOffsetPosition = (
    viewportPosition +
    unitNormal * (boundingBoxThickness / 2.0 + sign(boundingBoxThickness) * (`).concat(t?"curveThickness * u_widenessToThicknessRatio":"curveThickness",` + epsilon)) *
    max(0.0, a_direction) // NOTE: cutting the bounding box in half to avoid overdraw
  );

  position = viewportToClipspace(viewportOffsetPosition, u_dimensions);
  gl_Position = vec4(position, 0, 1);
    
`).concat(n?`
  v_targetSize = a_targetSize * u_pixelRatio / u_sizeRatio;
  v_targetPoint = viewportTarget;
`:"",`
`).concat(r?`
  v_sourceSize = a_sourceSize * u_pixelRatio / u_sizeRatio;
  v_sourcePoint = viewportSource;
`:"",`

  #ifdef PICKING_MODE
  // For picking mode, we use the ID as the color:
  v_color = a_id;
  #else
  // For normal mode, we use the color:
  v_color = a_color;
  #endif

  v_color.a *= bias;
}
`);return a}var S3=.25,lQ={arrowHead:null,curvatureAttribute:"curvature",defaultCurvature:S3},E3=WebGLRenderingContext,OC=E3.UNSIGNED_BYTE,lo=E3.FLOAT;function v0(e){var t=Ud(Ud({},lQ),e||{}),n=t,r=n.arrowHead,a=n.curvatureAttribute,i=n.drawLabel,l=(r==null?void 0:r.extremity)==="target"||(r==null?void 0:r.extremity)==="both",u=(r==null?void 0:r.extremity)==="source"||(r==null?void 0:r.extremity)==="both",c=["u_matrix","u_sizeRatio","u_dimensions","u_pixelRatio","u_feather","u_minEdgeThickness"].concat(Lh(r?["u_lengthToThicknessRatio","u_widenessToThicknessRatio"]:[]));return function(f){QZ(p,f);function p(){var g;WZ(this,p);for(var b=arguments.length,m=new Array(b),S=0;S<b;S++)m[S]=arguments[S];return g=ZZ(this,p,[].concat(m)),m3(y3(g),"drawLabel",i||aQ(t)),g}return KZ(p,[{key:"getDefinition",value:function(){return{VERTICES:6,VERTEX_SHADER_SOURCE:iQ(t),FRAGMENT_SHADER_SOURCE:oQ(t),METHOD:WebGLRenderingContext.TRIANGLES,UNIFORMS:c,ATTRIBUTES:[{name:"a_source",size:2,type:lo},{name:"a_target",size:2,type:lo}].concat(Lh(l?[{name:"a_targetSize",size:1,type:lo}]:[]),Lh(u?[{name:"a_sourceSize",size:1,type:lo}]:[]),[{name:"a_thickness",size:1,type:lo},{name:"a_curvature",size:1,type:lo},{name:"a_color",size:4,type:OC,normalized:!0},{name:"a_id",size:4,type:OC,normalized:!0}]),CONSTANT_ATTRIBUTES:[{name:"a_current",size:1,type:lo},{name:"a_direction",size:1,type:lo}],CONSTANT_DATA:[[0,1],[0,-1],[1,1],[0,-1],[1,1],[1,-1]]}}},{key:"processVisibleItem",value:function(b,m,S,v,A){var R,x=A.size||1,T=S.x,C=S.y,N=v.x,_=v.y,O=Qr(A.color),z=(R=A[a])!==null&&R!==void 0?R:S3,I=this.array;I[m++]=T,I[m++]=C,I[m++]=N,I[m++]=_,l&&(I[m++]=v.size),u&&(I[m++]=S.size),I[m++]=x,I[m++]=z,I[m++]=O,I[m++]=b}},{key:"setUniforms",value:function(b,m){var S=m.gl,v=m.uniformLocations,A=v.u_matrix,R=v.u_pixelRatio,x=v.u_feather,T=v.u_sizeRatio,C=v.u_dimensions,N=v.u_minEdgeThickness;if(S.uniformMatrix3fv(A,!1,b.matrix),S.uniform1f(R,b.pixelRatio),S.uniform1f(T,b.sizeRatio),S.uniform1f(x,b.antiAliasingFeather),S.uniform2f(C,b.width*b.pixelRatio,b.height*b.pixelRatio),S.uniform1f(N,b.minEdgeThickness),r){var _=v.u_lengthToThicknessRatio,O=v.u_widenessToThicknessRatio;S.uniform1f(_,r.lengthToThicknessRatio),S.uniform1f(O,r.widenessToThicknessRatio)}}}]),p}(vu)}var sQ=v0(),uQ=v0({arrowHead:Eu});v0({arrowHead:Ud(Ud({},Eu),{},{extremity:"both"})});class cQ{constructor(){Ea(this,"nodes",[]);Ea(this,"edges",[]);Ea(this,"nodeIdMap",{});Ea(this,"edgeIdMap",{});Ea(this,"edgeDynamicIdMap",{});Ea(this,"getNode",t=>{const n=this.nodeIdMap[t];if(n!==void 0)return this.nodes[n]});Ea(this,"getEdge",(t,n=!0)=>{const r=n?this.edgeDynamicIdMap[t]:this.edgeIdMap[t];if(r!==void 0)return this.edges[r]});Ea(this,"buildDynamicMap",()=>{this.edgeDynamicIdMap={};for(let t=0;t<this.edges.length;t++){const n=this.edges[t];this.edgeDynamicIdMap[n.dynamicId]=t}})}}const dQ=xk()(e=>({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null,moveToSelectedNode:!1,rawGraph:null,sigmaGraph:null,setSelectedNode:(t,n)=>e({selectedNode:t,moveToSelectedNode:n}),setFocusedNode:t=>e({focusedNode:t}),setSelectedEdge:t=>e({selectedEdge:t}),setFocusedEdge:t=>e({focusedEdge:t}),clearSelection:()=>e({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null}),reset:()=>e({selectedNode:null,focusedNode:null,selectedEdge:null,focusedEdge:null,rawGraph:null,sigmaGraph:null,moveToSelectedNode:!1}),setRawGraph:t=>e({rawGraph:t}),setSigmaGraph:t=>e({sigmaGraph:t}),setMoveToSelectedNode:t=>e({moveToSelectedNode:t})})),Et=Tk(dQ),fQ=({node:e,move:t})=>{const n=br(),{gotoNode:r}=l3();return k.useEffect(()=>{if(e)return n.getGraph().setNodeAttribute(e,"highlighted",!0),t&&(r(e),Et.getState().setMoveToSelectedNode(!1)),()=>{n.getGraph().setNodeAttribute(e,"highlighted",!1)}},[e,t,n,r]),null};function Ll(e,t){const n=br(),r=k.useRef(t);return wu(r.current,t)||(r.current=t),{positions:k.useCallback(()=>r.current?e(n.getGraph(),r.current):{},[n,r,e]),assign:k.useCallback(()=>{r.current&&e.assign(n.getGraph(),r.current)},[n,r,e])}}function S0(e,t){const n=br(),[r,a]=k.useState(!1),[i,l]=k.useState(null),u=k.useRef(t);return wu(u.current,t)||(u.current=t),k.useEffect(()=>{a(!1);let c=null;return u.current&&(c=new e(n.getGraph(),u.current)),l(c),()=>{c!==null&&c.kill()}},[n,u,l,a,e]),{stop:k.useCallback(()=>{i&&(i.stop(),a(!1))},[i,a]),start:k.useCallback(()=>{i&&(i.start(),a(!0))},[i,a]),kill:k.useCallback(()=>{i&&i.kill(),a(!1)},[i,a]),isRunning:r}}var Mh,DC;function xu(){if(DC)return Mh;DC=1;function e(n){return!n||typeof n!="object"||typeof n=="function"||Array.isArray(n)||n instanceof Set||n instanceof Map||n instanceof RegExp||n instanceof Date}function t(n,r){n=n||{};var a={};for(var i in r){var l=n[i],u=r[i];if(!e(u)){a[i]=t(l,u);continue}l===void 0?a[i]=u:a[i]=l}return a}return Mh=t,Mh}var Fh,IC;function pQ(){if(IC)return Fh;IC=1;function e(n){return function(r,a){return r+Math.floor(n()*(a-r+1))}}var t=e(Math.random);return t.createRandom=e,Fh=t,Fh}var zh,LC;function gQ(){if(LC)return zh;LC=1;var e=pQ().createRandom;function t(r){var a=e(r);return function(i){for(var l=i.length,u=l-1,c=-1;++c<l;){var f=a(c,u),p=i[f];i[f]=i[c],i[c]=p}}}var n=t(Math.random);return n.createShuffleInPlace=t,zh=n,zh}var Ph,MC;function hQ(){if(MC)return Ph;MC=1;var e=xu(),t=Jr(),n=gQ(),r={attributes:{x:"x",y:"y"},center:0,hierarchyAttributes:[],rng:Math.random,scale:1};function a(O,z,I,M,H){this.wrappedCircle=H||null,this.children={},this.countChildren=0,this.id=O||null,this.next=null,this.previous=null,this.x=z||null,this.y=I||null,H?this.r=1010101:this.r=M||999}a.prototype.hasChildren=function(){return this.countChildren>0},a.prototype.addChild=function(O,z){this.children[O]=z,++this.countChildren},a.prototype.getChild=function(O){if(!this.children.hasOwnProperty(O)){var z=new a;this.children[O]=z,++this.countChildren}return this.children[O]},a.prototype.applyPositionToChildren=function(){if(this.hasChildren()){var O=this;for(var z in O.children){var I=O.children[z];I.x+=O.x,I.y+=O.y,I.applyPositionToChildren()}}};function i(O,z,I){for(var M in z.children){var H=z.children[M];H.hasChildren()?i(O,H,I):I[H.id]={x:H.x,y:H.y}}}function l(O,z){var I=O.r-z.r,M=z.x-O.x,H=z.y-O.y;return I<0||I*I<M*M+H*H}function u(O,z){var I=O.r-z.r+1e-6,M=z.x-O.x,H=z.y-O.y;return I>0&&I*I>M*M+H*H}function c(O,z){for(var I=0;I<z.length;++I)if(!u(O,z[I]))return!1;return!0}function f(O){return new a(null,O.x,O.y,O.r)}function p(O,z){var I=O.x,M=O.y,H=O.r,q=z.x,P=z.y,W=z.r,Z=q-I,j=P-M,G=W-H,B=Math.sqrt(Z*Z+j*j);return new a(null,(I+q+Z/B*G)/2,(M+P+j/B*G)/2,(B+H+W)/2)}function g(O,z,I){var M=O.x,H=O.y,q=O.r,P=z.x,W=z.y,Z=z.r,j=I.x,G=I.y,B=I.r,X=M-P,D=M-j,V=H-W,U=H-G,L=Z-q,Y=B-q,Q=M*M+H*H-q*q,se=Q-P*P-W*W+Z*Z,re=Q-j*j-G*G+B*B,le=D*V-X*U,Ae=(V*re-U*se)/(le*2)-M,ae=(U*L-V*Y)/le,we=(D*se-X*re)/(le*2)-H,xe=(X*Y-D*L)/le,Ie=ae*ae+xe*xe-1,Ce=2*(q+Ae*ae+we*xe),Ee=Ae*Ae+we*we-q*q,J=-(Ie?(Ce+Math.sqrt(Ce*Ce-4*Ie*Ee))/(2*Ie):Ee/Ce);return new a(null,M+Ae+ae*J,H+we+xe*J,J)}function b(O){switch(O.length){case 1:return f(O[0]);case 2:return p(O[0],O[1]);case 3:return g(O[0],O[1],O[2]);default:throw new Error("graphology-layout/circlepack: Invalid basis length "+O.length)}}function m(O,z){var I,M;if(c(z,O))return[z];for(I=0;I<O.length;++I)if(l(z,O[I])&&c(p(O[I],z),O))return[O[I],z];for(I=0;I<O.length-1;++I)for(M=I+1;M<O.length;++M)if(l(p(O[I],O[M]),z)&&l(p(O[I],z),O[M])&&l(p(O[M],z),O[I])&&c(g(O[I],O[M],z),O))return[O[I],O[M],z];throw new Error("graphology-layout/circlepack: extendBasis failure !")}function S(O){var z=O.wrappedCircle,I=O.next.wrappedCircle,M=z.r+I.r,H=(z.x*I.r+I.x*z.r)/M,q=(z.y*I.r+I.y*z.r)/M;return H*H+q*q}function v(O,z){var I=0,M=O.slice(),H=O.length,q=[],P,W;for(z(M);I<H;)P=M[I],W&&u(W,P)?++I:(q=m(q,P),W=b(q),I=0);return W}function A(O,z,I){var M=O.x-z.x,H,q,P=O.y-z.y,W,Z,j=M*M+P*P;j?(q=z.r+I.r,q*=q,Z=O.r+I.r,Z*=Z,q>Z?(H=(j+Z-q)/(2*j),W=Math.sqrt(Math.max(0,Z/j-H*H)),I.x=O.x-H*M-W*P,I.y=O.y-H*P+W*M):(H=(j+q-Z)/(2*j),W=Math.sqrt(Math.max(0,q/j-H*H)),I.x=z.x+H*M-W*P,I.y=z.y+H*P+W*M)):(I.x=z.x+I.r,I.y=z.y)}function R(O,z){var I=O.r+z.r-1e-6,M=z.x-O.x,H=z.y-O.y;return I>0&&I*I>M*M+H*H}function x(O,z){var I=O.length;if(I===0)return 0;var M,H,q,P,W,Z,j,G,B,X;if(M=O[0],M.x=0,M.y=0,I<=1)return M.r;if(H=O[1],M.x=-H.r,H.x=M.r,H.y=0,I<=2)return M.r+H.r;q=O[2],A(H,M,q),M=new a(null,null,null,null,M),H=new a(null,null,null,null,H),q=new a(null,null,null,null,q),M.next=q.previous=H,H.next=M.previous=q,q.next=H.previous=M;e:for(Z=3;Z<I;++Z){q=O[Z],A(M.wrappedCircle,H.wrappedCircle,q),q=new a(null,null,null,null,q),j=H.next,G=M.previous,B=H.wrappedCircle.r,X=M.wrappedCircle.r;do if(B<=X){if(R(j.wrappedCircle,q.wrappedCircle)){H=j,M.next=H,H.previous=M,--Z;continue e}B+=j.wrappedCircle.r,j=j.next}else{if(R(G.wrappedCircle,q.wrappedCircle)){M=G,M.next=H,H.previous=M,--Z;continue e}X+=G.wrappedCircle.r,G=G.previous}while(j!==G.next);for(q.previous=M,q.next=H,M.next=H.previous=H=q,P=S(M);(q=q.next)!==H;)(W=S(q))<P&&(M=q,P=W);H=M.next}M=[H.wrappedCircle],q=H;for(var D=1e4;(q=q.next)!==H&&--D!==0;)M.push(q.wrappedCircle);for(q=v(M,z),Z=0;Z<I;++Z)M=O[Z],M.x-=q.x,M.y-=q.y;return q.r}function T(O,z){var I=0;if(O.hasChildren()){for(var M in O.children){var H=O.children[M];H.hasChildren()&&(H.r=T(H,z))}I=x(Object.values(O.children),z)}return I}function C(O,z){T(O,z);for(var I in O.children){var M=O.children[I];M.applyPositionToChildren()}}function N(O,z,I){if(!t(z))throw new Error("graphology-layout/circlepack: the given graph is not a valid graphology instance.");I=e(I,r);var M={},H={},q=z.nodes(),P=I.center,W=I.hierarchyAttributes,Z=n.createShuffleInPlace(I.rng),j=I.scale,G=new a;z.forEachNode(function(L,Y){var Q=Y.size?Y.size:1,se=new a(L,null,null,Q),re=G;W.forEach(function(le){var Ae=Y[le];re=re.getChild(Ae)}),re.addChild(L,se)}),C(G,Z),i(z,G,M);var B=q.length,X,D,V;for(V=0;V<B;V++){var U=q[V];X=P+j*M[U].x,D=P+j*M[U].y,H[U]={x:X,y:D},O&&(z.setNodeAttribute(U,I.attributes.x,X),z.setNodeAttribute(U,I.attributes.y,D))}return H}var _=N.bind(null,!1);return _.assign=N.bind(null,!0),Ph=_,Ph}var mQ=hQ();const bQ=an(mQ);function yQ(e={}){return Ll(bQ,e)}var Bh,FC;function vQ(){if(FC)return Bh;FC=1;var e=xu(),t=Jr(),n={dimensions:["x","y"],center:.5,scale:1};function r(i,l,u){if(!t(l))throw new Error("graphology-layout/random: the given graph is not a valid graphology instance.");u=e(u,n);var c=u.dimensions;if(!Array.isArray(c)||c.length!==2)throw new Error("graphology-layout/random: given dimensions are invalid.");var f=u.center,p=u.scale,g=Math.PI*2,b=(f-.5)*p,m=l.order,S=c[0],v=c[1];function A(T,C){return C[S]=p*Math.cos(T*g/m)+b,C[v]=p*Math.sin(T*g/m)+b,C}var R=0;if(!i){var x={};return l.forEachNode(function(T){x[T]=A(R++,{})}),x}l.updateEachNodeAttributes(function(T,C){return A(R++,C),C},{attributes:c})}var a=r.bind(null,!1);return a.assign=r.bind(null,!0),Bh=a,Bh}var SQ=vQ();const EQ=an(SQ);function wQ(e={}){return Ll(EQ,e)}var Gs={},zC;function E0(){if(zC)return Gs;zC=1;function e(r){return typeof r!="number"||isNaN(r)?1:r}function t(r,a){var i={},l=function(f){return typeof f>"u"?a:f};typeof a=="function"&&(l=a);var u=function(f){return l(f[r])},c=function(){return l(void 0)};return typeof r=="string"?(i.fromAttributes=u,i.fromGraph=function(f,p){return u(f.getNodeAttributes(p))},i.fromEntry=function(f,p){return u(p)}):typeof r=="function"?(i.fromAttributes=function(){throw new Error("graphology-utils/getters/createNodeValueGetter: irrelevant usage.")},i.fromGraph=function(f,p){return l(r(p,f.getNodeAttributes(p)))},i.fromEntry=function(f,p){return l(r(f,p))}):(i.fromAttributes=c,i.fromGraph=c,i.fromEntry=c),i}function n(r,a){var i={},l=function(f){return typeof f>"u"?a:f};typeof a=="function"&&(l=a);var u=function(f){return l(f[r])},c=function(){return l(void 0)};return typeof r=="string"?(i.fromAttributes=u,i.fromGraph=function(f,p){return u(f.getEdgeAttributes(p))},i.fromEntry=function(f,p){return u(p)},i.fromPartialEntry=i.fromEntry,i.fromMinimalEntry=i.fromEntry):typeof r=="function"?(i.fromAttributes=function(){throw new Error("graphology-utils/getters/createEdgeValueGetter: irrelevant usage.")},i.fromGraph=function(f,p){var g=f.extremities(p);return l(r(p,f.getEdgeAttributes(p),g[0],g[1],f.getNodeAttributes(g[0]),f.getNodeAttributes(g[1]),f.isUndirected(p)))},i.fromEntry=function(f,p,g,b,m,S,v){return l(r(f,p,g,b,m,S,v))},i.fromPartialEntry=function(f,p,g,b){return l(r(f,p,g,b))},i.fromMinimalEntry=function(f,p){return l(r(f,p))}):(i.fromAttributes=c,i.fromGraph=c,i.fromEntry=c,i.fromMinimalEntry=c),i}return Gs.createNodeValueGetter=t,Gs.createEdgeValueGetter=n,Gs.createEdgeWeightGetter=function(r){return n(r,e)},Gs}var Uh,PC;function w3(){if(PC)return Uh;PC=1;const{createNodeValueGetter:e,createEdgeValueGetter:t}=E0();return Uh=function(r,a,i){const{nodeXAttribute:l,nodeYAttribute:u}=i,{attraction:c,repulsion:f,gravity:p,inertia:g,maxMove:b}=i.settings;let{shouldSkipNode:m,shouldSkipEdge:S,isNodeFixed:v}=i;v=e(v),m=e(m,!1),S=t(S,!1);const A=r.filterNodes((T,C)=>!m.fromEntry(T,C)),R=A.length;for(let T=0;T<R;T++){const C=A[T],N=r.getNodeAttributes(C),_=a[C];_?a[C]={dx:_.dx*g,dy:_.dy*g,x:N[l]||0,y:N[u]||0}:a[C]={dx:0,dy:0,x:N[l]||0,y:N[u]||0}}if(f)for(let T=0;T<R;T++){const C=A[T],N=a[C];for(let _=T+1;_<R;_++){const O=A[_],z=a[O],I=z.x-N.x,M=z.y-N.y,H=Math.sqrt(I*I+M*M)||1,q=f/H*I,P=f/H*M;N.dx-=q,N.dy-=P,z.dx+=q,z.dy+=P}}if(c&&r.forEachEdge((T,C,N,_,O,z,I)=>{if(N===_||m.fromEntry(N,O)||m.fromEntry(_,z)||S.fromEntry(T,C,N,_,O,z,I))return;const M=a[N],H=a[_],q=H.x-M.x,P=H.y-M.y,W=Math.sqrt(q*q+P*P)||1,Z=c*W*q,j=c*W*P;M.dx+=Z,M.dy+=j,H.dx-=Z,H.dy-=j}),p)for(let T=0;T<R;T++){const C=A[T],N=a[C],{x:_,y:O}=N,z=Math.sqrt(_*_+O*O)||1;a[C].dx-=_*p*z,a[C].dy-=O*p*z}const x=!1;for(let T=0;T<R;T++){const C=A[T],N=a[C],_=Math.sqrt(N.dx*N.dx+N.dy*N.dy);_>b&&(N.dx*=b/_,N.dy*=b/_),v.fromGraph(r,C)?N.fixed=!0:(N.x+=N.dx,N.y+=N.dy,N.fixed=!1)}return{converged:x}},Uh}var Jc={},BC;function x3(){return BC||(BC=1,Jc.assignLayoutChanges=function(e,t,n){const{nodeXAttribute:r,nodeYAttribute:a}=n;e.updateEachNodeAttributes((i,l)=>{const u=t[i];return!u||u.fixed||(l[r]=u.x,l[a]=u.y),l},{attributes:["x","y"]})},Jc.collectLayoutChanges=function(e){const t={};for(const n in e){const r=e[n];t[n]={x:r.x,y:r.y}}return t}),Jc}var jh,UC;function k3(){return UC||(UC=1,jh={nodeXAttribute:"x",nodeYAttribute:"y",isNodeFixed:"fixed",shouldSkipNode:null,shouldSkipEdge:null,settings:{attraction:5e-4,repulsion:.1,gravity:1e-4,inertia:.6,maxMove:200}}),jh}var Gh,jC;function xQ(){if(jC)return Gh;jC=1;const e=Jr(),t=xu(),n=w3(),r=x3(),a=k3();function i(u,c,f){if(!e(c))throw new Error("graphology-layout-force: the given graph is not a valid graphology instance.");typeof f=="number"?f={maxIterations:f}:f=f||{};const p=f.maxIterations;if(f=t(f,a),typeof p!="number"||p<=0)throw new Error("graphology-layout-force: you should provide a positive number of maximum iterations.");const g={};let b=null,m;for(m=0;m<p&&(b=n(c,g,f),!b.converged);m++);if(u){r.assignLayoutChanges(c,g,f);return}return r.collectLayoutChanges(g)}const l=i.bind(null,!1);return l.assign=i.bind(null,!0),Gh=l,Gh}var kQ=xQ();const AQ=an(kQ);var Hh,GC;function TQ(){if(GC)return Hh;GC=1;const e=Jr(),t=xu(),n=w3(),r=x3(),a=k3();function i(l,u){if(!e(l))throw new Error("graphology-layout-force/worker: the given graph is not a valid graphology instance.");u=t(u,a),this.callbacks={},u.onConverged&&(this.callbacks.onConverged=u.onConverged),this.graph=l,this.params=u,this.nodeStates={},this.frameID=null,this.running=!1,this.killed=!1}return i.prototype.isRunning=function(){return this.running},i.prototype.runFrame=function(){let{converged:l}=n(this.graph,this.nodeStates,this.params);r.assignLayoutChanges(this.graph,this.nodeStates,this.params),l=!1,l?(this.callbacks.onConverged&&this.callbacks.onConverged(),this.stop()):this.frameID=window.requestAnimationFrame(()=>this.runFrame())},i.prototype.stop=function(){return this.running=!1,this.frameID!==null&&(window.cancelAnimationFrame(this.frameID),this.frameID=null),this},i.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-force/worker.start: layout was killed.");this.running||(this.running=!0,this.runFrame())},i.prototype.kill=function(){this.stop(),delete this.nodeStates,this.killed=!0},Hh=i,Hh}var _Q=TQ();const RQ=an(_Q);function CQ(e={maxIterations:100}){return Ll(AQ,e)}function NQ(e={}){return S0(RQ,e)}var $h,HC;function OQ(){if(HC)return $h;HC=1;var e=0,t=1,n=2,r=3,a=4,i=5,l=6,u=7,c=8,f=9,p=0,g=1,b=2,m=0,S=1,v=2,A=3,R=4,x=5,T=6,C=7,N=8,_=3,O=10,z=3,I=9,M=10;return $h=function(q,P,W){var Z,j,G,B,X,D,V,U,L,Y,Q=P.length,se=W.length,re=q.adjustSizes,le=q.barnesHutTheta*q.barnesHutTheta,Ae,ae,we,xe,Ie,Ce,Ee,J=[];for(G=0;G<Q;G+=O)P[G+a]=P[G+n],P[G+i]=P[G+r],P[G+n]=0,P[G+r]=0;if(q.outboundAttractionDistribution){for(Ae=0,G=0;G<Q;G+=O)Ae+=P[G+l];Ae/=Q/O}if(q.barnesHutOptimize){var fe=1/0,ke=-1/0,me=1/0,ve=-1/0,ie,ze,Pe;for(G=0;G<Q;G+=O)fe=Math.min(fe,P[G+e]),ke=Math.max(ke,P[G+e]),me=Math.min(me,P[G+t]),ve=Math.max(ve,P[G+t]);var he=ke-fe,Ne=ve-me;for(he>Ne?(me-=(he-Ne)/2,ve=me+he):(fe-=(Ne-he)/2,ke=fe+Ne),J[0+m]=-1,J[0+S]=(fe+ke)/2,J[0+v]=(me+ve)/2,J[0+A]=Math.max(ke-fe,ve-me),J[0+R]=-1,J[0+x]=-1,J[0+T]=0,J[0+C]=0,J[0+N]=0,Z=1,G=0;G<Q;G+=O)for(j=0,Pe=_;;)if(J[j+x]>=0){P[G+e]<J[j+S]?P[G+t]<J[j+v]?ie=J[j+x]:ie=J[j+x]+I:P[G+t]<J[j+v]?ie=J[j+x]+I*2:ie=J[j+x]+I*3,J[j+C]=(J[j+C]*J[j+T]+P[G+e]*P[G+l])/(J[j+T]+P[G+l]),J[j+N]=(J[j+N]*J[j+T]+P[G+t]*P[G+l])/(J[j+T]+P[G+l]),J[j+T]+=P[G+l],j=ie;continue}else if(J[j+m]<0){J[j+m]=G;break}else{if(J[j+x]=Z*I,U=J[j+A]/2,L=J[j+x],J[L+m]=-1,J[L+S]=J[j+S]-U,J[L+v]=J[j+v]-U,J[L+A]=U,J[L+R]=L+I,J[L+x]=-1,J[L+T]=0,J[L+C]=0,J[L+N]=0,L+=I,J[L+m]=-1,J[L+S]=J[j+S]-U,J[L+v]=J[j+v]+U,J[L+A]=U,J[L+R]=L+I,J[L+x]=-1,J[L+T]=0,J[L+C]=0,J[L+N]=0,L+=I,J[L+m]=-1,J[L+S]=J[j+S]+U,J[L+v]=J[j+v]-U,J[L+A]=U,J[L+R]=L+I,J[L+x]=-1,J[L+T]=0,J[L+C]=0,J[L+N]=0,L+=I,J[L+m]=-1,J[L+S]=J[j+S]+U,J[L+v]=J[j+v]+U,J[L+A]=U,J[L+R]=J[j+R],J[L+x]=-1,J[L+T]=0,J[L+C]=0,J[L+N]=0,Z+=4,P[J[j+m]+e]<J[j+S]?P[J[j+m]+t]<J[j+v]?ie=J[j+x]:ie=J[j+x]+I:P[J[j+m]+t]<J[j+v]?ie=J[j+x]+I*2:ie=J[j+x]+I*3,J[j+T]=P[J[j+m]+l],J[j+C]=P[J[j+m]+e],J[j+N]=P[J[j+m]+t],J[ie+m]=J[j+m],J[j+m]=-1,P[G+e]<J[j+S]?P[G+t]<J[j+v]?ze=J[j+x]:ze=J[j+x]+I:P[G+t]<J[j+v]?ze=J[j+x]+I*2:ze=J[j+x]+I*3,ie===ze)if(Pe--){j=ie;continue}else{Pe=_;break}J[ze+m]=G;break}}if(q.barnesHutOptimize)for(ae=q.scalingRatio,G=0;G<Q;G+=O)for(j=0;;)if(J[j+x]>=0)if(Ce=Math.pow(P[G+e]-J[j+C],2)+Math.pow(P[G+t]-J[j+N],2),Y=J[j+A],4*Y*Y/Ce<le){if(we=P[G+e]-J[j+C],xe=P[G+t]-J[j+N],re===!0?Ce>0?(Ee=ae*P[G+l]*J[j+T]/Ce,P[G+n]+=we*Ee,P[G+r]+=xe*Ee):Ce<0&&(Ee=-ae*P[G+l]*J[j+T]/Math.sqrt(Ce),P[G+n]+=we*Ee,P[G+r]+=xe*Ee):Ce>0&&(Ee=ae*P[G+l]*J[j+T]/Ce,P[G+n]+=we*Ee,P[G+r]+=xe*Ee),j=J[j+R],j<0)break;continue}else{j=J[j+x];continue}else{if(D=J[j+m],D>=0&&D!==G&&(we=P[G+e]-P[D+e],xe=P[G+t]-P[D+t],Ce=we*we+xe*xe,re===!0?Ce>0?(Ee=ae*P[G+l]*P[D+l]/Ce,P[G+n]+=we*Ee,P[G+r]+=xe*Ee):Ce<0&&(Ee=-ae*P[G+l]*P[D+l]/Math.sqrt(Ce),P[G+n]+=we*Ee,P[G+r]+=xe*Ee):Ce>0&&(Ee=ae*P[G+l]*P[D+l]/Ce,P[G+n]+=we*Ee,P[G+r]+=xe*Ee)),j=J[j+R],j<0)break;continue}else for(ae=q.scalingRatio,B=0;B<Q;B+=O)for(X=0;X<B;X+=O)we=P[B+e]-P[X+e],xe=P[B+t]-P[X+t],re===!0?(Ce=Math.sqrt(we*we+xe*xe)-P[B+c]-P[X+c],Ce>0?(Ee=ae*P[B+l]*P[X+l]/Ce/Ce,P[B+n]+=we*Ee,P[B+r]+=xe*Ee,P[X+n]-=we*Ee,P[X+r]-=xe*Ee):Ce<0&&(Ee=100*ae*P[B+l]*P[X+l],P[B+n]+=we*Ee,P[B+r]+=xe*Ee,P[X+n]-=we*Ee,P[X+r]-=xe*Ee)):(Ce=Math.sqrt(we*we+xe*xe),Ce>0&&(Ee=ae*P[B+l]*P[X+l]/Ce/Ce,P[B+n]+=we*Ee,P[B+r]+=xe*Ee,P[X+n]-=we*Ee,P[X+r]-=xe*Ee));for(L=q.gravity/q.scalingRatio,ae=q.scalingRatio,G=0;G<Q;G+=O)Ee=0,we=P[G+e],xe=P[G+t],Ce=Math.sqrt(Math.pow(we,2)+Math.pow(xe,2)),q.strongGravityMode?Ce>0&&(Ee=ae*P[G+l]*L):Ce>0&&(Ee=ae*P[G+l]*L/Ce),P[G+n]-=we*Ee,P[G+r]-=xe*Ee;for(ae=1*(q.outboundAttractionDistribution?Ae:1),V=0;V<se;V+=z)B=W[V+p],X=W[V+g],U=W[V+b],Ie=Math.pow(U,q.edgeWeightInfluence),we=P[B+e]-P[X+e],xe=P[B+t]-P[X+t],re===!0?(Ce=Math.sqrt(we*we+xe*xe)-P[B+c]-P[X+c],q.linLogMode?q.outboundAttractionDistribution?Ce>0&&(Ee=-ae*Ie*Math.log(1+Ce)/Ce/P[B+l]):Ce>0&&(Ee=-ae*Ie*Math.log(1+Ce)/Ce):q.outboundAttractionDistribution?Ce>0&&(Ee=-ae*Ie/P[B+l]):Ce>0&&(Ee=-ae*Ie)):(Ce=Math.sqrt(Math.pow(we,2)+Math.pow(xe,2)),q.linLogMode?q.outboundAttractionDistribution?Ce>0&&(Ee=-ae*Ie*Math.log(1+Ce)/Ce/P[B+l]):Ce>0&&(Ee=-ae*Ie*Math.log(1+Ce)/Ce):q.outboundAttractionDistribution?(Ce=1,Ee=-ae*Ie/P[B+l]):(Ce=1,Ee=-ae*Ie)),Ce>0&&(P[B+n]+=we*Ee,P[B+r]+=xe*Ee,P[X+n]-=we*Ee,P[X+r]-=xe*Ee);var ee,ce,Re,Fe,qe,mt;if(re===!0)for(G=0;G<Q;G+=O)P[G+f]!==1&&(ee=Math.sqrt(Math.pow(P[G+n],2)+Math.pow(P[G+r],2)),ee>M&&(P[G+n]=P[G+n]*M/ee,P[G+r]=P[G+r]*M/ee),ce=P[G+l]*Math.sqrt((P[G+a]-P[G+n])*(P[G+a]-P[G+n])+(P[G+i]-P[G+r])*(P[G+i]-P[G+r])),Re=Math.sqrt((P[G+a]+P[G+n])*(P[G+a]+P[G+n])+(P[G+i]+P[G+r])*(P[G+i]+P[G+r]))/2,Fe=.1*Math.log(1+Re)/(1+Math.sqrt(ce)),qe=P[G+e]+P[G+n]*(Fe/q.slowDown),P[G+e]=qe,mt=P[G+t]+P[G+r]*(Fe/q.slowDown),P[G+t]=mt);else for(G=0;G<Q;G+=O)P[G+f]!==1&&(ce=P[G+l]*Math.sqrt((P[G+a]-P[G+n])*(P[G+a]-P[G+n])+(P[G+i]-P[G+r])*(P[G+i]-P[G+r])),Re=Math.sqrt((P[G+a]+P[G+n])*(P[G+a]+P[G+n])+(P[G+i]+P[G+r])*(P[G+i]+P[G+r]))/2,Fe=P[G+u]*Math.log(1+Re)/(1+Math.sqrt(ce)),P[G+u]=Math.min(1,Math.sqrt(Fe*(Math.pow(P[G+n],2)+Math.pow(P[G+r],2))/(1+Math.sqrt(ce)))),qe=P[G+e]+P[G+n]*(Fe/q.slowDown),P[G+e]=qe,mt=P[G+t]+P[G+r]*(Fe/q.slowDown),P[G+t]=mt);return{}},$h}var xa={},$C;function A3(){if($C)return xa;$C=1;var e=10,t=3;return xa.assign=function(n){n=n||{};var r=Array.prototype.slice.call(arguments).slice(1),a,i,l;for(a=0,l=r.length;a<l;a++)if(r[a])for(i in r[a])n[i]=r[a][i];return n},xa.validateSettings=function(n){return"linLogMode"in n&&typeof n.linLogMode!="boolean"?{message:"the `linLogMode` setting should be a boolean."}:"outboundAttractionDistribution"in n&&typeof n.outboundAttractionDistribution!="boolean"?{message:"the `outboundAttractionDistribution` setting should be a boolean."}:"adjustSizes"in n&&typeof n.adjustSizes!="boolean"?{message:"the `adjustSizes` setting should be a boolean."}:"edgeWeightInfluence"in n&&typeof n.edgeWeightInfluence!="number"?{message:"the `edgeWeightInfluence` setting should be a number."}:"scalingRatio"in n&&!(typeof n.scalingRatio=="number"&&n.scalingRatio>=0)?{message:"the `scalingRatio` setting should be a number >= 0."}:"strongGravityMode"in n&&typeof n.strongGravityMode!="boolean"?{message:"the `strongGravityMode` setting should be a boolean."}:"gravity"in n&&!(typeof n.gravity=="number"&&n.gravity>=0)?{message:"the `gravity` setting should be a number >= 0."}:"slowDown"in n&&!(typeof n.slowDown=="number"||n.slowDown>=0)?{message:"the `slowDown` setting should be a number >= 0."}:"barnesHutOptimize"in n&&typeof n.barnesHutOptimize!="boolean"?{message:"the `barnesHutOptimize` setting should be a boolean."}:"barnesHutTheta"in n&&!(typeof n.barnesHutTheta=="number"&&n.barnesHutTheta>=0)?{message:"the `barnesHutTheta` setting should be a number >= 0."}:null},xa.graphToByteArrays=function(n,r){var a=n.order,i=n.size,l={},u,c=new Float32Array(a*e),f=new Float32Array(i*t);return u=0,n.forEachNode(function(p,g){l[p]=u,c[u]=g.x,c[u+1]=g.y,c[u+2]=0,c[u+3]=0,c[u+4]=0,c[u+5]=0,c[u+6]=1,c[u+7]=1,c[u+8]=g.size||1,c[u+9]=g.fixed?1:0,u+=e}),u=0,n.forEachEdge(function(p,g,b,m,S,v,A){var R=l[b],x=l[m],T=r(p,g,b,m,S,v,A);c[R+6]+=T,c[x+6]+=T,f[u]=R,f[u+1]=x,f[u+2]=T,u+=t}),{nodes:c,edges:f}},xa.assignLayoutChanges=function(n,r,a){var i=0;n.updateEachNodeAttributes(function(l,u){return u.x=r[i],u.y=r[i+1],i+=e,a?a(l,u):u})},xa.readGraphPositions=function(n,r){var a=0;n.forEachNode(function(i,l){r[a]=l.x,r[a+1]=l.y,a+=e})},xa.collectLayoutChanges=function(n,r,a){for(var i=n.nodes(),l={},u=0,c=0,f=r.length;u<f;u+=e){if(a){var p=Object.assign({},n.getNodeAttributes(i[c]));p.x=r[u],p.y=r[u+1],p=a(i[c],p),l[i[c]]={x:p.x,y:p.y}}else l[i[c]]={x:r[u],y:r[u+1]};c++}return l},xa.createWorker=function(r){var a=window.URL||window.webkitURL,i=r.toString(),l=a.createObjectURL(new Blob(["("+i+").call(this);"],{type:"text/javascript"})),u=new Worker(l);return a.revokeObjectURL(l),u},xa}var qh,qC;function T3(){return qC||(qC=1,qh={linLogMode:!1,outboundAttractionDistribution:!1,adjustSizes:!1,edgeWeightInfluence:1,scalingRatio:1,strongGravityMode:!1,gravity:1,slowDown:1,barnesHutOptimize:!1,barnesHutTheta:.5}),qh}var Vh,VC;function DQ(){if(VC)return Vh;VC=1;var e=Jr(),t=E0().createEdgeWeightGetter,n=OQ(),r=A3(),a=T3();function i(c,f,p){if(!e(f))throw new Error("graphology-layout-forceatlas2: the given graph is not a valid graphology instance.");typeof p=="number"&&(p={iterations:p});var g=p.iterations;if(typeof g!="number")throw new Error("graphology-layout-forceatlas2: invalid number of iterations.");if(g<=0)throw new Error("graphology-layout-forceatlas2: you should provide a positive number of iterations.");var b=t("getEdgeWeight"in p?p.getEdgeWeight:"weight").fromEntry,m=typeof p.outputReducer=="function"?p.outputReducer:null,S=r.assign({},a,p.settings),v=r.validateSettings(S);if(v)throw new Error("graphology-layout-forceatlas2: "+v.message);var A=r.graphToByteArrays(f,b),R;for(R=0;R<g;R++)n(S,A.nodes,A.edges);if(c){r.assignLayoutChanges(f,A.nodes,m);return}return r.collectLayoutChanges(f,A.nodes)}function l(c){var f=typeof c=="number"?c:c.order;return{barnesHutOptimize:f>2e3,strongGravityMode:!0,gravity:.05,scalingRatio:10,slowDown:1+Math.log(f)}}var u=i.bind(null,!1);return u.assign=i.bind(null,!0),u.inferSettings=l,Vh=u,Vh}var IQ=DQ();const LQ=an(IQ);var Wh,WC;function MQ(){return WC||(WC=1,Wh=function(){var t,n,r={};(function(){var i=0,l=1,u=2,c=3,f=4,p=5,g=6,b=7,m=8,S=9,v=0,A=1,R=2,x=0,T=1,C=2,N=3,_=4,O=5,z=6,I=7,M=8,H=3,q=10,P=3,W=9,Z=10;r.exports=function(G,B,X){var D,V,U,L,Y,Q,se,re,le,Ae,ae=B.length,we=X.length,xe=G.adjustSizes,Ie=G.barnesHutTheta*G.barnesHutTheta,Ce,Ee,J,fe,ke,me,ve,ie=[];for(U=0;U<ae;U+=q)B[U+f]=B[U+u],B[U+p]=B[U+c],B[U+u]=0,B[U+c]=0;if(G.outboundAttractionDistribution){for(Ce=0,U=0;U<ae;U+=q)Ce+=B[U+g];Ce/=ae/q}if(G.barnesHutOptimize){var ze=1/0,Pe=-1/0,he=1/0,Ne=-1/0,ee,ce,Re;for(U=0;U<ae;U+=q)ze=Math.min(ze,B[U+i]),Pe=Math.max(Pe,B[U+i]),he=Math.min(he,B[U+l]),Ne=Math.max(Ne,B[U+l]);var Fe=Pe-ze,qe=Ne-he;for(Fe>qe?(he-=(Fe-qe)/2,Ne=he+Fe):(ze-=(qe-Fe)/2,Pe=ze+qe),ie[0+x]=-1,ie[0+T]=(ze+Pe)/2,ie[0+C]=(he+Ne)/2,ie[0+N]=Math.max(Pe-ze,Ne-he),ie[0+_]=-1,ie[0+O]=-1,ie[0+z]=0,ie[0+I]=0,ie[0+M]=0,D=1,U=0;U<ae;U+=q)for(V=0,Re=H;;)if(ie[V+O]>=0){B[U+i]<ie[V+T]?B[U+l]<ie[V+C]?ee=ie[V+O]:ee=ie[V+O]+W:B[U+l]<ie[V+C]?ee=ie[V+O]+W*2:ee=ie[V+O]+W*3,ie[V+I]=(ie[V+I]*ie[V+z]+B[U+i]*B[U+g])/(ie[V+z]+B[U+g]),ie[V+M]=(ie[V+M]*ie[V+z]+B[U+l]*B[U+g])/(ie[V+z]+B[U+g]),ie[V+z]+=B[U+g],V=ee;continue}else if(ie[V+x]<0){ie[V+x]=U;break}else{if(ie[V+O]=D*W,re=ie[V+N]/2,le=ie[V+O],ie[le+x]=-1,ie[le+T]=ie[V+T]-re,ie[le+C]=ie[V+C]-re,ie[le+N]=re,ie[le+_]=le+W,ie[le+O]=-1,ie[le+z]=0,ie[le+I]=0,ie[le+M]=0,le+=W,ie[le+x]=-1,ie[le+T]=ie[V+T]-re,ie[le+C]=ie[V+C]+re,ie[le+N]=re,ie[le+_]=le+W,ie[le+O]=-1,ie[le+z]=0,ie[le+I]=0,ie[le+M]=0,le+=W,ie[le+x]=-1,ie[le+T]=ie[V+T]+re,ie[le+C]=ie[V+C]-re,ie[le+N]=re,ie[le+_]=le+W,ie[le+O]=-1,ie[le+z]=0,ie[le+I]=0,ie[le+M]=0,le+=W,ie[le+x]=-1,ie[le+T]=ie[V+T]+re,ie[le+C]=ie[V+C]+re,ie[le+N]=re,ie[le+_]=ie[V+_],ie[le+O]=-1,ie[le+z]=0,ie[le+I]=0,ie[le+M]=0,D+=4,B[ie[V+x]+i]<ie[V+T]?B[ie[V+x]+l]<ie[V+C]?ee=ie[V+O]:ee=ie[V+O]+W:B[ie[V+x]+l]<ie[V+C]?ee=ie[V+O]+W*2:ee=ie[V+O]+W*3,ie[V+z]=B[ie[V+x]+g],ie[V+I]=B[ie[V+x]+i],ie[V+M]=B[ie[V+x]+l],ie[ee+x]=ie[V+x],ie[V+x]=-1,B[U+i]<ie[V+T]?B[U+l]<ie[V+C]?ce=ie[V+O]:ce=ie[V+O]+W:B[U+l]<ie[V+C]?ce=ie[V+O]+W*2:ce=ie[V+O]+W*3,ee===ce)if(Re--){V=ee;continue}else{Re=H;break}ie[ce+x]=U;break}}if(G.barnesHutOptimize)for(Ee=G.scalingRatio,U=0;U<ae;U+=q)for(V=0;;)if(ie[V+O]>=0)if(me=Math.pow(B[U+i]-ie[V+I],2)+Math.pow(B[U+l]-ie[V+M],2),Ae=ie[V+N],4*Ae*Ae/me<Ie){if(J=B[U+i]-ie[V+I],fe=B[U+l]-ie[V+M],xe===!0?me>0?(ve=Ee*B[U+g]*ie[V+z]/me,B[U+u]+=J*ve,B[U+c]+=fe*ve):me<0&&(ve=-Ee*B[U+g]*ie[V+z]/Math.sqrt(me),B[U+u]+=J*ve,B[U+c]+=fe*ve):me>0&&(ve=Ee*B[U+g]*ie[V+z]/me,B[U+u]+=J*ve,B[U+c]+=fe*ve),V=ie[V+_],V<0)break;continue}else{V=ie[V+O];continue}else{if(Q=ie[V+x],Q>=0&&Q!==U&&(J=B[U+i]-B[Q+i],fe=B[U+l]-B[Q+l],me=J*J+fe*fe,xe===!0?me>0?(ve=Ee*B[U+g]*B[Q+g]/me,B[U+u]+=J*ve,B[U+c]+=fe*ve):me<0&&(ve=-Ee*B[U+g]*B[Q+g]/Math.sqrt(me),B[U+u]+=J*ve,B[U+c]+=fe*ve):me>0&&(ve=Ee*B[U+g]*B[Q+g]/me,B[U+u]+=J*ve,B[U+c]+=fe*ve)),V=ie[V+_],V<0)break;continue}else for(Ee=G.scalingRatio,L=0;L<ae;L+=q)for(Y=0;Y<L;Y+=q)J=B[L+i]-B[Y+i],fe=B[L+l]-B[Y+l],xe===!0?(me=Math.sqrt(J*J+fe*fe)-B[L+m]-B[Y+m],me>0?(ve=Ee*B[L+g]*B[Y+g]/me/me,B[L+u]+=J*ve,B[L+c]+=fe*ve,B[Y+u]-=J*ve,B[Y+c]-=fe*ve):me<0&&(ve=100*Ee*B[L+g]*B[Y+g],B[L+u]+=J*ve,B[L+c]+=fe*ve,B[Y+u]-=J*ve,B[Y+c]-=fe*ve)):(me=Math.sqrt(J*J+fe*fe),me>0&&(ve=Ee*B[L+g]*B[Y+g]/me/me,B[L+u]+=J*ve,B[L+c]+=fe*ve,B[Y+u]-=J*ve,B[Y+c]-=fe*ve));for(le=G.gravity/G.scalingRatio,Ee=G.scalingRatio,U=0;U<ae;U+=q)ve=0,J=B[U+i],fe=B[U+l],me=Math.sqrt(Math.pow(J,2)+Math.pow(fe,2)),G.strongGravityMode?me>0&&(ve=Ee*B[U+g]*le):me>0&&(ve=Ee*B[U+g]*le/me),B[U+u]-=J*ve,B[U+c]-=fe*ve;for(Ee=1*(G.outboundAttractionDistribution?Ce:1),se=0;se<we;se+=P)L=X[se+v],Y=X[se+A],re=X[se+R],ke=Math.pow(re,G.edgeWeightInfluence),J=B[L+i]-B[Y+i],fe=B[L+l]-B[Y+l],xe===!0?(me=Math.sqrt(J*J+fe*fe)-B[L+m]-B[Y+m],G.linLogMode?G.outboundAttractionDistribution?me>0&&(ve=-Ee*ke*Math.log(1+me)/me/B[L+g]):me>0&&(ve=-Ee*ke*Math.log(1+me)/me):G.outboundAttractionDistribution?me>0&&(ve=-Ee*ke/B[L+g]):me>0&&(ve=-Ee*ke)):(me=Math.sqrt(Math.pow(J,2)+Math.pow(fe,2)),G.linLogMode?G.outboundAttractionDistribution?me>0&&(ve=-Ee*ke*Math.log(1+me)/me/B[L+g]):me>0&&(ve=-Ee*ke*Math.log(1+me)/me):G.outboundAttractionDistribution?(me=1,ve=-Ee*ke/B[L+g]):(me=1,ve=-Ee*ke)),me>0&&(B[L+u]+=J*ve,B[L+c]+=fe*ve,B[Y+u]-=J*ve,B[Y+c]-=fe*ve);var mt,St,pt,Je,wt,rt;if(xe===!0)for(U=0;U<ae;U+=q)B[U+S]!==1&&(mt=Math.sqrt(Math.pow(B[U+u],2)+Math.pow(B[U+c],2)),mt>Z&&(B[U+u]=B[U+u]*Z/mt,B[U+c]=B[U+c]*Z/mt),St=B[U+g]*Math.sqrt((B[U+f]-B[U+u])*(B[U+f]-B[U+u])+(B[U+p]-B[U+c])*(B[U+p]-B[U+c])),pt=Math.sqrt((B[U+f]+B[U+u])*(B[U+f]+B[U+u])+(B[U+p]+B[U+c])*(B[U+p]+B[U+c]))/2,Je=.1*Math.log(1+pt)/(1+Math.sqrt(St)),wt=B[U+i]+B[U+u]*(Je/G.slowDown),B[U+i]=wt,rt=B[U+l]+B[U+c]*(Je/G.slowDown),B[U+l]=rt);else for(U=0;U<ae;U+=q)B[U+S]!==1&&(St=B[U+g]*Math.sqrt((B[U+f]-B[U+u])*(B[U+f]-B[U+u])+(B[U+p]-B[U+c])*(B[U+p]-B[U+c])),pt=Math.sqrt((B[U+f]+B[U+u])*(B[U+f]+B[U+u])+(B[U+p]+B[U+c])*(B[U+p]+B[U+c]))/2,Je=B[U+b]*Math.log(1+pt)/(1+Math.sqrt(St)),B[U+b]=Math.min(1,Math.sqrt(Je*(Math.pow(B[U+u],2)+Math.pow(B[U+c],2))/(1+Math.sqrt(St)))),wt=B[U+i]+B[U+u]*(Je/G.slowDown),B[U+i]=wt,rt=B[U+l]+B[U+c]*(Je/G.slowDown),B[U+l]=rt);return{}}})();var a=r.exports;self.addEventListener("message",function(i){var l=i.data;t=new Float32Array(l.nodes),l.edges&&(n=new Float32Array(l.edges)),a(l.settings,t,n),self.postMessage({nodes:t.buffer},[t.buffer])})}),Wh}var Yh,YC;function FQ(){if(YC)return Yh;YC=1;var e=MQ(),t=Jr(),n=E0().createEdgeWeightGetter,r=A3(),a=T3();function i(l,u){if(u=u||{},!t(l))throw new Error("graphology-layout-forceatlas2/worker: the given graph is not a valid graphology instance.");var c=n("getEdgeWeight"in u?u.getEdgeWeight:"weight").fromEntry,f=r.assign({},a,u.settings),p=r.validateSettings(f);if(p)throw new Error("graphology-layout-forceatlas2/worker: "+p.message);this.worker=null,this.graph=l,this.settings=f,this.getEdgeWeight=c,this.matrices=null,this.running=!1,this.killed=!1,this.outputReducer=typeof u.outputReducer=="function"?u.outputReducer:null,this.handleMessage=this.handleMessage.bind(this);var g=void 0,b=this;this.handleGraphUpdate=function(){b.worker&&b.worker.terminate(),g&&clearTimeout(g),g=setTimeout(function(){g=void 0,b.spawnWorker()},0)},l.on("nodeAdded",this.handleGraphUpdate),l.on("edgeAdded",this.handleGraphUpdate),l.on("nodeDropped",this.handleGraphUpdate),l.on("edgeDropped",this.handleGraphUpdate),this.spawnWorker()}return i.prototype.isRunning=function(){return this.running},i.prototype.spawnWorker=function(){this.worker&&this.worker.terminate(),this.worker=r.createWorker(e),this.worker.addEventListener("message",this.handleMessage),this.running&&(this.running=!1,this.start())},i.prototype.handleMessage=function(l){if(this.running){var u=new Float32Array(l.data.nodes);r.assignLayoutChanges(this.graph,u,this.outputReducer),this.outputReducer&&r.readGraphPositions(this.graph,u),this.matrices.nodes=u,this.askForIterations()}},i.prototype.askForIterations=function(l){var u=this.matrices,c={settings:this.settings,nodes:u.nodes.buffer},f=[u.nodes.buffer];return l&&(c.edges=u.edges.buffer,f.push(u.edges.buffer)),this.worker.postMessage(c,f),this},i.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-forceatlas2/worker.start: layout was killed.");return this.running?this:(this.matrices=r.graphToByteArrays(this.graph,this.getEdgeWeight),this.running=!0,this.askForIterations(!0),this)},i.prototype.stop=function(){return this.running=!1,this},i.prototype.kill=function(){if(this.killed)return this;this.running=!1,this.killed=!0,this.matrices=null,this.worker.terminate(),this.graph.removeListener("nodeAdded",this.handleGraphUpdate),this.graph.removeListener("edgeAdded",this.handleGraphUpdate),this.graph.removeListener("nodeDropped",this.handleGraphUpdate),this.graph.removeListener("edgeDropped",this.handleGraphUpdate)},Yh=i,Yh}var zQ=FQ();const PQ=an(zQ);function _3(e={iterations:100}){return Ll(LQ,e)}function BQ(e={}){return S0(PQ,e)}var Kh,KC;function UQ(){if(KC)return Kh;KC=1;var e=0,t=1,n=2,r=3;function a(l,u){return l+"§"+u}function i(){return .01*(.5-Math.random())}return Kh=function(u,c){var f=u.margin,p=u.ratio,g=u.expansion,b=u.gridSize,m=u.speed,S,v,A,R,x,T,C=!0,N=c.length,_=N/r|0,O=new Float32Array(_),z=new Float32Array(_),I=1/0,M=1/0,H=-1/0,q=-1/0;for(S=0;S<N;S+=r)A=c[S+e],R=c[S+t],T=c[S+n]*p+f,I=Math.min(I,A-T),H=Math.max(H,A+T),M=Math.min(M,R-T),q=Math.max(q,R+T);var P=H-I,W=q-M,Z=(I+H)/2,j=(M+q)/2;I=Z-g*P/2,H=Z+g*P/2,M=j-g*W/2,q=j+g*W/2;var G=new Array(b*b),B=G.length,X;for(X=0;X<B;X++)G[X]=[];var D,V,U,L,Y,Q,se,re,le,Ae;for(S=0;S<N;S+=r)for(A=c[S+e],R=c[S+t],T=c[S+n]*p+f,D=A-T,V=A+T,U=R-T,L=R+T,Y=Math.floor(b*(D-I)/(H-I)),Q=Math.floor(b*(V-I)/(H-I)),se=Math.floor(b*(U-M)/(q-M)),re=Math.floor(b*(L-M)/(q-M)),le=Y;le<=Q;le++)for(Ae=se;Ae<=re;Ae++)G[le*b+Ae].push(S);var ae,we=new Set,xe,Ie,Ce,Ee,J,fe,ke,me,ve,ie,ze,Pe,he;for(X=0;X<B;X++)for(ae=G[X],S=0,x=ae.length;S<x;S++)for(xe=ae[S],Ce=c[xe+e],J=c[xe+t],ke=c[xe+n],v=S+1;v<x;v++)Ie=ae[v],ve=a(xe,Ie),!(B>1&&we.has(ve))&&(B>1&&we.add(ve),Ee=c[Ie+e],fe=c[Ie+t],me=c[Ie+n],ie=Ee-Ce,ze=fe-J,Pe=Math.sqrt(ie*ie+ze*ze),he=Pe<ke*p+f+(me*p+f),he&&(C=!1,Ie=Ie/r|0,Pe>0?(O[Ie]+=ie/Pe*(1+ke),z[Ie]+=ze/Pe*(1+ke)):(O[Ie]+=P*i(),z[Ie]+=W*i())));for(S=0,v=0;S<N;S+=r,v++)c[S+e]+=O[v]*.1*m,c[S+t]+=z[v]*.1*m;return{converged:C}},Kh}var Xo={},XC;function R3(){if(XC)return Xo;XC=1;var e=3;return Xo.validateSettings=function(t){return"gridSize"in t&&typeof t.gridSize!="number"||t.gridSize<=0?{message:"the `gridSize` setting should be a positive number."}:"margin"in t&&typeof t.margin!="number"||t.margin<0?{message:"the `margin` setting should be 0 or a positive number."}:"expansion"in t&&typeof t.expansion!="number"||t.expansion<=0?{message:"the `expansion` setting should be a positive number."}:"ratio"in t&&typeof t.ratio!="number"||t.ratio<=0?{message:"the `ratio` setting should be a positive number."}:"speed"in t&&typeof t.speed!="number"||t.speed<=0?{message:"the `speed` setting should be a positive number."}:null},Xo.graphToByteArray=function(t,n){var r=t.order,a=new Float32Array(r*e),i=0;return t.forEachNode(function(l,u){typeof n=="function"&&(u=n(l,u)),a[i]=u.x,a[i+1]=u.y,a[i+2]=u.size||1,i+=e}),a},Xo.assignLayoutChanges=function(t,n,r){var a=0;t.forEachNode(function(i){var l={x:n[a],y:n[a+1]};typeof r=="function"&&(l=r(i,l)),t.mergeNodeAttributes(i,l),a+=e})},Xo.collectLayoutChanges=function(t,n,r){var a={},i=0;return t.forEachNode(function(l){var u={x:n[i],y:n[i+1]};typeof r=="function"&&(u=r(l,u)),a[l]=u,i+=e}),a},Xo.createWorker=function(n){var r=window.URL||window.webkitURL,a=n.toString(),i=r.createObjectURL(new Blob(["("+a+").call(this);"],{type:"text/javascript"})),l=new Worker(i);return r.revokeObjectURL(i),l},Xo}var Xh,ZC;function C3(){return ZC||(ZC=1,Xh={gridSize:20,margin:5,expansion:1.1,ratio:1,speed:3}),Xh}var Zh,QC;function jQ(){if(QC)return Zh;QC=1;var e=Jr(),t=UQ(),n=R3(),r=C3(),a=500;function i(u,c,f){if(!e(c))throw new Error("graphology-layout-noverlap: the given graph is not a valid graphology instance.");typeof f=="number"?f={maxIterations:f}:f=f||{};var p=f.maxIterations||a;if(typeof p!="number"||p<=0)throw new Error("graphology-layout-force: you should provide a positive number of maximum iterations.");var g=Object.assign({},r,f.settings),b=n.validateSettings(g);if(b)throw new Error("graphology-layout-noverlap: "+b.message);var m=n.graphToByteArray(c,f.inputReducer),S=!1,v;for(v=0;v<p&&!S;v++)S=t(g,m).converged;if(u){n.assignLayoutChanges(c,m,f.outputReducer);return}return n.collectLayoutChanges(c,m,f.outputReducer)}var l=i.bind(null,!1);return l.assign=i.bind(null,!0),Zh=l,Zh}var GQ=jQ();const HQ=an(GQ);var Qh,JC;function $Q(){return JC||(JC=1,Qh=function(){var t,n={};(function(){var a=0,i=1,l=2,u=3;function c(p,g){return p+"§"+g}function f(){return .01*(.5-Math.random())}n.exports=function(g,b){var m=g.margin,S=g.ratio,v=g.expansion,A=g.gridSize,R=g.speed,x,T,C,N,_,O,z=!0,I=b.length,M=I/u|0,H=new Float32Array(M),q=new Float32Array(M),P=1/0,W=1/0,Z=-1/0,j=-1/0;for(x=0;x<I;x+=u)C=b[x+a],N=b[x+i],O=b[x+l]*S+m,P=Math.min(P,C-O),Z=Math.max(Z,C+O),W=Math.min(W,N-O),j=Math.max(j,N+O);var G=Z-P,B=j-W,X=(P+Z)/2,D=(W+j)/2;P=X-v*G/2,Z=X+v*G/2,W=D-v*B/2,j=D+v*B/2;var V=new Array(A*A),U=V.length,L;for(L=0;L<U;L++)V[L]=[];var Y,Q,se,re,le,Ae,ae,we,xe,Ie;for(x=0;x<I;x+=u)for(C=b[x+a],N=b[x+i],O=b[x+l]*S+m,Y=C-O,Q=C+O,se=N-O,re=N+O,le=Math.floor(A*(Y-P)/(Z-P)),Ae=Math.floor(A*(Q-P)/(Z-P)),ae=Math.floor(A*(se-W)/(j-W)),we=Math.floor(A*(re-W)/(j-W)),xe=le;xe<=Ae;xe++)for(Ie=ae;Ie<=we;Ie++)V[xe*A+Ie].push(x);var Ce,Ee=new Set,J,fe,ke,me,ve,ie,ze,Pe,he,Ne,ee,ce,Re;for(L=0;L<U;L++)for(Ce=V[L],x=0,_=Ce.length;x<_;x++)for(J=Ce[x],ke=b[J+a],ve=b[J+i],ze=b[J+l],T=x+1;T<_;T++)fe=Ce[T],he=c(J,fe),!(U>1&&Ee.has(he))&&(U>1&&Ee.add(he),me=b[fe+a],ie=b[fe+i],Pe=b[fe+l],Ne=me-ke,ee=ie-ve,ce=Math.sqrt(Ne*Ne+ee*ee),Re=ce<ze*S+m+(Pe*S+m),Re&&(z=!1,fe=fe/u|0,ce>0?(H[fe]+=Ne/ce*(1+ze),q[fe]+=ee/ce*(1+ze)):(H[fe]+=G*f(),q[fe]+=B*f())));for(x=0,T=0;x<I;x+=u,T++)b[x+a]+=H[T]*.1*R,b[x+i]+=q[T]*.1*R;return{converged:z}}})();var r=n.exports;self.addEventListener("message",function(a){var i=a.data;t=new Float32Array(i.nodes);var l=r(i.settings,t);self.postMessage({result:l,nodes:t.buffer},[t.buffer])})}),Qh}var Jh,eN;function qQ(){if(eN)return Jh;eN=1;var e=$Q(),t=Jr(),n=R3(),r=C3();function a(i,l){if(l=l||{},!t(i))throw new Error("graphology-layout-noverlap/worker: the given graph is not a valid graphology instance.");var u=Object.assign({},r,l.settings),c=n.validateSettings(u);if(c)throw new Error("graphology-layout-noverlap/worker: "+c.message);this.worker=null,this.graph=i,this.settings=u,this.matrices=null,this.running=!1,this.killed=!1,this.inputReducer=l.inputReducer,this.outputReducer=l.outputReducer,this.callbacks={onConverged:typeof l.onConverged=="function"?l.onConverged:null},this.handleMessage=this.handleMessage.bind(this);var f=!1,p=this;this.handleAddition=function(){f||(f=!0,p.spawnWorker(),setTimeout(function(){f=!1},0))},i.on("nodeAdded",this.handleAddition),i.on("edgeAdded",this.handleAddition),this.spawnWorker()}return a.prototype.isRunning=function(){return this.running},a.prototype.spawnWorker=function(){this.worker&&this.worker.terminate(),this.worker=n.createWorker(e),this.worker.addEventListener("message",this.handleMessage),this.running&&(this.running=!1,this.start())},a.prototype.handleMessage=function(i){if(this.running){var l=new Float32Array(i.data.nodes);if(n.assignLayoutChanges(this.graph,l,this.outputReducer),this.matrices.nodes=l,i.data.result.converged){this.callbacks.onConverged&&this.callbacks.onConverged(),this.stop();return}this.askForIterations()}},a.prototype.askForIterations=function(){var i=this.matrices,l={settings:this.settings,nodes:i.nodes.buffer},u=[i.nodes.buffer];return this.worker.postMessage(l,u),this},a.prototype.start=function(){if(this.killed)throw new Error("graphology-layout-noverlap/worker.start: layout was killed.");return this.running?this:(this.matrices={nodes:n.graphToByteArray(this.graph,this.inputReducer)},this.running=!0,this.askForIterations(),this)},a.prototype.stop=function(){return this.running=!1,this},a.prototype.kill=function(){if(this.killed)return this;this.running=!1,this.killed=!0,this.matrices=null,this.worker.terminate(),this.graph.removeListener("nodeAdded",this.handleAddition),this.graph.removeListener("edgeAdded",this.handleAddition)},Jh=a,Jh}var VQ=qQ();const WQ=an(VQ);function YQ(e={}){return Ll(HQ,e)}function KQ(e={}){return S0(WQ,e)}var em,tN;function XQ(){if(tN)return em;tN=1;var e=xu(),t=Jr(),n={dimensions:["x","y"],center:.5,rng:Math.random,scale:1};function r(i,l,u){if(!t(l))throw new Error("graphology-layout/random: the given graph is not a valid graphology instance.");u=e(u,n);var c=u.dimensions;if(!Array.isArray(c)||c.length<1)throw new Error("graphology-layout/random: given dimensions are invalid.");var f=c.length,p=u.center,g=u.rng,b=u.scale,m=(p-.5)*b;function S(A){for(var R=0;R<f;R++)A[c[R]]=g()*b+m;return A}if(!i){var v={};return l.forEachNode(function(A){v[A]=S({})}),v}l.updateEachNodeAttributes(function(A,R){return S(R),R},{attributes:c})}var a=r.bind(null,!1);return a.assign=r.bind(null,!0),em=a,em}var ZQ=XQ();const QQ=an(ZQ);function JQ(e={}){return Ll(QQ,e)}var nN=1,eJ=.9,tJ=.8,nJ=.17,tm=.1,nm=.999,rJ=.9999,aJ=.99,oJ=/[\\\/_+.#"@\[\(\{&]/,iJ=/[\\\/_+.#"@\[\(\{&]/g,lJ=/[\s-]/,N3=/[\s-]/g;function Hx(e,t,n,r,a,i,l){if(i===t.length)return a===e.length?nN:aJ;var u=`${a},${i}`;if(l[u]!==void 0)return l[u];for(var c=r.charAt(i),f=n.indexOf(c,a),p=0,g,b,m,S;f>=0;)g=Hx(e,t,n,r,f+1,i+1,l),g>p&&(f===a?g*=nN:oJ.test(e.charAt(f-1))?(g*=tJ,m=e.slice(a,f-1).match(iJ),m&&a>0&&(g*=Math.pow(nm,m.length))):lJ.test(e.charAt(f-1))?(g*=eJ,S=e.slice(a,f-1).match(N3),S&&a>0&&(g*=Math.pow(nm,S.length))):(g*=nJ,a>0&&(g*=Math.pow(nm,f-a))),e.charAt(f)!==t.charAt(i)&&(g*=rJ)),(g<tm&&n.charAt(f-1)===r.charAt(i+1)||r.charAt(i+1)===r.charAt(i)&&n.charAt(f-1)!==r.charAt(i))&&(b=Hx(e,t,n,r,f+1,i+2,l),b*tm>g&&(g=b*tm)),g>p&&(p=g),f=n.indexOf(c,f+1);return l[u]=p,p}function rN(e){return e.toLowerCase().replace(N3," ")}function sJ(e,t,n){return e=n&&n.length>0?`${e+" "+n.join(" ")}`:e,Hx(e,t,rN(e),rN(t),0,0,{})}var rm={exports:{}},am={};/**
 * @license React
 * use-sync-external-store-shim.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var aN;function uJ(){if(aN)return am;aN=1;var e=nf();function t(g,b){return g===b&&(g!==0||1/g===1/b)||g!==g&&b!==b}var n=typeof Object.is=="function"?Object.is:t,r=e.useState,a=e.useEffect,i=e.useLayoutEffect,l=e.useDebugValue;function u(g,b){var m=b(),S=r({inst:{value:m,getSnapshot:b}}),v=S[0].inst,A=S[1];return i(function(){v.value=m,v.getSnapshot=b,c(v)&&A({inst:v})},[g,m,b]),a(function(){return c(v)&&A({inst:v}),g(function(){c(v)&&A({inst:v})})},[g]),l(m),m}function c(g){var b=g.getSnapshot;g=g.value;try{var m=b();return!n(g,m)}catch{return!0}}function f(g,b){return b()}var p=typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"?f:u;return am.useSyncExternalStore=e.useSyncExternalStore!==void 0?e.useSyncExternalStore:p,am}var oN;function cJ(){return oN||(oN=1,rm.exports=uJ()),rm.exports}var dJ=cJ(),Hs='[cmdk-group=""]',om='[cmdk-group-items=""]',fJ='[cmdk-group-heading=""]',w0='[cmdk-item=""]',iN=`${w0}:not([aria-disabled="true"])`,$x="cmdk-item-select",Qo="data-value",pJ=(e,t,n)=>sJ(e,t,n),O3=k.createContext(void 0),ku=()=>k.useContext(O3),D3=k.createContext(void 0),x0=()=>k.useContext(D3),I3=k.createContext(void 0),L3=k.forwardRef((e,t)=>{let n=ol(()=>{var U,L;return{search:"",value:(L=(U=e.value)!=null?U:e.defaultValue)!=null?L:"",filtered:{count:0,items:new Map,groups:new Set}}}),r=ol(()=>new Set),a=ol(()=>new Map),i=ol(()=>new Map),l=ol(()=>new Set),u=M3(e),{label:c,children:f,value:p,onValueChange:g,filter:b,shouldFilter:m,loop:S,disablePointerSelection:v=!1,vimBindings:A=!0,...R}=e,x=En(),T=En(),C=En(),N=k.useRef(null),_=kJ();ii(()=>{if(p!==void 0){let U=p.trim();n.current.value=U,O.emit()}},[p]),ii(()=>{_(6,P)},[]);let O=k.useMemo(()=>({subscribe:U=>(l.current.add(U),()=>l.current.delete(U)),snapshot:()=>n.current,setState:(U,L,Y)=>{var Q,se,re;if(!Object.is(n.current[U],L)){if(n.current[U]=L,U==="search")q(),M(),_(1,H);else if(U==="value"&&(Y||_(5,P),((Q=u.current)==null?void 0:Q.value)!==void 0)){let le=L??"";(re=(se=u.current).onValueChange)==null||re.call(se,le);return}O.emit()}},emit:()=>{l.current.forEach(U=>U())}}),[]),z=k.useMemo(()=>({value:(U,L,Y)=>{var Q;L!==((Q=i.current.get(U))==null?void 0:Q.value)&&(i.current.set(U,{value:L,keywords:Y}),n.current.filtered.items.set(U,I(L,Y)),_(2,()=>{M(),O.emit()}))},item:(U,L)=>(r.current.add(U),L&&(a.current.has(L)?a.current.get(L).add(U):a.current.set(L,new Set([U]))),_(3,()=>{q(),M(),n.current.value||H(),O.emit()}),()=>{i.current.delete(U),r.current.delete(U),n.current.filtered.items.delete(U);let Y=W();_(4,()=>{q(),(Y==null?void 0:Y.getAttribute("id"))===U&&H(),O.emit()})}),group:U=>(a.current.has(U)||a.current.set(U,new Set),()=>{i.current.delete(U),a.current.delete(U)}),filter:()=>u.current.shouldFilter,label:c||e["aria-label"],getDisablePointerSelection:()=>u.current.disablePointerSelection,listId:x,inputId:C,labelId:T,listInnerRef:N}),[]);function I(U,L){var Y,Q;let se=(Q=(Y=u.current)==null?void 0:Y.filter)!=null?Q:pJ;return U?se(U,n.current.search,L):0}function M(){if(!n.current.search||u.current.shouldFilter===!1)return;let U=n.current.filtered.items,L=[];n.current.filtered.groups.forEach(Q=>{let se=a.current.get(Q),re=0;se.forEach(le=>{let Ae=U.get(le);re=Math.max(Ae,re)}),L.push([Q,re])});let Y=N.current;Z().sort((Q,se)=>{var re,le;let Ae=Q.getAttribute("id"),ae=se.getAttribute("id");return((re=U.get(ae))!=null?re:0)-((le=U.get(Ae))!=null?le:0)}).forEach(Q=>{let se=Q.closest(om);se?se.appendChild(Q.parentElement===se?Q:Q.closest(`${om} > *`)):Y.appendChild(Q.parentElement===Y?Q:Q.closest(`${om} > *`))}),L.sort((Q,se)=>se[1]-Q[1]).forEach(Q=>{var se;let re=(se=N.current)==null?void 0:se.querySelector(`${Hs}[${Qo}="${encodeURIComponent(Q[0])}"]`);re==null||re.parentElement.appendChild(re)})}function H(){let U=Z().find(Y=>Y.getAttribute("aria-disabled")!=="true"),L=U==null?void 0:U.getAttribute(Qo);O.setState("value",L||void 0)}function q(){var U,L,Y,Q;if(!n.current.search||u.current.shouldFilter===!1){n.current.filtered.count=r.current.size;return}n.current.filtered.groups=new Set;let se=0;for(let re of r.current){let le=(L=(U=i.current.get(re))==null?void 0:U.value)!=null?L:"",Ae=(Q=(Y=i.current.get(re))==null?void 0:Y.keywords)!=null?Q:[],ae=I(le,Ae);n.current.filtered.items.set(re,ae),ae>0&&se++}for(let[re,le]of a.current)for(let Ae of le)if(n.current.filtered.items.get(Ae)>0){n.current.filtered.groups.add(re);break}n.current.filtered.count=se}function P(){var U,L,Y;let Q=W();Q&&(((U=Q.parentElement)==null?void 0:U.firstChild)===Q&&((Y=(L=Q.closest(Hs))==null?void 0:L.querySelector(fJ))==null||Y.scrollIntoView({block:"nearest"})),Q.scrollIntoView({block:"nearest"}))}function W(){var U;return(U=N.current)==null?void 0:U.querySelector(`${w0}[aria-selected="true"]`)}function Z(){var U;return Array.from(((U=N.current)==null?void 0:U.querySelectorAll(iN))||[])}function j(U){let L=Z()[U];L&&O.setState("value",L.getAttribute(Qo))}function G(U){var L;let Y=W(),Q=Z(),se=Q.findIndex(le=>le===Y),re=Q[se+U];(L=u.current)!=null&&L.loop&&(re=se+U<0?Q[Q.length-1]:se+U===Q.length?Q[0]:Q[se+U]),re&&O.setState("value",re.getAttribute(Qo))}function B(U){let L=W(),Y=L==null?void 0:L.closest(Hs),Q;for(;Y&&!Q;)Y=U>0?wJ(Y,Hs):xJ(Y,Hs),Q=Y==null?void 0:Y.querySelector(iN);Q?O.setState("value",Q.getAttribute(Qo)):G(U)}let X=()=>j(Z().length-1),D=U=>{U.preventDefault(),U.metaKey?X():U.altKey?B(1):G(1)},V=U=>{U.preventDefault(),U.metaKey?j(0):U.altKey?B(-1):G(-1)};return k.createElement(Xe.div,{ref:t,tabIndex:-1,...R,"cmdk-root":"",onKeyDown:U=>{var L;if((L=R.onKeyDown)==null||L.call(R,U),!U.defaultPrevented)switch(U.key){case"n":case"j":{A&&U.ctrlKey&&D(U);break}case"ArrowDown":{D(U);break}case"p":case"k":{A&&U.ctrlKey&&V(U);break}case"ArrowUp":{V(U);break}case"Home":{U.preventDefault(),j(0);break}case"End":{U.preventDefault(),X();break}case"Enter":if(!U.nativeEvent.isComposing&&U.keyCode!==229){U.preventDefault();let Y=W();if(Y){let Q=new Event($x);Y.dispatchEvent(Q)}}}}},k.createElement("label",{"cmdk-label":"",htmlFor:z.inputId,id:z.labelId,style:TJ},c),Nf(e,U=>k.createElement(D3.Provider,{value:O},k.createElement(O3.Provider,{value:z},U))))}),gJ=k.forwardRef((e,t)=>{var n,r;let a=En(),i=k.useRef(null),l=k.useContext(I3),u=ku(),c=M3(e),f=(r=(n=c.current)==null?void 0:n.forceMount)!=null?r:l==null?void 0:l.forceMount;ii(()=>{if(!f)return u.item(a,l==null?void 0:l.id)},[f]);let p=F3(a,i,[e.value,e.children,i],e.keywords),g=x0(),b=li(_=>_.value&&_.value===p.current),m=li(_=>f||u.filter()===!1?!0:_.search?_.filtered.items.get(a)>0:!0);k.useEffect(()=>{let _=i.current;if(!(!_||e.disabled))return _.addEventListener($x,S),()=>_.removeEventListener($x,S)},[m,e.onSelect,e.disabled]);function S(){var _,O;v(),(O=(_=c.current).onSelect)==null||O.call(_,p.current)}function v(){g.setState("value",p.current,!0)}if(!m)return null;let{disabled:A,value:R,onSelect:x,forceMount:T,keywords:C,...N}=e;return k.createElement(Xe.div,{ref:ru([i,t]),...N,id:a,"cmdk-item":"",role:"option","aria-disabled":!!A,"aria-selected":!!b,"data-disabled":!!A,"data-selected":!!b,onPointerMove:A||u.getDisablePointerSelection()?void 0:v,onClick:A?void 0:S},e.children)}),hJ=k.forwardRef((e,t)=>{let{heading:n,children:r,forceMount:a,...i}=e,l=En(),u=k.useRef(null),c=k.useRef(null),f=En(),p=ku(),g=li(m=>a||p.filter()===!1?!0:m.search?m.filtered.groups.has(l):!0);ii(()=>p.group(l),[]),F3(l,u,[e.value,e.heading,c]);let b=k.useMemo(()=>({id:l,forceMount:a}),[a]);return k.createElement(Xe.div,{ref:ru([u,t]),...i,"cmdk-group":"",role:"presentation",hidden:g?void 0:!0},n&&k.createElement("div",{ref:c,"cmdk-group-heading":"","aria-hidden":!0,id:f},n),Nf(e,m=>k.createElement("div",{"cmdk-group-items":"",role:"group","aria-labelledby":n?f:void 0},k.createElement(I3.Provider,{value:b},m))))}),mJ=k.forwardRef((e,t)=>{let{alwaysRender:n,...r}=e,a=k.useRef(null),i=li(l=>!l.search);return!n&&!i?null:k.createElement(Xe.div,{ref:ru([a,t]),...r,"cmdk-separator":"",role:"separator"})}),bJ=k.forwardRef((e,t)=>{let{onValueChange:n,...r}=e,a=e.value!=null,i=x0(),l=li(p=>p.search),u=li(p=>p.value),c=ku(),f=k.useMemo(()=>{var p;let g=(p=c.listInnerRef.current)==null?void 0:p.querySelector(`${w0}[${Qo}="${encodeURIComponent(u)}"]`);return g==null?void 0:g.getAttribute("id")},[]);return k.useEffect(()=>{e.value!=null&&i.setState("search",e.value)},[e.value]),k.createElement(Xe.input,{ref:t,...r,"cmdk-input":"",autoComplete:"off",autoCorrect:"off",spellCheck:!1,"aria-autocomplete":"list",role:"combobox","aria-expanded":!0,"aria-controls":c.listId,"aria-labelledby":c.labelId,"aria-activedescendant":f,id:c.inputId,type:"text",value:a?e.value:l,onChange:p=>{a||i.setState("search",p.target.value),n==null||n(p.target.value)}})}),yJ=k.forwardRef((e,t)=>{let{children:n,label:r="Suggestions",...a}=e,i=k.useRef(null),l=k.useRef(null),u=ku();return k.useEffect(()=>{if(l.current&&i.current){let c=l.current,f=i.current,p,g=new ResizeObserver(()=>{p=requestAnimationFrame(()=>{let b=c.offsetHeight;f.style.setProperty("--cmdk-list-height",b.toFixed(1)+"px")})});return g.observe(c),()=>{cancelAnimationFrame(p),g.unobserve(c)}}},[]),k.createElement(Xe.div,{ref:ru([i,t]),...a,"cmdk-list":"",role:"listbox","aria-label":r,id:u.listId},Nf(e,c=>k.createElement("div",{ref:ru([l,u.listInnerRef]),"cmdk-list-sizer":""},c)))}),vJ=k.forwardRef((e,t)=>{let{open:n,onOpenChange:r,overlayClassName:a,contentClassName:i,container:l,...u}=e;return k.createElement(Bk,{open:n,onOpenChange:r},k.createElement(Uk,{container:l},k.createElement(gf,{"cmdk-overlay":"",className:a}),k.createElement(hf,{"aria-label":e.label,"cmdk-dialog":"",className:i},k.createElement(L3,{ref:t,...u}))))}),SJ=k.forwardRef((e,t)=>li(n=>n.filtered.count===0)?k.createElement(Xe.div,{ref:t,...e,"cmdk-empty":"",role:"presentation"}):null),EJ=k.forwardRef((e,t)=>{let{progress:n,children:r,label:a="Loading...",...i}=e;return k.createElement(Xe.div,{ref:t,...i,"cmdk-loading":"",role:"progressbar","aria-valuenow":n,"aria-valuemin":0,"aria-valuemax":100,"aria-label":a},Nf(e,l=>k.createElement("div",{"aria-hidden":!0},l)))}),jn=Object.assign(L3,{List:yJ,Item:gJ,Input:bJ,Group:hJ,Separator:mJ,Dialog:vJ,Empty:SJ,Loading:EJ});function wJ(e,t){let n=e.nextElementSibling;for(;n;){if(n.matches(t))return n;n=n.nextElementSibling}}function xJ(e,t){let n=e.previousElementSibling;for(;n;){if(n.matches(t))return n;n=n.previousElementSibling}}function M3(e){let t=k.useRef(e);return ii(()=>{t.current=e}),t}var ii=typeof window>"u"?k.useEffect:k.useLayoutEffect;function ol(e){let t=k.useRef();return t.current===void 0&&(t.current=e()),t}function ru(e){return t=>{e.forEach(n=>{typeof n=="function"?n(t):n!=null&&(n.current=t)})}}function li(e){let t=x0(),n=()=>e(t.snapshot());return dJ.useSyncExternalStore(t.subscribe,n,n)}function F3(e,t,n,r=[]){let a=k.useRef(),i=ku();return ii(()=>{var l;let u=(()=>{var f;for(let p of n){if(typeof p=="string")return p.trim();if(typeof p=="object"&&"current"in p)return p.current?(f=p.current.textContent)==null?void 0:f.trim():a.current}})(),c=r.map(f=>f.trim());i.value(e,u,c),(l=t.current)==null||l.setAttribute(Qo,u),a.current=u}),a}var kJ=()=>{let[e,t]=k.useState(),n=ol(()=>new Map);return ii(()=>{n.current.forEach(r=>r()),n.current=new Map},[e]),(r,a)=>{n.current.set(r,a),t({})}};function AJ(e){let t=e.type;return typeof t=="function"?t(e.props):"render"in t?t.render(e.props):e}function Nf({asChild:e,children:t},n){return e&&k.isValidElement(t)?k.cloneElement(AJ(t),{ref:t.ref},n(t.props.children)):n(t)}var TJ={position:"absolute",width:"1px",height:"1px",padding:"0",margin:"-1px",overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",borderWidth:"0"};const z3=Bk,P3=GP,_J=Uk,B3=k.forwardRef(({className:e,...t},n)=>w.jsx(gf,{ref:n,className:Me("data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 fixed inset-0 z-50 bg-black/80",e),...t}));B3.displayName=gf.displayName;const k0=k.forwardRef(({className:e,children:t,...n},r)=>w.jsxs(_J,{children:[w.jsx(B3,{}),w.jsxs(hf,{ref:r,className:Me("bg-background data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[state=closed]:slide-out-to-top-[48%] data-[state=open]:slide-in-from-top-[48%] fixed top-[50%] left-[50%] z-50 grid w-full max-w-lg translate-x-[-50%] translate-y-[-50%] gap-4 border p-6 shadow-lg duration-200 sm:rounded-lg",e),...n,children:[t,w.jsxs(Hk,{className:"ring-offset-background focus:ring-ring data-[state=open]:bg-accent data-[state=open]:text-muted-foreground absolute top-4 right-4 rounded-sm opacity-70 transition-opacity hover:opacity-100 focus:ring-2 focus:ring-offset-2 focus:outline-none disabled:pointer-events-none",children:[w.jsx(dP,{className:"h-4 w-4"}),w.jsx("span",{className:"sr-only",children:"Close"})]})]})]}));k0.displayName=hf.displayName;const A0=({className:e,...t})=>w.jsx("div",{className:Me("flex flex-col space-y-1.5 text-center sm:text-left",e),...t});A0.displayName="DialogHeader";const T0=k.forwardRef(({className:e,...t},n)=>w.jsx(jk,{ref:n,className:Me("text-lg leading-none font-semibold tracking-tight",e),...t}));T0.displayName=jk.displayName;const _0=k.forwardRef(({className:e,...t},n)=>w.jsx(Gk,{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));_0.displayName=Gk.displayName;const Of=k.forwardRef(({className:e,...t},n)=>w.jsx(jn,{ref:n,className:Me("bg-popover text-popover-foreground flex h-full w-full flex-col overflow-hidden rounded-md",e),...t}));Of.displayName=jn.displayName;const R0=k.forwardRef(({className:e,...t},n)=>w.jsxs("div",{className:"flex items-center border-b px-3","cmdk-input-wrapper":"",children:[w.jsx(r8,{className:"mr-2 h-4 w-4 shrink-0 opacity-50"}),w.jsx(jn.Input,{ref:n,className:Me("placeholder:text-muted-foreground flex h-11 w-full rounded-md bg-transparent py-3 text-sm outline-none disabled:cursor-not-allowed disabled:opacity-50",e),...t})]}));R0.displayName=jn.Input.displayName;const Df=k.forwardRef(({className:e,...t},n)=>w.jsx(jn.List,{ref:n,className:Me("max-h-[300px] overflow-x-hidden overflow-y-auto",e),...t}));Df.displayName=jn.List.displayName;const C0=k.forwardRef((e,t)=>w.jsx(jn.Empty,{ref:t,className:"py-6 text-center text-sm",...e}));C0.displayName=jn.Empty.displayName;const Ml=k.forwardRef(({className:e,...t},n)=>w.jsx(jn.Group,{ref:n,className:Me("text-foreground [&_[cmdk-group-heading]]:text-muted-foreground overflow-hidden p-1 [&_[cmdk-group-heading]]:px-2 [&_[cmdk-group-heading]]:py-1.5 [&_[cmdk-group-heading]]:text-xs [&_[cmdk-group-heading]]:font-medium",e),...t}));Ml.displayName=jn.Group.displayName;const RJ=k.forwardRef(({className:e,...t},n)=>w.jsx(jn.Separator,{ref:n,className:Me("bg-border -mx-1 h-px",e),...t}));RJ.displayName=jn.Separator.displayName;const Fl=k.forwardRef(({className:e,...t},n)=>w.jsx(jn.Item,{ref:n,className:Me("data-[selected='true']:bg-accent data-[selected=true]:text-accent-foreground relative flex cursor-default items-center gap-2 rounded-sm px-2 py-1.5 text-sm outline-none select-none data-[disabled=true]:pointer-events-none data-[disabled=true]:opacity-50 [&_svg]:pointer-events-none [&_svg]:size-4 [&_svg]:shrink-0",e),...t}));Fl.displayName=jn.Item.displayName;const CJ=({layout:e,autoRunFor:t})=>{const n=br(),{stop:r,start:a,isRunning:i}=e;return k.useEffect(()=>{if(!n)return;let l=null;return t!==void 0&&t>-1&&n.getGraph().order>0&&(a(),l=t>0?window.setTimeout(()=>{r()},t):null),()=>{r(),l&&clearTimeout(l)}},[t,a,r,n]),w.jsx(Lt,{size:"icon",onClick:()=>i?r():a(),tooltip:i?"Stop the layout animation":"Start the layout animation",variant:Yr,children:i?w.jsx(Zq,{}):w.jsx(Jq,{})})},NJ=()=>{const e=br(),[t,n]=k.useState("Circular"),[r,a]=k.useState(!1),i=We.use.graphLayoutMaxIterations(),l=wQ(),u=yQ(),c=JQ(),f=YQ({settings:{margin:1}}),p=CQ({maxIterations:i}),g=_3({iterations:i}),b=KQ(),m=NQ(),S=BQ(),v=k.useMemo(()=>({Circular:{layout:l},Circlepack:{layout:u},Random:{layout:c},Noverlaps:{layout:f,worker:b},"Force Directed":{layout:p,worker:m},"Force Atlas":{layout:g,worker:S}}),[u,l,p,g,f,c,m,b,S]),A=k.useCallback(R=>{console.debug(R);const{positions:x}=v[R].layout;zX(e.getGraph(),x(),{duration:500}),n(R)},[v,e]);return w.jsxs(w.Fragment,{children:[w.jsx("div",{children:v[t]&&"worker"in v[t]&&w.jsx(CJ,{layout:v[t].worker})}),w.jsx("div",{children:w.jsxs(kf,{open:r,onOpenChange:a,children:[w.jsx(Af,{asChild:!0,children:w.jsx(Lt,{size:"icon",variant:Yr,onClick:()=>a(R=>!R),tooltip:"Layout Graph",children:w.jsx(Uq,{})})}),w.jsx(yu,{side:"right",align:"center",className:"p-1",children:w.jsx(Of,{children:w.jsx(Df,{children:w.jsx(Ml,{children:Object.keys(v).map(R=>w.jsx(Fl,{onSelect:()=>{A(R)},className:"cursor-pointer text-xs",children:R},R))})})})})]})})]})};var Sd={exports:{}},OJ=Sd.exports,lN;function DJ(){return lN||(lN=1,function(e){(function(t,n,r){function a(c){var f=this,p=u();f.next=function(){var g=2091639*f.s0+f.c*23283064365386963e-26;return f.s0=f.s1,f.s1=f.s2,f.s2=g-(f.c=g|0)},f.c=1,f.s0=p(" "),f.s1=p(" "),f.s2=p(" "),f.s0-=p(c),f.s0<0&&(f.s0+=1),f.s1-=p(c),f.s1<0&&(f.s1+=1),f.s2-=p(c),f.s2<0&&(f.s2+=1),p=null}function i(c,f){return f.c=c.c,f.s0=c.s0,f.s1=c.s1,f.s2=c.s2,f}function l(c,f){var p=new a(c),g=f&&f.state,b=p.next;return b.int32=function(){return p.next()*4294967296|0},b.double=function(){return b()+(b()*2097152|0)*11102230246251565e-32},b.quick=b,g&&(typeof g=="object"&&i(g,p),b.state=function(){return i(p,{})}),b}function u(){var c=4022871197,f=function(p){p=String(p);for(var g=0;g<p.length;g++){c+=p.charCodeAt(g);var b=.02519603282416938*c;c=b>>>0,b-=c,b*=c,c=b>>>0,b-=c,c+=b*4294967296}return(c>>>0)*23283064365386963e-26};return f}n&&n.exports?n.exports=l:this.alea=l})(OJ,e)}(Sd)),Sd.exports}var Ed={exports:{}},IJ=Ed.exports,sN;function LJ(){return sN||(sN=1,function(e){(function(t,n,r){function a(u){var c=this,f="";c.x=0,c.y=0,c.z=0,c.w=0,c.next=function(){var g=c.x^c.x<<11;return c.x=c.y,c.y=c.z,c.z=c.w,c.w^=c.w>>>19^g^g>>>8},u===(u|0)?c.x=u:f+=u;for(var p=0;p<f.length+64;p++)c.x^=f.charCodeAt(p)|0,c.next()}function i(u,c){return c.x=u.x,c.y=u.y,c.z=u.z,c.w=u.w,c}function l(u,c){var f=new a(u),p=c&&c.state,g=function(){return(f.next()>>>0)/4294967296};return g.double=function(){do var b=f.next()>>>11,m=(f.next()>>>0)/4294967296,S=(b+m)/(1<<21);while(S===0);return S},g.int32=f.next,g.quick=g,p&&(typeof p=="object"&&i(p,f),g.state=function(){return i(f,{})}),g}n&&n.exports?n.exports=l:this.xor128=l})(IJ,e)}(Ed)),Ed.exports}var wd={exports:{}},MJ=wd.exports,uN;function FJ(){return uN||(uN=1,function(e){(function(t,n,r){function a(u){var c=this,f="";c.next=function(){var g=c.x^c.x>>>2;return c.x=c.y,c.y=c.z,c.z=c.w,c.w=c.v,(c.d=c.d+362437|0)+(c.v=c.v^c.v<<4^(g^g<<1))|0},c.x=0,c.y=0,c.z=0,c.w=0,c.v=0,u===(u|0)?c.x=u:f+=u;for(var p=0;p<f.length+64;p++)c.x^=f.charCodeAt(p)|0,p==f.length&&(c.d=c.x<<10^c.x>>>4),c.next()}function i(u,c){return c.x=u.x,c.y=u.y,c.z=u.z,c.w=u.w,c.v=u.v,c.d=u.d,c}function l(u,c){var f=new a(u),p=c&&c.state,g=function(){return(f.next()>>>0)/4294967296};return g.double=function(){do var b=f.next()>>>11,m=(f.next()>>>0)/4294967296,S=(b+m)/(1<<21);while(S===0);return S},g.int32=f.next,g.quick=g,p&&(typeof p=="object"&&i(p,f),g.state=function(){return i(f,{})}),g}n&&n.exports?n.exports=l:this.xorwow=l})(MJ,e)}(wd)),wd.exports}var xd={exports:{}},zJ=xd.exports,cN;function PJ(){return cN||(cN=1,function(e){(function(t,n,r){function a(u){var c=this;c.next=function(){var p=c.x,g=c.i,b,m;return b=p[g],b^=b>>>7,m=b^b<<24,b=p[g+1&7],m^=b^b>>>10,b=p[g+3&7],m^=b^b>>>3,b=p[g+4&7],m^=b^b<<7,b=p[g+7&7],b=b^b<<13,m^=b^b<<9,p[g]=m,c.i=g+1&7,m};function f(p,g){var b,m=[];if(g===(g|0))m[0]=g;else for(g=""+g,b=0;b<g.length;++b)m[b&7]=m[b&7]<<15^g.charCodeAt(b)+m[b+1&7]<<13;for(;m.length<8;)m.push(0);for(b=0;b<8&&m[b]===0;++b);for(b==8?m[7]=-1:m[b],p.x=m,p.i=0,b=256;b>0;--b)p.next()}f(c,u)}function i(u,c){return c.x=u.x.slice(),c.i=u.i,c}function l(u,c){u==null&&(u=+new Date);var f=new a(u),p=c&&c.state,g=function(){return(f.next()>>>0)/4294967296};return g.double=function(){do var b=f.next()>>>11,m=(f.next()>>>0)/4294967296,S=(b+m)/(1<<21);while(S===0);return S},g.int32=f.next,g.quick=g,p&&(p.x&&i(p,f),g.state=function(){return i(f,{})}),g}n&&n.exports?n.exports=l:this.xorshift7=l})(zJ,e)}(xd)),xd.exports}var kd={exports:{}},BJ=kd.exports,dN;function UJ(){return dN||(dN=1,function(e){(function(t,n,r){function a(u){var c=this;c.next=function(){var p=c.w,g=c.X,b=c.i,m,S;return c.w=p=p+1640531527|0,S=g[b+34&127],m=g[b=b+1&127],S^=S<<13,m^=m<<17,S^=S>>>15,m^=m>>>12,S=g[b]=S^m,c.i=b,S+(p^p>>>16)|0};function f(p,g){var b,m,S,v,A,R=[],x=128;for(g===(g|0)?(m=g,g=null):(g=g+"\0",m=0,x=Math.max(x,g.length)),S=0,v=-32;v<x;++v)g&&(m^=g.charCodeAt((v+32)%g.length)),v===0&&(A=m),m^=m<<10,m^=m>>>15,m^=m<<4,m^=m>>>13,v>=0&&(A=A+1640531527|0,b=R[v&127]^=m+A,S=b==0?S+1:0);for(S>=128&&(R[(g&&g.length||0)&127]=-1),S=127,v=4*128;v>0;--v)m=R[S+34&127],b=R[S=S+1&127],m^=m<<13,b^=b<<17,m^=m>>>15,b^=b>>>12,R[S]=m^b;p.w=A,p.X=R,p.i=S}f(c,u)}function i(u,c){return c.i=u.i,c.w=u.w,c.X=u.X.slice(),c}function l(u,c){u==null&&(u=+new Date);var f=new a(u),p=c&&c.state,g=function(){return(f.next()>>>0)/4294967296};return g.double=function(){do var b=f.next()>>>11,m=(f.next()>>>0)/4294967296,S=(b+m)/(1<<21);while(S===0);return S},g.int32=f.next,g.quick=g,p&&(p.X&&i(p,f),g.state=function(){return i(f,{})}),g}n&&n.exports?n.exports=l:this.xor4096=l})(BJ,e)}(kd)),kd.exports}var Ad={exports:{}},jJ=Ad.exports,fN;function GJ(){return fN||(fN=1,function(e){(function(t,n,r){function a(u){var c=this,f="";c.next=function(){var g=c.b,b=c.c,m=c.d,S=c.a;return g=g<<25^g>>>7^b,b=b-m|0,m=m<<24^m>>>8^S,S=S-g|0,c.b=g=g<<20^g>>>12^b,c.c=b=b-m|0,c.d=m<<16^b>>>16^S,c.a=S-g|0},c.a=0,c.b=0,c.c=-1640531527,c.d=1367130551,u===Math.floor(u)?(c.a=u/4294967296|0,c.b=u|0):f+=u;for(var p=0;p<f.length+20;p++)c.b^=f.charCodeAt(p)|0,c.next()}function i(u,c){return c.a=u.a,c.b=u.b,c.c=u.c,c.d=u.d,c}function l(u,c){var f=new a(u),p=c&&c.state,g=function(){return(f.next()>>>0)/4294967296};return g.double=function(){do var b=f.next()>>>11,m=(f.next()>>>0)/4294967296,S=(b+m)/(1<<21);while(S===0);return S},g.int32=f.next,g.quick=g,p&&(typeof p=="object"&&i(p,f),g.state=function(){return i(f,{})}),g}n&&n.exports?n.exports=l:this.tychei=l})(jJ,e)}(Ad)),Ad.exports}var Td={exports:{}};const HJ={},$J=Object.freeze(Object.defineProperty({__proto__:null,default:HJ},Symbol.toStringTag,{value:"Module"})),qJ=pH($J);var VJ=Td.exports,pN;function WJ(){return pN||(pN=1,function(e){(function(t,n,r){var a=256,i=6,l=52,u="random",c=r.pow(a,i),f=r.pow(2,l),p=f*2,g=a-1,b;function m(C,N,_){var O=[];N=N==!0?{entropy:!0}:N||{};var z=R(A(N.entropy?[C,T(n)]:C??x(),3),O),I=new S(O),M=function(){for(var H=I.g(i),q=c,P=0;H<f;)H=(H+P)*a,q*=a,P=I.g(1);for(;H>=p;)H/=2,q/=2,P>>>=1;return(H+P)/q};return M.int32=function(){return I.g(4)|0},M.quick=function(){return I.g(4)/4294967296},M.double=M,R(T(I.S),n),(N.pass||_||function(H,q,P,W){return W&&(W.S&&v(W,I),H.state=function(){return v(I,{})}),P?(r[u]=H,q):H})(M,z,"global"in N?N.global:this==r,N.state)}function S(C){var N,_=C.length,O=this,z=0,I=O.i=O.j=0,M=O.S=[];for(_||(C=[_++]);z<a;)M[z]=z++;for(z=0;z<a;z++)M[z]=M[I=g&I+C[z%_]+(N=M[z])],M[I]=N;(O.g=function(H){for(var q,P=0,W=O.i,Z=O.j,j=O.S;H--;)q=j[W=g&W+1],P=P*a+j[g&(j[W]=j[Z=g&Z+q])+(j[Z]=q)];return O.i=W,O.j=Z,P})(a)}function v(C,N){return N.i=C.i,N.j=C.j,N.S=C.S.slice(),N}function A(C,N){var _=[],O=typeof C,z;if(N&&O=="object")for(z in C)try{_.push(A(C[z],N-1))}catch{}return _.length?_:O=="string"?C:C+"\0"}function R(C,N){for(var _=C+"",O,z=0;z<_.length;)N[g&z]=g&(O^=N[g&z]*19)+_.charCodeAt(z++);return T(N)}function x(){try{var C;return b&&(C=b.randomBytes)?C=C(a):(C=new Uint8Array(a),(t.crypto||t.msCrypto).getRandomValues(C)),T(C)}catch{var N=t.navigator,_=N&&N.plugins;return[+new Date,t,_,t.screen,T(n)]}}function T(C){return String.fromCharCode.apply(0,C)}if(R(r.random(),n),e.exports){e.exports=m;try{b=qJ}catch{}}else r["seed"+u]=m})(typeof self<"u"?self:VJ,[],Math)}(Td)),Td.exports}var im,gN;function YJ(){if(gN)return im;gN=1;var e=DJ(),t=LJ(),n=FJ(),r=PJ(),a=UJ(),i=GJ(),l=WJ();return l.alea=e,l.xor128=t,l.xorwow=n,l.xorshift7=r,l.xor4096=a,l.tychei=i,im=l,im}var KJ=YJ();const XJ=an(KJ),ZJ=e=>{if(!e||!Array.isArray(e.nodes)||!Array.isArray(e.edges))return!1;for(const t of e.nodes)if(!t.id||!t.labels||!t.properties)return!1;for(const t of e.edges)if(!t.id||!t.source||!t.target)return!1;for(const t of e.edges){const n=e.getNode(t.source),r=e.getNode(t.target);if(n==null||r==null)return!1}return!0},QJ=async(e,t,n)=>{let r=null;try{r=await sq(e,t,n)}catch(i){return Pn.getState().setErrorMessage(Nr(i),"Query Graphs Error!"),null}let a=null;if(r){const i={},l={};for(let p=0;p<r.nodes.length;p++){const g=r.nodes[p];i[g.id]=p,XJ(g.id,{global:!0}),g.color=b9(),g.x=Math.random(),g.y=Math.random(),g.degree=0,g.size=10}for(let p=0;p<r.edges.length;p++){const g=r.edges[p];l[g.id]=p;const b=i[g.source],m=i[g.target];if(b!==void 0&&b!==void 0){const S=r.nodes[b],v=r.nodes[m];if(!S){console.error(`Source node ${g.source} is undefined`);continue}if(!v){console.error(`Target node ${g.target} is undefined`);continue}S.degree+=1,v.degree+=1}}let u=Number.MAX_SAFE_INTEGER,c=0;for(const p of r.nodes)u=Math.min(u,p.degree),c=Math.max(c,p.degree);const f=c-u;if(f>0){const p=A9-iR;for(const g of r.nodes)g.size=Math.round(iR+p*Math.pow((g.degree-u)/f,.5))}a=new cQ,a.nodes=r.nodes,a.edges=r.edges,a.nodeIdMap=i,a.edgeIdMap=l,ZJ(a)||(a=null,console.error("Invalid graph data")),console.log("Graph data loaded")}return a},JJ=e=>{const t=new nu;for(const n of(e==null?void 0:e.nodes)??[])t.addNode(n.id,{label:n.labels.join(", "),color:n.color,x:n.x,y:n.y,size:n.size,borderColor:E9,borderSize:.2});for(const n of(e==null?void 0:e.edges)??[])n.dynamicId=t.addDirectedEdge(n.source,n.target,{label:n.type||void 0});return t},Ji={label:"",maxQueryDepth:0,minDegree:0},U3=()=>{const e=We.use.queryLabel(),t=Et.use.rawGraph(),n=Et.use.sigmaGraph(),r=We.use.graphQueryMaxDepth(),a=We.use.graphMinDegree(),i=k.useCallback(c=>(t==null?void 0:t.getNode(c))||null,[t]),l=k.useCallback((c,f=!0)=>(t==null?void 0:t.getEdge(c,f))||null,[t]);return k.useEffect(()=>{if(e){if(Ji.label!==e||Ji.maxQueryDepth!==r||Ji.minDegree!==a){Ji.label=e,Ji.maxQueryDepth=r,Ji.minDegree=a;const c=Et.getState();c.reset(),QJ(e,r,a).then(f=>{c.setSigmaGraph(JJ(f)),f==null||f.buildDynamicMap(),c.setRawGraph(f)})}}else{const c=Et.getState();c.reset(),c.setSigmaGraph(new nu)}},[e,r,a]),{lightrageGraph:k.useCallback(()=>{if(n)return n;const c=new nu;return Et.getState().setSigmaGraph(c),c},[n]),getNode:i,getEdge:l}},ed=e=>!!(e.type.startsWith("mouse")&&e.buttons!==0),eee=({disableHoverEffect:e})=>{const{lightrageGraph:t}=U3(),n=br(),r=i3(),a=o3(),i=dZ(),l=We.use.graphLayoutMaxIterations(),{assign:u}=_3({iterations:l}),{theme:c}=l0(),f=We.use.enableHideUnselectedEdges(),p=Et.use.selectedNode(),g=Et.use.focusedNode(),b=Et.use.selectedEdge(),m=Et.use.focusedEdge();return k.useEffect(()=>{const S=t();i(S),u()},[u,i,t,l]),k.useEffect(()=>{const{setFocusedNode:S,setSelectedNode:v,setFocusedEdge:A,setSelectedEdge:R,clearSelection:x}=Et.getState();r({enterNode:T=>{ed(T.event.original)||S(T.node)},leaveNode:T=>{ed(T.event.original)||S(null)},clickNode:T=>{v(T.node),R(null)},clickEdge:T=>{R(T.edge),v(null)},enterEdge:T=>{ed(T.event.original)||A(T.edge)},leaveEdge:T=>{ed(T.event.original)||A(null)},clickStage:()=>x()})},[r]),k.useEffect(()=>{const S=c==="dark",v=S?y9:void 0,A=S?x9:void 0;a({nodeReducer:(R,x)=>{const T=n.getGraph(),C={...x,highlighted:x.highlighted||!1,labelColor:v};if(!e){C.highlighted=!1;const N=g||p,_=m||b;if(N)(R===N||T.neighbors(N).includes(R))&&(C.highlighted=!0,R===p&&(C.borderColor=w9));else if(_)T.extremities(_).includes(R)&&(C.highlighted=!0,C.size=3);else return C;C.highlighted?S&&(C.labelColor=v9):C.color=S9}return C},edgeReducer:(R,x)=>{const T=n.getGraph(),C={...x,hidden:!1,labelColor:v,color:A};if(!e){const N=g||p;N?f?T.extremities(R).includes(N)||(C.hidden=!0):T.extremities(R).includes(N)&&(C.color=oR):(m||b)&&(R===b?C.color=k9:R===m?C.color=oR:f&&(C.hidden=!0))}return C}})},[p,g,b,m,a,n,e,c,f]),null},tee=()=>{const{zoomIn:e,zoomOut:t,reset:n}=l3({duration:200,factor:1.5}),r=k.useCallback(()=>e(),[e]),a=k.useCallback(()=>t(),[t]),i=k.useCallback(()=>n(),[n]);return w.jsxs(w.Fragment,{children:[w.jsx(Lt,{variant:Yr,onClick:r,tooltip:"Zoom In",size:"icon",children:w.jsx(h8,{})}),w.jsx(Lt,{variant:Yr,onClick:a,tooltip:"Zoom Out",size:"icon",children:w.jsx(b8,{})}),w.jsx(Lt,{variant:Yr,onClick:i,tooltip:"Reset Zoom",size:"icon",children:w.jsx(Fq,{})})]})},nee=()=>{const{isFullScreen:e,toggle:t}=fZ();return w.jsx(w.Fragment,{children:e?w.jsx(Lt,{variant:Yr,onClick:t,tooltip:"Windowed",size:"icon",children:w.jsx(Wq,{})}):w.jsx(Lt,{variant:Yr,onClick:t,tooltip:"Full Screen",size:"icon",children:w.jsx(qq,{})})})};function j3(e){const t=k.useRef({value:e,previous:e});return k.useMemo(()=>(t.current.value!==e&&(t.current.previous=t.current.value,t.current.value=e),t.current.previous),[e])}var N0="Checkbox",[ree,rve]=mr(N0),[aee,oee]=ree(N0),G3=k.forwardRef((e,t)=>{const{__scopeCheckbox:n,name:r,checked:a,defaultChecked:i,required:l,disabled:u,value:c="on",onCheckedChange:f,form:p,...g}=e,[b,m]=k.useState(null),S=ft(t,C=>m(C)),v=k.useRef(!1),A=b?p||!!b.closest("form"):!0,[R=!1,x]=Oa({prop:a,defaultProp:i,onChange:f}),T=k.useRef(R);return k.useEffect(()=>{const C=b==null?void 0:b.form;if(C){const N=()=>x(T.current);return C.addEventListener("reset",N),()=>C.removeEventListener("reset",N)}},[b,x]),w.jsxs(aee,{scope:n,state:R,disabled:u,children:[w.jsx(Xe.button,{type:"button",role:"checkbox","aria-checked":ho(R)?"mixed":R,"aria-required":l,"data-state":q3(R),"data-disabled":u?"":void 0,disabled:u,value:c,...g,ref:S,onKeyDown:Ye(e.onKeyDown,C=>{C.key==="Enter"&&C.preventDefault()}),onClick:Ye(e.onClick,C=>{x(N=>ho(N)?!0:!N),A&&(v.current=C.isPropagationStopped(),v.current||C.stopPropagation())})}),A&&w.jsx(iee,{control:b,bubbles:!v.current,name:r,value:c,checked:R,required:l,disabled:u,form:p,style:{transform:"translateX(-100%)"},defaultChecked:ho(i)?!1:i})]})});G3.displayName=N0;var H3="CheckboxIndicator",$3=k.forwardRef((e,t)=>{const{__scopeCheckbox:n,forceMount:r,...a}=e,i=oee(H3,n);return w.jsx(Jn,{present:r||ho(i.state)||i.state===!0,children:w.jsx(Xe.span,{"data-state":q3(i.state),"data-disabled":i.disabled?"":void 0,...a,ref:t,style:{pointerEvents:"none",...e.style}})})});$3.displayName=H3;var iee=e=>{const{control:t,checked:n,bubbles:r=!0,defaultChecked:a,...i}=e,l=k.useRef(null),u=j3(n),c=yB(t);k.useEffect(()=>{const p=l.current,g=window.HTMLInputElement.prototype,m=Object.getOwnPropertyDescriptor(g,"checked").set;if(u!==n&&m){const S=new Event("click",{bubbles:r});p.indeterminate=ho(n),m.call(p,ho(n)?!1:n),p.dispatchEvent(S)}},[u,n,r]);const f=k.useRef(ho(n)?!1:n);return w.jsx("input",{type:"checkbox","aria-hidden":!0,defaultChecked:a??f.current,...i,tabIndex:-1,ref:l,style:{...e.style,...c,position:"absolute",pointerEvents:"none",opacity:0,margin:0}})};function ho(e){return e==="indeterminate"}function q3(e){return ho(e)?"indeterminate":e?"checked":"unchecked"}var V3=G3,lee=$3;const Ks=k.forwardRef(({className:e,...t},n)=>w.jsx(V3,{ref:n,className:Me("peer border-primary ring-offset-background focus-visible:ring-ring data-[state=checked]:bg-primary data-[state=checked]:text-primary-foreground h-4 w-4 shrink-0 rounded-sm border focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none disabled:cursor-not-allowed disabled:opacity-50",e),...t,children:w.jsx(lee,{className:Me("flex items-center justify-center text-current"),children:w.jsx(Nk,{className:"h-4 w-4"})})}));Ks.displayName=V3.displayName;var see="Separator",hN="horizontal",uee=["horizontal","vertical"],W3=k.forwardRef((e,t)=>{const{decorative:n,orientation:r=hN,...a}=e,i=cee(r)?r:hN,u=n?{role:"none"}:{"aria-orientation":i==="vertical"?i:void 0,role:"separator"};return w.jsx(Xe.div,{"data-orientation":i,...u,...a,ref:t})});W3.displayName=see;function cee(e){return uee.includes(e)}var Y3=W3;const il=k.forwardRef(({className:e,orientation:t="horizontal",decorative:n=!0,...r},a)=>w.jsx(Y3,{ref:a,decorative:n,orientation:t,className:Me("bg-border shrink-0",t==="horizontal"?"h-[1px] w-full":"h-full w-[1px]",e),...r}));il.displayName=Y3.displayName;const so=({checked:e,onCheckedChange:t,label:n})=>w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsx(Ks,{checked:e,onCheckedChange:t}),w.jsx("label",{htmlFor:"terms",className:"text-sm leading-none font-medium peer-disabled:cursor-not-allowed peer-disabled:opacity-70",children:n})]}),lm=({value:e,onEditFinished:t,label:n,min:r,max:a})=>{const[i,l]=k.useState(e),u=k.useCallback(f=>{const p=f.target.value.trim();if(p.length===0){l(null);return}const g=Number.parseInt(p);if(!isNaN(g)&&g!==i){if(r!==void 0&&g<r||a!==void 0&&g>a)return;l(g)}},[i,r,a]),c=k.useCallback(()=>{i!==null&&e!==i&&t(i)},[e,i,t]);return w.jsxs("div",{className:"flex flex-col gap-2",children:[w.jsx("label",{htmlFor:"terms",className:"text-sm leading-none font-medium peer-disabled:cursor-not-allowed peer-disabled:opacity-70",children:n}),w.jsx(Eo,{type:"number",value:i===null?"":i,onChange:u,className:"h-6 w-full min-w-0 pr-1",min:r,max:a,onBlur:c,onKeyDown:f=>{f.key==="Enter"&&c()}})]})};function dee(){const[e,t]=k.useState(!1),[n,r]=k.useState(""),a=We.use.showPropertyPanel(),i=We.use.showNodeSearchBar(),l=We.use.showNodeLabel(),u=We.use.enableEdgeEvents(),c=We.use.enableNodeDrag(),f=We.use.enableHideUnselectedEdges(),p=We.use.showEdgeLabel(),g=We.use.graphQueryMaxDepth(),b=We.use.graphMinDegree(),m=We.use.graphLayoutMaxIterations(),S=We.use.enableHealthCheck(),v=We.use.apiKey();k.useEffect(()=>{r(v||"")},[v,e]);const A=k.useCallback(()=>We.setState(P=>({enableNodeDrag:!P.enableNodeDrag})),[]),R=k.useCallback(()=>We.setState(P=>({enableEdgeEvents:!P.enableEdgeEvents})),[]),x=k.useCallback(()=>We.setState(P=>({enableHideUnselectedEdges:!P.enableHideUnselectedEdges})),[]),T=k.useCallback(()=>We.setState(P=>({showEdgeLabel:!P.showEdgeLabel})),[]),C=k.useCallback(()=>We.setState(P=>({showPropertyPanel:!P.showPropertyPanel})),[]),N=k.useCallback(()=>We.setState(P=>({showNodeSearchBar:!P.showNodeSearchBar})),[]),_=k.useCallback(()=>We.setState(P=>({showNodeLabel:!P.showNodeLabel})),[]),O=k.useCallback(()=>We.setState(P=>({enableHealthCheck:!P.enableHealthCheck})),[]),z=k.useCallback(P=>{P<1||We.setState({graphQueryMaxDepth:P})},[]),I=k.useCallback(P=>{P<0||We.setState({graphMinDegree:P})},[]),M=k.useCallback(P=>{P<1||We.setState({graphLayoutMaxIterations:P})},[]),H=k.useCallback(async()=>{We.setState({apiKey:n||null}),await Pn.getState().check(),t(!1)},[n]),q=k.useCallback(P=>{r(P.target.value)},[r]);return w.jsxs(kf,{open:e,onOpenChange:t,children:[w.jsx(Af,{asChild:!0,children:w.jsx(Lt,{variant:Yr,tooltip:"Settings",size:"icon",children:w.jsx(l8,{})})}),w.jsx(yu,{side:"right",align:"start",className:"mb-2 p-2",onCloseAutoFocus:P=>P.preventDefault(),children:w.jsxs("div",{className:"flex flex-col gap-2",children:[w.jsx(so,{checked:S,onCheckedChange:O,label:"Health Check"}),w.jsx(il,{}),w.jsx(so,{checked:a,onCheckedChange:C,label:"Show Property Panel"}),w.jsx(so,{checked:i,onCheckedChange:N,label:"Show Search Bar"}),w.jsx(il,{}),w.jsx(so,{checked:l,onCheckedChange:_,label:"Show Node Label"}),w.jsx(so,{checked:c,onCheckedChange:A,label:"Node Draggable"}),w.jsx(il,{}),w.jsx(so,{checked:p,onCheckedChange:T,label:"Show Edge Label"}),w.jsx(so,{checked:f,onCheckedChange:x,label:"Hide Unselected Edges"}),w.jsx(so,{checked:u,onCheckedChange:R,label:"Edge Events"}),w.jsx(il,{}),w.jsx(lm,{label:"Max Query Depth",min:1,value:g,onEditFinished:z}),w.jsx(lm,{label:"Minimum Degree",min:0,value:b,onEditFinished:I}),w.jsx(lm,{label:"Max Layout Iterations",min:1,max:20,value:m,onEditFinished:M}),w.jsx(il,{}),w.jsxs("div",{className:"flex flex-col gap-2",children:[w.jsx("label",{className:"text-sm font-medium",children:"API Key"}),w.jsxs("form",{className:"flex h-6 gap-2",onSubmit:P=>P.preventDefault(),children:[w.jsx("div",{className:"w-0 flex-1",children:w.jsx(Eo,{type:"password",value:n,onChange:q,placeholder:"Enter your API key",className:"max-h-full w-full min-w-0",autoComplete:"off"})}),w.jsx(Lt,{onClick:H,variant:"outline",size:"sm",className:"max-h-full shrink-0",children:"Save"})]})]})]})})]})}const fee="ENTRIES",K3="KEYS",X3="VALUES",fn="";class sm{constructor(t,n){const r=t._tree,a=Array.from(r.keys());this.set=t,this._type=n,this._path=a.length>0?[{node:r,keys:a}]:[]}next(){const t=this.dive();return this.backtrack(),t}dive(){if(this._path.length===0)return{done:!0,value:void 0};const{node:t,keys:n}=el(this._path);if(el(n)===fn)return{done:!1,value:this.result()};const r=t.get(el(n));return this._path.push({node:r,keys:Array.from(r.keys())}),this.dive()}backtrack(){if(this._path.length===0)return;const t=el(this._path).keys;t.pop(),!(t.length>0)&&(this._path.pop(),this.backtrack())}key(){return this.set._prefix+this._path.map(({keys:t})=>el(t)).filter(t=>t!==fn).join("")}value(){return el(this._path).node.get(fn)}result(){switch(this._type){case X3:return this.value();case K3:return this.key();default:return[this.key(),this.value()]}}[Symbol.iterator](){return this}}const el=e=>e[e.length-1],pee=(e,t,n)=>{const r=new Map;if(t===void 0)return r;const a=t.length+1,i=a+n,l=new Uint8Array(i*a).fill(n+1);for(let u=0;u<a;++u)l[u]=u;for(let u=1;u<i;++u)l[u*a]=u;return Z3(e,t,n,r,l,1,a,""),r},Z3=(e,t,n,r,a,i,l,u)=>{const c=i*l;e:for(const f of e.keys())if(f===fn){const p=a[c-1];p<=n&&r.set(u,[e.get(f),p])}else{let p=i;for(let g=0;g<f.length;++g,++p){const b=f[g],m=l*p,S=m-l;let v=a[m];const A=Math.max(0,p-n-1),R=Math.min(l-1,p+n);for(let x=A;x<R;++x){const T=b!==t[x],C=a[S+x]+ +T,N=a[S+x+1]+1,_=a[m+x]+1,O=a[m+x+1]=Math.min(C,N,_);O<v&&(v=O)}if(v>n)continue e}Z3(e.get(f),t,n,r,a,p,l,u+f)}};class po{constructor(t=new Map,n=""){this._size=void 0,this._tree=t,this._prefix=n}atPrefix(t){if(!t.startsWith(this._prefix))throw new Error("Mismatched prefix");const[n,r]=Gd(this._tree,t.slice(this._prefix.length));if(n===void 0){const[a,i]=O0(r);for(const l of a.keys())if(l!==fn&&l.startsWith(i)){const u=new Map;return u.set(l.slice(i.length),a.get(l)),new po(u,t)}}return new po(n,t)}clear(){this._size=void 0,this._tree.clear()}delete(t){return this._size=void 0,gee(this._tree,t)}entries(){return new sm(this,fee)}forEach(t){for(const[n,r]of this)t(n,r,this)}fuzzyGet(t,n){return pee(this._tree,t,n)}get(t){const n=qx(this._tree,t);return n!==void 0?n.get(fn):void 0}has(t){const n=qx(this._tree,t);return n!==void 0&&n.has(fn)}keys(){return new sm(this,K3)}set(t,n){if(typeof t!="string")throw new Error("key must be a string");return this._size=void 0,um(this._tree,t).set(fn,n),this}get size(){if(this._size)return this._size;this._size=0;const t=this.entries();for(;!t.next().done;)this._size+=1;return this._size}update(t,n){if(typeof t!="string")throw new Error("key must be a string");this._size=void 0;const r=um(this._tree,t);return r.set(fn,n(r.get(fn))),this}fetch(t,n){if(typeof t!="string")throw new Error("key must be a string");this._size=void 0;const r=um(this._tree,t);let a=r.get(fn);return a===void 0&&r.set(fn,a=n()),a}values(){return new sm(this,X3)}[Symbol.iterator](){return this.entries()}static from(t){const n=new po;for(const[r,a]of t)n.set(r,a);return n}static fromObject(t){return po.from(Object.entries(t))}}const Gd=(e,t,n=[])=>{if(t.length===0||e==null)return[e,n];for(const r of e.keys())if(r!==fn&&t.startsWith(r))return n.push([e,r]),Gd(e.get(r),t.slice(r.length),n);return n.push([e,t]),Gd(void 0,"",n)},qx=(e,t)=>{if(t.length===0||e==null)return e;for(const n of e.keys())if(n!==fn&&t.startsWith(n))return qx(e.get(n),t.slice(n.length))},um=(e,t)=>{const n=t.length;e:for(let r=0;e&&r<n;){for(const i of e.keys())if(i!==fn&&t[r]===i[0]){const l=Math.min(n-r,i.length);let u=1;for(;u<l&&t[r+u]===i[u];)++u;const c=e.get(i);if(u===i.length)e=c;else{const f=new Map;f.set(i.slice(u),c),e.set(t.slice(r,r+u),f),e.delete(i),e=f}r+=u;continue e}const a=new Map;return e.set(t.slice(r),a),a}return e},gee=(e,t)=>{const[n,r]=Gd(e,t);if(n!==void 0){if(n.delete(fn),n.size===0)Q3(r);else if(n.size===1){const[a,i]=n.entries().next().value;J3(r,a,i)}}},Q3=e=>{if(e.length===0)return;const[t,n]=O0(e);if(t.delete(n),t.size===0)Q3(e.slice(0,-1));else if(t.size===1){const[r,a]=t.entries().next().value;r!==fn&&J3(e.slice(0,-1),r,a)}},J3=(e,t,n)=>{if(e.length===0)return;const[r,a]=O0(e);r.set(a+t,n),r.delete(a)},O0=e=>e[e.length-1],D0="or",e4="and",hee="and_not";class mo{constructor(t){if((t==null?void 0:t.fields)==null)throw new Error('MiniSearch: option "fields" must be provided');const n=t.autoVacuum==null||t.autoVacuum===!0?fm:t.autoVacuum;this._options={...dm,...t,autoVacuum:n,searchOptions:{...mN,...t.searchOptions||{}},autoSuggestOptions:{...See,...t.autoSuggestOptions||{}}},this._index=new po,this._documentCount=0,this._documentIds=new Map,this._idToShortId=new Map,this._fieldIds={},this._fieldLength=new Map,this._avgFieldLength=[],this._nextId=0,this._storedFields=new Map,this._dirtCount=0,this._currentVacuum=null,this._enqueuedVacuum=null,this._enqueuedVacuumConditions=Wx,this.addFields(this._options.fields)}add(t){const{extractField:n,tokenize:r,processTerm:a,fields:i,idField:l}=this._options,u=n(t,l);if(u==null)throw new Error(`MiniSearch: document does not have ID field "${l}"`);if(this._idToShortId.has(u))throw new Error(`MiniSearch: duplicate ID ${u}`);const c=this.addDocumentId(u);this.saveStoredFields(c,t);for(const f of i){const p=n(t,f);if(p==null)continue;const g=r(p.toString(),f),b=this._fieldIds[f],m=new Set(g).size;this.addFieldLength(c,b,this._documentCount-1,m);for(const S of g){const v=a(S,f);if(Array.isArray(v))for(const A of v)this.addTerm(b,c,A);else v&&this.addTerm(b,c,v)}}}addAll(t){for(const n of t)this.add(n)}addAllAsync(t,n={}){const{chunkSize:r=10}=n,a={chunk:[],promise:Promise.resolve()},{chunk:i,promise:l}=t.reduce(({chunk:u,promise:c},f,p)=>(u.push(f),(p+1)%r===0?{chunk:[],promise:c.then(()=>new Promise(g=>setTimeout(g,0))).then(()=>this.addAll(u))}:{chunk:u,promise:c}),a);return l.then(()=>this.addAll(i))}remove(t){const{tokenize:n,processTerm:r,extractField:a,fields:i,idField:l}=this._options,u=a(t,l);if(u==null)throw new Error(`MiniSearch: document does not have ID field "${l}"`);const c=this._idToShortId.get(u);if(c==null)throw new Error(`MiniSearch: cannot remove document with ID ${u}: it is not in the index`);for(const f of i){const p=a(t,f);if(p==null)continue;const g=n(p.toString(),f),b=this._fieldIds[f],m=new Set(g).size;this.removeFieldLength(c,b,this._documentCount,m);for(const S of g){const v=r(S,f);if(Array.isArray(v))for(const A of v)this.removeTerm(b,c,A);else v&&this.removeTerm(b,c,v)}}this._storedFields.delete(c),this._documentIds.delete(c),this._idToShortId.delete(u),this._fieldLength.delete(c),this._documentCount-=1}removeAll(t){if(t)for(const n of t)this.remove(n);else{if(arguments.length>0)throw new Error("Expected documents to be present. Omit the argument to remove all documents.");this._index=new po,this._documentCount=0,this._documentIds=new Map,this._idToShortId=new Map,this._fieldLength=new Map,this._avgFieldLength=[],this._storedFields=new Map,this._nextId=0}}discard(t){const n=this._idToShortId.get(t);if(n==null)throw new Error(`MiniSearch: cannot discard document with ID ${t}: it is not in the index`);this._idToShortId.delete(t),this._documentIds.delete(n),this._storedFields.delete(n),(this._fieldLength.get(n)||[]).forEach((r,a)=>{this.removeFieldLength(n,a,this._documentCount,r)}),this._fieldLength.delete(n),this._documentCount-=1,this._dirtCount+=1,this.maybeAutoVacuum()}maybeAutoVacuum(){if(this._options.autoVacuum===!1)return;const{minDirtFactor:t,minDirtCount:n,batchSize:r,batchWait:a}=this._options.autoVacuum;this.conditionalVacuum({batchSize:r,batchWait:a},{minDirtCount:n,minDirtFactor:t})}discardAll(t){const n=this._options.autoVacuum;try{this._options.autoVacuum=!1;for(const r of t)this.discard(r)}finally{this._options.autoVacuum=n}this.maybeAutoVacuum()}replace(t){const{idField:n,extractField:r}=this._options,a=r(t,n);this.discard(a),this.add(t)}vacuum(t={}){return this.conditionalVacuum(t)}conditionalVacuum(t,n){return this._currentVacuum?(this._enqueuedVacuumConditions=this._enqueuedVacuumConditions&&n,this._enqueuedVacuum!=null?this._enqueuedVacuum:(this._enqueuedVacuum=this._currentVacuum.then(()=>{const r=this._enqueuedVacuumConditions;return this._enqueuedVacuumConditions=Wx,this.performVacuuming(t,r)}),this._enqueuedVacuum)):this.vacuumConditionsMet(n)===!1?Promise.resolve():(this._currentVacuum=this.performVacuuming(t),this._currentVacuum)}async performVacuuming(t,n){const r=this._dirtCount;if(this.vacuumConditionsMet(n)){const a=t.batchSize||Vx.batchSize,i=t.batchWait||Vx.batchWait;let l=1;for(const[u,c]of this._index){for(const[f,p]of c)for(const[g]of p)this._documentIds.has(g)||(p.size<=1?c.delete(f):p.delete(g));this._index.get(u).size===0&&this._index.delete(u),l%a===0&&await new Promise(f=>setTimeout(f,i)),l+=1}this._dirtCount-=r}await null,this._currentVacuum=this._enqueuedVacuum,this._enqueuedVacuum=null}vacuumConditionsMet(t){if(t==null)return!0;let{minDirtCount:n,minDirtFactor:r}=t;return n=n||fm.minDirtCount,r=r||fm.minDirtFactor,this.dirtCount>=n&&this.dirtFactor>=r}get isVacuuming(){return this._currentVacuum!=null}get dirtCount(){return this._dirtCount}get dirtFactor(){return this._dirtCount/(1+this._documentCount+this._dirtCount)}has(t){return this._idToShortId.has(t)}getStoredFields(t){const n=this._idToShortId.get(t);if(n!=null)return this._storedFields.get(n)}search(t,n={}){const{searchOptions:r}=this._options,a={...r,...n},i=this.executeQuery(t,n),l=[];for(const[u,{score:c,terms:f,match:p}]of i){const g=f.length||1,b={id:this._documentIds.get(u),score:c*g,terms:Object.keys(p),queryTerms:f,match:p};Object.assign(b,this._storedFields.get(u)),(a.filter==null||a.filter(b))&&l.push(b)}return t===mo.wildcard&&a.boostDocument==null||l.sort(yN),l}autoSuggest(t,n={}){n={...this._options.autoSuggestOptions,...n};const r=new Map;for(const{score:i,terms:l}of this.search(t,n)){const u=l.join(" "),c=r.get(u);c!=null?(c.score+=i,c.count+=1):r.set(u,{score:i,terms:l,count:1})}const a=[];for(const[i,{score:l,terms:u,count:c}]of r)a.push({suggestion:i,terms:u,score:l/c});return a.sort(yN),a}get documentCount(){return this._documentCount}get termCount(){return this._index.size}static loadJSON(t,n){if(n==null)throw new Error("MiniSearch: loadJSON should be given the same options used when serializing the index");return this.loadJS(JSON.parse(t),n)}static async loadJSONAsync(t,n){if(n==null)throw new Error("MiniSearch: loadJSON should be given the same options used when serializing the index");return this.loadJSAsync(JSON.parse(t),n)}static getDefault(t){if(dm.hasOwnProperty(t))return cm(dm,t);throw new Error(`MiniSearch: unknown option "${t}"`)}static loadJS(t,n){const{index:r,documentIds:a,fieldLength:i,storedFields:l,serializationVersion:u}=t,c=this.instantiateMiniSearch(t,n);c._documentIds=td(a),c._fieldLength=td(i),c._storedFields=td(l);for(const[f,p]of c._documentIds)c._idToShortId.set(p,f);for(const[f,p]of r){const g=new Map;for(const b of Object.keys(p)){let m=p[b];u===1&&(m=m.ds),g.set(parseInt(b,10),td(m))}c._index.set(f,g)}return c}static async loadJSAsync(t,n){const{index:r,documentIds:a,fieldLength:i,storedFields:l,serializationVersion:u}=t,c=this.instantiateMiniSearch(t,n);c._documentIds=await nd(a),c._fieldLength=await nd(i),c._storedFields=await nd(l);for(const[p,g]of c._documentIds)c._idToShortId.set(g,p);let f=0;for(const[p,g]of r){const b=new Map;for(const m of Object.keys(g)){let S=g[m];u===1&&(S=S.ds),b.set(parseInt(m,10),await nd(S))}++f%1e3===0&&await t4(0),c._index.set(p,b)}return c}static instantiateMiniSearch(t,n){const{documentCount:r,nextId:a,fieldIds:i,averageFieldLength:l,dirtCount:u,serializationVersion:c}=t;if(c!==1&&c!==2)throw new Error("MiniSearch: cannot deserialize an index created with an incompatible version");const f=new mo(n);return f._documentCount=r,f._nextId=a,f._idToShortId=new Map,f._fieldIds=i,f._avgFieldLength=l,f._dirtCount=u||0,f._index=new po,f}executeQuery(t,n={}){if(t===mo.wildcard)return this.executeWildcardQuery(n);if(typeof t!="string"){const b={...n,...t,queries:void 0},m=t.queries.map(S=>this.executeQuery(S,b));return this.combineResults(m,b.combineWith)}const{tokenize:r,processTerm:a,searchOptions:i}=this._options,l={tokenize:r,processTerm:a,...i,...n},{tokenize:u,processTerm:c}=l,g=u(t).flatMap(b=>c(b)).filter(b=>!!b).map(vee(l)).map(b=>this.executeQuerySpec(b,l));return this.combineResults(g,l.combineWith)}executeQuerySpec(t,n){const r={...this._options.searchOptions,...n},a=(r.fields||this._options.fields).reduce((v,A)=>({...v,[A]:cm(r.boost,A)||1}),{}),{boostDocument:i,weights:l,maxFuzzy:u,bm25:c}=r,{fuzzy:f,prefix:p}={...mN.weights,...l},g=this._index.get(t.term),b=this.termResults(t.term,t.term,1,t.termBoost,g,a,i,c);let m,S;if(t.prefix&&(m=this._index.atPrefix(t.term)),t.fuzzy){const v=t.fuzzy===!0?.2:t.fuzzy,A=v<1?Math.min(u,Math.round(t.term.length*v)):v;A&&(S=this._index.fuzzyGet(t.term,A))}if(m)for(const[v,A]of m){const R=v.length-t.term.length;if(!R)continue;S==null||S.delete(v);const x=p*v.length/(v.length+.3*R);this.termResults(t.term,v,x,t.termBoost,A,a,i,c,b)}if(S)for(const v of S.keys()){const[A,R]=S.get(v);if(!R)continue;const x=f*v.length/(v.length+R);this.termResults(t.term,v,x,t.termBoost,A,a,i,c,b)}return b}executeWildcardQuery(t){const n=new Map,r={...this._options.searchOptions,...t};for(const[a,i]of this._documentIds){const l=r.boostDocument?r.boostDocument(i,"",this._storedFields.get(a)):1;n.set(a,{score:l,terms:[],match:{}})}return n}combineResults(t,n=D0){if(t.length===0)return new Map;const r=n.toLowerCase(),a=mee[r];if(!a)throw new Error(`Invalid combination operator: ${n}`);return t.reduce(a)||new Map}toJSON(){const t=[];for(const[n,r]of this._index){const a={};for(const[i,l]of r)a[i]=Object.fromEntries(l);t.push([n,a])}return{documentCount:this._documentCount,nextId:this._nextId,documentIds:Object.fromEntries(this._documentIds),fieldIds:this._fieldIds,fieldLength:Object.fromEntries(this._fieldLength),averageFieldLength:this._avgFieldLength,storedFields:Object.fromEntries(this._storedFields),dirtCount:this._dirtCount,index:t,serializationVersion:2}}termResults(t,n,r,a,i,l,u,c,f=new Map){if(i==null)return f;for(const p of Object.keys(l)){const g=l[p],b=this._fieldIds[p],m=i.get(b);if(m==null)continue;let S=m.size;const v=this._avgFieldLength[b];for(const A of m.keys()){if(!this._documentIds.has(A)){this.removeTerm(b,A,n),S-=1;continue}const R=u?u(this._documentIds.get(A),n,this._storedFields.get(A)):1;if(!R)continue;const x=m.get(A),T=this._fieldLength.get(A)[b],C=yee(x,S,this._documentCount,T,v,c),N=r*a*g*R*C,_=f.get(A);if(_){_.score+=N,Eee(_.terms,t);const O=cm(_.match,n);O?O.push(p):_.match[n]=[p]}else f.set(A,{score:N,terms:[t],match:{[n]:[p]}})}}return f}addTerm(t,n,r){const a=this._index.fetch(r,vN);let i=a.get(t);if(i==null)i=new Map,i.set(n,1),a.set(t,i);else{const l=i.get(n);i.set(n,(l||0)+1)}}removeTerm(t,n,r){if(!this._index.has(r)){this.warnDocumentChanged(n,t,r);return}const a=this._index.fetch(r,vN),i=a.get(t);i==null||i.get(n)==null?this.warnDocumentChanged(n,t,r):i.get(n)<=1?i.size<=1?a.delete(t):i.delete(n):i.set(n,i.get(n)-1),this._index.get(r).size===0&&this._index.delete(r)}warnDocumentChanged(t,n,r){for(const a of Object.keys(this._fieldIds))if(this._fieldIds[a]===n){this._options.logger("warn",`MiniSearch: document with ID ${this._documentIds.get(t)} has changed before removal: term "${r}" was not present in field "${a}". Removing a document after it has changed can corrupt the index!`,"version_conflict");return}}addDocumentId(t){const n=this._nextId;return this._idToShortId.set(t,n),this._documentIds.set(n,t),this._documentCount+=1,this._nextId+=1,n}addFields(t){for(let n=0;n<t.length;n++)this._fieldIds[t[n]]=n}addFieldLength(t,n,r,a){let i=this._fieldLength.get(t);i==null&&this._fieldLength.set(t,i=[]),i[n]=a;const u=(this._avgFieldLength[n]||0)*r+a;this._avgFieldLength[n]=u/(r+1)}removeFieldLength(t,n,r,a){if(r===1){this._avgFieldLength[n]=0;return}const i=this._avgFieldLength[n]*r-a;this._avgFieldLength[n]=i/(r-1)}saveStoredFields(t,n){const{storeFields:r,extractField:a}=this._options;if(r==null||r.length===0)return;let i=this._storedFields.get(t);i==null&&this._storedFields.set(t,i={});for(const l of r){const u=a(n,l);u!==void 0&&(i[l]=u)}}}mo.wildcard=Symbol("*");const cm=(e,t)=>Object.prototype.hasOwnProperty.call(e,t)?e[t]:void 0,mee={[D0]:(e,t)=>{for(const n of t.keys()){const r=e.get(n);if(r==null)e.set(n,t.get(n));else{const{score:a,terms:i,match:l}=t.get(n);r.score=r.score+a,r.match=Object.assign(r.match,l),bN(r.terms,i)}}return e},[e4]:(e,t)=>{const n=new Map;for(const r of t.keys()){const a=e.get(r);if(a==null)continue;const{score:i,terms:l,match:u}=t.get(r);bN(a.terms,l),n.set(r,{score:a.score+i,terms:a.terms,match:Object.assign(a.match,u)})}return n},[hee]:(e,t)=>{for(const n of t.keys())e.delete(n);return e}},bee={k:1.2,b:.7,d:.5},yee=(e,t,n,r,a,i)=>{const{k:l,b:u,d:c}=i;return Math.log(1+(n-t+.5)/(t+.5))*(c+e*(l+1)/(e+l*(1-u+u*r/a)))},vee=e=>(t,n,r)=>{const a=typeof e.fuzzy=="function"?e.fuzzy(t,n,r):e.fuzzy||!1,i=typeof e.prefix=="function"?e.prefix(t,n,r):e.prefix===!0,l=typeof e.boostTerm=="function"?e.boostTerm(t,n,r):1;return{term:t,fuzzy:a,prefix:i,termBoost:l}},dm={idField:"id",extractField:(e,t)=>e[t],tokenize:e=>e.split(wee),processTerm:e=>e.toLowerCase(),fields:void 0,searchOptions:void 0,storeFields:[],logger:(e,t)=>{typeof(console==null?void 0:console[e])=="function"&&console[e](t)},autoVacuum:!0},mN={combineWith:D0,prefix:!1,fuzzy:!1,maxFuzzy:6,boost:{},weights:{fuzzy:.45,prefix:.375},bm25:bee},See={combineWith:e4,prefix:(e,t,n)=>t===n.length-1},Vx={batchSize:1e3,batchWait:10},Wx={minDirtFactor:.1,minDirtCount:20},fm={...Vx,...Wx},Eee=(e,t)=>{e.includes(t)||e.push(t)},bN=(e,t)=>{for(const n of t)e.includes(n)||e.push(n)},yN=({score:e},{score:t})=>t-e,vN=()=>new Map,td=e=>{const t=new Map;for(const n of Object.keys(e))t.set(parseInt(n,10),e[n]);return t},nd=async e=>{const t=new Map;let n=0;for(const r of Object.keys(e))t.set(parseInt(r,10),e[r]),++n%1e3===0&&await t4(0);return t},t4=e=>new Promise(t=>setTimeout(t,e)),wee=/[\n\r\p{Z}\p{P}]+/u;function Yx(){return Yx=Object.assign?Object.assign.bind():function(e){for(var t=1;t<arguments.length;t++){var n=arguments[t];for(var r in n)({}).hasOwnProperty.call(n,r)&&(e[r]=n[r])}return e},Yx.apply(null,arguments)}function au(e){"@babel/helpers - typeof";return au=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(t){return typeof t}:function(t){return t&&typeof Symbol=="function"&&t.constructor===Symbol&&t!==Symbol.prototype?"symbol":typeof t},au(e)}function xee(e,t){if(au(e)!="object"||!e)return e;var n=e[Symbol.toPrimitive];if(n!==void 0){var r=n.call(e,t);if(au(r)!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(t==="string"?String:Number)(e)}function kee(e){var t=xee(e,"string");return au(t)=="symbol"?t:t+""}function n4(e,t,n){return(t=kee(t))in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Kx(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=Array(t);n<t;n++)r[n]=e[n];return r}function Aee(e){if(Array.isArray(e))return Kx(e)}function Tee(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function _ee(e,t){if(e){if(typeof e=="string")return Kx(e,t);var n={}.toString.call(e).slice(8,-1);return n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set"?Array.from(e):n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)?Kx(e,t):void 0}}function Ree(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Xx(e){return Aee(e)||Tee(e)||_ee(e)||Ree()}function Cee(e,t){if(e==null)return{};var n={};for(var r in e)if({}.hasOwnProperty.call(e,r)){if(t.indexOf(r)!==-1)continue;n[r]=e[r]}return n}function Nee(e,t){if(e==null)return{};var n,r,a=Cee(e,t);if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(r=0;r<i.length;r++)n=i[r],t.indexOf(n)===-1&&{}.propertyIsEnumerable.call(e,n)&&(a[n]=e[n])}return a}const Oee={index:new mo({fields:[]})};k.createContext(Oee);const Zx=({label:e,color:t,hidden:n,labels:r={}})=>ye.createElement("div",{className:"node"},ye.createElement("span",{className:"render "+(n?"circle":"disc"),style:{backgroundColor:t||"#000"}}),ye.createElement("span",{className:`label ${n?"text-muted":""} ${e?"":"text-italic"}`},e||r.no_label||"No label")),Dee=({id:e,labels:t})=>{const n=br(),r=k.useMemo(()=>{const a=n.getGraph().getNodeAttributes(e),i=n.getSetting("nodeReducer");return Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},a),i?i(e,a):{})},[n,e]);return ye.createElement(Zx,Object.assign({},r,{labels:t}))},Iee=({label:e,color:t,source:n,target:r,hidden:a,directed:i,labels:l={}})=>ye.createElement("div",{className:"edge"},ye.createElement(Zx,Object.assign({},n,{labels:l})),ye.createElement("div",{className:"body"},ye.createElement("div",{className:"render"},ye.createElement("span",{className:a?"dotted":"dash",style:{borderColor:t||"#000"}})," ",i&&ye.createElement("span",{className:"arrow",style:{borderTopColor:t||"#000"}})),ye.createElement("span",{className:`label ${a?"text-muted":""} ${e?"":"fst-italic"}`},e||l.no_label||"No label")),ye.createElement(Zx,Object.assign({},r,{labels:l}))),Lee=({id:e,labels:t})=>{const n=br(),r=k.useMemo(()=>{const a=n.getGraph().getEdgeAttributes(e),i=n.getSetting("nodeReducer"),l=n.getSetting("edgeReducer"),u=n.getGraph().getNodeAttributes(n.getGraph().source(e)),c=n.getGraph().getNodeAttributes(n.getGraph().target(e));return Object.assign(Object.assign(Object.assign({color:n.getSetting("defaultEdgeColor"),directed:n.getGraph().isDirected(e)},a),l?l(e,a):{}),{source:Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},u),i?i(e,u):{}),target:Object.assign(Object.assign({color:n.getSetting("defaultNodeColor")},c),i?i(e,c):{})})},[n,e]);return ye.createElement(Iee,Object.assign({},r,{labels:t}))};function I0(e,t){const[n,r]=k.useState(e);return k.useEffect(()=>{const a=setTimeout(()=>{r(e)},t);return()=>{clearTimeout(a)}},[e,t]),n}function Mee({fetcher:e,preload:t,filterFn:n,renderOption:r,getOptionValue:a,notFound:i,loadingSkeleton:l,label:u,placeholder:c="Select...",value:f,onChange:p,onFocus:g,disabled:b=!1,className:m,noResultsMessage:S}){const[v,A]=k.useState(!1),[R,x]=k.useState(!1),[T,C]=k.useState([]),[N,_]=k.useState(!1),[O,z]=k.useState(null),[I,M]=k.useState(f),[H,q]=k.useState(null),[P,W]=k.useState(""),Z=I0(P,t?0:150),[j,G]=k.useState([]);k.useEffect(()=>{A(!0),M(f)},[f]),k.useEffect(()=>{v||(async()=>{try{_(!0),z(null);const V=f!==null?await e(f):[];G(V),C(V)}catch(V){z(V instanceof Error?V.message:"Failed to fetch options")}finally{_(!1)}})()},[v,e,f]),k.useEffect(()=>{const D=async()=>{try{_(!0),z(null);const V=await e(Z);G(V),C(V)}catch(V){z(V instanceof Error?V.message:"Failed to fetch options")}finally{_(!1)}};v&&t?t&&C(Z?j.filter(V=>n?n(V,Z):!0):j):D()},[e,Z,v,t,n]);const B=k.useCallback(D=>{D!==I&&(M(D),p(D)),x(!1)},[I,M,x,p]),X=k.useCallback(D=>{D!==H&&(q(D),g(D))},[H,q,g]);return w.jsx("div",{className:Me(b&&"cursor-not-allowed opacity-50",m),onFocus:()=>{x(!0)},onBlur:()=>x(!1),children:w.jsxs(Of,{shouldFilter:!1,className:"bg-transparent",children:[w.jsxs("div",{children:[w.jsx(R0,{placeholder:c,value:P,className:"max-h-8",onValueChange:D=>{W(D),D&&!R&&x(!0)}}),N&&T.length>0&&w.jsx("div",{className:"absolute top-1/2 right-2 flex -translate-y-1/2 transform items-center",children:w.jsx(cP,{className:"h-4 w-4 animate-spin"})})]}),w.jsxs(Df,{hidden:!R||Z.length===0,children:[O&&w.jsx("div",{className:"text-destructive p-4 text-center",children:O}),N&&T.length===0&&(l||w.jsx(Fee,{})),!N&&!O&&T.length===0&&(i||w.jsx(C0,{children:S??`No ${u.toLowerCase()} found.`})),w.jsx(Ml,{children:T.map((D,V)=>w.jsxs(w.Fragment,{children:[w.jsx(Fl,{value:a(D),onSelect:B,onMouseEnter:()=>X(a(D)),className:"truncate",children:r(D)},a(D)+`${V}`),V!==T.length-1&&w.jsx("div",{className:"bg-foreground/10 h-[1px]"},V)]}))})]})]})})}function Fee(){return w.jsx(Ml,{children:w.jsx(Fl,{disabled:!0,children:w.jsxs("div",{className:"flex w-full items-center gap-2",children:[w.jsx("div",{className:"bg-muted h-6 w-6 animate-pulse rounded-full"}),w.jsxs("div",{className:"flex flex-1 flex-col gap-1",children:[w.jsx("div",{className:"bg-muted h-4 w-24 animate-pulse rounded"}),w.jsx("div",{className:"bg-muted h-3 w-16 animate-pulse rounded"})]})]})})})}function zee(e){return w.jsxs("div",{children:[e.type==="nodes"&&w.jsx(Dee,{id:e.id}),e.type==="edges"&&w.jsx(Lee,{id:e.id}),e.type==="message"&&w.jsx("div",{children:e.message})]})}const pm="__message_item",rd={graph:null,searchEngine:null},Pee=({onChange:e,onFocus:t,value:n})=>{const r=Et.use.sigmaGraph(),a=k.useMemo(()=>{if(rd.graph==r)return rd.searchEngine;if(!r||r.nodes().length==0)return;rd.graph=r;const l=new mo({idField:"id",fields:["label"],searchOptions:{prefix:!0,fuzzy:.2,boost:{label:2}}}),u=r.nodes().map(c=>({id:c,label:r.getNodeAttribute(c,"label")}));return l.addAll(u),rd.searchEngine=l,l},[r]),i=k.useCallback(async l=>{if(t&&t(null),!l||!a)return[];const u=a.search(l).map(c=>({id:c.id,type:"nodes"}));return u.length<=lh?u:[...u.slice(0,lh),{type:"message",id:pm,message:`And ${u.length-lh} others`}]},[a,t]);return w.jsx(Mee,{className:"bg-background/60 w-24 rounded-xl border-1 opacity-60 backdrop-blur-lg transition-all hover:w-fit hover:opacity-100",fetcher:i,renderOption:zee,getOptionValue:l=>l.id,value:n&&n.type!=="message"?n.id:null,onChange:l=>{l!==pm&&e(l?{id:l,type:"nodes"}:null)},onFocus:l=>{l!==pm&&t&&t(l?{id:l,type:"nodes"}:null)},label:"item",placeholder:"Search nodes..."})},Bee=({...e})=>w.jsx(Pee,{...e});function Uee({fetcher:e,preload:t,filterFn:n,renderOption:r,getOptionValue:a,getDisplayValue:i,notFound:l,loadingSkeleton:u,label:c,placeholder:f="Select...",value:p,onChange:g,disabled:b=!1,className:m,triggerClassName:S,searchInputClassName:v,noResultsMessage:A,triggerTooltip:R,clearable:x=!0}){const[T,C]=k.useState(!1),[N,_]=k.useState(!1),[O,z]=k.useState([]),[I,M]=k.useState(!1),[H,q]=k.useState(null),[P,W]=k.useState(p),[Z,j]=k.useState(null),[G,B]=k.useState(""),X=I0(G,t?0:150),[D,V]=k.useState([]);k.useEffect(()=>{C(!0),W(p)},[p]),k.useEffect(()=>{if(p&&O.length>0){const L=O.find(Y=>a(Y)===p);L&&j(L)}},[p,O,a]),k.useEffect(()=>{T||(async()=>{try{M(!0),q(null);const Y=await e(p);V(Y),z(Y)}catch(Y){q(Y instanceof Error?Y.message:"Failed to fetch options")}finally{M(!1)}})()},[T,e,p]),k.useEffect(()=>{const L=async()=>{try{M(!0),q(null);const Y=await e(X);V(Y),z(Y)}catch(Y){q(Y instanceof Error?Y.message:"Failed to fetch options")}finally{M(!1)}};T&&t?t&&z(X?D.filter(Y=>n?n(Y,X):!0):D):L()},[e,X,T,t,n]);const U=k.useCallback(L=>{const Y=x&&L===P?"":L;W(Y),j(O.find(Q=>a(Q)===Y)||null),g(Y),_(!1)},[P,g,x,O,a]);return w.jsxs(kf,{open:N,onOpenChange:_,children:[w.jsx(Af,{asChild:!0,children:w.jsxs(Lt,{variant:"outline",role:"combobox","aria-expanded":N,className:Me("justify-between",b&&"cursor-not-allowed opacity-50",S),disabled:b,tooltip:R,side:"bottom",children:[Z?i(Z):f,w.jsx(Aq,{className:"opacity-50",size:10})]})}),w.jsx(yu,{className:Me("p-0",m),onCloseAutoFocus:L=>L.preventDefault(),children:w.jsxs(Of,{shouldFilter:!1,children:[w.jsxs("div",{className:"relative w-full border-b",children:[w.jsx(R0,{placeholder:`Search ${c.toLowerCase()}...`,value:G,onValueChange:L=>{B(L)},className:v}),I&&O.length>0&&w.jsx("div",{className:"absolute top-1/2 right-2 flex -translate-y-1/2 transform items-center",children:w.jsx(cP,{className:"h-4 w-4 animate-spin"})})]}),w.jsxs(Df,{children:[H&&w.jsx("div",{className:"text-destructive p-4 text-center",children:H}),I&&O.length===0&&(u||w.jsx(jee,{})),!I&&!H&&O.length===0&&(l||w.jsx(C0,{children:A??`No ${c.toLowerCase()} found.`})),w.jsx(Ml,{children:O.map(L=>w.jsxs(Fl,{value:a(L),onSelect:U,className:"truncate",children:[r(L),w.jsx(Nk,{className:Me("ml-auto h-3 w-3",P===a(L)?"opacity-100":"opacity-0")})]},a(L)))})]})]})})]})}function jee(){return w.jsx(Ml,{children:w.jsx(Fl,{disabled:!0,children:w.jsxs("div",{className:"flex w-full items-center gap-2",children:[w.jsx("div",{className:"bg-muted h-6 w-6 animate-pulse rounded-full"}),w.jsxs("div",{className:"flex flex-1 flex-col gap-1",children:[w.jsx("div",{className:"bg-muted h-4 w-24 animate-pulse rounded"}),w.jsx("div",{className:"bg-muted h-3 w-16 animate-pulse rounded"})]})]})})})}const tl={graph:null,searchEngine:null,labels:[]},Gee=()=>{const e=We.use.queryLabel(),t=Et.use.sigmaGraph(),n=k.useCallback(async()=>{if(tl.graph==t)return{labels:tl.labels,searchEngine:tl.searchEngine};const i=["*"].concat(await uq());i.includes(We.getState().queryLabel)||We.getState().setQueryLabel(i[0]);const l=new mo({idField:"id",fields:["value"],searchOptions:{prefix:!0,fuzzy:.2,boost:{label:2}}}),u=i.map((c,f)=>({id:f,value:c}));return l.addAll(u),tl.graph=t,tl.searchEngine=l,tl.labels=i,{labels:i,searchEngine:l}},[t]),r=k.useCallback(async i=>{const{labels:l,searchEngine:u}=await n();let c=l;return i&&(c=u.search(i).map(f=>l[f.id])),c.length<=sh?c:[...c.slice(0,sh),`And ${c.length-sh} others`]},[n]),a=k.useCallback(i=>{i.startsWith("And ")&&i.endsWith(" others")||We.getState().setQueryLabel(i)},[]);return w.jsx(Uee,{className:"ml-2",triggerClassName:"max-h-8",searchInputClassName:"max-h-8",triggerTooltip:"Select query label",fetcher:r,renderOption:i=>w.jsx("div",{children:i}),getOptionValue:i=>i,getDisplayValue:i=>w.jsx("div",{children:i}),notFound:w.jsx("div",{className:"py-6 text-center text-sm",children:"No labels found"}),label:"Label",placeholder:"Search labels...",value:e!==null?e:"",onChange:a})},Mn=({text:e,className:t,tooltipClassName:n,tooltip:r,side:a,onClick:i})=>r?w.jsx(FB,{delayDuration:200,children:w.jsxs(zB,{children:[w.jsx(PB,{asChild:!0,children:w.jsx("label",{className:Me(t,i!==void 0?"cursor-pointer":void 0),onClick:i,children:e})}),w.jsx(a0,{side:a,className:n,children:r})]})}):w.jsx("label",{className:Me(t,i!==void 0?"cursor-pointer":void 0),onClick:i,children:e}),Hee=()=>{const{getNode:e,getEdge:t}=U3(),n=Et.use.selectedNode(),r=Et.use.focusedNode(),a=Et.use.selectedEdge(),i=Et.use.focusedEdge(),[l,u]=k.useState(null),[c,f]=k.useState(null);return k.useEffect(()=>{let p=null,g=null;r?(p="node",g=e(r)):n?(p="node",g=e(n)):i?(p="edge",g=t(i,!0)):a&&(p="edge",g=t(a,!0)),g?(p=="node"?u($ee(g)):u(qee(g)),f(p)):(u(null),f(null))},[r,n,i,a,u,f,e,t]),l?w.jsx("div",{className:"bg-background/80 max-w-xs rounded-lg border-2 p-2 text-xs backdrop-blur-lg",children:c=="node"?w.jsx(Vee,{node:l}):w.jsx(Wee,{edge:l})}):w.jsx(w.Fragment,{})},$ee=e=>{const t=Et.getState(),n=[];if(t.sigmaGraph&&t.rawGraph)for(const r of t.sigmaGraph.edges(e.id)){const a=t.rawGraph.getEdge(r,!0);if(a){const l=e.id===a.source?a.target:a.source,u=t.rawGraph.getNode(l);u&&n.push({type:"Neighbour",id:l,label:u.properties.entity_id?u.properties.entity_id:u.labels.join(", ")})}}return{...e,relationships:n}},qee=e=>{var a,i;const t=Et.getState(),n=(a=t.rawGraph)==null?void 0:a.getNode(e.source),r=(i=t.rawGraph)==null?void 0:i.getNode(e.target);return{...e,sourceNode:n,targetNode:r}},Wr=({name:e,value:t,onClick:n,tooltip:r})=>w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsx("label",{className:"text-primary/60 tracking-wide",children:e}),":",w.jsx(Mn,{className:"hover:bg-primary/20 rounded p-1 text-ellipsis",tooltipClassName:"max-w-80",text:t,tooltip:r||t,side:"left",onClick:n})]}),Vee=({node:e})=>w.jsxs("div",{className:"flex flex-col gap-2",children:[w.jsx("label",{className:"text-md pl-1 font-bold tracking-wide text-sky-300",children:"Node"}),w.jsxs("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:[w.jsx(Wr,{name:"Id",value:e.id}),w.jsx(Wr,{name:"Labels",value:e.labels.join(", "),onClick:()=>{Et.getState().setSelectedNode(e.id,!0)}}),w.jsx(Wr,{name:"Degree",value:e.degree})]}),w.jsx("label",{className:"text-md pl-1 font-bold tracking-wide text-yellow-400/90",children:"Properties"}),w.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:Object.keys(e.properties).sort().map(t=>w.jsx(Wr,{name:t,value:e.properties[t]},t))}),e.relationships.length>0&&w.jsxs(w.Fragment,{children:[w.jsx("label",{className:"text-md pl-1 font-bold tracking-wide text-teal-600/90",children:"Relationships"}),w.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:e.relationships.map(({type:t,id:n,label:r})=>w.jsx(Wr,{name:t,value:r,onClick:()=>{Et.getState().setSelectedNode(n,!0)}},n))})]})]}),Wee=({edge:e})=>w.jsxs("div",{className:"flex flex-col gap-2",children:[w.jsx("label",{className:"text-md pl-1 font-bold tracking-wide text-teal-600",children:"Relationship"}),w.jsxs("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:[w.jsx(Wr,{name:"Id",value:e.id}),e.type&&w.jsx(Wr,{name:"Type",value:e.type}),w.jsx(Wr,{name:"Source",value:e.sourceNode?e.sourceNode.labels.join(", "):e.source,onClick:()=>{Et.getState().setSelectedNode(e.source,!0)}}),w.jsx(Wr,{name:"Target",value:e.targetNode?e.targetNode.labels.join(", "):e.target,onClick:()=>{Et.getState().setSelectedNode(e.target,!0)}})]}),w.jsx("label",{className:"text-md pl-1 font-bold tracking-wide text-yellow-400/90",children:"Properties"}),w.jsx("div",{className:"bg-primary/5 max-h-96 overflow-auto rounded p-1",children:Object.keys(e.properties).sort().map(t=>w.jsx(Wr,{name:t,value:e.properties[t]},t))})]}),SN={allowInvalidContainer:!0,defaultNodeType:"default",defaultEdgeType:"curvedArrow",renderEdgeLabels:!1,edgeProgramClasses:{arrow:QU,curvedArrow:uQ,curvedNoArrow:sQ},nodeProgramClasses:{default:qZ,circel:Su,point:vZ},labelGridCellSize:60,labelRenderedSizeThreshold:12,enableEdgeEvents:!0,labelColor:{color:"#000",attribute:"labelColor"},edgeLabelColor:{color:"#000",attribute:"labelColor"},edgeLabelSize:8,labelSize:12},Yee=()=>{const e=i3(),t=br(),[n,r]=k.useState(null);return k.useEffect(()=>{e({downNode:a=>{r(a.node),t.getGraph().setNodeAttribute(a.node,"highlighted",!0)},mousemovebody:a=>{if(!n)return;const i=t.viewportToGraph(a);t.getGraph().setNodeAttribute(n,"x",i.x),t.getGraph().setNodeAttribute(n,"y",i.y),a.preventSigmaDefault(),a.original.preventDefault(),a.original.stopPropagation()},mouseup:()=>{n&&(r(null),t.getGraph().removeNodeAttribute(n,"highlighted"))},mousedown:()=>{t.getCustomBBox()||t.setCustomBBox(t.getBBox())}})},[e,t,n]),null},Kee=()=>{const[e,t]=k.useState(SN),n=Et.use.selectedNode(),r=Et.use.focusedNode(),a=Et.use.moveToSelectedNode(),i=We.use.showPropertyPanel(),l=We.use.showNodeSearchBar(),u=We.use.showNodeLabel(),c=We.use.enableEdgeEvents(),f=We.use.enableNodeDrag(),p=We.use.showEdgeLabel();k.useEffect(()=>{t({...SN,enableEdgeEvents:c,renderEdgeLabels:p,renderLabels:u})},[u,c,p]);const g=k.useCallback(v=>{v===null?Et.getState().setFocusedNode(null):v.type==="nodes"&&Et.getState().setFocusedNode(v.id)},[]),b=k.useCallback(v=>{v===null?Et.getState().setSelectedNode(null):v.type==="nodes"&&Et.getState().setSelectedNode(v.id,!0)},[]),m=k.useMemo(()=>r??n,[r,n]),S=k.useMemo(()=>n?{type:"nodes",id:n}:null,[n]);return w.jsxs(pZ,{settings:e,className:"!bg-background !size-full overflow-hidden",children:[w.jsx(eee,{}),f&&w.jsx(Yee,{}),w.jsx(fQ,{node:m,move:a}),w.jsxs("div",{className:"absolute top-2 left-2 flex items-start gap-2",children:[w.jsx(Gee,{}),l&&w.jsx(Bee,{value:S,onFocus:g,onChange:b})]}),w.jsxs("div",{className:"bg-background/60 absolute bottom-2 left-2 flex flex-col rounded-xl border-2 backdrop-blur-lg",children:[w.jsx(dee,{}),w.jsx(tee,{}),w.jsx(NJ,{}),w.jsx(nee,{})]}),i&&w.jsx("div",{className:"absolute top-2 right-2",children:w.jsx(Hee,{})})]})},r4=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{className:"relative w-full overflow-auto",children:w.jsx("table",{ref:n,className:Me("w-full caption-bottom text-sm",e),...t})}));r4.displayName="Table";const a4=k.forwardRef(({className:e,...t},n)=>w.jsx("thead",{ref:n,className:Me("[&_tr]:border-b",e),...t}));a4.displayName="TableHeader";const o4=k.forwardRef(({className:e,...t},n)=>w.jsx("tbody",{ref:n,className:Me("[&_tr:last-child]:border-0",e),...t}));o4.displayName="TableBody";const Xee=k.forwardRef(({className:e,...t},n)=>w.jsx("tfoot",{ref:n,className:Me("bg-muted/50 border-t font-medium [&>tr]:last:border-b-0",e),...t}));Xee.displayName="TableFooter";const Qx=k.forwardRef(({className:e,...t},n)=>w.jsx("tr",{ref:n,className:Me("hover:bg-muted/50 data-[state=selected]:bg-muted border-b transition-colors",e),...t}));Qx.displayName="TableRow";const Ta=k.forwardRef(({className:e,...t},n)=>w.jsx("th",{ref:n,className:Me("text-muted-foreground h-10 px-2 text-left align-middle font-medium [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t}));Ta.displayName="TableHead";const _a=k.forwardRef(({className:e,...t},n)=>w.jsx("td",{ref:n,className:Me("p-2 align-middle [&:has([role=checkbox])]:pr-0 [&>[role=checkbox]]:translate-y-[2px]",e),...t}));_a.displayName="TableCell";const Zee=k.forwardRef(({className:e,...t},n)=>w.jsx("caption",{ref:n,className:Me("text-muted-foreground mt-4 text-sm",e),...t}));Zee.displayName="TableCaption";const ou=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("bg-card text-card-foreground rounded-xl border shadow",e),...t}));ou.displayName="Card";const Hd=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("flex flex-col space-y-1.5 p-6",e),...t}));Hd.displayName="CardHeader";const iu=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("leading-none font-semibold tracking-tight",e),...t}));iu.displayName="CardTitle";const If=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("text-muted-foreground text-sm",e),...t}));If.displayName="CardDescription";const $d=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("p-6 pt-0",e),...t}));$d.displayName="CardContent";const Qee=k.forwardRef(({className:e,...t},n)=>w.jsx("div",{ref:n,className:Me("flex items-center p-6 pt-0",e),...t}));Qee.displayName="CardFooter";function Jee({title:e,description:t,icon:n=Lq,action:r,className:a,...i}){return w.jsxs(ou,{className:Me("flex w-full flex-col items-center justify-center space-y-6 bg-transparent p-16",a),...i,children:[w.jsx("div",{className:"mr-4 shrink-0 rounded-full border border-dashed p-4",children:w.jsx(n,{className:"text-muted-foreground size-8","aria-hidden":"true"})}),w.jsxs("div",{className:"flex flex-col items-center gap-1.5 text-center",children:[w.jsx(iu,{children:e}),t?w.jsx(If,{children:t}):null]}),r||null]})}var gm={exports:{}},hm,EN;function ete(){if(EN)return hm;EN=1;var e="SECRET_DO_NOT_PASS_THIS_OR_YOU_WILL_BE_FIRED";return hm=e,hm}var mm,wN;function tte(){if(wN)return mm;wN=1;var e=ete();function t(){}function n(){}return n.resetWarningCache=t,mm=function(){function r(l,u,c,f,p,g){if(g!==e){var b=new Error("Calling PropTypes validators directly is not supported by the `prop-types` package. Use PropTypes.checkPropTypes() to call them. Read more at http://fb.me/use-check-prop-types");throw b.name="Invariant Violation",b}}r.isRequired=r;function a(){return r}var i={array:r,bigint:r,bool:r,func:r,number:r,object:r,string:r,symbol:r,any:r,arrayOf:a,element:r,elementType:r,instanceOf:a,node:r,objectOf:a,oneOf:a,oneOfType:a,shape:a,exact:a,checkPropTypes:n,resetWarningCache:t};return i.PropTypes=i,i},mm}var xN;function nte(){return xN||(xN=1,gm.exports=tte()()),gm.exports}var rte=nte();const Ct=an(rte),ate=new Map([["1km","application/vnd.1000minds.decision-model+xml"],["3dml","text/vnd.in3d.3dml"],["3ds","image/x-3ds"],["3g2","video/3gpp2"],["3gp","video/3gp"],["3gpp","video/3gpp"],["3mf","model/3mf"],["7z","application/x-7z-compressed"],["7zip","application/x-7z-compressed"],["123","application/vnd.lotus-1-2-3"],["aab","application/x-authorware-bin"],["aac","audio/x-acc"],["aam","application/x-authorware-map"],["aas","application/x-authorware-seg"],["abw","application/x-abiword"],["ac","application/vnd.nokia.n-gage.ac+xml"],["ac3","audio/ac3"],["acc","application/vnd.americandynamics.acc"],["ace","application/x-ace-compressed"],["acu","application/vnd.acucobol"],["acutc","application/vnd.acucorp"],["adp","audio/adpcm"],["aep","application/vnd.audiograph"],["afm","application/x-font-type1"],["afp","application/vnd.ibm.modcap"],["ahead","application/vnd.ahead.space"],["ai","application/pdf"],["aif","audio/x-aiff"],["aifc","audio/x-aiff"],["aiff","audio/x-aiff"],["air","application/vnd.adobe.air-application-installer-package+zip"],["ait","application/vnd.dvb.ait"],["ami","application/vnd.amiga.ami"],["amr","audio/amr"],["apk","application/vnd.android.package-archive"],["apng","image/apng"],["appcache","text/cache-manifest"],["application","application/x-ms-application"],["apr","application/vnd.lotus-approach"],["arc","application/x-freearc"],["arj","application/x-arj"],["asc","application/pgp-signature"],["asf","video/x-ms-asf"],["asm","text/x-asm"],["aso","application/vnd.accpac.simply.aso"],["asx","video/x-ms-asf"],["atc","application/vnd.acucorp"],["atom","application/atom+xml"],["atomcat","application/atomcat+xml"],["atomdeleted","application/atomdeleted+xml"],["atomsvc","application/atomsvc+xml"],["atx","application/vnd.antix.game-component"],["au","audio/x-au"],["avi","video/x-msvideo"],["avif","image/avif"],["aw","application/applixware"],["azf","application/vnd.airzip.filesecure.azf"],["azs","application/vnd.airzip.filesecure.azs"],["azv","image/vnd.airzip.accelerator.azv"],["azw","application/vnd.amazon.ebook"],["b16","image/vnd.pco.b16"],["bat","application/x-msdownload"],["bcpio","application/x-bcpio"],["bdf","application/x-font-bdf"],["bdm","application/vnd.syncml.dm+wbxml"],["bdoc","application/x-bdoc"],["bed","application/vnd.realvnc.bed"],["bh2","application/vnd.fujitsu.oasysprs"],["bin","application/octet-stream"],["blb","application/x-blorb"],["blorb","application/x-blorb"],["bmi","application/vnd.bmi"],["bmml","application/vnd.balsamiq.bmml+xml"],["bmp","image/bmp"],["book","application/vnd.framemaker"],["box","application/vnd.previewsystems.box"],["boz","application/x-bzip2"],["bpk","application/octet-stream"],["bpmn","application/octet-stream"],["bsp","model/vnd.valve.source.compiled-map"],["btif","image/prs.btif"],["buffer","application/octet-stream"],["bz","application/x-bzip"],["bz2","application/x-bzip2"],["c","text/x-c"],["c4d","application/vnd.clonk.c4group"],["c4f","application/vnd.clonk.c4group"],["c4g","application/vnd.clonk.c4group"],["c4p","application/vnd.clonk.c4group"],["c4u","application/vnd.clonk.c4group"],["c11amc","application/vnd.cluetrust.cartomobile-config"],["c11amz","application/vnd.cluetrust.cartomobile-config-pkg"],["cab","application/vnd.ms-cab-compressed"],["caf","audio/x-caf"],["cap","application/vnd.tcpdump.pcap"],["car","application/vnd.curl.car"],["cat","application/vnd.ms-pki.seccat"],["cb7","application/x-cbr"],["cba","application/x-cbr"],["cbr","application/x-cbr"],["cbt","application/x-cbr"],["cbz","application/x-cbr"],["cc","text/x-c"],["cco","application/x-cocoa"],["cct","application/x-director"],["ccxml","application/ccxml+xml"],["cdbcmsg","application/vnd.contact.cmsg"],["cda","application/x-cdf"],["cdf","application/x-netcdf"],["cdfx","application/cdfx+xml"],["cdkey","application/vnd.mediastation.cdkey"],["cdmia","application/cdmi-capability"],["cdmic","application/cdmi-container"],["cdmid","application/cdmi-domain"],["cdmio","application/cdmi-object"],["cdmiq","application/cdmi-queue"],["cdr","application/cdr"],["cdx","chemical/x-cdx"],["cdxml","application/vnd.chemdraw+xml"],["cdy","application/vnd.cinderella"],["cer","application/pkix-cert"],["cfs","application/x-cfs-compressed"],["cgm","image/cgm"],["chat","application/x-chat"],["chm","application/vnd.ms-htmlhelp"],["chrt","application/vnd.kde.kchart"],["cif","chemical/x-cif"],["cii","application/vnd.anser-web-certificate-issue-initiation"],["cil","application/vnd.ms-artgalry"],["cjs","application/node"],["cla","application/vnd.claymore"],["class","application/octet-stream"],["clkk","application/vnd.crick.clicker.keyboard"],["clkp","application/vnd.crick.clicker.palette"],["clkt","application/vnd.crick.clicker.template"],["clkw","application/vnd.crick.clicker.wordbank"],["clkx","application/vnd.crick.clicker"],["clp","application/x-msclip"],["cmc","application/vnd.cosmocaller"],["cmdf","chemical/x-cmdf"],["cml","chemical/x-cml"],["cmp","application/vnd.yellowriver-custom-menu"],["cmx","image/x-cmx"],["cod","application/vnd.rim.cod"],["coffee","text/coffeescript"],["com","application/x-msdownload"],["conf","text/plain"],["cpio","application/x-cpio"],["cpp","text/x-c"],["cpt","application/mac-compactpro"],["crd","application/x-mscardfile"],["crl","application/pkix-crl"],["crt","application/x-x509-ca-cert"],["crx","application/x-chrome-extension"],["cryptonote","application/vnd.rig.cryptonote"],["csh","application/x-csh"],["csl","application/vnd.citationstyles.style+xml"],["csml","chemical/x-csml"],["csp","application/vnd.commonspace"],["csr","application/octet-stream"],["css","text/css"],["cst","application/x-director"],["csv","text/csv"],["cu","application/cu-seeme"],["curl","text/vnd.curl"],["cww","application/prs.cww"],["cxt","application/x-director"],["cxx","text/x-c"],["dae","model/vnd.collada+xml"],["daf","application/vnd.mobius.daf"],["dart","application/vnd.dart"],["dataless","application/vnd.fdsn.seed"],["davmount","application/davmount+xml"],["dbf","application/vnd.dbf"],["dbk","application/docbook+xml"],["dcr","application/x-director"],["dcurl","text/vnd.curl.dcurl"],["dd2","application/vnd.oma.dd2+xml"],["ddd","application/vnd.fujixerox.ddd"],["ddf","application/vnd.syncml.dmddf+xml"],["dds","image/vnd.ms-dds"],["deb","application/x-debian-package"],["def","text/plain"],["deploy","application/octet-stream"],["der","application/x-x509-ca-cert"],["dfac","application/vnd.dreamfactory"],["dgc","application/x-dgc-compressed"],["dic","text/x-c"],["dir","application/x-director"],["dis","application/vnd.mobius.dis"],["disposition-notification","message/disposition-notification"],["dist","application/octet-stream"],["distz","application/octet-stream"],["djv","image/vnd.djvu"],["djvu","image/vnd.djvu"],["dll","application/octet-stream"],["dmg","application/x-apple-diskimage"],["dmn","application/octet-stream"],["dmp","application/vnd.tcpdump.pcap"],["dms","application/octet-stream"],["dna","application/vnd.dna"],["doc","application/msword"],["docm","application/vnd.ms-word.template.macroEnabled.12"],["docx","application/vnd.openxmlformats-officedocument.wordprocessingml.document"],["dot","application/msword"],["dotm","application/vnd.ms-word.template.macroEnabled.12"],["dotx","application/vnd.openxmlformats-officedocument.wordprocessingml.template"],["dp","application/vnd.osgi.dp"],["dpg","application/vnd.dpgraph"],["dra","audio/vnd.dra"],["drle","image/dicom-rle"],["dsc","text/prs.lines.tag"],["dssc","application/dssc+der"],["dtb","application/x-dtbook+xml"],["dtd","application/xml-dtd"],["dts","audio/vnd.dts"],["dtshd","audio/vnd.dts.hd"],["dump","application/octet-stream"],["dvb","video/vnd.dvb.file"],["dvi","application/x-dvi"],["dwd","application/atsc-dwd+xml"],["dwf","model/vnd.dwf"],["dwg","image/vnd.dwg"],["dxf","image/vnd.dxf"],["dxp","application/vnd.spotfire.dxp"],["dxr","application/x-director"],["ear","application/java-archive"],["ecelp4800","audio/vnd.nuera.ecelp4800"],["ecelp7470","audio/vnd.nuera.ecelp7470"],["ecelp9600","audio/vnd.nuera.ecelp9600"],["ecma","application/ecmascript"],["edm","application/vnd.novadigm.edm"],["edx","application/vnd.novadigm.edx"],["efif","application/vnd.picsel"],["ei6","application/vnd.pg.osasli"],["elc","application/octet-stream"],["emf","image/emf"],["eml","message/rfc822"],["emma","application/emma+xml"],["emotionml","application/emotionml+xml"],["emz","application/x-msmetafile"],["eol","audio/vnd.digital-winds"],["eot","application/vnd.ms-fontobject"],["eps","application/postscript"],["epub","application/epub+zip"],["es","application/ecmascript"],["es3","application/vnd.eszigno3+xml"],["esa","application/vnd.osgi.subsystem"],["esf","application/vnd.epson.esf"],["et3","application/vnd.eszigno3+xml"],["etx","text/x-setext"],["eva","application/x-eva"],["evy","application/x-envoy"],["exe","application/octet-stream"],["exi","application/exi"],["exp","application/express"],["exr","image/aces"],["ext","application/vnd.novadigm.ext"],["ez","application/andrew-inset"],["ez2","application/vnd.ezpix-album"],["ez3","application/vnd.ezpix-package"],["f","text/x-fortran"],["f4v","video/mp4"],["f77","text/x-fortran"],["f90","text/x-fortran"],["fbs","image/vnd.fastbidsheet"],["fcdt","application/vnd.adobe.formscentral.fcdt"],["fcs","application/vnd.isac.fcs"],["fdf","application/vnd.fdf"],["fdt","application/fdt+xml"],["fe_launch","application/vnd.denovo.fcselayout-link"],["fg5","application/vnd.fujitsu.oasysgp"],["fgd","application/x-director"],["fh","image/x-freehand"],["fh4","image/x-freehand"],["fh5","image/x-freehand"],["fh7","image/x-freehand"],["fhc","image/x-freehand"],["fig","application/x-xfig"],["fits","image/fits"],["flac","audio/x-flac"],["fli","video/x-fli"],["flo","application/vnd.micrografx.flo"],["flv","video/x-flv"],["flw","application/vnd.kde.kivio"],["flx","text/vnd.fmi.flexstor"],["fly","text/vnd.fly"],["fm","application/vnd.framemaker"],["fnc","application/vnd.frogans.fnc"],["fo","application/vnd.software602.filler.form+xml"],["for","text/x-fortran"],["fpx","image/vnd.fpx"],["frame","application/vnd.framemaker"],["fsc","application/vnd.fsc.weblaunch"],["fst","image/vnd.fst"],["ftc","application/vnd.fluxtime.clip"],["fti","application/vnd.anser-web-funds-transfer-initiation"],["fvt","video/vnd.fvt"],["fxp","application/vnd.adobe.fxp"],["fxpl","application/vnd.adobe.fxp"],["fzs","application/vnd.fuzzysheet"],["g2w","application/vnd.geoplan"],["g3","image/g3fax"],["g3w","application/vnd.geospace"],["gac","application/vnd.groove-account"],["gam","application/x-tads"],["gbr","application/rpki-ghostbusters"],["gca","application/x-gca-compressed"],["gdl","model/vnd.gdl"],["gdoc","application/vnd.google-apps.document"],["geo","application/vnd.dynageo"],["geojson","application/geo+json"],["gex","application/vnd.geometry-explorer"],["ggb","application/vnd.geogebra.file"],["ggt","application/vnd.geogebra.tool"],["ghf","application/vnd.groove-help"],["gif","image/gif"],["gim","application/vnd.groove-identity-message"],["glb","model/gltf-binary"],["gltf","model/gltf+json"],["gml","application/gml+xml"],["gmx","application/vnd.gmx"],["gnumeric","application/x-gnumeric"],["gpg","application/gpg-keys"],["gph","application/vnd.flographit"],["gpx","application/gpx+xml"],["gqf","application/vnd.grafeq"],["gqs","application/vnd.grafeq"],["gram","application/srgs"],["gramps","application/x-gramps-xml"],["gre","application/vnd.geometry-explorer"],["grv","application/vnd.groove-injector"],["grxml","application/srgs+xml"],["gsf","application/x-font-ghostscript"],["gsheet","application/vnd.google-apps.spreadsheet"],["gslides","application/vnd.google-apps.presentation"],["gtar","application/x-gtar"],["gtm","application/vnd.groove-tool-message"],["gtw","model/vnd.gtw"],["gv","text/vnd.graphviz"],["gxf","application/gxf"],["gxt","application/vnd.geonext"],["gz","application/gzip"],["gzip","application/gzip"],["h","text/x-c"],["h261","video/h261"],["h263","video/h263"],["h264","video/h264"],["hal","application/vnd.hal+xml"],["hbci","application/vnd.hbci"],["hbs","text/x-handlebars-template"],["hdd","application/x-virtualbox-hdd"],["hdf","application/x-hdf"],["heic","image/heic"],["heics","image/heic-sequence"],["heif","image/heif"],["heifs","image/heif-sequence"],["hej2","image/hej2k"],["held","application/atsc-held+xml"],["hh","text/x-c"],["hjson","application/hjson"],["hlp","application/winhlp"],["hpgl","application/vnd.hp-hpgl"],["hpid","application/vnd.hp-hpid"],["hps","application/vnd.hp-hps"],["hqx","application/mac-binhex40"],["hsj2","image/hsj2"],["htc","text/x-component"],["htke","application/vnd.kenameaapp"],["htm","text/html"],["html","text/html"],["hvd","application/vnd.yamaha.hv-dic"],["hvp","application/vnd.yamaha.hv-voice"],["hvs","application/vnd.yamaha.hv-script"],["i2g","application/vnd.intergeo"],["icc","application/vnd.iccprofile"],["ice","x-conference/x-cooltalk"],["icm","application/vnd.iccprofile"],["ico","image/x-icon"],["ics","text/calendar"],["ief","image/ief"],["ifb","text/calendar"],["ifm","application/vnd.shana.informed.formdata"],["iges","model/iges"],["igl","application/vnd.igloader"],["igm","application/vnd.insors.igm"],["igs","model/iges"],["igx","application/vnd.micrografx.igx"],["iif","application/vnd.shana.informed.interchange"],["img","application/octet-stream"],["imp","application/vnd.accpac.simply.imp"],["ims","application/vnd.ms-ims"],["in","text/plain"],["ini","text/plain"],["ink","application/inkml+xml"],["inkml","application/inkml+xml"],["install","application/x-install-instructions"],["iota","application/vnd.astraea-software.iota"],["ipfix","application/ipfix"],["ipk","application/vnd.shana.informed.package"],["irm","application/vnd.ibm.rights-management"],["irp","application/vnd.irepository.package+xml"],["iso","application/x-iso9660-image"],["itp","application/vnd.shana.informed.formtemplate"],["its","application/its+xml"],["ivp","application/vnd.immervision-ivp"],["ivu","application/vnd.immervision-ivu"],["jad","text/vnd.sun.j2me.app-descriptor"],["jade","text/jade"],["jam","application/vnd.jam"],["jar","application/java-archive"],["jardiff","application/x-java-archive-diff"],["java","text/x-java-source"],["jhc","image/jphc"],["jisp","application/vnd.jisp"],["jls","image/jls"],["jlt","application/vnd.hp-jlyt"],["jng","image/x-jng"],["jnlp","application/x-java-jnlp-file"],["joda","application/vnd.joost.joda-archive"],["jp2","image/jp2"],["jpe","image/jpeg"],["jpeg","image/jpeg"],["jpf","image/jpx"],["jpg","image/jpeg"],["jpg2","image/jp2"],["jpgm","video/jpm"],["jpgv","video/jpeg"],["jph","image/jph"],["jpm","video/jpm"],["jpx","image/jpx"],["js","application/javascript"],["json","application/json"],["json5","application/json5"],["jsonld","application/ld+json"],["jsonl","application/jsonl"],["jsonml","application/jsonml+json"],["jsx","text/jsx"],["jxr","image/jxr"],["jxra","image/jxra"],["jxrs","image/jxrs"],["jxs","image/jxs"],["jxsc","image/jxsc"],["jxsi","image/jxsi"],["jxss","image/jxss"],["kar","audio/midi"],["karbon","application/vnd.kde.karbon"],["kdb","application/octet-stream"],["kdbx","application/x-keepass2"],["key","application/x-iwork-keynote-sffkey"],["kfo","application/vnd.kde.kformula"],["kia","application/vnd.kidspiration"],["kml","application/vnd.google-earth.kml+xml"],["kmz","application/vnd.google-earth.kmz"],["kne","application/vnd.kinar"],["knp","application/vnd.kinar"],["kon","application/vnd.kde.kontour"],["kpr","application/vnd.kde.kpresenter"],["kpt","application/vnd.kde.kpresenter"],["kpxx","application/vnd.ds-keypoint"],["ksp","application/vnd.kde.kspread"],["ktr","application/vnd.kahootz"],["ktx","image/ktx"],["ktx2","image/ktx2"],["ktz","application/vnd.kahootz"],["kwd","application/vnd.kde.kword"],["kwt","application/vnd.kde.kword"],["lasxml","application/vnd.las.las+xml"],["latex","application/x-latex"],["lbd","application/vnd.llamagraphics.life-balance.desktop"],["lbe","application/vnd.llamagraphics.life-balance.exchange+xml"],["les","application/vnd.hhe.lesson-player"],["less","text/less"],["lgr","application/lgr+xml"],["lha","application/octet-stream"],["link66","application/vnd.route66.link66+xml"],["list","text/plain"],["list3820","application/vnd.ibm.modcap"],["listafp","application/vnd.ibm.modcap"],["litcoffee","text/coffeescript"],["lnk","application/x-ms-shortcut"],["log","text/plain"],["lostxml","application/lost+xml"],["lrf","application/octet-stream"],["lrm","application/vnd.ms-lrm"],["ltf","application/vnd.frogans.ltf"],["lua","text/x-lua"],["luac","application/x-lua-bytecode"],["lvp","audio/vnd.lucent.voice"],["lwp","application/vnd.lotus-wordpro"],["lzh","application/octet-stream"],["m1v","video/mpeg"],["m2a","audio/mpeg"],["m2v","video/mpeg"],["m3a","audio/mpeg"],["m3u","text/plain"],["m3u8","application/vnd.apple.mpegurl"],["m4a","audio/x-m4a"],["m4p","application/mp4"],["m4s","video/iso.segment"],["m4u","application/vnd.mpegurl"],["m4v","video/x-m4v"],["m13","application/x-msmediaview"],["m14","application/x-msmediaview"],["m21","application/mp21"],["ma","application/mathematica"],["mads","application/mads+xml"],["maei","application/mmt-aei+xml"],["mag","application/vnd.ecowin.chart"],["maker","application/vnd.framemaker"],["man","text/troff"],["manifest","text/cache-manifest"],["map","application/json"],["mar","application/octet-stream"],["markdown","text/markdown"],["mathml","application/mathml+xml"],["mb","application/mathematica"],["mbk","application/vnd.mobius.mbk"],["mbox","application/mbox"],["mc1","application/vnd.medcalcdata"],["mcd","application/vnd.mcd"],["mcurl","text/vnd.curl.mcurl"],["md","text/markdown"],["mdb","application/x-msaccess"],["mdi","image/vnd.ms-modi"],["mdx","text/mdx"],["me","text/troff"],["mesh","model/mesh"],["meta4","application/metalink4+xml"],["metalink","application/metalink+xml"],["mets","application/mets+xml"],["mfm","application/vnd.mfmp"],["mft","application/rpki-manifest"],["mgp","application/vnd.osgeo.mapguide.package"],["mgz","application/vnd.proteus.magazine"],["mid","audio/midi"],["midi","audio/midi"],["mie","application/x-mie"],["mif","application/vnd.mif"],["mime","message/rfc822"],["mj2","video/mj2"],["mjp2","video/mj2"],["mjs","application/javascript"],["mk3d","video/x-matroska"],["mka","audio/x-matroska"],["mkd","text/x-markdown"],["mks","video/x-matroska"],["mkv","video/x-matroska"],["mlp","application/vnd.dolby.mlp"],["mmd","application/vnd.chipnuts.karaoke-mmd"],["mmf","application/vnd.smaf"],["mml","text/mathml"],["mmr","image/vnd.fujixerox.edmics-mmr"],["mng","video/x-mng"],["mny","application/x-msmoney"],["mobi","application/x-mobipocket-ebook"],["mods","application/mods+xml"],["mov","video/quicktime"],["movie","video/x-sgi-movie"],["mp2","audio/mpeg"],["mp2a","audio/mpeg"],["mp3","audio/mpeg"],["mp4","video/mp4"],["mp4a","audio/mp4"],["mp4s","application/mp4"],["mp4v","video/mp4"],["mp21","application/mp21"],["mpc","application/vnd.mophun.certificate"],["mpd","application/dash+xml"],["mpe","video/mpeg"],["mpeg","video/mpeg"],["mpg","video/mpeg"],["mpg4","video/mp4"],["mpga","audio/mpeg"],["mpkg","application/vnd.apple.installer+xml"],["mpm","application/vnd.blueice.multipass"],["mpn","application/vnd.mophun.application"],["mpp","application/vnd.ms-project"],["mpt","application/vnd.ms-project"],["mpy","application/vnd.ibm.minipay"],["mqy","application/vnd.mobius.mqy"],["mrc","application/marc"],["mrcx","application/marcxml+xml"],["ms","text/troff"],["mscml","application/mediaservercontrol+xml"],["mseed","application/vnd.fdsn.mseed"],["mseq","application/vnd.mseq"],["msf","application/vnd.epson.msf"],["msg","application/vnd.ms-outlook"],["msh","model/mesh"],["msi","application/x-msdownload"],["msl","application/vnd.mobius.msl"],["msm","application/octet-stream"],["msp","application/octet-stream"],["msty","application/vnd.muvee.style"],["mtl","model/mtl"],["mts","model/vnd.mts"],["mus","application/vnd.musician"],["musd","application/mmt-usd+xml"],["musicxml","application/vnd.recordare.musicxml+xml"],["mvb","application/x-msmediaview"],["mvt","application/vnd.mapbox-vector-tile"],["mwf","application/vnd.mfer"],["mxf","application/mxf"],["mxl","application/vnd.recordare.musicxml"],["mxmf","audio/mobile-xmf"],["mxml","application/xv+xml"],["mxs","application/vnd.triscape.mxs"],["mxu","video/vnd.mpegurl"],["n-gage","application/vnd.nokia.n-gage.symbian.install"],["n3","text/n3"],["nb","application/mathematica"],["nbp","application/vnd.wolfram.player"],["nc","application/x-netcdf"],["ncx","application/x-dtbncx+xml"],["nfo","text/x-nfo"],["ngdat","application/vnd.nokia.n-gage.data"],["nitf","application/vnd.nitf"],["nlu","application/vnd.neurolanguage.nlu"],["nml","application/vnd.enliven"],["nnd","application/vnd.noblenet-directory"],["nns","application/vnd.noblenet-sealer"],["nnw","application/vnd.noblenet-web"],["npx","image/vnd.net-fpx"],["nq","application/n-quads"],["nsc","application/x-conference"],["nsf","application/vnd.lotus-notes"],["nt","application/n-triples"],["ntf","application/vnd.nitf"],["numbers","application/x-iwork-numbers-sffnumbers"],["nzb","application/x-nzb"],["oa2","application/vnd.fujitsu.oasys2"],["oa3","application/vnd.fujitsu.oasys3"],["oas","application/vnd.fujitsu.oasys"],["obd","application/x-msbinder"],["obgx","application/vnd.openblox.game+xml"],["obj","model/obj"],["oda","application/oda"],["odb","application/vnd.oasis.opendocument.database"],["odc","application/vnd.oasis.opendocument.chart"],["odf","application/vnd.oasis.opendocument.formula"],["odft","application/vnd.oasis.opendocument.formula-template"],["odg","application/vnd.oasis.opendocument.graphics"],["odi","application/vnd.oasis.opendocument.image"],["odm","application/vnd.oasis.opendocument.text-master"],["odp","application/vnd.oasis.opendocument.presentation"],["ods","application/vnd.oasis.opendocument.spreadsheet"],["odt","application/vnd.oasis.opendocument.text"],["oga","audio/ogg"],["ogex","model/vnd.opengex"],["ogg","audio/ogg"],["ogv","video/ogg"],["ogx","application/ogg"],["omdoc","application/omdoc+xml"],["onepkg","application/onenote"],["onetmp","application/onenote"],["onetoc","application/onenote"],["onetoc2","application/onenote"],["opf","application/oebps-package+xml"],["opml","text/x-opml"],["oprc","application/vnd.palm"],["opus","audio/ogg"],["org","text/x-org"],["osf","application/vnd.yamaha.openscoreformat"],["osfpvg","application/vnd.yamaha.openscoreformat.osfpvg+xml"],["osm","application/vnd.openstreetmap.data+xml"],["otc","application/vnd.oasis.opendocument.chart-template"],["otf","font/otf"],["otg","application/vnd.oasis.opendocument.graphics-template"],["oth","application/vnd.oasis.opendocument.text-web"],["oti","application/vnd.oasis.opendocument.image-template"],["otp","application/vnd.oasis.opendocument.presentation-template"],["ots","application/vnd.oasis.opendocument.spreadsheet-template"],["ott","application/vnd.oasis.opendocument.text-template"],["ova","application/x-virtualbox-ova"],["ovf","application/x-virtualbox-ovf"],["owl","application/rdf+xml"],["oxps","application/oxps"],["oxt","application/vnd.openofficeorg.extension"],["p","text/x-pascal"],["p7a","application/x-pkcs7-signature"],["p7b","application/x-pkcs7-certificates"],["p7c","application/pkcs7-mime"],["p7m","application/pkcs7-mime"],["p7r","application/x-pkcs7-certreqresp"],["p7s","application/pkcs7-signature"],["p8","application/pkcs8"],["p10","application/x-pkcs10"],["p12","application/x-pkcs12"],["pac","application/x-ns-proxy-autoconfig"],["pages","application/x-iwork-pages-sffpages"],["pas","text/x-pascal"],["paw","application/vnd.pawaafile"],["pbd","application/vnd.powerbuilder6"],["pbm","image/x-portable-bitmap"],["pcap","application/vnd.tcpdump.pcap"],["pcf","application/x-font-pcf"],["pcl","application/vnd.hp-pcl"],["pclxl","application/vnd.hp-pclxl"],["pct","image/x-pict"],["pcurl","application/vnd.curl.pcurl"],["pcx","image/x-pcx"],["pdb","application/x-pilot"],["pde","text/x-processing"],["pdf","application/pdf"],["pem","application/x-x509-user-cert"],["pfa","application/x-font-type1"],["pfb","application/x-font-type1"],["pfm","application/x-font-type1"],["pfr","application/font-tdpfr"],["pfx","application/x-pkcs12"],["pgm","image/x-portable-graymap"],["pgn","application/x-chess-pgn"],["pgp","application/pgp"],["php","application/x-httpd-php"],["php3","application/x-httpd-php"],["php4","application/x-httpd-php"],["phps","application/x-httpd-php-source"],["phtml","application/x-httpd-php"],["pic","image/x-pict"],["pkg","application/octet-stream"],["pki","application/pkixcmp"],["pkipath","application/pkix-pkipath"],["pkpass","application/vnd.apple.pkpass"],["pl","application/x-perl"],["plb","application/vnd.3gpp.pic-bw-large"],["plc","application/vnd.mobius.plc"],["plf","application/vnd.pocketlearn"],["pls","application/pls+xml"],["pm","application/x-perl"],["pml","application/vnd.ctc-posml"],["png","image/png"],["pnm","image/x-portable-anymap"],["portpkg","application/vnd.macports.portpkg"],["pot","application/vnd.ms-powerpoint"],["potm","application/vnd.ms-powerpoint.presentation.macroEnabled.12"],["potx","application/vnd.openxmlformats-officedocument.presentationml.template"],["ppa","application/vnd.ms-powerpoint"],["ppam","application/vnd.ms-powerpoint.addin.macroEnabled.12"],["ppd","application/vnd.cups-ppd"],["ppm","image/x-portable-pixmap"],["pps","application/vnd.ms-powerpoint"],["ppsm","application/vnd.ms-powerpoint.slideshow.macroEnabled.12"],["ppsx","application/vnd.openxmlformats-officedocument.presentationml.slideshow"],["ppt","application/powerpoint"],["pptm","application/vnd.ms-powerpoint.presentation.macroEnabled.12"],["pptx","application/vnd.openxmlformats-officedocument.presentationml.presentation"],["pqa","application/vnd.palm"],["prc","application/x-pilot"],["pre","application/vnd.lotus-freelance"],["prf","application/pics-rules"],["provx","application/provenance+xml"],["ps","application/postscript"],["psb","application/vnd.3gpp.pic-bw-small"],["psd","application/x-photoshop"],["psf","application/x-font-linux-psf"],["pskcxml","application/pskc+xml"],["pti","image/prs.pti"],["ptid","application/vnd.pvi.ptid1"],["pub","application/x-mspublisher"],["pvb","application/vnd.3gpp.pic-bw-var"],["pwn","application/vnd.3m.post-it-notes"],["pya","audio/vnd.ms-playready.media.pya"],["pyv","video/vnd.ms-playready.media.pyv"],["qam","application/vnd.epson.quickanime"],["qbo","application/vnd.intu.qbo"],["qfx","application/vnd.intu.qfx"],["qps","application/vnd.publishare-delta-tree"],["qt","video/quicktime"],["qwd","application/vnd.quark.quarkxpress"],["qwt","application/vnd.quark.quarkxpress"],["qxb","application/vnd.quark.quarkxpress"],["qxd","application/vnd.quark.quarkxpress"],["qxl","application/vnd.quark.quarkxpress"],["qxt","application/vnd.quark.quarkxpress"],["ra","audio/x-realaudio"],["ram","audio/x-pn-realaudio"],["raml","application/raml+yaml"],["rapd","application/route-apd+xml"],["rar","application/x-rar"],["ras","image/x-cmu-raster"],["rcprofile","application/vnd.ipunplugged.rcprofile"],["rdf","application/rdf+xml"],["rdz","application/vnd.data-vision.rdz"],["relo","application/p2p-overlay+xml"],["rep","application/vnd.businessobjects"],["res","application/x-dtbresource+xml"],["rgb","image/x-rgb"],["rif","application/reginfo+xml"],["rip","audio/vnd.rip"],["ris","application/x-research-info-systems"],["rl","application/resource-lists+xml"],["rlc","image/vnd.fujixerox.edmics-rlc"],["rld","application/resource-lists-diff+xml"],["rm","audio/x-pn-realaudio"],["rmi","audio/midi"],["rmp","audio/x-pn-realaudio-plugin"],["rms","application/vnd.jcp.javame.midlet-rms"],["rmvb","application/vnd.rn-realmedia-vbr"],["rnc","application/relax-ng-compact-syntax"],["rng","application/xml"],["roa","application/rpki-roa"],["roff","text/troff"],["rp9","application/vnd.cloanto.rp9"],["rpm","audio/x-pn-realaudio-plugin"],["rpss","application/vnd.nokia.radio-presets"],["rpst","application/vnd.nokia.radio-preset"],["rq","application/sparql-query"],["rs","application/rls-services+xml"],["rsa","application/x-pkcs7"],["rsat","application/atsc-rsat+xml"],["rsd","application/rsd+xml"],["rsheet","application/urc-ressheet+xml"],["rss","application/rss+xml"],["rtf","text/rtf"],["rtx","text/richtext"],["run","application/x-makeself"],["rusd","application/route-usd+xml"],["rv","video/vnd.rn-realvideo"],["s","text/x-asm"],["s3m","audio/s3m"],["saf","application/vnd.yamaha.smaf-audio"],["sass","text/x-sass"],["sbml","application/sbml+xml"],["sc","application/vnd.ibm.secure-container"],["scd","application/x-msschedule"],["scm","application/vnd.lotus-screencam"],["scq","application/scvp-cv-request"],["scs","application/scvp-cv-response"],["scss","text/x-scss"],["scurl","text/vnd.curl.scurl"],["sda","application/vnd.stardivision.draw"],["sdc","application/vnd.stardivision.calc"],["sdd","application/vnd.stardivision.impress"],["sdkd","application/vnd.solent.sdkm+xml"],["sdkm","application/vnd.solent.sdkm+xml"],["sdp","application/sdp"],["sdw","application/vnd.stardivision.writer"],["sea","application/octet-stream"],["see","application/vnd.seemail"],["seed","application/vnd.fdsn.seed"],["sema","application/vnd.sema"],["semd","application/vnd.semd"],["semf","application/vnd.semf"],["senmlx","application/senml+xml"],["sensmlx","application/sensml+xml"],["ser","application/java-serialized-object"],["setpay","application/set-payment-initiation"],["setreg","application/set-registration-initiation"],["sfd-hdstx","application/vnd.hydrostatix.sof-data"],["sfs","application/vnd.spotfire.sfs"],["sfv","text/x-sfv"],["sgi","image/sgi"],["sgl","application/vnd.stardivision.writer-global"],["sgm","text/sgml"],["sgml","text/sgml"],["sh","application/x-sh"],["shar","application/x-shar"],["shex","text/shex"],["shf","application/shf+xml"],["shtml","text/html"],["sid","image/x-mrsid-image"],["sieve","application/sieve"],["sig","application/pgp-signature"],["sil","audio/silk"],["silo","model/mesh"],["sis","application/vnd.symbian.install"],["sisx","application/vnd.symbian.install"],["sit","application/x-stuffit"],["sitx","application/x-stuffitx"],["siv","application/sieve"],["skd","application/vnd.koan"],["skm","application/vnd.koan"],["skp","application/vnd.koan"],["skt","application/vnd.koan"],["sldm","application/vnd.ms-powerpoint.slide.macroenabled.12"],["sldx","application/vnd.openxmlformats-officedocument.presentationml.slide"],["slim","text/slim"],["slm","text/slim"],["sls","application/route-s-tsid+xml"],["slt","application/vnd.epson.salt"],["sm","application/vnd.stepmania.stepchart"],["smf","application/vnd.stardivision.math"],["smi","application/smil"],["smil","application/smil"],["smv","video/x-smv"],["smzip","application/vnd.stepmania.package"],["snd","audio/basic"],["snf","application/x-font-snf"],["so","application/octet-stream"],["spc","application/x-pkcs7-certificates"],["spdx","text/spdx"],["spf","application/vnd.yamaha.smaf-phrase"],["spl","application/x-futuresplash"],["spot","text/vnd.in3d.spot"],["spp","application/scvp-vp-response"],["spq","application/scvp-vp-request"],["spx","audio/ogg"],["sql","application/x-sql"],["src","application/x-wais-source"],["srt","application/x-subrip"],["sru","application/sru+xml"],["srx","application/sparql-results+xml"],["ssdl","application/ssdl+xml"],["sse","application/vnd.kodak-descriptor"],["ssf","application/vnd.epson.ssf"],["ssml","application/ssml+xml"],["sst","application/octet-stream"],["st","application/vnd.sailingtracker.track"],["stc","application/vnd.sun.xml.calc.template"],["std","application/vnd.sun.xml.draw.template"],["stf","application/vnd.wt.stf"],["sti","application/vnd.sun.xml.impress.template"],["stk","application/hyperstudio"],["stl","model/stl"],["stpx","model/step+xml"],["stpxz","model/step-xml+zip"],["stpz","model/step+zip"],["str","application/vnd.pg.format"],["stw","application/vnd.sun.xml.writer.template"],["styl","text/stylus"],["stylus","text/stylus"],["sub","text/vnd.dvb.subtitle"],["sus","application/vnd.sus-calendar"],["susp","application/vnd.sus-calendar"],["sv4cpio","application/x-sv4cpio"],["sv4crc","application/x-sv4crc"],["svc","application/vnd.dvb.service"],["svd","application/vnd.svd"],["svg","image/svg+xml"],["svgz","image/svg+xml"],["swa","application/x-director"],["swf","application/x-shockwave-flash"],["swi","application/vnd.aristanetworks.swi"],["swidtag","application/swid+xml"],["sxc","application/vnd.sun.xml.calc"],["sxd","application/vnd.sun.xml.draw"],["sxg","application/vnd.sun.xml.writer.global"],["sxi","application/vnd.sun.xml.impress"],["sxm","application/vnd.sun.xml.math"],["sxw","application/vnd.sun.xml.writer"],["t","text/troff"],["t3","application/x-t3vm-image"],["t38","image/t38"],["taglet","application/vnd.mynfc"],["tao","application/vnd.tao.intent-module-archive"],["tap","image/vnd.tencent.tap"],["tar","application/x-tar"],["tcap","application/vnd.3gpp2.tcap"],["tcl","application/x-tcl"],["td","application/urc-targetdesc+xml"],["teacher","application/vnd.smart.teacher"],["tei","application/tei+xml"],["teicorpus","application/tei+xml"],["tex","application/x-tex"],["texi","application/x-texinfo"],["texinfo","application/x-texinfo"],["text","text/plain"],["tfi","application/thraud+xml"],["tfm","application/x-tex-tfm"],["tfx","image/tiff-fx"],["tga","image/x-tga"],["tgz","application/x-tar"],["thmx","application/vnd.ms-officetheme"],["tif","image/tiff"],["tiff","image/tiff"],["tk","application/x-tcl"],["tmo","application/vnd.tmobile-livetv"],["toml","application/toml"],["torrent","application/x-bittorrent"],["tpl","application/vnd.groove-tool-template"],["tpt","application/vnd.trid.tpt"],["tr","text/troff"],["tra","application/vnd.trueapp"],["trig","application/trig"],["trm","application/x-msterminal"],["ts","video/mp2t"],["tsd","application/timestamped-data"],["tsv","text/tab-separated-values"],["ttc","font/collection"],["ttf","font/ttf"],["ttl","text/turtle"],["ttml","application/ttml+xml"],["twd","application/vnd.simtech-mindmapper"],["twds","application/vnd.simtech-mindmapper"],["txd","application/vnd.genomatix.tuxedo"],["txf","application/vnd.mobius.txf"],["txt","text/plain"],["u8dsn","message/global-delivery-status"],["u8hdr","message/global-headers"],["u8mdn","message/global-disposition-notification"],["u8msg","message/global"],["u32","application/x-authorware-bin"],["ubj","application/ubjson"],["udeb","application/x-debian-package"],["ufd","application/vnd.ufdl"],["ufdl","application/vnd.ufdl"],["ulx","application/x-glulx"],["umj","application/vnd.umajin"],["unityweb","application/vnd.unity"],["uoml","application/vnd.uoml+xml"],["uri","text/uri-list"],["uris","text/uri-list"],["urls","text/uri-list"],["usdz","model/vnd.usdz+zip"],["ustar","application/x-ustar"],["utz","application/vnd.uiq.theme"],["uu","text/x-uuencode"],["uva","audio/vnd.dece.audio"],["uvd","application/vnd.dece.data"],["uvf","application/vnd.dece.data"],["uvg","image/vnd.dece.graphic"],["uvh","video/vnd.dece.hd"],["uvi","image/vnd.dece.graphic"],["uvm","video/vnd.dece.mobile"],["uvp","video/vnd.dece.pd"],["uvs","video/vnd.dece.sd"],["uvt","application/vnd.dece.ttml+xml"],["uvu","video/vnd.uvvu.mp4"],["uvv","video/vnd.dece.video"],["uvva","audio/vnd.dece.audio"],["uvvd","application/vnd.dece.data"],["uvvf","application/vnd.dece.data"],["uvvg","image/vnd.dece.graphic"],["uvvh","video/vnd.dece.hd"],["uvvi","image/vnd.dece.graphic"],["uvvm","video/vnd.dece.mobile"],["uvvp","video/vnd.dece.pd"],["uvvs","video/vnd.dece.sd"],["uvvt","application/vnd.dece.ttml+xml"],["uvvu","video/vnd.uvvu.mp4"],["uvvv","video/vnd.dece.video"],["uvvx","application/vnd.dece.unspecified"],["uvvz","application/vnd.dece.zip"],["uvx","application/vnd.dece.unspecified"],["uvz","application/vnd.dece.zip"],["vbox","application/x-virtualbox-vbox"],["vbox-extpack","application/x-virtualbox-vbox-extpack"],["vcard","text/vcard"],["vcd","application/x-cdlink"],["vcf","text/x-vcard"],["vcg","application/vnd.groove-vcard"],["vcs","text/x-vcalendar"],["vcx","application/vnd.vcx"],["vdi","application/x-virtualbox-vdi"],["vds","model/vnd.sap.vds"],["vhd","application/x-virtualbox-vhd"],["vis","application/vnd.visionary"],["viv","video/vnd.vivo"],["vlc","application/videolan"],["vmdk","application/x-virtualbox-vmdk"],["vob","video/x-ms-vob"],["vor","application/vnd.stardivision.writer"],["vox","application/x-authorware-bin"],["vrml","model/vrml"],["vsd","application/vnd.visio"],["vsf","application/vnd.vsf"],["vss","application/vnd.visio"],["vst","application/vnd.visio"],["vsw","application/vnd.visio"],["vtf","image/vnd.valve.source.texture"],["vtt","text/vtt"],["vtu","model/vnd.vtu"],["vxml","application/voicexml+xml"],["w3d","application/x-director"],["wad","application/x-doom"],["wadl","application/vnd.sun.wadl+xml"],["war","application/java-archive"],["wasm","application/wasm"],["wav","audio/x-wav"],["wax","audio/x-ms-wax"],["wbmp","image/vnd.wap.wbmp"],["wbs","application/vnd.criticaltools.wbs+xml"],["wbxml","application/wbxml"],["wcm","application/vnd.ms-works"],["wdb","application/vnd.ms-works"],["wdp","image/vnd.ms-photo"],["weba","audio/webm"],["webapp","application/x-web-app-manifest+json"],["webm","video/webm"],["webmanifest","application/manifest+json"],["webp","image/webp"],["wg","application/vnd.pmi.widget"],["wgt","application/widget"],["wks","application/vnd.ms-works"],["wm","video/x-ms-wm"],["wma","audio/x-ms-wma"],["wmd","application/x-ms-wmd"],["wmf","image/wmf"],["wml","text/vnd.wap.wml"],["wmlc","application/wmlc"],["wmls","text/vnd.wap.wmlscript"],["wmlsc","application/vnd.wap.wmlscriptc"],["wmv","video/x-ms-wmv"],["wmx","video/x-ms-wmx"],["wmz","application/x-msmetafile"],["woff","font/woff"],["woff2","font/woff2"],["word","application/msword"],["wpd","application/vnd.wordperfect"],["wpl","application/vnd.ms-wpl"],["wps","application/vnd.ms-works"],["wqd","application/vnd.wqd"],["wri","application/x-mswrite"],["wrl","model/vrml"],["wsc","message/vnd.wfa.wsc"],["wsdl","application/wsdl+xml"],["wspolicy","application/wspolicy+xml"],["wtb","application/vnd.webturbo"],["wvx","video/x-ms-wvx"],["x3d","model/x3d+xml"],["x3db","model/x3d+fastinfoset"],["x3dbz","model/x3d+binary"],["x3dv","model/x3d-vrml"],["x3dvz","model/x3d+vrml"],["x3dz","model/x3d+xml"],["x32","application/x-authorware-bin"],["x_b","model/vnd.parasolid.transmit.binary"],["x_t","model/vnd.parasolid.transmit.text"],["xaml","application/xaml+xml"],["xap","application/x-silverlight-app"],["xar","application/vnd.xara"],["xav","application/xcap-att+xml"],["xbap","application/x-ms-xbap"],["xbd","application/vnd.fujixerox.docuworks.binder"],["xbm","image/x-xbitmap"],["xca","application/xcap-caps+xml"],["xcs","application/calendar+xml"],["xdf","application/xcap-diff+xml"],["xdm","application/vnd.syncml.dm+xml"],["xdp","application/vnd.adobe.xdp+xml"],["xdssc","application/dssc+xml"],["xdw","application/vnd.fujixerox.docuworks"],["xel","application/xcap-el+xml"],["xenc","application/xenc+xml"],["xer","application/patch-ops-error+xml"],["xfdf","application/vnd.adobe.xfdf"],["xfdl","application/vnd.xfdl"],["xht","application/xhtml+xml"],["xhtml","application/xhtml+xml"],["xhvml","application/xv+xml"],["xif","image/vnd.xiff"],["xl","application/excel"],["xla","application/vnd.ms-excel"],["xlam","application/vnd.ms-excel.addin.macroEnabled.12"],["xlc","application/vnd.ms-excel"],["xlf","application/xliff+xml"],["xlm","application/vnd.ms-excel"],["xls","application/vnd.ms-excel"],["xlsb","application/vnd.ms-excel.sheet.binary.macroEnabled.12"],["xlsm","application/vnd.ms-excel.sheet.macroEnabled.12"],["xlsx","application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"],["xlt","application/vnd.ms-excel"],["xltm","application/vnd.ms-excel.template.macroEnabled.12"],["xltx","application/vnd.openxmlformats-officedocument.spreadsheetml.template"],["xlw","application/vnd.ms-excel"],["xm","audio/xm"],["xml","application/xml"],["xns","application/xcap-ns+xml"],["xo","application/vnd.olpc-sugar"],["xop","application/xop+xml"],["xpi","application/x-xpinstall"],["xpl","application/xproc+xml"],["xpm","image/x-xpixmap"],["xpr","application/vnd.is-xpr"],["xps","application/vnd.ms-xpsdocument"],["xpw","application/vnd.intercon.formnet"],["xpx","application/vnd.intercon.formnet"],["xsd","application/xml"],["xsl","application/xml"],["xslt","application/xslt+xml"],["xsm","application/vnd.syncml+xml"],["xspf","application/xspf+xml"],["xul","application/vnd.mozilla.xul+xml"],["xvm","application/xv+xml"],["xvml","application/xv+xml"],["xwd","image/x-xwindowdump"],["xyz","chemical/x-xyz"],["xz","application/x-xz"],["yaml","text/yaml"],["yang","application/yang"],["yin","application/yin+xml"],["yml","text/yaml"],["ymp","text/x-suse-ymp"],["z","application/x-compress"],["z1","application/x-zmachine"],["z2","application/x-zmachine"],["z3","application/x-zmachine"],["z4","application/x-zmachine"],["z5","application/x-zmachine"],["z6","application/x-zmachine"],["z7","application/x-zmachine"],["z8","application/x-zmachine"],["zaz","application/vnd.zzazz.deck+xml"],["zip","application/zip"],["zir","application/vnd.zul"],["zirz","application/vnd.zul"],["zmm","application/vnd.handheld-entertainment+xml"],["zsh","text/x-scriptzsh"]]);function El(e,t,n){const r=ote(e),{webkitRelativePath:a}=e,i=typeof t=="string"?t:typeof a=="string"&&a.length>0?a:`./${e.name}`;return typeof r.path!="string"&&kN(r,"path",i),kN(r,"relativePath",i),r}function ote(e){const{name:t}=e;if(t&&t.lastIndexOf(".")!==-1&&!e.type){const r=t.split(".").pop().toLowerCase(),a=ate.get(r);a&&Object.defineProperty(e,"type",{value:a,writable:!1,configurable:!1,enumerable:!0})}return e}function kN(e,t,n){Object.defineProperty(e,t,{value:n,writable:!1,configurable:!1,enumerable:!0})}const ite=[".DS_Store","Thumbs.db"];function lte(e){return ci(this,void 0,void 0,function*(){return qd(e)&&ste(e.dataTransfer)?fte(e.dataTransfer,e.type):ute(e)?cte(e):Array.isArray(e)&&e.every(t=>"getFile"in t&&typeof t.getFile=="function")?dte(e):[]})}function ste(e){return qd(e)}function ute(e){return qd(e)&&qd(e.target)}function qd(e){return typeof e=="object"&&e!==null}function cte(e){return Jx(e.target.files).map(t=>El(t))}function dte(e){return ci(this,void 0,void 0,function*(){return(yield Promise.all(e.map(n=>n.getFile()))).map(n=>El(n))})}function fte(e,t){return ci(this,void 0,void 0,function*(){if(e.items){const n=Jx(e.items).filter(a=>a.kind==="file");if(t!=="drop")return n;const r=yield Promise.all(n.map(pte));return AN(i4(r))}return AN(Jx(e.files).map(n=>El(n)))})}function AN(e){return e.filter(t=>ite.indexOf(t.name)===-1)}function Jx(e){if(e===null)return[];const t=[];for(let n=0;n<e.length;n++){const r=e[n];t.push(r)}return t}function pte(e){if(typeof e.webkitGetAsEntry!="function")return TN(e);const t=e.webkitGetAsEntry();return t&&t.isDirectory?l4(t):TN(e,t)}function i4(e){return e.reduce((t,n)=>[...t,...Array.isArray(n)?i4(n):[n]],[])}function TN(e,t){return ci(this,void 0,void 0,function*(){var n;if(globalThis.isSecureContext&&typeof e.getAsFileSystemHandle=="function"){const i=yield e.getAsFileSystemHandle();if(i===null)throw new Error(`${e} is not a File`);if(i!==void 0){const l=yield i.getFile();return l.handle=i,El(l)}}const r=e.getAsFile();if(!r)throw new Error(`${e} is not a File`);return El(r,(n=t==null?void 0:t.fullPath)!==null&&n!==void 0?n:void 0)})}function gte(e){return ci(this,void 0,void 0,function*(){return e.isDirectory?l4(e):hte(e)})}function l4(e){const t=e.createReader();return new Promise((n,r)=>{const a=[];function i(){t.readEntries(l=>ci(this,void 0,void 0,function*(){if(l.length){const u=Promise.all(l.map(gte));a.push(u),i()}else try{const u=yield Promise.all(a);n(u)}catch(u){r(u)}}),l=>{r(l)})}i()})}function hte(e){return ci(this,void 0,void 0,function*(){return new Promise((t,n)=>{e.file(r=>{const a=El(r,e.fullPath);t(a)},r=>{n(r)})})})}var ad={},_N;function mte(){return _N||(_N=1,ad.__esModule=!0,ad.default=function(e,t){if(e&&t){var n=Array.isArray(t)?t:t.split(",");if(n.length===0)return!0;var r=e.name||"",a=(e.type||"").toLowerCase(),i=a.replace(/\/.*$/,"");return n.some(function(l){var u=l.trim().toLowerCase();return u.charAt(0)==="."?r.toLowerCase().endsWith(u):u.endsWith("/*")?i===u.replace(/\/.*$/,""):a===u})}return!0}),ad}var bte=mte();const bm=an(bte);function RN(e){return Ste(e)||vte(e)||u4(e)||yte()}function yte(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function vte(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function Ste(e){if(Array.isArray(e))return ek(e)}function CN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function NN(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?CN(Object(n),!0).forEach(function(r){s4(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):CN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function s4(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function lu(e,t){return xte(e)||wte(e,t)||u4(e,t)||Ete()}function Ete(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function u4(e,t){if(e){if(typeof e=="string")return ek(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return ek(e,t)}}function ek(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function wte(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],a=!0,i=!1,l,u;try{for(n=n.call(e);!(a=(l=n.next()).done)&&(r.push(l.value),!(t&&r.length===t));a=!0);}catch(c){i=!0,u=c}finally{try{!a&&n.return!=null&&n.return()}finally{if(i)throw u}}return r}}function xte(e){if(Array.isArray(e))return e}var kte=typeof bm=="function"?bm:bm.default,Ate="file-invalid-type",Tte="file-too-large",_te="file-too-small",Rte="too-many-files",Cte=function(){var t=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"",n=t.split(","),r=n.length>1?"one of ".concat(n.join(", ")):n[0];return{code:Ate,message:"File type must be ".concat(r)}},ON=function(t){return{code:Tte,message:"File is larger than ".concat(t," ").concat(t===1?"byte":"bytes")}},DN=function(t){return{code:_te,message:"File is smaller than ".concat(t," ").concat(t===1?"byte":"bytes")}},Nte={code:Rte,message:"Too many files"};function c4(e,t){var n=e.type==="application/x-moz-file"||kte(e,t);return[n,n?null:Cte(t)]}function d4(e,t,n){if(Jo(e.size))if(Jo(t)&&Jo(n)){if(e.size>n)return[!1,ON(n)];if(e.size<t)return[!1,DN(t)]}else{if(Jo(t)&&e.size<t)return[!1,DN(t)];if(Jo(n)&&e.size>n)return[!1,ON(n)]}return[!0,null]}function Jo(e){return e!=null}function Ote(e){var t=e.files,n=e.accept,r=e.minSize,a=e.maxSize,i=e.multiple,l=e.maxFiles,u=e.validator;return!i&&t.length>1||i&&l>=1&&t.length>l?!1:t.every(function(c){var f=c4(c,n),p=lu(f,1),g=p[0],b=d4(c,r,a),m=lu(b,1),S=m[0],v=u?u(c):null;return g&&S&&!v})}function Vd(e){return typeof e.isPropagationStopped=="function"?e.isPropagationStopped():typeof e.cancelBubble<"u"?e.cancelBubble:!1}function od(e){return e.dataTransfer?Array.prototype.some.call(e.dataTransfer.types,function(t){return t==="Files"||t==="application/x-moz-file"}):!!e.target&&!!e.target.files}function IN(e){e.preventDefault()}function Dte(e){return e.indexOf("MSIE")!==-1||e.indexOf("Trident/")!==-1}function Ite(e){return e.indexOf("Edge/")!==-1}function Lte(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:window.navigator.userAgent;return Dte(e)||Ite(e)}function $r(){for(var e=arguments.length,t=new Array(e),n=0;n<e;n++)t[n]=arguments[n];return function(r){for(var a=arguments.length,i=new Array(a>1?a-1:0),l=1;l<a;l++)i[l-1]=arguments[l];return t.some(function(u){return!Vd(r)&&u&&u.apply(void 0,[r].concat(i)),Vd(r)})}}function Mte(){return"showOpenFilePicker"in window}function Fte(e){if(Jo(e)){var t=Object.entries(e).filter(function(n){var r=lu(n,2),a=r[0],i=r[1],l=!0;return f4(a)||(console.warn('Skipped "'.concat(a,'" because it is not a valid MIME type. Check https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types for a list of valid MIME types.')),l=!1),(!Array.isArray(i)||!i.every(p4))&&(console.warn('Skipped "'.concat(a,'" because an invalid file extension was provided.')),l=!1),l}).reduce(function(n,r){var a=lu(r,2),i=a[0],l=a[1];return NN(NN({},n),{},s4({},i,l))},{});return[{description:"Files",accept:t}]}return e}function zte(e){if(Jo(e))return Object.entries(e).reduce(function(t,n){var r=lu(n,2),a=r[0],i=r[1];return[].concat(RN(t),[a],RN(i))},[]).filter(function(t){return f4(t)||p4(t)}).join(",")}function Pte(e){return e instanceof DOMException&&(e.name==="AbortError"||e.code===e.ABORT_ERR)}function Bte(e){return e instanceof DOMException&&(e.name==="SecurityError"||e.code===e.SECURITY_ERR)}function f4(e){return e==="audio/*"||e==="video/*"||e==="image/*"||e==="text/*"||e==="application/*"||/\w+\/[-+.\w]+/g.test(e)}function p4(e){return/^.*\.[\w]+$/.test(e)}var Ute=["children"],jte=["open"],Gte=["refKey","role","onKeyDown","onFocus","onBlur","onClick","onDragEnter","onDragOver","onDragLeave","onDrop"],Hte=["refKey","onChange","onClick"];function $te(e){return Wte(e)||Vte(e)||g4(e)||qte()}function qte(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function Vte(e){if(typeof Symbol<"u"&&e[Symbol.iterator]!=null||e["@@iterator"]!=null)return Array.from(e)}function Wte(e){if(Array.isArray(e))return tk(e)}function ym(e,t){return Xte(e)||Kte(e,t)||g4(e,t)||Yte()}function Yte(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function g4(e,t){if(e){if(typeof e=="string")return tk(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);if(n==="Object"&&e.constructor&&(n=e.constructor.name),n==="Map"||n==="Set")return Array.from(e);if(n==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return tk(e,t)}}function tk(e,t){(t==null||t>e.length)&&(t=e.length);for(var n=0,r=new Array(t);n<t;n++)r[n]=e[n];return r}function Kte(e,t){var n=e==null?null:typeof Symbol<"u"&&e[Symbol.iterator]||e["@@iterator"];if(n!=null){var r=[],a=!0,i=!1,l,u;try{for(n=n.call(e);!(a=(l=n.next()).done)&&(r.push(l.value),!(t&&r.length===t));a=!0);}catch(c){i=!0,u=c}finally{try{!a&&n.return!=null&&n.return()}finally{if(i)throw u}}return r}}function Xte(e){if(Array.isArray(e))return e}function LN(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function Pt(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?LN(Object(n),!0).forEach(function(r){nk(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):LN(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function nk(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}function Wd(e,t){if(e==null)return{};var n=Zte(e,t),r,a;if(Object.getOwnPropertySymbols){var i=Object.getOwnPropertySymbols(e);for(a=0;a<i.length;a++)r=i[a],!(t.indexOf(r)>=0)&&Object.prototype.propertyIsEnumerable.call(e,r)&&(n[r]=e[r])}return n}function Zte(e,t){if(e==null)return{};var n={},r=Object.keys(e),a,i;for(i=0;i<r.length;i++)a=r[i],!(t.indexOf(a)>=0)&&(n[a]=e[a]);return n}var Lf=k.forwardRef(function(e,t){var n=e.children,r=Wd(e,Ute),a=Qte(r),i=a.open,l=Wd(a,jte);return k.useImperativeHandle(t,function(){return{open:i}},[i]),ye.createElement(k.Fragment,null,n(Pt(Pt({},l),{},{open:i})))});Lf.displayName="Dropzone";var h4={disabled:!1,getFilesFromEvent:lte,maxSize:1/0,minSize:0,multiple:!0,maxFiles:0,preventDropOnDocument:!0,noClick:!1,noKeyboard:!1,noDrag:!1,noDragEventsBubbling:!1,validator:null,useFsAccessApi:!1,autoFocus:!1};Lf.defaultProps=h4;Lf.propTypes={children:Ct.func,accept:Ct.objectOf(Ct.arrayOf(Ct.string)),multiple:Ct.bool,preventDropOnDocument:Ct.bool,noClick:Ct.bool,noKeyboard:Ct.bool,noDrag:Ct.bool,noDragEventsBubbling:Ct.bool,minSize:Ct.number,maxSize:Ct.number,maxFiles:Ct.number,disabled:Ct.bool,getFilesFromEvent:Ct.func,onFileDialogCancel:Ct.func,onFileDialogOpen:Ct.func,useFsAccessApi:Ct.bool,autoFocus:Ct.bool,onDragEnter:Ct.func,onDragLeave:Ct.func,onDragOver:Ct.func,onDrop:Ct.func,onDropAccepted:Ct.func,onDropRejected:Ct.func,onError:Ct.func,validator:Ct.func};var rk={isFocused:!1,isFileDialogActive:!1,isDragActive:!1,isDragAccept:!1,isDragReject:!1,acceptedFiles:[],fileRejections:[]};function Qte(){var e=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},t=Pt(Pt({},h4),e),n=t.accept,r=t.disabled,a=t.getFilesFromEvent,i=t.maxSize,l=t.minSize,u=t.multiple,c=t.maxFiles,f=t.onDragEnter,p=t.onDragLeave,g=t.onDragOver,b=t.onDrop,m=t.onDropAccepted,S=t.onDropRejected,v=t.onFileDialogCancel,A=t.onFileDialogOpen,R=t.useFsAccessApi,x=t.autoFocus,T=t.preventDropOnDocument,C=t.noClick,N=t.noKeyboard,_=t.noDrag,O=t.noDragEventsBubbling,z=t.onError,I=t.validator,M=k.useMemo(function(){return zte(n)},[n]),H=k.useMemo(function(){return Fte(n)},[n]),q=k.useMemo(function(){return typeof A=="function"?A:MN},[A]),P=k.useMemo(function(){return typeof v=="function"?v:MN},[v]),W=k.useRef(null),Z=k.useRef(null),j=k.useReducer(Jte,rk),G=ym(j,2),B=G[0],X=G[1],D=B.isFocused,V=B.isFileDialogActive,U=k.useRef(typeof window<"u"&&window.isSecureContext&&R&&Mte()),L=function(){!U.current&&V&&setTimeout(function(){if(Z.current){var Ne=Z.current.files;Ne.length||(X({type:"closeDialog"}),P())}},300)};k.useEffect(function(){return window.addEventListener("focus",L,!1),function(){window.removeEventListener("focus",L,!1)}},[Z,V,P,U]);var Y=k.useRef([]),Q=function(Ne){W.current&&W.current.contains(Ne.target)||(Ne.preventDefault(),Y.current=[])};k.useEffect(function(){return T&&(document.addEventListener("dragover",IN,!1),document.addEventListener("drop",Q,!1)),function(){T&&(document.removeEventListener("dragover",IN),document.removeEventListener("drop",Q))}},[W,T]),k.useEffect(function(){return!r&&x&&W.current&&W.current.focus(),function(){}},[W,x,r]);var se=k.useCallback(function(he){z?z(he):console.error(he)},[z]),re=k.useCallback(function(he){he.preventDefault(),he.persist(),ve(he),Y.current=[].concat($te(Y.current),[he.target]),od(he)&&Promise.resolve(a(he)).then(function(Ne){if(!(Vd(he)&&!O)){var ee=Ne.length,ce=ee>0&&Ote({files:Ne,accept:M,minSize:l,maxSize:i,multiple:u,maxFiles:c,validator:I}),Re=ee>0&&!ce;X({isDragAccept:ce,isDragReject:Re,isDragActive:!0,type:"setDraggedFiles"}),f&&f(he)}}).catch(function(Ne){return se(Ne)})},[a,f,se,O,M,l,i,u,c,I]),le=k.useCallback(function(he){he.preventDefault(),he.persist(),ve(he);var Ne=od(he);if(Ne&&he.dataTransfer)try{he.dataTransfer.dropEffect="copy"}catch{}return Ne&&g&&g(he),!1},[g,O]),Ae=k.useCallback(function(he){he.preventDefault(),he.persist(),ve(he);var Ne=Y.current.filter(function(ce){return W.current&&W.current.contains(ce)}),ee=Ne.indexOf(he.target);ee!==-1&&Ne.splice(ee,1),Y.current=Ne,!(Ne.length>0)&&(X({type:"setDraggedFiles",isDragActive:!1,isDragAccept:!1,isDragReject:!1}),od(he)&&p&&p(he))},[W,p,O]),ae=k.useCallback(function(he,Ne){var ee=[],ce=[];he.forEach(function(Re){var Fe=c4(Re,M),qe=ym(Fe,2),mt=qe[0],St=qe[1],pt=d4(Re,l,i),Je=ym(pt,2),wt=Je[0],rt=Je[1],bt=I?I(Re):null;if(mt&&wt&&!bt)ee.push(Re);else{var Bt=[St,rt];bt&&(Bt=Bt.concat(bt)),ce.push({file:Re,errors:Bt.filter(function(sn){return sn})})}}),(!u&&ee.length>1||u&&c>=1&&ee.length>c)&&(ee.forEach(function(Re){ce.push({file:Re,errors:[Nte]})}),ee.splice(0)),X({acceptedFiles:ee,fileRejections:ce,isDragReject:ce.length>0,type:"setFiles"}),b&&b(ee,ce,Ne),ce.length>0&&S&&S(ce,Ne),ee.length>0&&m&&m(ee,Ne)},[X,u,M,l,i,c,b,m,S,I]),we=k.useCallback(function(he){he.preventDefault(),he.persist(),ve(he),Y.current=[],od(he)&&Promise.resolve(a(he)).then(function(Ne){Vd(he)&&!O||ae(Ne,he)}).catch(function(Ne){return se(Ne)}),X({type:"reset"})},[a,ae,se,O]),xe=k.useCallback(function(){if(U.current){X({type:"openDialog"}),q();var he={multiple:u,types:H};window.showOpenFilePicker(he).then(function(Ne){return a(Ne)}).then(function(Ne){ae(Ne,null),X({type:"closeDialog"})}).catch(function(Ne){Pte(Ne)?(P(Ne),X({type:"closeDialog"})):Bte(Ne)?(U.current=!1,Z.current?(Z.current.value=null,Z.current.click()):se(new Error("Cannot open the file picker because the https://developer.mozilla.org/en-US/docs/Web/API/File_System_Access_API is not supported and no <input> was provided."))):se(Ne)});return}Z.current&&(X({type:"openDialog"}),q(),Z.current.value=null,Z.current.click())},[X,q,P,R,ae,se,H,u]),Ie=k.useCallback(function(he){!W.current||!W.current.isEqualNode(he.target)||(he.key===" "||he.key==="Enter"||he.keyCode===32||he.keyCode===13)&&(he.preventDefault(),xe())},[W,xe]),Ce=k.useCallback(function(){X({type:"focus"})},[]),Ee=k.useCallback(function(){X({type:"blur"})},[]),J=k.useCallback(function(){C||(Lte()?setTimeout(xe,0):xe())},[C,xe]),fe=function(Ne){return r?null:Ne},ke=function(Ne){return N?null:fe(Ne)},me=function(Ne){return _?null:fe(Ne)},ve=function(Ne){O&&Ne.stopPropagation()},ie=k.useMemo(function(){return function(){var he=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},Ne=he.refKey,ee=Ne===void 0?"ref":Ne,ce=he.role,Re=he.onKeyDown,Fe=he.onFocus,qe=he.onBlur,mt=he.onClick,St=he.onDragEnter,pt=he.onDragOver,Je=he.onDragLeave,wt=he.onDrop,rt=Wd(he,Gte);return Pt(Pt(nk({onKeyDown:ke($r(Re,Ie)),onFocus:ke($r(Fe,Ce)),onBlur:ke($r(qe,Ee)),onClick:fe($r(mt,J)),onDragEnter:me($r(St,re)),onDragOver:me($r(pt,le)),onDragLeave:me($r(Je,Ae)),onDrop:me($r(wt,we)),role:typeof ce=="string"&&ce!==""?ce:"presentation"},ee,W),!r&&!N?{tabIndex:0}:{}),rt)}},[W,Ie,Ce,Ee,J,re,le,Ae,we,N,_,r]),ze=k.useCallback(function(he){he.stopPropagation()},[]),Pe=k.useMemo(function(){return function(){var he=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},Ne=he.refKey,ee=Ne===void 0?"ref":Ne,ce=he.onChange,Re=he.onClick,Fe=Wd(he,Hte),qe=nk({accept:M,multiple:u,type:"file",style:{border:0,clip:"rect(0, 0, 0, 0)",clipPath:"inset(50%)",height:"1px",margin:"0 -1px -1px 0",overflow:"hidden",padding:0,position:"absolute",width:"1px",whiteSpace:"nowrap"},onChange:fe($r(ce,we)),onClick:fe($r(Re,ze)),tabIndex:-1},ee,Z);return Pt(Pt({},qe),Fe)}},[Z,n,u,we,r]);return Pt(Pt({},B),{},{isFocused:D&&!r,getRootProps:ie,getInputProps:Pe,rootRef:W,inputRef:Z,open:fe(xe)})}function Jte(e,t){switch(t.type){case"focus":return Pt(Pt({},e),{},{isFocused:!0});case"blur":return Pt(Pt({},e),{},{isFocused:!1});case"openDialog":return Pt(Pt({},rk),{},{isFileDialogActive:!0});case"closeDialog":return Pt(Pt({},e),{},{isFileDialogActive:!1});case"setDraggedFiles":return Pt(Pt({},e),{},{isDragActive:t.isDragActive,isDragAccept:t.isDragAccept,isDragReject:t.isDragReject});case"setFiles":return Pt(Pt({},e),{},{acceptedFiles:t.acceptedFiles,fileRejections:t.fileRejections,isDragReject:t.isDragReject});case"reset":return Pt({},rk);default:return e}}function MN(){}var L0="Progress",M0=100,[ene,ave]=mr(L0),[tne,nne]=ene(L0),m4=k.forwardRef((e,t)=>{const{__scopeProgress:n,value:r=null,max:a,getValueLabel:i=rne,...l}=e;(a||a===0)&&!FN(a)&&console.error(ane(`${a}`,"Progress"));const u=FN(a)?a:M0;r!==null&&!zN(r,u)&&console.error(one(`${r}`,"Progress"));const c=zN(r,u)?r:null,f=Yd(c)?i(c,u):void 0;return w.jsx(tne,{scope:n,value:c,max:u,children:w.jsx(Xe.div,{"aria-valuemax":u,"aria-valuemin":0,"aria-valuenow":Yd(c)?c:void 0,"aria-valuetext":f,role:"progressbar","data-state":v4(c,u),"data-value":c??void 0,"data-max":u,...l,ref:t})})});m4.displayName=L0;var b4="ProgressIndicator",y4=k.forwardRef((e,t)=>{const{__scopeProgress:n,...r}=e,a=nne(b4,n);return w.jsx(Xe.div,{"data-state":v4(a.value,a.max),"data-value":a.value??void 0,"data-max":a.max,...r,ref:t})});y4.displayName=b4;function rne(e,t){return`${Math.round(e/t*100)}%`}function v4(e,t){return e==null?"indeterminate":e===t?"complete":"loading"}function Yd(e){return typeof e=="number"}function FN(e){return Yd(e)&&!isNaN(e)&&e>0}function zN(e,t){return Yd(e)&&!isNaN(e)&&e<=t&&e>=0}function ane(e,t){return`Invalid prop \`max\` of value \`${e}\` supplied to \`${t}\`. Only numbers greater than 0 are valid max values. Defaulting to \`${M0}\`.`}function one(e,t){return`Invalid prop \`value\` of value \`${e}\` supplied to \`${t}\`. The \`value\` prop must be:
  - a positive number
  - less than the value passed to \`max\` (or ${M0} if no \`max\` prop is set)
  - \`null\` or \`undefined\` if the progress is indeterminate.

Defaulting to \`null\`.`}var S4=m4,ine=y4;const E4=k.forwardRef(({className:e,value:t,...n},r)=>w.jsx(S4,{ref:r,className:Me("bg-secondary relative h-4 w-full overflow-hidden rounded-full",e),...n,children:w.jsx(ine,{className:"bg-primary h-full w-full flex-1 transition-all",style:{transform:`translateX(-${100-(t||0)}%)`}})}));E4.displayName=S4.displayName;function ak(e,[t,n]){return Math.min(n,Math.max(t,e))}function lne(e,t){return k.useReducer((n,r)=>t[n][r]??n,e)}var F0="ScrollArea",[w4,ove]=mr(F0),[sne,yr]=w4(F0),x4=k.forwardRef((e,t)=>{const{__scopeScrollArea:n,type:r="hover",dir:a,scrollHideDelay:i=600,...l}=e,[u,c]=k.useState(null),[f,p]=k.useState(null),[g,b]=k.useState(null),[m,S]=k.useState(null),[v,A]=k.useState(null),[R,x]=k.useState(0),[T,C]=k.useState(0),[N,_]=k.useState(!1),[O,z]=k.useState(!1),I=ft(t,H=>c(H)),M=Tf(a);return w.jsx(sne,{scope:n,type:r,dir:M,scrollHideDelay:i,scrollArea:u,viewport:f,onViewportChange:p,content:g,onContentChange:b,scrollbarX:m,onScrollbarXChange:S,scrollbarXEnabled:N,onScrollbarXEnabledChange:_,scrollbarY:v,onScrollbarYChange:A,scrollbarYEnabled:O,onScrollbarYEnabledChange:z,onCornerWidthChange:x,onCornerHeightChange:C,children:w.jsx(Xe.div,{dir:M,...l,ref:I,style:{position:"relative","--radix-scroll-area-corner-width":R+"px","--radix-scroll-area-corner-height":T+"px",...e.style}})})});x4.displayName=F0;var k4="ScrollAreaViewport",A4=k.forwardRef((e,t)=>{const{__scopeScrollArea:n,children:r,nonce:a,...i}=e,l=yr(k4,n),u=k.useRef(null),c=ft(t,u,l.onViewportChange);return w.jsxs(w.Fragment,{children:[w.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-scroll-area-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-scroll-area-viewport]::-webkit-scrollbar{display:none}"},nonce:a}),w.jsx(Xe.div,{"data-radix-scroll-area-viewport":"",...i,ref:c,style:{overflowX:l.scrollbarXEnabled?"scroll":"hidden",overflowY:l.scrollbarYEnabled?"scroll":"hidden",...e.style},children:w.jsx("div",{ref:l.onContentChange,style:{minWidth:"100%",display:"table"},children:r})})]})});A4.displayName=k4;var ea="ScrollAreaScrollbar",z0=k.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=yr(ea,e.__scopeScrollArea),{onScrollbarXEnabledChange:i,onScrollbarYEnabledChange:l}=a,u=e.orientation==="horizontal";return k.useEffect(()=>(u?i(!0):l(!0),()=>{u?i(!1):l(!1)}),[u,i,l]),a.type==="hover"?w.jsx(une,{...r,ref:t,forceMount:n}):a.type==="scroll"?w.jsx(cne,{...r,ref:t,forceMount:n}):a.type==="auto"?w.jsx(T4,{...r,ref:t,forceMount:n}):a.type==="always"?w.jsx(P0,{...r,ref:t}):null});z0.displayName=ea;var une=k.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=yr(ea,e.__scopeScrollArea),[i,l]=k.useState(!1);return k.useEffect(()=>{const u=a.scrollArea;let c=0;if(u){const f=()=>{window.clearTimeout(c),l(!0)},p=()=>{c=window.setTimeout(()=>l(!1),a.scrollHideDelay)};return u.addEventListener("pointerenter",f),u.addEventListener("pointerleave",p),()=>{window.clearTimeout(c),u.removeEventListener("pointerenter",f),u.removeEventListener("pointerleave",p)}}},[a.scrollArea,a.scrollHideDelay]),w.jsx(Jn,{present:n||i,children:w.jsx(T4,{"data-state":i?"visible":"hidden",...r,ref:t})})}),cne=k.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=yr(ea,e.__scopeScrollArea),i=e.orientation==="horizontal",l=Ff(()=>c("SCROLL_END"),100),[u,c]=lne("hidden",{hidden:{SCROLL:"scrolling"},scrolling:{SCROLL_END:"idle",POINTER_ENTER:"interacting"},interacting:{SCROLL:"interacting",POINTER_LEAVE:"idle"},idle:{HIDE:"hidden",SCROLL:"scrolling",POINTER_ENTER:"interacting"}});return k.useEffect(()=>{if(u==="idle"){const f=window.setTimeout(()=>c("HIDE"),a.scrollHideDelay);return()=>window.clearTimeout(f)}},[u,a.scrollHideDelay,c]),k.useEffect(()=>{const f=a.viewport,p=i?"scrollLeft":"scrollTop";if(f){let g=f[p];const b=()=>{const m=f[p];g!==m&&(c("SCROLL"),l()),g=m};return f.addEventListener("scroll",b),()=>f.removeEventListener("scroll",b)}},[a.viewport,i,c,l]),w.jsx(Jn,{present:n||u!=="hidden",children:w.jsx(P0,{"data-state":u==="hidden"?"hidden":"visible",...r,ref:t,onPointerEnter:Ye(e.onPointerEnter,()=>c("POINTER_ENTER")),onPointerLeave:Ye(e.onPointerLeave,()=>c("POINTER_LEAVE"))})})}),T4=k.forwardRef((e,t)=>{const n=yr(ea,e.__scopeScrollArea),{forceMount:r,...a}=e,[i,l]=k.useState(!1),u=e.orientation==="horizontal",c=Ff(()=>{if(n.viewport){const f=n.viewport.offsetWidth<n.viewport.scrollWidth,p=n.viewport.offsetHeight<n.viewport.scrollHeight;l(u?f:p)}},10);return wl(n.viewport,c),wl(n.content,c),w.jsx(Jn,{present:r||i,children:w.jsx(P0,{"data-state":i?"visible":"hidden",...a,ref:t})})}),P0=k.forwardRef((e,t)=>{const{orientation:n="vertical",...r}=e,a=yr(ea,e.__scopeScrollArea),i=k.useRef(null),l=k.useRef(0),[u,c]=k.useState({content:0,viewport:0,scrollbar:{size:0,paddingStart:0,paddingEnd:0}}),f=O4(u.viewport,u.content),p={...r,sizes:u,onSizesChange:c,hasThumb:f>0&&f<1,onThumbChange:b=>i.current=b,onThumbPointerUp:()=>l.current=0,onThumbPointerDown:b=>l.current=b};function g(b,m){return mne(b,l.current,u,m)}return n==="horizontal"?w.jsx(dne,{...p,ref:t,onThumbPositionChange:()=>{if(a.viewport&&i.current){const b=a.viewport.scrollLeft,m=PN(b,u,a.dir);i.current.style.transform=`translate3d(${m}px, 0, 0)`}},onWheelScroll:b=>{a.viewport&&(a.viewport.scrollLeft=b)},onDragScroll:b=>{a.viewport&&(a.viewport.scrollLeft=g(b,a.dir))}}):n==="vertical"?w.jsx(fne,{...p,ref:t,onThumbPositionChange:()=>{if(a.viewport&&i.current){const b=a.viewport.scrollTop,m=PN(b,u);i.current.style.transform=`translate3d(0, ${m}px, 0)`}},onWheelScroll:b=>{a.viewport&&(a.viewport.scrollTop=b)},onDragScroll:b=>{a.viewport&&(a.viewport.scrollTop=g(b))}}):null}),dne=k.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,i=yr(ea,e.__scopeScrollArea),[l,u]=k.useState(),c=k.useRef(null),f=ft(t,c,i.onScrollbarXChange);return k.useEffect(()=>{c.current&&u(getComputedStyle(c.current))},[c]),w.jsx(R4,{"data-orientation":"horizontal",...a,ref:f,sizes:n,style:{bottom:0,left:i.dir==="rtl"?"var(--radix-scroll-area-corner-width)":0,right:i.dir==="ltr"?"var(--radix-scroll-area-corner-width)":0,"--radix-scroll-area-thumb-width":Mf(n)+"px",...e.style},onThumbPointerDown:p=>e.onThumbPointerDown(p.x),onDragScroll:p=>e.onDragScroll(p.x),onWheelScroll:(p,g)=>{if(i.viewport){const b=i.viewport.scrollLeft+p.deltaX;e.onWheelScroll(b),I4(b,g)&&p.preventDefault()}},onResize:()=>{c.current&&i.viewport&&l&&r({content:i.viewport.scrollWidth,viewport:i.viewport.offsetWidth,scrollbar:{size:c.current.clientWidth,paddingStart:Xd(l.paddingLeft),paddingEnd:Xd(l.paddingRight)}})}})}),fne=k.forwardRef((e,t)=>{const{sizes:n,onSizesChange:r,...a}=e,i=yr(ea,e.__scopeScrollArea),[l,u]=k.useState(),c=k.useRef(null),f=ft(t,c,i.onScrollbarYChange);return k.useEffect(()=>{c.current&&u(getComputedStyle(c.current))},[c]),w.jsx(R4,{"data-orientation":"vertical",...a,ref:f,sizes:n,style:{top:0,right:i.dir==="ltr"?0:void 0,left:i.dir==="rtl"?0:void 0,bottom:"var(--radix-scroll-area-corner-height)","--radix-scroll-area-thumb-height":Mf(n)+"px",...e.style},onThumbPointerDown:p=>e.onThumbPointerDown(p.y),onDragScroll:p=>e.onDragScroll(p.y),onWheelScroll:(p,g)=>{if(i.viewport){const b=i.viewport.scrollTop+p.deltaY;e.onWheelScroll(b),I4(b,g)&&p.preventDefault()}},onResize:()=>{c.current&&i.viewport&&l&&r({content:i.viewport.scrollHeight,viewport:i.viewport.offsetHeight,scrollbar:{size:c.current.clientHeight,paddingStart:Xd(l.paddingTop),paddingEnd:Xd(l.paddingBottom)}})}})}),[pne,_4]=w4(ea),R4=k.forwardRef((e,t)=>{const{__scopeScrollArea:n,sizes:r,hasThumb:a,onThumbChange:i,onThumbPointerUp:l,onThumbPointerDown:u,onThumbPositionChange:c,onDragScroll:f,onWheelScroll:p,onResize:g,...b}=e,m=yr(ea,n),[S,v]=k.useState(null),A=ft(t,I=>v(I)),R=k.useRef(null),x=k.useRef(""),T=m.viewport,C=r.content-r.viewport,N=pn(p),_=pn(c),O=Ff(g,10);function z(I){if(R.current){const M=I.clientX-R.current.left,H=I.clientY-R.current.top;f({x:M,y:H})}}return k.useEffect(()=>{const I=M=>{const H=M.target;(S==null?void 0:S.contains(H))&&N(M,C)};return document.addEventListener("wheel",I,{passive:!1}),()=>document.removeEventListener("wheel",I,{passive:!1})},[T,S,C,N]),k.useEffect(_,[r,_]),wl(S,O),wl(m.content,O),w.jsx(pne,{scope:n,scrollbar:S,hasThumb:a,onThumbChange:pn(i),onThumbPointerUp:pn(l),onThumbPositionChange:_,onThumbPointerDown:pn(u),children:w.jsx(Xe.div,{...b,ref:A,style:{position:"absolute",...b.style},onPointerDown:Ye(e.onPointerDown,I=>{I.button===0&&(I.target.setPointerCapture(I.pointerId),R.current=S.getBoundingClientRect(),x.current=document.body.style.webkitUserSelect,document.body.style.webkitUserSelect="none",m.viewport&&(m.viewport.style.scrollBehavior="auto"),z(I))}),onPointerMove:Ye(e.onPointerMove,z),onPointerUp:Ye(e.onPointerUp,I=>{const M=I.target;M.hasPointerCapture(I.pointerId)&&M.releasePointerCapture(I.pointerId),document.body.style.webkitUserSelect=x.current,m.viewport&&(m.viewport.style.scrollBehavior=""),R.current=null})})})}),Kd="ScrollAreaThumb",C4=k.forwardRef((e,t)=>{const{forceMount:n,...r}=e,a=_4(Kd,e.__scopeScrollArea);return w.jsx(Jn,{present:n||a.hasThumb,children:w.jsx(gne,{ref:t,...r})})}),gne=k.forwardRef((e,t)=>{const{__scopeScrollArea:n,style:r,...a}=e,i=yr(Kd,n),l=_4(Kd,n),{onThumbPositionChange:u}=l,c=ft(t,g=>l.onThumbChange(g)),f=k.useRef(void 0),p=Ff(()=>{f.current&&(f.current(),f.current=void 0)},100);return k.useEffect(()=>{const g=i.viewport;if(g){const b=()=>{if(p(),!f.current){const m=bne(g,u);f.current=m,u()}};return u(),g.addEventListener("scroll",b),()=>g.removeEventListener("scroll",b)}},[i.viewport,p,u]),w.jsx(Xe.div,{"data-state":l.hasThumb?"visible":"hidden",...a,ref:c,style:{width:"var(--radix-scroll-area-thumb-width)",height:"var(--radix-scroll-area-thumb-height)",...r},onPointerDownCapture:Ye(e.onPointerDownCapture,g=>{const m=g.target.getBoundingClientRect(),S=g.clientX-m.left,v=g.clientY-m.top;l.onThumbPointerDown({x:S,y:v})}),onPointerUp:Ye(e.onPointerUp,l.onThumbPointerUp)})});C4.displayName=Kd;var B0="ScrollAreaCorner",N4=k.forwardRef((e,t)=>{const n=yr(B0,e.__scopeScrollArea),r=!!(n.scrollbarX&&n.scrollbarY);return n.type!=="scroll"&&r?w.jsx(hne,{...e,ref:t}):null});N4.displayName=B0;var hne=k.forwardRef((e,t)=>{const{__scopeScrollArea:n,...r}=e,a=yr(B0,n),[i,l]=k.useState(0),[u,c]=k.useState(0),f=!!(i&&u);return wl(a.scrollbarX,()=>{var g;const p=((g=a.scrollbarX)==null?void 0:g.offsetHeight)||0;a.onCornerHeightChange(p),c(p)}),wl(a.scrollbarY,()=>{var g;const p=((g=a.scrollbarY)==null?void 0:g.offsetWidth)||0;a.onCornerWidthChange(p),l(p)}),f?w.jsx(Xe.div,{...r,ref:t,style:{width:i,height:u,position:"absolute",right:a.dir==="ltr"?0:void 0,left:a.dir==="rtl"?0:void 0,bottom:0,...e.style}}):null});function Xd(e){return e?parseInt(e,10):0}function O4(e,t){const n=e/t;return isNaN(n)?0:n}function Mf(e){const t=O4(e.viewport,e.content),n=e.scrollbar.paddingStart+e.scrollbar.paddingEnd,r=(e.scrollbar.size-n)*t;return Math.max(r,18)}function mne(e,t,n,r="ltr"){const a=Mf(n),i=a/2,l=t||i,u=a-l,c=n.scrollbar.paddingStart+l,f=n.scrollbar.size-n.scrollbar.paddingEnd-u,p=n.content-n.viewport,g=r==="ltr"?[0,p]:[p*-1,0];return D4([c,f],g)(e)}function PN(e,t,n="ltr"){const r=Mf(t),a=t.scrollbar.paddingStart+t.scrollbar.paddingEnd,i=t.scrollbar.size-a,l=t.content-t.viewport,u=i-r,c=n==="ltr"?[0,l]:[l*-1,0],f=ak(e,c);return D4([0,l],[0,u])(f)}function D4(e,t){return n=>{if(e[0]===e[1]||t[0]===t[1])return t[0];const r=(t[1]-t[0])/(e[1]-e[0]);return t[0]+r*(n-e[0])}}function I4(e,t){return e>0&&e<t}var bne=(e,t=()=>{})=>{let n={left:e.scrollLeft,top:e.scrollTop},r=0;return function a(){const i={left:e.scrollLeft,top:e.scrollTop},l=n.left!==i.left,u=n.top!==i.top;(l||u)&&t(),n=i,r=window.requestAnimationFrame(a)}(),()=>window.cancelAnimationFrame(r)};function Ff(e,t){const n=pn(e),r=k.useRef(0);return k.useEffect(()=>()=>window.clearTimeout(r.current),[]),k.useCallback(()=>{window.clearTimeout(r.current),r.current=window.setTimeout(n,t)},[n,t])}function wl(e,t){const n=pn(t);wn(()=>{let r=0;if(e){const a=new ResizeObserver(()=>{cancelAnimationFrame(r),r=window.requestAnimationFrame(n)});return a.observe(e),()=>{window.cancelAnimationFrame(r),a.unobserve(e)}}},[e,n])}var L4=x4,yne=A4,vne=N4;const M4=k.forwardRef(({className:e,children:t,...n},r)=>w.jsxs(L4,{ref:r,className:Me("relative overflow-hidden",e),...n,children:[w.jsx(yne,{className:"h-full w-full rounded-[inherit]",children:t}),w.jsx(F4,{}),w.jsx(vne,{})]}));M4.displayName=L4.displayName;const F4=k.forwardRef(({className:e,orientation:t="vertical",...n},r)=>w.jsx(z0,{ref:r,orientation:t,className:Me("flex touch-none transition-colors select-none",t==="vertical"&&"h-full w-2.5 border-l border-l-transparent p-[1px]",t==="horizontal"&&"h-2.5 flex-col border-t border-t-transparent p-[1px]",e),...n,children:w.jsx(C4,{className:"bg-border relative flex-1 rounded-full"})}));F4.displayName=z0.displayName;function ok(e,t={}){const{decimals:n=0,sizeType:r="normal"}=t,a=["Bytes","KB","MB","GB","TB"],i=["Bytes","KiB","MiB","GiB","TiB"];if(e===0)return"0 Byte";const l=Math.floor(Math.log(e)/Math.log(1024));return`${(e/Math.pow(1024,l)).toFixed(n)} ${r==="accurate"?i[l]??"Bytes":a[l]??"Bytes"}`}function Sne(e){const{value:t,onValueChange:n,onUpload:r,progresses:a,accept:i=_9,maxSize:l=1024*1024*200,maxFileCount:u=1,multiple:c=!1,disabled:f=!1,description:p,className:g,...b}=e,[m,S]=Oa({prop:t,onChange:n}),v=k.useCallback((x,T)=>{if(!c&&u===1&&x.length>1){vn.error("Cannot upload more than 1 file at a time");return}if(((m==null?void 0:m.length)??0)+x.length>u){vn.error(`Cannot upload more than ${u} files`);return}const C=x.map(_=>Object.assign(_,{preview:URL.createObjectURL(_)})),N=m?[...m,...C]:C;if(S(N),T.length>0&&T.forEach(({file:_})=>{vn.error(`File ${_.name} was rejected`)}),r&&N.length>0&&N.length<=u){const _=N.length>0?`${N.length} files`:"file";vn.promise(r(N),{loading:`Uploading ${_}...`,success:()=>(S([]),`${_} uploaded`),error:`Failed to upload ${_}`})}},[m,u,c,r,S]);function A(x){if(!m)return;const T=m.filter((C,N)=>N!==x);S(T),n==null||n(T)}k.useEffect(()=>()=>{m&&m.forEach(x=>{z4(x)&&URL.revokeObjectURL(x.preview)})},[]);const R=f||((m==null?void 0:m.length)??0)>=u;return w.jsxs("div",{className:"relative flex flex-col gap-6 overflow-hidden",children:[w.jsx(Lf,{onDrop:v,accept:i,maxSize:l,maxFiles:u,multiple:u>1||c,disabled:R,children:({getRootProps:x,getInputProps:T,isDragActive:C})=>w.jsxs("div",{...x(),className:Me("group border-muted-foreground/25 hover:bg-muted/25 relative grid h-52 w-full cursor-pointer place-items-center rounded-lg border-2 border-dashed px-5 py-2.5 text-center transition","ring-offset-background focus-visible:ring-ring focus-visible:ring-2 focus-visible:ring-offset-2 focus-visible:outline-none",C&&"border-muted-foreground/50",R&&"pointer-events-none opacity-60",g),...b,children:[w.jsx("input",{...T()}),C?w.jsxs("div",{className:"flex flex-col items-center justify-center gap-4 sm:px-5",children:[w.jsx("div",{className:"rounded-full border border-dashed p-3",children:w.jsx(wx,{className:"text-muted-foreground size-7","aria-hidden":"true"})}),w.jsx("p",{className:"text-muted-foreground font-medium",children:"Drop the files here"})]}):w.jsxs("div",{className:"flex flex-col items-center justify-center gap-4 sm:px-5",children:[w.jsx("div",{className:"rounded-full border border-dashed p-3",children:w.jsx(wx,{className:"text-muted-foreground size-7","aria-hidden":"true"})}),w.jsxs("div",{className:"flex flex-col gap-px",children:[w.jsx("p",{className:"text-muted-foreground font-medium",children:"Drag and drop files here, or click to select files"}),p?w.jsx("p",{className:"text-muted-foreground/70 text-sm",children:p}):w.jsxs("p",{className:"text-muted-foreground/70 text-sm",children:["You can upload",u>1?` ${u===1/0?"multiple":u}
                      files (up to ${ok(l)} each)`:` a file with ${ok(l)}`,"Supported formats: TXT, MD, DOCX, PDF, PPTX, RTF, ODT, EPUB, HTML, HTM, TEX, JSON, XML, YAML, YML, CSV, LOG, CONF, INI, PROPERTIES, SQL, BAT, SH, C, CPP, PY, JAVA, JS, TS, SWIFT, GO, RB, PHP, CSS, SCSS, LESS"]})]})]})]})}),m!=null&&m.length?w.jsx(M4,{className:"h-fit w-full px-3",children:w.jsx("div",{className:"flex max-h-48 flex-col gap-4",children:m==null?void 0:m.map((x,T)=>w.jsx(Ene,{file:x,onRemove:()=>A(T),progress:a==null?void 0:a[x.name]},T))})}):null]})}function Ene({file:e,progress:t,onRemove:n}){return w.jsxs("div",{className:"relative flex items-center gap-2.5",children:[w.jsxs("div",{className:"flex flex-1 gap-2.5",children:[z4(e)?w.jsx(wne,{file:e}):null,w.jsxs("div",{className:"flex w-full flex-col gap-2",children:[w.jsxs("div",{className:"flex flex-col gap-px",children:[w.jsx("p",{className:"text-foreground/80 line-clamp-1 text-sm font-medium",children:e.name}),w.jsx("p",{className:"text-muted-foreground text-xs",children:ok(e.size)})]}),t?w.jsx(E4,{value:t}):null]})]}),w.jsx("div",{className:"flex items-center gap-2",children:w.jsxs(Lt,{type:"button",variant:"outline",size:"icon",className:"size-7",onClick:n,children:[w.jsx(dP,{className:"size-4","aria-hidden":"true"}),w.jsx("span",{className:"sr-only",children:"Remove file"})]})})]})}function z4(e){return"preview"in e&&typeof e.preview=="string"}function wne({file:e}){return e.type.startsWith("image/")?w.jsx("div",{className:"aspect-square shrink-0 rounded-md object-cover"}):w.jsx(Dq,{className:"text-muted-foreground size-10","aria-hidden":"true"})}function xne(){const[e,t]=k.useState(!1),[n,r]=k.useState(!1),[a,i]=k.useState({}),l=k.useCallback(async u=>{r(!0);try{await Promise.all(u.map(async c=>{try{const f=await hq(c,p=>{console.debug(`Uploading ${c.name}: ${p}%`),i(g=>({...g,[c.name]:p}))});f.status==="success"?vn.success(`Upload Success:
${c.name} uploaded successfully`):vn.error(`Upload Failed:
${c.name}
${f.message}`)}catch(f){vn.error(`Upload Failed:
${c.name}
${Nr(f)}`)}}))}catch(c){vn.error(`Upload Failed
`+Nr(c))}finally{r(!1)}},[r,i]);return w.jsxs(z3,{open:e,onOpenChange:u=>{n&&!u||t(u)},children:[w.jsx(P3,{asChild:!0,children:w.jsxs(Lt,{variant:"default",side:"bottom",tooltip:"Upload documents",size:"sm",children:[w.jsx(wx,{})," Upload"]})}),w.jsxs(k0,{className:"sm:max-w-xl",onCloseAutoFocus:u=>u.preventDefault(),children:[w.jsxs(A0,{children:[w.jsx(T0,{children:"Upload documents"}),w.jsx(_0,{children:"Drag and drop your documents here or click to browse."})]}),w.jsx(Sne,{maxFileCount:1/0,maxSize:200*1024*1024,description:"supported types: TXT, MD, DOCX, PDF, PPTX, RTF, ODT, EPUB, HTML, HTM, TEX, JSON, XML, YAML, YML, CSV, LOG, CONF, INI, PROPERTIES, SQL, BAT, SH, C, CPP, PY, JAVA, JS, TS, SWIFT, GO, RB, PHP, CSS, SCSS, LESS",onUpload:l,progresses:a,disabled:n})]})]})}function kne(){const[e,t]=k.useState(!1),n=k.useCallback(async()=>{try{const r=await mq();r.status==="success"?(vn.success("Documents cleared successfully"),t(!1)):vn.error(`Clear Documents Failed:
${r.message}`)}catch(r){vn.error(`Clear Documents Failed:
`+Nr(r))}},[t]);return w.jsxs(z3,{open:e,onOpenChange:t,children:[w.jsx(P3,{asChild:!0,children:w.jsxs(Lt,{variant:"outline",side:"bottom",tooltip:"Clear documents",size:"sm",children:[w.jsx(uP,{})," Clear"]})}),w.jsxs(k0,{className:"sm:max-w-xl",onCloseAutoFocus:r=>r.preventDefault(),children:[w.jsxs(A0,{children:[w.jsx(T0,{children:"Clear documents"}),w.jsx(_0,{children:"Do you really want to clear all documents?"})]}),w.jsx(Lt,{variant:"destructive",onClick:n,children:"YES"})]})]})}function Ane(){const e=Pn.use.health(),[t,n]=k.useState(null),r=k.useCallback(async()=>{try{const i=await dq();i&&i.statuses&&Object.values(i.statuses).reduce((u,c)=>u+c.length,0)>0?n(i):n(null)}catch(i){vn.error(`Failed to load documents
`+Nr(i))}},[n]);k.useEffect(()=>{r()},[]);const a=k.useCallback(async()=>{try{const{status:i}=await fq();vn.message(i)}catch(i){vn.error(`Failed to load documents
`+Nr(i))}},[]);return k.useEffect(()=>{const i=setInterval(async()=>{if(e)try{await r()}catch(l){vn.error(`Failed to get scan progress
`+Nr(l))}},5e3);return()=>clearInterval(i)},[e,r]),w.jsxs(ou,{className:"!size-full !rounded-none !border-none",children:[w.jsx(Hd,{children:w.jsx(iu,{className:"text-lg",children:"Document Management"})}),w.jsxs($d,{className:"space-y-4",children:[w.jsxs("div",{className:"flex gap-2",children:[w.jsxs(Lt,{variant:"outline",onClick:a,side:"bottom",tooltip:"Scan documents",size:"sm",children:[w.jsx(t8,{})," Scan"]}),w.jsx("div",{className:"flex-1"}),w.jsx(kne,{}),w.jsx(xne,{})]}),w.jsxs(ou,{children:[w.jsxs(Hd,{children:[w.jsx(iu,{children:"Uploaded documents"}),w.jsx(If,{children:"view the uploaded documents here"})]}),w.jsxs($d,{children:[!t&&w.jsx(Jee,{title:"No documents uploaded",description:"upload documents to see them here"}),t&&w.jsxs(r4,{children:[w.jsx(a4,{children:w.jsxs(Qx,{children:[w.jsx(Ta,{children:"ID"}),w.jsx(Ta,{children:"Summary"}),w.jsx(Ta,{children:"Status"}),w.jsx(Ta,{children:"Length"}),w.jsx(Ta,{children:"Chunks"}),w.jsx(Ta,{children:"Created"}),w.jsx(Ta,{children:"Updated"}),w.jsx(Ta,{children:"Metadata"})]})}),w.jsx(o4,{className:"text-sm",children:Object.entries(t.statuses).map(([i,l])=>l.map(u=>w.jsxs(Qx,{children:[w.jsx(_a,{className:"truncate font-mono",children:u.id}),w.jsx(_a,{className:"max-w-xs min-w-24 truncate",children:w.jsx(Mn,{text:u.content_summary,tooltip:u.content_summary,tooltipClassName:"max-w-none overflow-visible block"})}),w.jsxs(_a,{children:[i==="processed"&&w.jsx("span",{className:"text-green-600",children:"Completed"}),i==="processing"&&w.jsx("span",{className:"text-blue-600",children:"Processing"}),i==="pending"&&w.jsx("span",{className:"text-yellow-600",children:"Pending"}),i==="failed"&&w.jsx("span",{className:"text-red-600",children:"Failed"}),u.error&&w.jsx("span",{className:"ml-2 text-red-500",title:u.error,children:"⚠️"})]}),w.jsx(_a,{children:u.content_length??"-"}),w.jsx(_a,{children:u.chunks_count??"-"}),w.jsx(_a,{className:"truncate",children:new Date(u.created_at).toLocaleString()}),w.jsx(_a,{className:"truncate",children:new Date(u.updated_at).toLocaleString()}),w.jsx(_a,{className:"max-w-xs truncate",children:u.metadata?JSON.stringify(u.metadata):"-"})]},u.id)))})]})]})]})]})]})}function P4(e,t){var n={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(n[r]=e[r]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var a=0,r=Object.getOwnPropertySymbols(e);a<r.length;a++)t.indexOf(r[a])<0&&Object.prototype.propertyIsEnumerable.call(e,r[a])&&(n[r[a]]=e[r[a]]);return n}var su;(function(e){e.event="event",e.props="prop"})(su||(su={}));function fo(){}function Tne(e){var t,n=void 0;return function(){for(var r=[],a=arguments.length;a--;)r[a]=arguments[a];return t&&r.length===t.length&&r.every(function(i,l){return i===t[l]})||(t=r,n=e.apply(void 0,r)),n}}function uu(e){return!!(e||"").match(/\d/)}function gl(e){return e==null}function _ne(e){return typeof e=="number"&&isNaN(e)}function B4(e){return gl(e)||_ne(e)||typeof e=="number"&&!isFinite(e)}function U4(e){return e.replace(/[-[\]/{}()*+?.\\^$|]/g,"\\$&")}function Rne(e){switch(e){case"lakh":return/(\d+?)(?=(\d\d)+(\d)(?!\d))(\.\d+)?/g;case"wan":return/(\d)(?=(\d{4})+(?!\d))/g;case"thousand":default:return/(\d)(?=(\d{3})+(?!\d))/g}}function Cne(e,t,n){var r=Rne(n),a=e.search(/[1-9]/);return a=a===-1?e.length:a,e.substring(0,a)+e.substring(a,e.length).replace(r,"$1"+t)}function Nne(e){var t=k.useRef(e);t.current=e;var n=k.useRef(function(){for(var r=[],a=arguments.length;a--;)r[a]=arguments[a];return t.current.apply(t,r)});return n.current}function U0(e,t){t===void 0&&(t=!0);var n=e[0]==="-",r=n&&t;e=e.replace("-","");var a=e.split("."),i=a[0],l=a[1]||"";return{beforeDecimal:i,afterDecimal:l,hasNegation:n,addNegation:r}}function One(e){if(!e)return e;var t=e[0]==="-";t&&(e=e.substring(1,e.length));var n=e.split("."),r=n[0].replace(/^0+/,"")||"0",a=n[1]||"";return(t?"-":"")+r+(a?"."+a:"")}function j4(e,t,n){for(var r="",a=n?"0":"",i=0;i<=t-1;i++)r+=e[i]||a;return r}function BN(e,t){return Array(t+1).join(e)}function G4(e){var t=e+"",n=t[0]==="-"?"-":"";n&&(t=t.substring(1));var r=t.split(/[eE]/g),a=r[0],i=r[1];if(i=Number(i),!i)return n+a;a=a.replace(".","");var l=1+i,u=a.length;return l<0?a="0."+BN("0",Math.abs(l))+a:l>=u?a=a+BN("0",l-u):a=(a.substring(0,l)||"0")+"."+a.substring(l),n+a}function UN(e,t,n){if(["","-"].indexOf(e)!==-1)return e;var r=(e.indexOf(".")!==-1||n)&&t,a=U0(e),i=a.beforeDecimal,l=a.afterDecimal,u=a.hasNegation,c=parseFloat("0."+(l||"0")),f=l.length<=t?"0."+l:c.toFixed(t),p=f.split("."),g=i;i&&Number(p[0])&&(g=i.split("").reverse().reduce(function(v,A,R){return v.length>R?(Number(v[0])+Number(A)).toString()+v.substring(1,v.length):A+v},p[0]));var b=j4(p[1]||"",t,n),m=u?"-":"",S=r?".":"";return""+m+g+S+b}function ei(e,t){if(e.value=e.value,e!==null){if(e.createTextRange){var n=e.createTextRange();return n.move("character",t),n.select(),!0}return e.selectionStart||e.selectionStart===0?(e.focus(),e.setSelectionRange(t,t),!0):(e.focus(),!1)}}var H4=Tne(function(e,t){for(var n=0,r=0,a=e.length,i=t.length;e[n]===t[n]&&n<a;)n++;for(;e[a-1-r]===t[i-1-r]&&i-r>n&&a-r>n;)r++;return{from:{start:n,end:a-r},to:{start:n,end:i-r}}}),Dne=function(e,t){var n=Math.min(e.selectionStart,t);return{from:{start:n,end:e.selectionEnd},to:{start:n,end:t}}};function Ine(e,t,n){return Math.min(Math.max(e,t),n)}function vm(e){return Math.max(e.selectionStart,e.selectionEnd)}function Lne(){return typeof navigator<"u"&&!(navigator.platform&&/iPhone|iPod/.test(navigator.platform))}function Mne(e){return{from:{start:0,end:0},to:{start:0,end:e.length},lastValue:""}}function Fne(e){var t=e.currentValue,n=e.formattedValue,r=e.currentValueIndex,a=e.formattedValueIndex;return t[r]===n[a]}function zne(e,t,n,r,a,i,l){l===void 0&&(l=Fne);var u=a.findIndex(function(C){return C}),c=e.slice(0,u);!t&&!n.startsWith(c)&&(t=c,n=c+n,r=r+c.length);for(var f=n.length,p=e.length,g={},b=new Array(f),m=0;m<f;m++){b[m]=-1;for(var S=0,v=p;S<v;S++){var A=l({currentValue:n,lastValue:t,formattedValue:e,currentValueIndex:m,formattedValueIndex:S});if(A&&g[S]!==!0){b[m]=S,g[S]=!0;break}}}for(var R=r;R<f&&(b[R]===-1||!i(n[R]));)R++;var x=R===f||b[R]===-1?p:b[R];for(R=r-1;R>0&&b[R]===-1;)R--;var T=R===-1||b[R]===-1?0:b[R]+1;return T>x?x:r-T<x-r?T:x}function jN(e,t,n,r){var a=e.length;if(t=Ine(t,0,a),r==="left"){for(;t>=0&&!n[t];)t--;t===-1&&(t=n.indexOf(!0))}else{for(;t<=a&&!n[t];)t++;t>a&&(t=n.lastIndexOf(!0))}return t===-1&&(t=a),t}function Pne(e){for(var t=Array.from({length:e.length+1}).map(function(){return!0}),n=0,r=t.length;n<r;n++)t[n]=!!(uu(e[n])||uu(e[n-1]));return t}function $4(e,t,n,r,a,i){i===void 0&&(i=fo);var l=Nne(function(S,v){var A,R;return B4(S)?(R="",A=""):typeof S=="number"||v?(R=typeof S=="number"?G4(S):S,A=r(R)):(R=a(S,void 0),A=r(R)),{formattedValue:A,numAsString:R}}),u=k.useState(function(){return l(gl(e)?t:e,n)}),c=u[0],f=u[1],p=function(S,v){S.formattedValue!==c.formattedValue&&f({formattedValue:S.formattedValue,numAsString:S.value}),i(S,v)},g=e,b=n;gl(e)&&(g=c.numAsString,b=!0);var m=l(g,b);return k.useMemo(function(){f(m)},[m.formattedValue]),[c,p]}function Bne(e){return e.replace(/[^0-9]/g,"")}function Une(e){return e}function jne(e){var t=e.type;t===void 0&&(t="text");var n=e.displayType;n===void 0&&(n="input");var r=e.customInput,a=e.renderText,i=e.getInputRef,l=e.format;l===void 0&&(l=Une);var u=e.removeFormatting;u===void 0&&(u=Bne);var c=e.defaultValue,f=e.valueIsNumericString,p=e.onValueChange,g=e.isAllowed,b=e.onChange;b===void 0&&(b=fo);var m=e.onKeyDown;m===void 0&&(m=fo);var S=e.onMouseUp;S===void 0&&(S=fo);var v=e.onFocus;v===void 0&&(v=fo);var A=e.onBlur;A===void 0&&(A=fo);var R=e.value,x=e.getCaretBoundary;x===void 0&&(x=Pne);var T=e.isValidInputCharacter;T===void 0&&(T=uu);var C=e.isCharacterSame,N=P4(e,["type","displayType","customInput","renderText","getInputRef","format","removeFormatting","defaultValue","valueIsNumericString","onValueChange","isAllowed","onChange","onKeyDown","onMouseUp","onFocus","onBlur","value","getCaretBoundary","isValidInputCharacter","isCharacterSame"]),_=$4(R,c,!!f,l,u,p),O=_[0],z=O.formattedValue,I=O.numAsString,M=_[1],H=k.useRef(),q=k.useRef({formattedValue:z,numAsString:I}),P=function(fe,ke){q.current={formattedValue:fe.formattedValue,numAsString:fe.value},M(fe,ke)},W=k.useState(!1),Z=W[0],j=W[1],G=k.useRef(null),B=k.useRef({setCaretTimeout:null,focusTimeout:null});k.useEffect(function(){return j(!0),function(){clearTimeout(B.current.setCaretTimeout),clearTimeout(B.current.focusTimeout)}},[]);var X=l,D=function(fe,ke){var me=parseFloat(ke);return{formattedValue:fe,value:ke,floatValue:isNaN(me)?void 0:me}},V=function(fe,ke,me){fe.selectionStart===0&&fe.selectionEnd===fe.value.length||(ei(fe,ke),B.current.setCaretTimeout=setTimeout(function(){fe.value===me&&fe.selectionStart!==ke&&ei(fe,ke)},0))},U=function(fe,ke,me){return jN(fe,ke,x(fe),me)},L=function(fe,ke,me){var ve=x(ke),ie=zne(ke,z,fe,me,ve,T,C);return ie=jN(ke,ie,ve),ie},Y=function(fe){var ke=fe.formattedValue;ke===void 0&&(ke="");var me=fe.input,ve=fe.source,ie=fe.event,ze=fe.numAsString,Pe;if(me){var he=fe.inputValue||me.value,Ne=vm(me);me.value=ke,Pe=L(he,ke,Ne),Pe!==void 0&&V(me,Pe,ke)}ke!==z&&P(D(ke,ze),{event:ie,source:ve})};k.useEffect(function(){var fe=q.current,ke=fe.formattedValue,me=fe.numAsString;(z!==ke||I!==me)&&P(D(z,I),{event:void 0,source:su.props})},[z,I]);var Q=G.current?vm(G.current):void 0,se=typeof window<"u"?k.useLayoutEffect:k.useEffect;se(function(){var fe=G.current;if(z!==q.current.formattedValue&&fe){var ke=L(q.current.formattedValue,z,Q);fe.value=z,V(fe,ke,z)}},[z]);var re=function(fe,ke,me){var ve=ke.target,ie=H.current?Dne(H.current,ve.selectionEnd):H4(z,fe),ze=Object.assign(Object.assign({},ie),{lastValue:z}),Pe=u(fe,ze),he=X(Pe);if(Pe=u(he,void 0),g&&!g(D(he,Pe))){var Ne=ke.target,ee=vm(Ne),ce=L(fe,z,ee);return Ne.value=z,V(Ne,ce,z),!1}return Y({formattedValue:he,numAsString:Pe,inputValue:fe,event:ke,source:me,input:ke.target}),!0},le=function(fe,ke){ke===void 0&&(ke=0);var me=fe.selectionStart,ve=fe.selectionEnd;H.current={selectionStart:me,selectionEnd:ve+ke}},Ae=function(fe){var ke=fe.target,me=ke.value,ve=re(me,fe,su.event);ve&&b(fe),H.current=void 0},ae=function(fe){var ke=fe.target,me=fe.key,ve=ke.selectionStart,ie=ke.selectionEnd,ze=ke.value;ze===void 0&&(ze="");var Pe;me==="ArrowLeft"||me==="Backspace"?Pe=Math.max(ve-1,0):me==="ArrowRight"?Pe=Math.min(ve+1,ze.length):me==="Delete"&&(Pe=ve);var he=0;me==="Delete"&&ve===ie&&(he=1);var Ne=me==="ArrowLeft"||me==="ArrowRight";if(Pe===void 0||ve!==ie&&!Ne){m(fe),le(ke,he);return}var ee=Pe;if(Ne){var ce=me==="ArrowLeft"?"left":"right";ee=U(ze,Pe,ce),ee!==Pe&&fe.preventDefault()}else me==="Delete"&&!T(ze[Pe])?ee=U(ze,Pe,"right"):me==="Backspace"&&!T(ze[Pe])&&(ee=U(ze,Pe,"left"));ee!==Pe&&V(ke,ee,ze),m(fe),le(ke,he)},we=function(fe){var ke=fe.target,me=function(){var ve=ke.selectionStart,ie=ke.selectionEnd,ze=ke.value;if(ze===void 0&&(ze=""),ve===ie){var Pe=U(ze,ve);Pe!==ve&&V(ke,Pe,ze)}};me(),requestAnimationFrame(function(){me()}),S(fe),le(ke)},xe=function(fe){fe.persist&&fe.persist();var ke=fe.target,me=fe.currentTarget;G.current=ke,B.current.focusTimeout=setTimeout(function(){var ve=ke.selectionStart,ie=ke.selectionEnd,ze=ke.value;ze===void 0&&(ze="");var Pe=U(ze,ve);Pe!==ve&&!(ve===0&&ie===ze.length)&&V(ke,Pe,ze),v(Object.assign(Object.assign({},fe),{currentTarget:me}))},0)},Ie=function(fe){G.current=null,clearTimeout(B.current.focusTimeout),clearTimeout(B.current.setCaretTimeout),A(fe)},Ce=Z&&Lne()?"numeric":void 0,Ee=Object.assign({inputMode:Ce},N,{type:t,value:z,onChange:Ae,onKeyDown:ae,onMouseUp:we,onFocus:xe,onBlur:Ie});if(n==="text")return a?ye.createElement(ye.Fragment,null,a(z,N)||null):ye.createElement("span",Object.assign({},N,{ref:i}),z);if(r){var J=r;return ye.createElement(J,Object.assign({},Ee,{ref:i}))}return ye.createElement("input",Object.assign({},Ee,{ref:i}))}function GN(e,t){var n=t.decimalScale,r=t.fixedDecimalScale,a=t.prefix;a===void 0&&(a="");var i=t.suffix;i===void 0&&(i="");var l=t.allowNegative,u=t.thousandsGroupStyle;if(u===void 0&&(u="thousand"),e===""||e==="-")return e;var c=zf(t),f=c.thousandSeparator,p=c.decimalSeparator,g=n!==0&&e.indexOf(".")!==-1||n&&r,b=U0(e,l),m=b.beforeDecimal,S=b.afterDecimal,v=b.addNegation;return n!==void 0&&(S=j4(S,n,!!r)),f&&(m=Cne(m,f,u)),a&&(m=a+m),i&&(S=S+i),v&&(m="-"+m),e=m+(g&&p||"")+S,e}function zf(e){var t=e.decimalSeparator;t===void 0&&(t=".");var n=e.thousandSeparator,r=e.allowedDecimalSeparators;return n===!0&&(n=","),r||(r=[t,"."]),{decimalSeparator:t,thousandSeparator:n,allowedDecimalSeparators:r}}function Gne(e,t){e===void 0&&(e="");var n=new RegExp("(-)"),r=new RegExp("(-)(.)*(-)"),a=n.test(e),i=r.test(e);return e=e.replace(/-/g,""),a&&!i&&t&&(e="-"+e),e}function Hne(e,t){return new RegExp("(^-)|[0-9]|"+U4(e),"g")}function $ne(e,t,n){return e===""?!0:!(t!=null&&t.match(/\d/))&&!(n!=null&&n.match(/\d/))&&typeof e=="string"&&!isNaN(Number(e))}function qne(e,t,n){var r;t===void 0&&(t=Mne(e));var a=n.allowNegative,i=n.prefix;i===void 0&&(i="");var l=n.suffix;l===void 0&&(l="");var u=n.decimalScale,c=t.from,f=t.to,p=f.start,g=f.end,b=zf(n),m=b.allowedDecimalSeparators,S=b.decimalSeparator,v=e[g]===S;if(uu(e)&&(e===i||e===l)&&t.lastValue==="")return e;if(g-p===1&&m.indexOf(e[p])!==-1){var A=u===0?"":S;e=e.substring(0,p)+A+e.substring(p+1,e.length)}var R=function(G,B,X){var D=!1,V=!1;i.startsWith("-")?D=!1:G.startsWith("--")?(D=!1,V=!0):l.startsWith("-")&&G.length===l.length?D=!1:G[0]==="-"&&(D=!0);var U=D?1:0;return V&&(U=2),U&&(G=G.substring(U),B-=U,X-=U),{value:G,start:B,end:X,hasNegation:D}},x=R(e,p,g),T=x.hasNegation;r=x,e=r.value,p=r.start,g=r.end;var C=R(t.lastValue,c.start,c.end),N=C.start,_=C.end,O=C.value,z=e.substring(p,g);e.length&&O.length&&(N>O.length-l.length||_<i.length)&&!(z&&l.startsWith(z))&&(e=O);var I=0;e.startsWith(i)?I+=i.length:p<i.length&&(I=p),e=e.substring(I),g-=I;var M=e.length,H=e.length-l.length;e.endsWith(l)?M=H:(g>H||g>e.length-l.length)&&(M=g),e=e.substring(0,M),e=Gne(T?"-"+e:e,a),e=(e.match(Hne(S))||[]).join("");var q=e.indexOf(S);e=e.replace(new RegExp(U4(S),"g"),function(G,B){return B===q?".":""});var P=U0(e,a),W=P.beforeDecimal,Z=P.afterDecimal,j=P.addNegation;return f.end-f.start<c.end-c.start&&W===""&&v&&!parseFloat(Z)&&(e=j?"-":""),e}function Vne(e,t){var n=t.prefix;n===void 0&&(n="");var r=t.suffix;r===void 0&&(r="");var a=Array.from({length:e.length+1}).map(function(){return!0}),i=e[0]==="-";a.fill(!1,0,n.length+(i?1:0));var l=e.length;return a.fill(!1,l-r.length+1,l+1),a}function Wne(e){var t=zf(e),n=t.thousandSeparator,r=t.decimalSeparator,a=e.prefix;a===void 0&&(a="");var i=e.allowNegative;if(i===void 0&&(i=!0),n===r)throw new Error(`
        Decimal separator can't be same as thousand separator.
        thousandSeparator: `+n+` (thousandSeparator = {true} is same as thousandSeparator = ",")
        decimalSeparator: `+r+` (default value for decimalSeparator is .)
     `);return a.startsWith("-")&&i&&(console.error(`
      Prefix can't start with '-' when allowNegative is true.
      prefix: `+a+`
      allowNegative: `+i+`
    `),i=!1),Object.assign(Object.assign({},e),{allowNegative:i})}function Yne(e){e=Wne(e),e.decimalSeparator,e.allowedDecimalSeparators,e.thousandsGroupStyle;var t=e.suffix,n=e.allowNegative,r=e.allowLeadingZeros,a=e.onKeyDown;a===void 0&&(a=fo);var i=e.onBlur;i===void 0&&(i=fo);var l=e.thousandSeparator,u=e.decimalScale,c=e.fixedDecimalScale,f=e.prefix;f===void 0&&(f="");var p=e.defaultValue,g=e.value,b=e.valueIsNumericString,m=e.onValueChange,S=P4(e,["decimalSeparator","allowedDecimalSeparators","thousandsGroupStyle","suffix","allowNegative","allowLeadingZeros","onKeyDown","onBlur","thousandSeparator","decimalScale","fixedDecimalScale","prefix","defaultValue","value","valueIsNumericString","onValueChange"]),v=zf(e),A=v.decimalSeparator,R=v.allowedDecimalSeparators,x=function(j){return GN(j,e)},T=function(j,G){return qne(j,G,e)},C=gl(g)?p:g,N=b??$ne(C,f,t);gl(g)?gl(p)||(N=N||typeof p=="number"):N=N||typeof g=="number";var _=function(j){return B4(j)?j:(typeof j=="number"&&(j=G4(j)),N&&typeof u=="number"?UN(j,u,!!c):j)},O=$4(_(g),_(p),!!N,x,T,m),z=O[0],I=z.numAsString,M=z.formattedValue,H=O[1],q=function(j){var G=j.target,B=j.key,X=G.selectionStart,D=G.selectionEnd,V=G.value;if(V===void 0&&(V=""),(B==="Backspace"||B==="Delete")&&D<f.length){j.preventDefault();return}if(X!==D){a(j);return}B==="Backspace"&&V[0]==="-"&&X===f.length+1&&n&&ei(G,1),u&&c&&(B==="Backspace"&&V[X-1]===A?(ei(G,X-1),j.preventDefault()):B==="Delete"&&V[X]===A&&j.preventDefault()),R!=null&&R.includes(B)&&V[X]===A&&ei(G,X+1);var U=l===!0?",":l;B==="Backspace"&&V[X-1]===U&&ei(G,X-1),B==="Delete"&&V[X]===U&&ei(G,X+1),a(j)},P=function(j){var G=I;if(G.match(/\d/g)||(G=""),r||(G=One(G)),c&&u&&(G=UN(G,u,c)),G!==I){var B=GN(G,e);H({formattedValue:B,value:G,floatValue:parseFloat(G)},{event:j,source:su.event})}i(j)},W=function(j){return j===A?!0:uu(j)},Z=function(j){var G=j.currentValue,B=j.lastValue,X=j.formattedValue,D=j.currentValueIndex,V=j.formattedValueIndex,U=G[D],L=X[V],Y=H4(B,G),Q=Y.to,se=function(re){return T(re).indexOf(".")+f.length};return g===0&&c&&u&&G[Q.start]===A&&se(G)<D&&se(X)>V?!1:D>=Q.start&&D<Q.end&&R&&R.includes(U)&&L===A?!0:U===L};return Object.assign(Object.assign({},S),{value:M,valueIsNumericString:!1,isValidInputCharacter:W,isCharacterSame:Z,onValueChange:H,format:x,removeFormatting:T,getCaretBoundary:function(j){return Vne(j,e)},onKeyDown:q,onBlur:P})}function Kne(e){var t=Yne(e);return ye.createElement(jne,Object.assign({},t))}const ll=k.forwardRef(({stepper:e,thousandSeparator:t,placeholder:n,defaultValue:r,min:a=-1/0,max:i=1/0,onValueChange:l,fixedDecimalScale:u=!1,decimalScale:c=0,className:f=void 0,suffix:p,prefix:g,value:b,...m},S)=>{const[v,A]=k.useState(b??r),R=k.useCallback(()=>{A(N=>N===void 0?e??1:Math.min(N+(e??1),i))},[e,i]),x=k.useCallback(()=>{A(N=>N===void 0?-(e??1):Math.max(N-(e??1),a))},[e,a]);k.useEffect(()=>{b!==void 0&&A(b)},[b]);const T=N=>{const _=N.floatValue===void 0?void 0:N.floatValue;A(_),l&&l(_)},C=()=>{v!==void 0&&(v<a?(A(a),S.current.value=String(a)):v>i&&(A(i),S.current.value=String(i)))};return w.jsxs("div",{className:"relative flex",children:[w.jsx(Kne,{value:v,onValueChange:T,thousandSeparator:t,decimalScale:c,fixedDecimalScale:u,allowNegative:a<0,valueIsNumericString:!0,onBlur:C,max:i,min:a,suffix:p,prefix:g,customInput:N=>w.jsx(Eo,{...N,className:Me("w-full",f)}),placeholder:n,className:"[appearance:textfield] [&::-webkit-inner-spin-button]:appearance-none [&::-webkit-outer-spin-button]:appearance-none",getInputRef:S,...m}),w.jsxs("div",{className:"absolute top-0 right-0 bottom-0 flex flex-col",children:[w.jsx(Lt,{"aria-label":"Increase value",className:"border-input h-1/2 rounded-l-none rounded-br-none border-b border-l px-2 focus-visible:relative",variant:"outline",onClick:R,disabled:v===i,children:w.jsx(sP,{size:15})}),w.jsx(Lt,{"aria-label":"Decrease value",className:"border-input h-1/2 rounded-l-none rounded-tr-none border-b border-l px-2 focus-visible:relative",variant:"outline",onClick:x,disabled:v===a,children:w.jsx(Ok,{size:15})})]})]})});ll.displayName="NumberInput";var Xne=[" ","Enter","ArrowUp","ArrowDown"],Zne=[" ","Enter"],Au="Select",[Pf,Bf,Qne]=tU(Au),[zl,ive]=mr(Au,[Qne,Nl]),Uf=Nl(),[Jne,xo]=zl(Au),[ere,tre]=zl(Au),q4=e=>{const{__scopeSelect:t,children:n,open:r,defaultOpen:a,onOpenChange:i,value:l,defaultValue:u,onValueChange:c,dir:f,name:p,autoComplete:g,disabled:b,required:m,form:S}=e,v=Uf(t),[A,R]=k.useState(null),[x,T]=k.useState(null),[C,N]=k.useState(!1),_=Tf(f),[O=!1,z]=Oa({prop:r,defaultProp:a,onChange:i}),[I,M]=Oa({prop:l,defaultProp:u,onChange:c}),H=k.useRef(null),q=A?S||!!A.closest("form"):!0,[P,W]=k.useState(new Set),Z=Array.from(P).map(j=>j.props.value).join(";");return w.jsx(Jk,{...v,children:w.jsxs(Jne,{required:m,scope:t,trigger:A,onTriggerChange:R,valueNode:x,onValueNodeChange:T,valueNodeHasChildren:C,onValueNodeHasChildrenChange:N,contentId:En(),value:I,onValueChange:M,open:O,onOpenChange:z,dir:_,triggerPointerDownPosRef:H,disabled:b,children:[w.jsx(Pf.Provider,{scope:t,children:w.jsx(ere,{scope:e.__scopeSelect,onNativeOptionAdd:k.useCallback(j=>{W(G=>new Set(G).add(j))},[]),onNativeOptionRemove:k.useCallback(j=>{W(G=>{const B=new Set(G);return B.delete(j),B})},[]),children:n})}),q?w.jsxs(bj,{"aria-hidden":!0,required:m,tabIndex:-1,name:p,autoComplete:g,value:I,onChange:j=>M(j.target.value),disabled:b,form:S,children:[I===void 0?w.jsx("option",{value:""}):null,Array.from(P)]},Z):null]})})};q4.displayName=Au;var V4="SelectTrigger",W4=k.forwardRef((e,t)=>{const{__scopeSelect:n,disabled:r=!1,...a}=e,i=Uf(n),l=xo(V4,n),u=l.disabled||r,c=ft(t,l.onTriggerChange),f=Bf(n),p=k.useRef("touch"),[g,b,m]=yj(v=>{const A=f().filter(T=>!T.disabled),R=A.find(T=>T.value===l.value),x=vj(A,v,R);x!==void 0&&l.onValueChange(x.value)}),S=v=>{u||(l.onOpenChange(!0),m()),v&&(l.triggerPointerDownPosRef.current={x:Math.round(v.pageX),y:Math.round(v.pageY)})};return w.jsx(vf,{asChild:!0,...i,children:w.jsx(Xe.button,{type:"button",role:"combobox","aria-controls":l.contentId,"aria-expanded":l.open,"aria-required":l.required,"aria-autocomplete":"none",dir:l.dir,"data-state":l.open?"open":"closed",disabled:u,"data-disabled":u?"":void 0,"data-placeholder":mj(l.value)?"":void 0,...a,ref:c,onClick:Ye(a.onClick,v=>{v.currentTarget.focus(),p.current!=="mouse"&&S(v)}),onPointerDown:Ye(a.onPointerDown,v=>{p.current=v.pointerType;const A=v.target;A.hasPointerCapture(v.pointerId)&&A.releasePointerCapture(v.pointerId),v.button===0&&v.ctrlKey===!1&&v.pointerType==="mouse"&&(S(v),v.preventDefault())}),onKeyDown:Ye(a.onKeyDown,v=>{const A=g.current!=="";!(v.ctrlKey||v.altKey||v.metaKey)&&v.key.length===1&&b(v.key),!(A&&v.key===" ")&&Xne.includes(v.key)&&(S(),v.preventDefault())})})})});W4.displayName=V4;var Y4="SelectValue",K4=k.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:a,children:i,placeholder:l="",...u}=e,c=xo(Y4,n),{onValueNodeHasChildrenChange:f}=c,p=i!==void 0,g=ft(t,c.onValueNodeChange);return wn(()=>{f(p)},[f,p]),w.jsx(Xe.span,{...u,ref:g,style:{pointerEvents:"none"},children:mj(c.value)?w.jsx(w.Fragment,{children:l}):i})});K4.displayName=Y4;var nre="SelectIcon",X4=k.forwardRef((e,t)=>{const{__scopeSelect:n,children:r,...a}=e;return w.jsx(Xe.span,{"aria-hidden":!0,...a,ref:t,children:r||"▼"})});X4.displayName=nre;var rre="SelectPortal",Z4=e=>w.jsx(df,{asChild:!0,...e});Z4.displayName=rre;var si="SelectContent",Q4=k.forwardRef((e,t)=>{const n=xo(si,e.__scopeSelect),[r,a]=k.useState();if(wn(()=>{a(new DocumentFragment)},[]),!n.open){const i=r;return i?gu.createPortal(w.jsx(J4,{scope:e.__scopeSelect,children:w.jsx(Pf.Slot,{scope:e.__scopeSelect,children:w.jsx("div",{children:e.children})})}),i):null}return w.jsx(ej,{...e,ref:t})});Q4.displayName=si;var Rr=10,[J4,ko]=zl(si),are="SelectContentImpl",ej=k.forwardRef((e,t)=>{const{__scopeSelect:n,position:r="item-aligned",onCloseAutoFocus:a,onEscapeKeyDown:i,onPointerDownOutside:l,side:u,sideOffset:c,align:f,alignOffset:p,arrowPadding:g,collisionBoundary:b,collisionPadding:m,sticky:S,hideWhenDetached:v,avoidCollisions:A,...R}=e,x=xo(si,n),[T,C]=k.useState(null),[N,_]=k.useState(null),O=ft(t,re=>C(re)),[z,I]=k.useState(null),[M,H]=k.useState(null),q=Bf(n),[P,W]=k.useState(!1),Z=k.useRef(!1);k.useEffect(()=>{if(T)return Lk(T)},[T]),Ik();const j=k.useCallback(re=>{const[le,...Ae]=q().map(xe=>xe.ref.current),[ae]=Ae.slice(-1),we=document.activeElement;for(const xe of re)if(xe===we||(xe==null||xe.scrollIntoView({block:"nearest"}),xe===le&&N&&(N.scrollTop=0),xe===ae&&N&&(N.scrollTop=N.scrollHeight),xe==null||xe.focus(),document.activeElement!==we))return},[q,N]),G=k.useCallback(()=>j([z,T]),[j,z,T]);k.useEffect(()=>{P&&G()},[P,G]);const{onOpenChange:B,triggerPointerDownPosRef:X}=x;k.useEffect(()=>{if(T){let re={x:0,y:0};const le=ae=>{var we,xe;re={x:Math.abs(Math.round(ae.pageX)-(((we=X.current)==null?void 0:we.x)??0)),y:Math.abs(Math.round(ae.pageY)-(((xe=X.current)==null?void 0:xe.y)??0))}},Ae=ae=>{re.x<=10&&re.y<=10?ae.preventDefault():T.contains(ae.target)||B(!1),document.removeEventListener("pointermove",le),X.current=null};return X.current!==null&&(document.addEventListener("pointermove",le),document.addEventListener("pointerup",Ae,{capture:!0,once:!0})),()=>{document.removeEventListener("pointermove",le),document.removeEventListener("pointerup",Ae,{capture:!0})}}},[T,B,X]),k.useEffect(()=>{const re=()=>B(!1);return window.addEventListener("blur",re),window.addEventListener("resize",re),()=>{window.removeEventListener("blur",re),window.removeEventListener("resize",re)}},[B]);const[D,V]=yj(re=>{const le=q().filter(we=>!we.disabled),Ae=le.find(we=>we.ref.current===document.activeElement),ae=vj(le,re,Ae);ae&&setTimeout(()=>ae.ref.current.focus())}),U=k.useCallback((re,le,Ae)=>{const ae=!Z.current&&!Ae;(x.value!==void 0&&x.value===le||ae)&&(I(re),ae&&(Z.current=!0))},[x.value]),L=k.useCallback(()=>T==null?void 0:T.focus(),[T]),Y=k.useCallback((re,le,Ae)=>{const ae=!Z.current&&!Ae;(x.value!==void 0&&x.value===le||ae)&&H(re)},[x.value]),Q=r==="popper"?ik:tj,se=Q===ik?{side:u,sideOffset:c,align:f,alignOffset:p,arrowPadding:g,collisionBoundary:b,collisionPadding:m,sticky:S,hideWhenDetached:v,avoidCollisions:A}:{};return w.jsx(J4,{scope:n,content:T,viewport:N,onViewportChange:_,itemRefCallback:U,selectedItem:z,onItemLeave:L,itemTextRefCallback:Y,focusSelectedItem:G,selectedItemText:M,position:r,isPositioned:P,searchRef:D,children:w.jsx(pf,{as:bo,allowPinchZoom:!0,children:w.jsx(cf,{asChild:!0,trapped:x.open,onMountAutoFocus:re=>{re.preventDefault()},onUnmountAutoFocus:Ye(a,re=>{var le;(le=x.trigger)==null||le.focus({preventScroll:!0}),re.preventDefault()}),children:w.jsx(hu,{asChild:!0,disableOutsidePointerEvents:!0,onEscapeKeyDown:i,onPointerDownOutside:l,onFocusOutside:re=>re.preventDefault(),onDismiss:()=>x.onOpenChange(!1),children:w.jsx(Q,{role:"listbox",id:x.contentId,"data-state":x.open?"open":"closed",dir:x.dir,onContextMenu:re=>re.preventDefault(),...R,...se,onPlaced:()=>W(!0),ref:O,style:{display:"flex",flexDirection:"column",outline:"none",...R.style},onKeyDown:Ye(R.onKeyDown,re=>{const le=re.ctrlKey||re.altKey||re.metaKey;if(re.key==="Tab"&&re.preventDefault(),!le&&re.key.length===1&&V(re.key),["ArrowUp","ArrowDown","Home","End"].includes(re.key)){let ae=q().filter(we=>!we.disabled).map(we=>we.ref.current);if(["ArrowUp","End"].includes(re.key)&&(ae=ae.slice().reverse()),["ArrowUp","ArrowDown"].includes(re.key)){const we=re.target,xe=ae.indexOf(we);ae=ae.slice(xe+1)}setTimeout(()=>j(ae)),re.preventDefault()}})})})})})})});ej.displayName=are;var ore="SelectItemAlignedPosition",tj=k.forwardRef((e,t)=>{const{__scopeSelect:n,onPlaced:r,...a}=e,i=xo(si,n),l=ko(si,n),[u,c]=k.useState(null),[f,p]=k.useState(null),g=ft(t,O=>p(O)),b=Bf(n),m=k.useRef(!1),S=k.useRef(!0),{viewport:v,selectedItem:A,selectedItemText:R,focusSelectedItem:x}=l,T=k.useCallback(()=>{if(i.trigger&&i.valueNode&&u&&f&&v&&A&&R){const O=i.trigger.getBoundingClientRect(),z=f.getBoundingClientRect(),I=i.valueNode.getBoundingClientRect(),M=R.getBoundingClientRect();if(i.dir!=="rtl"){const we=M.left-z.left,xe=I.left-we,Ie=O.left-xe,Ce=O.width+Ie,Ee=Math.max(Ce,z.width),J=window.innerWidth-Rr,fe=ak(xe,[Rr,Math.max(Rr,J-Ee)]);u.style.minWidth=Ce+"px",u.style.left=fe+"px"}else{const we=z.right-M.right,xe=window.innerWidth-I.right-we,Ie=window.innerWidth-O.right-xe,Ce=O.width+Ie,Ee=Math.max(Ce,z.width),J=window.innerWidth-Rr,fe=ak(xe,[Rr,Math.max(Rr,J-Ee)]);u.style.minWidth=Ce+"px",u.style.right=fe+"px"}const H=b(),q=window.innerHeight-Rr*2,P=v.scrollHeight,W=window.getComputedStyle(f),Z=parseInt(W.borderTopWidth,10),j=parseInt(W.paddingTop,10),G=parseInt(W.borderBottomWidth,10),B=parseInt(W.paddingBottom,10),X=Z+j+P+B+G,D=Math.min(A.offsetHeight*5,X),V=window.getComputedStyle(v),U=parseInt(V.paddingTop,10),L=parseInt(V.paddingBottom,10),Y=O.top+O.height/2-Rr,Q=q-Y,se=A.offsetHeight/2,re=A.offsetTop+se,le=Z+j+re,Ae=X-le;if(le<=Y){const we=H.length>0&&A===H[H.length-1].ref.current;u.style.bottom="0px";const xe=f.clientHeight-v.offsetTop-v.offsetHeight,Ie=Math.max(Q,se+(we?L:0)+xe+G),Ce=le+Ie;u.style.height=Ce+"px"}else{const we=H.length>0&&A===H[0].ref.current;u.style.top="0px";const Ie=Math.max(Y,Z+v.offsetTop+(we?U:0)+se)+Ae;u.style.height=Ie+"px",v.scrollTop=le-Y+v.offsetTop}u.style.margin=`${Rr}px 0`,u.style.minHeight=D+"px",u.style.maxHeight=q+"px",r==null||r(),requestAnimationFrame(()=>m.current=!0)}},[b,i.trigger,i.valueNode,u,f,v,A,R,i.dir,r]);wn(()=>T(),[T]);const[C,N]=k.useState();wn(()=>{f&&N(window.getComputedStyle(f).zIndex)},[f]);const _=k.useCallback(O=>{O&&S.current===!0&&(T(),x==null||x(),S.current=!1)},[T,x]);return w.jsx(lre,{scope:n,contentWrapper:u,shouldExpandOnScrollRef:m,onScrollButtonChange:_,children:w.jsx("div",{ref:c,style:{display:"flex",flexDirection:"column",position:"fixed",zIndex:C},children:w.jsx(Xe.div,{...a,ref:g,style:{boxSizing:"border-box",maxHeight:"100%",...a.style}})})})});tj.displayName=ore;var ire="SelectPopperPosition",ik=k.forwardRef((e,t)=>{const{__scopeSelect:n,align:r="start",collisionPadding:a=Rr,...i}=e,l=Uf(n);return w.jsx(e0,{...l,...i,ref:t,align:r,collisionPadding:a,style:{boxSizing:"border-box",...i.style,"--radix-select-content-transform-origin":"var(--radix-popper-transform-origin)","--radix-select-content-available-width":"var(--radix-popper-available-width)","--radix-select-content-available-height":"var(--radix-popper-available-height)","--radix-select-trigger-width":"var(--radix-popper-anchor-width)","--radix-select-trigger-height":"var(--radix-popper-anchor-height)"}})});ik.displayName=ire;var[lre,j0]=zl(si,{}),lk="SelectViewport",nj=k.forwardRef((e,t)=>{const{__scopeSelect:n,nonce:r,...a}=e,i=ko(lk,n),l=j0(lk,n),u=ft(t,i.onViewportChange),c=k.useRef(0);return w.jsxs(w.Fragment,{children:[w.jsx("style",{dangerouslySetInnerHTML:{__html:"[data-radix-select-viewport]{scrollbar-width:none;-ms-overflow-style:none;-webkit-overflow-scrolling:touch;}[data-radix-select-viewport]::-webkit-scrollbar{display:none}"},nonce:r}),w.jsx(Pf.Slot,{scope:n,children:w.jsx(Xe.div,{"data-radix-select-viewport":"",role:"presentation",...a,ref:u,style:{position:"relative",flex:1,overflow:"hidden auto",...a.style},onScroll:Ye(a.onScroll,f=>{const p=f.currentTarget,{contentWrapper:g,shouldExpandOnScrollRef:b}=l;if(b!=null&&b.current&&g){const m=Math.abs(c.current-p.scrollTop);if(m>0){const S=window.innerHeight-Rr*2,v=parseFloat(g.style.minHeight),A=parseFloat(g.style.height),R=Math.max(v,A);if(R<S){const x=R+m,T=Math.min(S,x),C=x-T;g.style.height=T+"px",g.style.bottom==="0px"&&(p.scrollTop=C>0?C:0,g.style.justifyContent="flex-end")}}}c.current=p.scrollTop})})})]})});nj.displayName=lk;var rj="SelectGroup",[sre,ure]=zl(rj),aj=k.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=En();return w.jsx(sre,{scope:n,id:a,children:w.jsx(Xe.div,{role:"group","aria-labelledby":a,...r,ref:t})})});aj.displayName=rj;var oj="SelectLabel",ij=k.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=ure(oj,n);return w.jsx(Xe.div,{id:a.id,...r,ref:t})});ij.displayName=oj;var Zd="SelectItem",[cre,lj]=zl(Zd),sj=k.forwardRef((e,t)=>{const{__scopeSelect:n,value:r,disabled:a=!1,textValue:i,...l}=e,u=xo(Zd,n),c=ko(Zd,n),f=u.value===r,[p,g]=k.useState(i??""),[b,m]=k.useState(!1),S=ft(t,x=>{var T;return(T=c.itemRefCallback)==null?void 0:T.call(c,x,r,a)}),v=En(),A=k.useRef("touch"),R=()=>{a||(u.onValueChange(r),u.onOpenChange(!1))};if(r==="")throw new Error("A <Select.Item /> must have a value prop that is not an empty string. This is because the Select value can be set to an empty string to clear the selection and show the placeholder.");return w.jsx(cre,{scope:n,value:r,disabled:a,textId:v,isSelected:f,onItemTextChange:k.useCallback(x=>{g(T=>T||((x==null?void 0:x.textContent)??"").trim())},[]),children:w.jsx(Pf.ItemSlot,{scope:n,value:r,disabled:a,textValue:p,children:w.jsx(Xe.div,{role:"option","aria-labelledby":v,"data-highlighted":b?"":void 0,"aria-selected":f&&b,"data-state":f?"checked":"unchecked","aria-disabled":a||void 0,"data-disabled":a?"":void 0,tabIndex:a?void 0:-1,...l,ref:S,onFocus:Ye(l.onFocus,()=>m(!0)),onBlur:Ye(l.onBlur,()=>m(!1)),onClick:Ye(l.onClick,()=>{A.current!=="mouse"&&R()}),onPointerUp:Ye(l.onPointerUp,()=>{A.current==="mouse"&&R()}),onPointerDown:Ye(l.onPointerDown,x=>{A.current=x.pointerType}),onPointerMove:Ye(l.onPointerMove,x=>{var T;A.current=x.pointerType,a?(T=c.onItemLeave)==null||T.call(c):A.current==="mouse"&&x.currentTarget.focus({preventScroll:!0})}),onPointerLeave:Ye(l.onPointerLeave,x=>{var T;x.currentTarget===document.activeElement&&((T=c.onItemLeave)==null||T.call(c))}),onKeyDown:Ye(l.onKeyDown,x=>{var C;((C=c.searchRef)==null?void 0:C.current)!==""&&x.key===" "||(Zne.includes(x.key)&&R(),x.key===" "&&x.preventDefault())})})})})});sj.displayName=Zd;var Ws="SelectItemText",uj=k.forwardRef((e,t)=>{const{__scopeSelect:n,className:r,style:a,...i}=e,l=xo(Ws,n),u=ko(Ws,n),c=lj(Ws,n),f=tre(Ws,n),[p,g]=k.useState(null),b=ft(t,R=>g(R),c.onItemTextChange,R=>{var x;return(x=u.itemTextRefCallback)==null?void 0:x.call(u,R,c.value,c.disabled)}),m=p==null?void 0:p.textContent,S=k.useMemo(()=>w.jsx("option",{value:c.value,disabled:c.disabled,children:m},c.value),[c.disabled,c.value,m]),{onNativeOptionAdd:v,onNativeOptionRemove:A}=f;return wn(()=>(v(S),()=>A(S)),[v,A,S]),w.jsxs(w.Fragment,{children:[w.jsx(Xe.span,{id:c.textId,...i,ref:b}),c.isSelected&&l.valueNode&&!l.valueNodeHasChildren?gu.createPortal(i.children,l.valueNode):null]})});uj.displayName=Ws;var cj="SelectItemIndicator",dj=k.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return lj(cj,n).isSelected?w.jsx(Xe.span,{"aria-hidden":!0,...r,ref:t}):null});dj.displayName=cj;var sk="SelectScrollUpButton",fj=k.forwardRef((e,t)=>{const n=ko(sk,e.__scopeSelect),r=j0(sk,e.__scopeSelect),[a,i]=k.useState(!1),l=ft(t,r.onScrollButtonChange);return wn(()=>{if(n.viewport&&n.isPositioned){let u=function(){const f=c.scrollTop>0;i(f)};const c=n.viewport;return u(),c.addEventListener("scroll",u),()=>c.removeEventListener("scroll",u)}},[n.viewport,n.isPositioned]),a?w.jsx(gj,{...e,ref:l,onAutoScroll:()=>{const{viewport:u,selectedItem:c}=n;u&&c&&(u.scrollTop=u.scrollTop-c.offsetHeight)}}):null});fj.displayName=sk;var uk="SelectScrollDownButton",pj=k.forwardRef((e,t)=>{const n=ko(uk,e.__scopeSelect),r=j0(uk,e.__scopeSelect),[a,i]=k.useState(!1),l=ft(t,r.onScrollButtonChange);return wn(()=>{if(n.viewport&&n.isPositioned){let u=function(){const f=c.scrollHeight-c.clientHeight,p=Math.ceil(c.scrollTop)<f;i(p)};const c=n.viewport;return u(),c.addEventListener("scroll",u),()=>c.removeEventListener("scroll",u)}},[n.viewport,n.isPositioned]),a?w.jsx(gj,{...e,ref:l,onAutoScroll:()=>{const{viewport:u,selectedItem:c}=n;u&&c&&(u.scrollTop=u.scrollTop+c.offsetHeight)}}):null});pj.displayName=uk;var gj=k.forwardRef((e,t)=>{const{__scopeSelect:n,onAutoScroll:r,...a}=e,i=ko("SelectScrollButton",n),l=k.useRef(null),u=Bf(n),c=k.useCallback(()=>{l.current!==null&&(window.clearInterval(l.current),l.current=null)},[]);return k.useEffect(()=>()=>c(),[c]),wn(()=>{var p;const f=u().find(g=>g.ref.current===document.activeElement);(p=f==null?void 0:f.ref.current)==null||p.scrollIntoView({block:"nearest"})},[u]),w.jsx(Xe.div,{"aria-hidden":!0,...a,ref:t,style:{flexShrink:0,...a.style},onPointerDown:Ye(a.onPointerDown,()=>{l.current===null&&(l.current=window.setInterval(r,50))}),onPointerMove:Ye(a.onPointerMove,()=>{var f;(f=i.onItemLeave)==null||f.call(i),l.current===null&&(l.current=window.setInterval(r,50))}),onPointerLeave:Ye(a.onPointerLeave,()=>{c()})})}),dre="SelectSeparator",hj=k.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e;return w.jsx(Xe.div,{"aria-hidden":!0,...r,ref:t})});hj.displayName=dre;var ck="SelectArrow",fre=k.forwardRef((e,t)=>{const{__scopeSelect:n,...r}=e,a=Uf(n),i=xo(ck,n),l=ko(ck,n);return i.open&&l.position==="popper"?w.jsx(t0,{...a,...r,ref:t}):null});fre.displayName=ck;function mj(e){return e===""||e===void 0}var bj=k.forwardRef((e,t)=>{const{value:n,...r}=e,a=k.useRef(null),i=ft(t,a),l=j3(n);return k.useEffect(()=>{const u=a.current,c=window.HTMLSelectElement.prototype,p=Object.getOwnPropertyDescriptor(c,"value").set;if(l!==n&&p){const g=new Event("change",{bubbles:!0});p.call(u,n),u.dispatchEvent(g)}},[l,n]),w.jsx(n0,{asChild:!0,children:w.jsx("select",{...r,ref:i,defaultValue:n})})});bj.displayName="BubbleSelect";function yj(e){const t=pn(e),n=k.useRef(""),r=k.useRef(0),a=k.useCallback(l=>{const u=n.current+l;t(u),function c(f){n.current=f,window.clearTimeout(r.current),f!==""&&(r.current=window.setTimeout(()=>c(""),1e3))}(u)},[t]),i=k.useCallback(()=>{n.current="",window.clearTimeout(r.current)},[]);return k.useEffect(()=>()=>window.clearTimeout(r.current),[]),[n,a,i]}function vj(e,t,n){const a=t.length>1&&Array.from(t).every(f=>f===t[0])?t[0]:t,i=n?e.indexOf(n):-1;let l=pre(e,Math.max(i,0));a.length===1&&(l=l.filter(f=>f!==n));const c=l.find(f=>f.textValue.toLowerCase().startsWith(a.toLowerCase()));return c!==n?c:void 0}function pre(e,t){return e.map((n,r)=>e[(t+r)%e.length])}var gre=q4,Sj=W4,hre=K4,mre=X4,bre=Z4,Ej=Q4,yre=nj,vre=aj,wj=ij,xj=sj,Sre=uj,Ere=dj,kj=fj,Aj=pj,Tj=hj;const HN=gre,$N=vre,qN=hre,dk=k.forwardRef(({className:e,children:t,...n},r)=>w.jsxs(Sj,{ref:r,className:Me("border-input bg-background ring-offset-background placeholder:text-muted-foreground focus:ring-ring flex h-10 w-full items-center justify-between rounded-md border px-3 py-2 text-sm focus:ring-2 focus:ring-offset-2 focus:outline-none disabled:cursor-not-allowed disabled:opacity-50 [&>span]:line-clamp-1",e),...n,children:[t,w.jsx(mre,{asChild:!0,children:w.jsx(Ok,{className:"h-4 w-4 opacity-50"})})]}));dk.displayName=Sj.displayName;const _j=k.forwardRef(({className:e,...t},n)=>w.jsx(kj,{ref:n,className:Me("flex cursor-default items-center justify-center py-1",e),...t,children:w.jsx(sP,{className:"h-4 w-4"})}));_j.displayName=kj.displayName;const Rj=k.forwardRef(({className:e,...t},n)=>w.jsx(Aj,{ref:n,className:Me("flex cursor-default items-center justify-center py-1",e),...t,children:w.jsx(Ok,{className:"h-4 w-4"})}));Rj.displayName=Aj.displayName;const fk=k.forwardRef(({className:e,children:t,position:n="popper",...r},a)=>w.jsx(bre,{children:w.jsxs(Ej,{ref:a,className:Me("bg-popover text-popover-foreground data-[state=open]:animate-in data-[state=closed]:animate-out data-[state=closed]:fade-out-0 data-[state=open]:fade-in-0 data-[state=closed]:zoom-out-95 data-[state=open]:zoom-in-95 data-[side=bottom]:slide-in-from-top-2 data-[side=left]:slide-in-from-right-2 data-[side=right]:slide-in-from-left-2 data-[side=top]:slide-in-from-bottom-2 relative z-50 max-h-96 min-w-[8rem] overflow-hidden rounded-md border shadow-md",n==="popper"&&"data-[side=bottom]:translate-y-1 data-[side=left]:-translate-x-1 data-[side=right]:translate-x-1 data-[side=top]:-translate-y-1",e),position:n,...r,children:[w.jsx(_j,{}),w.jsx(yre,{className:Me("p-1",n==="popper"&&"h-[var(--radix-select-trigger-height)] w-full min-w-[var(--radix-select-trigger-width)]"),children:t}),w.jsx(Rj,{})]})}));fk.displayName=Ej.displayName;const wre=k.forwardRef(({className:e,...t},n)=>w.jsx(wj,{ref:n,className:Me("py-1.5 pr-2 pl-8 text-sm font-semibold",e),...t}));wre.displayName=wj.displayName;const Ra=k.forwardRef(({className:e,children:t,...n},r)=>w.jsxs(xj,{ref:r,className:Me("focus:bg-accent focus:text-accent-foreground relative flex w-full cursor-default items-center rounded-sm py-1.5 pr-2 pl-8 text-sm outline-none select-none data-[disabled]:pointer-events-none data-[disabled]:opacity-50",e),...n,children:[w.jsx("span",{className:"absolute left-2 flex h-3.5 w-3.5 items-center justify-center",children:w.jsx(Ere,{children:w.jsx(Nk,{className:"h-4 w-4"})})}),w.jsx(Sre,{children:t})]}));Ra.displayName=xj.displayName;const xre=k.forwardRef(({className:e,...t},n)=>w.jsx(Tj,{ref:n,className:Me("bg-muted -mx-1 my-1 h-px",e),...t}));xre.displayName=Tj.displayName;function kre(){var n,r;const e=We(a=>a.querySettings),t=k.useCallback((a,i)=>{We.getState().updateQuerySettings({[a]:i})},[]);return w.jsxs(ou,{className:"flex shrink-0 flex-col",children:[w.jsxs(Hd,{className:"px-4 pt-4 pb-2",children:[w.jsx(iu,{children:"Parameters"}),w.jsx(If,{children:"Configure your query parameters"})]}),w.jsx($d,{className:"m-0 flex grow flex-col p-0 text-xs",children:w.jsx("div",{className:"relative size-full",children:w.jsxs("div",{className:"absolute inset-0 flex flex-col gap-2 overflow-auto px-2",children:[w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Query Mode",tooltip:"Select the retrieval strategy:\\n• Naive: Basic search without advanced techniques\\n• Local: Context-dependent information retrieval\\n• Global: Utilizes global knowledge base\\n• Hybrid: Combines local and global retrieval\\n• Mix: Integrates knowledge graph with vector retrieval",side:"left"}),w.jsxs(HN,{value:e.mode,onValueChange:a=>t("mode",a),children:[w.jsx(dk,{className:"hover:bg-primary/5 h-9 cursor-pointer focus:ring-0 focus:ring-offset-0 focus:outline-0 active:right-0",children:w.jsx(qN,{})}),w.jsx(fk,{children:w.jsxs($N,{children:[w.jsx(Ra,{value:"naive",children:"Naive"}),w.jsx(Ra,{value:"local",children:"Local"}),w.jsx(Ra,{value:"global",children:"Global"}),w.jsx(Ra,{value:"hybrid",children:"Hybrid"}),w.jsx(Ra,{value:"mix",children:"Mix"})]})})]})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Response Format",tooltip:"Defines the response format. Examples:\\n• Multiple Paragraphs\\n• Single Paragraph\\n• Bullet Points",side:"left"}),w.jsxs(HN,{value:e.response_type,onValueChange:a=>t("response_type",a),children:[w.jsx(dk,{className:"hover:bg-primary/5 h-9 cursor-pointer focus:ring-0 focus:ring-offset-0 focus:outline-0 active:right-0",children:w.jsx(qN,{})}),w.jsx(fk,{children:w.jsxs($N,{children:[w.jsx(Ra,{value:"Multiple Paragraphs",children:"Multiple Paragraphs"}),w.jsx(Ra,{value:"Single Paragraph",children:"Single Paragraph"}),w.jsx(Ra,{value:"Bullet Points",children:"Bullet Points"})]})})]})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Top K Results",tooltip:"Number of top items to retrieve. Represents entities in 'local' mode and relationships in 'global' mode",side:"left"}),w.jsx(ll,{id:"top_k",stepper:1,value:e.top_k,onValueChange:a=>t("top_k",a),min:1,placeholder:"Number of results"})]}),w.jsxs(w.Fragment,{children:[w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Max Tokens for Text Unit",tooltip:"Maximum number of tokens allowed for each retrieved text chunk",side:"left"}),w.jsx(ll,{id:"max_token_for_text_unit",stepper:500,value:e.max_token_for_text_unit,onValueChange:a=>t("max_token_for_text_unit",a),min:1,placeholder:"Max tokens for text unit"})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{text:"Max Tokens for Global Context",tooltip:"Maximum number of tokens allocated for relationship descriptions in global retrieval",side:"left"}),w.jsx(ll,{id:"max_token_for_global_context",stepper:500,value:e.max_token_for_global_context,onValueChange:a=>t("max_token_for_global_context",a),min:1,placeholder:"Max tokens for global context"})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Max Tokens for Local Context",tooltip:"Maximum number of tokens allocated for entity descriptions in local retrieval",side:"left"}),w.jsx(ll,{id:"max_token_for_local_context",stepper:500,value:e.max_token_for_local_context,onValueChange:a=>t("max_token_for_local_context",a),min:1,placeholder:"Max tokens for local context"})]})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"History Turns",tooltip:"Number of complete conversation turns (user-assistant pairs) to consider in the response context",side:"left"}),w.jsx(ll,{className:"!border-input",id:"history_turns",stepper:1,type:"text",value:e.history_turns,onValueChange:a=>t("history_turns",a),min:0,placeholder:"Number of history turns"})]}),w.jsxs(w.Fragment,{children:[w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"High-Level Keywords",tooltip:"List of high-level keywords to prioritize in retrieval. Separate with commas",side:"left"}),w.jsx(Eo,{id:"hl_keywords",type:"text",value:(n=e.hl_keywords)==null?void 0:n.join(", "),onChange:a=>{const i=a.target.value.split(",").map(l=>l.trim()).filter(l=>l!=="");t("hl_keywords",i)},placeholder:"Enter keywords"})]}),w.jsxs(w.Fragment,{children:[w.jsx(Mn,{className:"ml-1",text:"Low-Level Keywords",tooltip:"List of low-level keywords to refine retrieval focus. Separate with commas",side:"left"}),w.jsx(Eo,{id:"ll_keywords",type:"text",value:(r=e.ll_keywords)==null?void 0:r.join(", "),onChange:a=>{const i=a.target.value.split(",").map(l=>l.trim()).filter(l=>l!=="");t("ll_keywords",i)},placeholder:"Enter keywords"})]})]}),w.jsxs(w.Fragment,{children:[w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsx(Mn,{className:"ml-1",text:"Only Need Context",tooltip:"If True, only returns the retrieved context without generating a response",side:"left"}),w.jsx("div",{className:"grow"}),w.jsx(Ks,{className:"mr-1 cursor-pointer",id:"only_need_context",checked:e.only_need_context,onCheckedChange:a=>t("only_need_context",a)})]}),w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsx(Mn,{className:"ml-1",text:"Only Need Prompt",tooltip:"If True, only returns the generated prompt without producing a response",side:"left"}),w.jsx("div",{className:"grow"}),w.jsx(Ks,{className:"mr-1 cursor-pointer",id:"only_need_prompt",checked:e.only_need_prompt,onCheckedChange:a=>t("only_need_prompt",a)})]}),w.jsxs("div",{className:"flex items-center gap-2",children:[w.jsx(Mn,{className:"ml-1",text:"Stream Response",tooltip:"If True, enables streaming output for real-time responses",side:"left"}),w.jsx("div",{className:"grow"}),w.jsx(Ks,{className:"mr-1 cursor-pointer",id:"stream",checked:e.stream,onCheckedChange:a=>t("stream",a)})]})]})]})})})]})}function Are(e,t){const n={};return(e[e.length-1]===""?[...e,""]:e).join((n.padRight?" ":"")+","+(n.padLeft===!1?"":" ")).trim()}const Tre=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,_re=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,Rre={};function VN(e,t){return(Rre.jsx?_re:Tre).test(e)}const Cre=/[ \t\n\f\r]/g;function Nre(e){return typeof e=="object"?e.type==="text"?WN(e.value):!1:WN(e)}function WN(e){return e.replace(Cre,"")===""}class Tu{constructor(t,n,r){this.property=t,this.normal=n,r&&(this.space=r)}}Tu.prototype.property={};Tu.prototype.normal={};Tu.prototype.space=null;function Cj(e,t){const n={},r={};let a=-1;for(;++a<e.length;)Object.assign(n,e[a].property),Object.assign(r,e[a].normal);return new Tu(n,r,t)}function pk(e){return e.toLowerCase()}class vr{constructor(t,n){this.property=t,this.attribute=n}}vr.prototype.space=null;vr.prototype.boolean=!1;vr.prototype.booleanish=!1;vr.prototype.overloadedBoolean=!1;vr.prototype.number=!1;vr.prototype.commaSeparated=!1;vr.prototype.spaceSeparated=!1;vr.prototype.commaOrSpaceSeparated=!1;vr.prototype.mustUseProperty=!1;vr.prototype.defined=!1;let Ore=0;const tt=di(),Yt=di(),Nj=di(),Oe=di(),It=di(),hl=di(),Yn=di();function di(){return 2**++Ore}const gk=Object.freeze(Object.defineProperty({__proto__:null,boolean:tt,booleanish:Yt,commaOrSpaceSeparated:Yn,commaSeparated:hl,number:Oe,overloadedBoolean:Nj,spaceSeparated:It},Symbol.toStringTag,{value:"Module"})),Sm=Object.keys(gk);class G0 extends vr{constructor(t,n,r,a){let i=-1;if(super(t,n),YN(this,"space",a),typeof r=="number")for(;++i<Sm.length;){const l=Sm[i];YN(this,Sm[i],(r&gk[l])===gk[l])}}}G0.prototype.defined=!0;function YN(e,t,n){n&&(e[t]=n)}const Dre={}.hasOwnProperty;function Pl(e){const t={},n={};let r;for(r in e.properties)if(Dre.call(e.properties,r)){const a=e.properties[r],i=new G0(r,e.transform(e.attributes||{},r),a,e.space);e.mustUseProperty&&e.mustUseProperty.includes(r)&&(i.mustUseProperty=!0),t[r]=i,n[pk(r)]=r,n[pk(i.attribute)]=r}return new Tu(t,n,e.space)}const Oj=Pl({space:"xlink",transform(e,t){return"xlink:"+t.slice(5).toLowerCase()},properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}}),Dj=Pl({space:"xml",transform(e,t){return"xml:"+t.slice(3).toLowerCase()},properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function Ij(e,t){return t in e?e[t]:t}function Lj(e,t){return Ij(e,t.toLowerCase())}const Mj=Pl({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:Lj,properties:{xmlns:null,xmlnsXLink:null}}),Fj=Pl({transform(e,t){return t==="role"?t:"aria-"+t.slice(4).toLowerCase()},properties:{ariaActiveDescendant:null,ariaAtomic:Yt,ariaAutoComplete:null,ariaBusy:Yt,ariaChecked:Yt,ariaColCount:Oe,ariaColIndex:Oe,ariaColSpan:Oe,ariaControls:It,ariaCurrent:null,ariaDescribedBy:It,ariaDetails:null,ariaDisabled:Yt,ariaDropEffect:It,ariaErrorMessage:null,ariaExpanded:Yt,ariaFlowTo:It,ariaGrabbed:Yt,ariaHasPopup:null,ariaHidden:Yt,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:It,ariaLevel:Oe,ariaLive:null,ariaModal:Yt,ariaMultiLine:Yt,ariaMultiSelectable:Yt,ariaOrientation:null,ariaOwns:It,ariaPlaceholder:null,ariaPosInSet:Oe,ariaPressed:Yt,ariaReadOnly:Yt,ariaRelevant:null,ariaRequired:Yt,ariaRoleDescription:It,ariaRowCount:Oe,ariaRowIndex:Oe,ariaRowSpan:Oe,ariaSelected:Yt,ariaSetSize:Oe,ariaSort:null,ariaValueMax:Oe,ariaValueMin:Oe,ariaValueNow:Oe,ariaValueText:null,role:null}}),Ire=Pl({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:Lj,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:hl,acceptCharset:It,accessKey:It,action:null,allow:null,allowFullScreen:tt,allowPaymentRequest:tt,allowUserMedia:tt,alt:null,as:null,async:tt,autoCapitalize:null,autoComplete:It,autoFocus:tt,autoPlay:tt,blocking:It,capture:null,charSet:null,checked:tt,cite:null,className:It,cols:Oe,colSpan:null,content:null,contentEditable:Yt,controls:tt,controlsList:It,coords:Oe|hl,crossOrigin:null,data:null,dateTime:null,decoding:null,default:tt,defer:tt,dir:null,dirName:null,disabled:tt,download:Nj,draggable:Yt,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:tt,formTarget:null,headers:It,height:Oe,hidden:tt,high:Oe,href:null,hrefLang:null,htmlFor:It,httpEquiv:It,id:null,imageSizes:null,imageSrcSet:null,inert:tt,inputMode:null,integrity:null,is:null,isMap:tt,itemId:null,itemProp:It,itemRef:It,itemScope:tt,itemType:It,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:tt,low:Oe,manifest:null,max:null,maxLength:Oe,media:null,method:null,min:null,minLength:Oe,multiple:tt,muted:tt,name:null,nonce:null,noModule:tt,noValidate:tt,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:tt,optimum:Oe,pattern:null,ping:It,placeholder:null,playsInline:tt,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:tt,referrerPolicy:null,rel:It,required:tt,reversed:tt,rows:Oe,rowSpan:Oe,sandbox:It,scope:null,scoped:tt,seamless:tt,selected:tt,shadowRootClonable:tt,shadowRootDelegatesFocus:tt,shadowRootMode:null,shape:null,size:Oe,sizes:null,slot:null,span:Oe,spellCheck:Yt,src:null,srcDoc:null,srcLang:null,srcSet:null,start:Oe,step:null,style:null,tabIndex:Oe,target:null,title:null,translate:null,type:null,typeMustMatch:tt,useMap:null,value:Yt,width:Oe,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:It,axis:null,background:null,bgColor:null,border:Oe,borderColor:null,bottomMargin:Oe,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:tt,declare:tt,event:null,face:null,frame:null,frameBorder:null,hSpace:Oe,leftMargin:Oe,link:null,longDesc:null,lowSrc:null,marginHeight:Oe,marginWidth:Oe,noResize:tt,noHref:tt,noShade:tt,noWrap:tt,object:null,profile:null,prompt:null,rev:null,rightMargin:Oe,rules:null,scheme:null,scrolling:Yt,standby:null,summary:null,text:null,topMargin:Oe,valueType:null,version:null,vAlign:null,vLink:null,vSpace:Oe,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:tt,disableRemotePlayback:tt,prefix:null,property:null,results:Oe,security:null,unselectable:null}}),Lre=Pl({space:"svg",attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},transform:Ij,properties:{about:Yn,accentHeight:Oe,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:Oe,amplitude:Oe,arabicForm:null,ascent:Oe,attributeName:null,attributeType:null,azimuth:Oe,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:Oe,by:null,calcMode:null,capHeight:Oe,className:It,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:Oe,diffuseConstant:Oe,direction:null,display:null,dur:null,divisor:Oe,dominantBaseline:null,download:tt,dx:null,dy:null,edgeMode:null,editable:null,elevation:Oe,enableBackground:null,end:null,event:null,exponent:Oe,externalResourcesRequired:null,fill:null,fillOpacity:Oe,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:hl,g2:hl,glyphName:hl,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:Oe,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:Oe,horizOriginX:Oe,horizOriginY:Oe,id:null,ideographic:Oe,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:Oe,k:Oe,k1:Oe,k2:Oe,k3:Oe,k4:Oe,kernelMatrix:Yn,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:Oe,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:Oe,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:Oe,overlineThickness:Oe,paintOrder:null,panose1:null,path:null,pathLength:Oe,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:It,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:Oe,pointsAtY:Oe,pointsAtZ:Oe,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:Yn,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:Yn,rev:Yn,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:Yn,requiredFeatures:Yn,requiredFonts:Yn,requiredFormats:Yn,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:Oe,specularExponent:Oe,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:Oe,strikethroughThickness:Oe,string:null,stroke:null,strokeDashArray:Yn,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:Oe,strokeOpacity:Oe,strokeWidth:null,style:null,surfaceScale:Oe,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:Yn,tabIndex:Oe,tableValues:null,target:null,targetX:Oe,targetY:Oe,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:Yn,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:Oe,underlineThickness:Oe,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:Oe,values:null,vAlphabetic:Oe,vMathematical:Oe,vectorEffect:null,vHanging:Oe,vIdeographic:Oe,version:null,vertAdvY:Oe,vertOriginX:Oe,vertOriginY:Oe,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:Oe,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null}}),Mre=/^data[-\w.:]+$/i,KN=/-[a-z]/g,Fre=/[A-Z]/g;function zre(e,t){const n=pk(t);let r=t,a=vr;if(n in e.normal)return e.property[e.normal[n]];if(n.length>4&&n.slice(0,4)==="data"&&Mre.test(t)){if(t.charAt(4)==="-"){const i=t.slice(5).replace(KN,Bre);r="data"+i.charAt(0).toUpperCase()+i.slice(1)}else{const i=t.slice(4);if(!KN.test(i)){let l=i.replace(Fre,Pre);l.charAt(0)!=="-"&&(l="-"+l),t="data"+l}}a=G0}return new a(r,t)}function Pre(e){return"-"+e.toLowerCase()}function Bre(e){return e.charAt(1).toUpperCase()}const Ure={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},jre=Cj([Dj,Oj,Mj,Fj,Ire],"html"),H0=Cj([Dj,Oj,Mj,Fj,Lre],"svg");function Gre(e){return e.join(" ").trim()}var nl={},Em,XN;function Hre(){if(XN)return Em;XN=1;var e=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,t=/\n/g,n=/^\s*/,r=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,a=/^:\s*/,i=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,l=/^[;\s]*/,u=/^\s+|\s+$/g,c=`
`,f="/",p="*",g="",b="comment",m="declaration";Em=function(v,A){if(typeof v!="string")throw new TypeError("First argument must be a string");if(!v)return[];A=A||{};var R=1,x=1;function T(P){var W=P.match(t);W&&(R+=W.length);var Z=P.lastIndexOf(c);x=~Z?P.length-Z:x+P.length}function C(){var P={line:R,column:x};return function(W){return W.position=new N(P),z(),W}}function N(P){this.start=P,this.end={line:R,column:x},this.source=A.source}N.prototype.content=v;function _(P){var W=new Error(A.source+":"+R+":"+x+": "+P);if(W.reason=P,W.filename=A.source,W.line=R,W.column=x,W.source=v,!A.silent)throw W}function O(P){var W=P.exec(v);if(W){var Z=W[0];return T(Z),v=v.slice(Z.length),W}}function z(){O(n)}function I(P){var W;for(P=P||[];W=M();)W!==!1&&P.push(W);return P}function M(){var P=C();if(!(f!=v.charAt(0)||p!=v.charAt(1))){for(var W=2;g!=v.charAt(W)&&(p!=v.charAt(W)||f!=v.charAt(W+1));)++W;if(W+=2,g===v.charAt(W-1))return _("End of comment missing");var Z=v.slice(2,W-2);return x+=2,T(Z),v=v.slice(W),x+=2,P({type:b,comment:Z})}}function H(){var P=C(),W=O(r);if(W){if(M(),!O(a))return _("property missing ':'");var Z=O(i),j=P({type:m,property:S(W[0].replace(e,g)),value:Z?S(Z[0].replace(e,g)):g});return O(l),j}}function q(){var P=[];I(P);for(var W;W=H();)W!==!1&&(P.push(W),I(P));return P}return z(),q()};function S(v){return v?v.replace(u,g):g}return Em}var ZN;function $re(){if(ZN)return nl;ZN=1;var e=nl&&nl.__importDefault||function(r){return r&&r.__esModule?r:{default:r}};Object.defineProperty(nl,"__esModule",{value:!0}),nl.default=n;var t=e(Hre());function n(r,a){var i=null;if(!r||typeof r!="string")return i;var l=(0,t.default)(r),u=typeof a=="function";return l.forEach(function(c){if(c.type==="declaration"){var f=c.property,p=c.value;u?a(f,p,c):p&&(i=i||{},i[f]=p)}}),i}return nl}var qre=$re();const QN=an(qre),Vre=QN.default||QN,zj=Pj("end"),$0=Pj("start");function Pj(e){return t;function t(n){const r=n&&n.position&&n.position[e]||{};if(typeof r.line=="number"&&r.line>0&&typeof r.column=="number"&&r.column>0)return{line:r.line,column:r.column,offset:typeof r.offset=="number"&&r.offset>-1?r.offset:void 0}}}function Wre(e){const t=$0(e),n=zj(e);if(t&&n)return{start:t,end:n}}function Xs(e){return!e||typeof e!="object"?"":"position"in e||"type"in e?JN(e.position):"start"in e||"end"in e?JN(e):"line"in e||"column"in e?hk(e):""}function hk(e){return eO(e&&e.line)+":"+eO(e&&e.column)}function JN(e){return hk(e&&e.start)+"-"+hk(e&&e.end)}function eO(e){return e&&typeof e=="number"?e:1}class xn extends Error{constructor(t,n,r){super(),typeof n=="string"&&(r=n,n=void 0);let a="",i={},l=!1;if(n&&("line"in n&&"column"in n?i={place:n}:"start"in n&&"end"in n?i={place:n}:"type"in n?i={ancestors:[n],place:n.position}:i={...n}),typeof t=="string"?a=t:!i.cause&&t&&(l=!0,a=t.message,i.cause=t),!i.ruleId&&!i.source&&typeof r=="string"){const c=r.indexOf(":");c===-1?i.ruleId=r:(i.source=r.slice(0,c),i.ruleId=r.slice(c+1))}if(!i.place&&i.ancestors&&i.ancestors){const c=i.ancestors[i.ancestors.length-1];c&&(i.place=c.position)}const u=i.place&&"start"in i.place?i.place.start:i.place;this.ancestors=i.ancestors||void 0,this.cause=i.cause||void 0,this.column=u?u.column:void 0,this.fatal=void 0,this.file,this.message=a,this.line=u?u.line:void 0,this.name=Xs(i.place)||"1:1",this.place=i.place||void 0,this.reason=this.message,this.ruleId=i.ruleId||void 0,this.source=i.source||void 0,this.stack=l&&i.cause&&typeof i.cause.stack=="string"?i.cause.stack:"",this.actual,this.expected,this.note,this.url}}xn.prototype.file="";xn.prototype.name="";xn.prototype.reason="";xn.prototype.message="";xn.prototype.stack="";xn.prototype.column=void 0;xn.prototype.line=void 0;xn.prototype.ancestors=void 0;xn.prototype.cause=void 0;xn.prototype.fatal=void 0;xn.prototype.place=void 0;xn.prototype.ruleId=void 0;xn.prototype.source=void 0;const q0={}.hasOwnProperty,Yre=new Map,Kre=/[A-Z]/g,Xre=/-([a-z])/g,Zre=new Set(["table","tbody","thead","tfoot","tr"]),Qre=new Set(["td","th"]),Bj="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function Uj(e,t){if(!t||t.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const n=t.filePath||void 0;let r;if(t.development){if(typeof t.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");r=iae(n,t.jsxDEV)}else{if(typeof t.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof t.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");r=oae(n,t.jsx,t.jsxs)}const a={Fragment:t.Fragment,ancestors:[],components:t.components||{},create:r,elementAttributeNameCase:t.elementAttributeNameCase||"react",evaluater:t.createEvaluater?t.createEvaluater():void 0,filePath:n,ignoreInvalidStyle:t.ignoreInvalidStyle||!1,passKeys:t.passKeys!==!1,passNode:t.passNode||!1,schema:t.space==="svg"?H0:jre,stylePropertyNameCase:t.stylePropertyNameCase||"dom",tableCellAlignToStyle:t.tableCellAlignToStyle!==!1},i=jj(a,e,void 0);return i&&typeof i!="string"?i:a.create(e,a.Fragment,{children:i||void 0},void 0)}function jj(e,t,n){if(t.type==="element")return Jre(e,t,n);if(t.type==="mdxFlowExpression"||t.type==="mdxTextExpression")return eae(e,t);if(t.type==="mdxJsxFlowElement"||t.type==="mdxJsxTextElement")return nae(e,t,n);if(t.type==="mdxjsEsm")return tae(e,t);if(t.type==="root")return rae(e,t,n);if(t.type==="text")return aae(e,t)}function Jre(e,t,n){const r=e.schema;let a=r;t.tagName.toLowerCase()==="svg"&&r.space==="html"&&(a=H0,e.schema=a),e.ancestors.push(t);const i=Hj(e,t.tagName,!1),l=lae(e,t);let u=W0(e,t);return Zre.has(t.tagName)&&(u=u.filter(function(c){return typeof c=="string"?!Nre(c):!0})),Gj(e,l,i,t),V0(l,u),e.ancestors.pop(),e.schema=r,e.create(t,i,l,n)}function eae(e,t){if(t.data&&t.data.estree&&e.evaluater){const r=t.data.estree.body[0];return r.type,e.evaluater.evaluateExpression(r.expression)}cu(e,t.position)}function tae(e,t){if(t.data&&t.data.estree&&e.evaluater)return e.evaluater.evaluateProgram(t.data.estree);cu(e,t.position)}function nae(e,t,n){const r=e.schema;let a=r;t.name==="svg"&&r.space==="html"&&(a=H0,e.schema=a),e.ancestors.push(t);const i=t.name===null?e.Fragment:Hj(e,t.name,!0),l=sae(e,t),u=W0(e,t);return Gj(e,l,i,t),V0(l,u),e.ancestors.pop(),e.schema=r,e.create(t,i,l,n)}function rae(e,t,n){const r={};return V0(r,W0(e,t)),e.create(t,e.Fragment,r,n)}function aae(e,t){return t.value}function Gj(e,t,n,r){typeof n!="string"&&n!==e.Fragment&&e.passNode&&(t.node=r)}function V0(e,t){if(t.length>0){const n=t.length>1?t:t[0];n&&(e.children=n)}}function oae(e,t,n){return r;function r(a,i,l,u){const f=Array.isArray(l.children)?n:t;return u?f(i,l,u):f(i,l)}}function iae(e,t){return n;function n(r,a,i,l){const u=Array.isArray(i.children),c=$0(r);return t(a,i,l,u,{columnNumber:c?c.column-1:void 0,fileName:e,lineNumber:c?c.line:void 0},void 0)}}function lae(e,t){const n={};let r,a;for(a in t.properties)if(a!=="children"&&q0.call(t.properties,a)){const i=uae(e,a,t.properties[a]);if(i){const[l,u]=i;e.tableCellAlignToStyle&&l==="align"&&typeof u=="string"&&Qre.has(t.tagName)?r=u:n[l]=u}}if(r){const i=n.style||(n.style={});i[e.stylePropertyNameCase==="css"?"text-align":"textAlign"]=r}return n}function sae(e,t){const n={};for(const r of t.attributes)if(r.type==="mdxJsxExpressionAttribute")if(r.data&&r.data.estree&&e.evaluater){const i=r.data.estree.body[0];i.type;const l=i.expression;l.type;const u=l.properties[0];u.type,Object.assign(n,e.evaluater.evaluateExpression(u.argument))}else cu(e,t.position);else{const a=r.name;let i;if(r.value&&typeof r.value=="object")if(r.value.data&&r.value.data.estree&&e.evaluater){const u=r.value.data.estree.body[0];u.type,i=e.evaluater.evaluateExpression(u.expression)}else cu(e,t.position);else i=r.value===null?!0:r.value;n[a]=i}return n}function W0(e,t){const n=[];let r=-1;const a=e.passKeys?new Map:Yre;for(;++r<t.children.length;){const i=t.children[r];let l;if(e.passKeys){const c=i.type==="element"?i.tagName:i.type==="mdxJsxFlowElement"||i.type==="mdxJsxTextElement"?i.name:void 0;if(c){const f=a.get(c)||0;l=c+"-"+f,a.set(c,f+1)}}const u=jj(e,i,l);u!==void 0&&n.push(u)}return n}function uae(e,t,n){const r=zre(e.schema,t);if(!(n==null||typeof n=="number"&&Number.isNaN(n))){if(Array.isArray(n)&&(n=r.commaSeparated?Are(n):Gre(n)),r.property==="style"){let a=typeof n=="object"?n:cae(e,String(n));return e.stylePropertyNameCase==="css"&&(a=dae(a)),["style",a]}return[e.elementAttributeNameCase==="react"&&r.space?Ure[r.property]||r.property:r.attribute,n]}}function cae(e,t){const n={};try{Vre(t,r)}catch(a){if(!e.ignoreInvalidStyle){const i=a,l=new xn("Cannot parse `style` attribute",{ancestors:e.ancestors,cause:i,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw l.file=e.filePath||void 0,l.url=Bj+"#cannot-parse-style-attribute",l}}return n;function r(a,i){let l=a;l.slice(0,2)!=="--"&&(l.slice(0,4)==="-ms-"&&(l="ms-"+l.slice(4)),l=l.replace(Xre,pae)),n[l]=i}}function Hj(e,t,n){let r;if(!n)r={type:"Literal",value:t};else if(t.includes(".")){const a=t.split(".");let i=-1,l;for(;++i<a.length;){const u=VN(a[i])?{type:"Identifier",name:a[i]}:{type:"Literal",value:a[i]};l=l?{type:"MemberExpression",object:l,property:u,computed:!!(i&&u.type==="Literal"),optional:!1}:u}r=l}else r=VN(t)&&!/^[a-z]/.test(t)?{type:"Identifier",name:t}:{type:"Literal",value:t};if(r.type==="Literal"){const a=r.value;return q0.call(e.components,a)?e.components[a]:a}if(e.evaluater)return e.evaluater.evaluateExpression(r);cu(e)}function cu(e,t){const n=new xn("Cannot handle MDX estrees without `createEvaluater`",{ancestors:e.ancestors,place:t,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw n.file=e.filePath||void 0,n.url=Bj+"#cannot-handle-mdx-estrees-without-createevaluater",n}function dae(e){const t={};let n;for(n in e)q0.call(e,n)&&(t[fae(n)]=e[n]);return t}function fae(e){let t=e.replace(Kre,gae);return t.slice(0,3)==="ms-"&&(t="-"+t),t}function pae(e,t){return t.toUpperCase()}function gae(e){return"-"+e.toLowerCase()}const wm={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},hae={};function Y0(e,t){const n=hae,r=typeof n.includeImageAlt=="boolean"?n.includeImageAlt:!0,a=typeof n.includeHtml=="boolean"?n.includeHtml:!0;return $j(e,r,a)}function $j(e,t,n){if(mae(e)){if("value"in e)return e.type==="html"&&!n?"":e.value;if(t&&"alt"in e&&e.alt)return e.alt;if("children"in e)return tO(e.children,t,n)}return Array.isArray(e)?tO(e,t,n):""}function tO(e,t,n){const r=[];let a=-1;for(;++a<e.length;)r[a]=$j(e[a],t,n);return r.join("")}function mae(e){return!!(e&&typeof e=="object")}const nO=document.createElement("i");function K0(e){const t="&"+e+";";nO.innerHTML=t;const n=nO.textContent;return n.charCodeAt(n.length-1)===59&&e!=="semi"||n===t?!1:n}function Qn(e,t,n,r){const a=e.length;let i=0,l;if(t<0?t=-t>a?0:a+t:t=t>a?a:t,n=n>0?n:0,r.length<1e4)l=Array.from(r),l.unshift(t,n),e.splice(...l);else for(n&&e.splice(t,n);i<r.length;)l=r.slice(i,i+1e4),l.unshift(t,0),e.splice(...l),i+=1e4,t+=1e4}function gr(e,t){return e.length>0?(Qn(e,e.length,0,t),e):t}const rO={}.hasOwnProperty;function qj(e){const t={};let n=-1;for(;++n<e.length;)bae(t,e[n]);return t}function bae(e,t){let n;for(n in t){const a=(rO.call(e,n)?e[n]:void 0)||(e[n]={}),i=t[n];let l;if(i)for(l in i){rO.call(a,l)||(a[l]=[]);const u=i[l];yae(a[l],Array.isArray(u)?u:u?[u]:[])}}}function yae(e,t){let n=-1;const r=[];for(;++n<t.length;)(t[n].add==="after"?e:r).push(t[n]);Qn(e,0,0,r)}function Vj(e,t){const n=Number.parseInt(e,t);return n<9||n===11||n>13&&n<32||n>126&&n<160||n>55295&&n<57344||n>64975&&n<65008||(n&65535)===65535||(n&65535)===65534||n>1114111?"�":String.fromCodePoint(n)}function Or(e){return e.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const _n=Ao(/[A-Za-z]/),Sn=Ao(/[\dA-Za-z]/),vae=Ao(/[#-'*+\--9=?A-Z^-~]/);function Qd(e){return e!==null&&(e<32||e===127)}const mk=Ao(/\d/),Sae=Ao(/[\dA-Fa-f]/),Eae=Ao(/[!-/:-@[-`{-~]/);function $e(e){return e!==null&&e<-2}function Nt(e){return e!==null&&(e<0||e===32)}function ut(e){return e===-2||e===-1||e===32}const jf=Ao(new RegExp("\\p{P}|\\p{S}","u")),ui=Ao(/\s/);function Ao(e){return t;function t(n){return n!==null&&n>-1&&e.test(String.fromCharCode(n))}}function Bl(e){const t=[];let n=-1,r=0,a=0;for(;++n<e.length;){const i=e.charCodeAt(n);let l="";if(i===37&&Sn(e.charCodeAt(n+1))&&Sn(e.charCodeAt(n+2)))a=2;else if(i<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(i))||(l=String.fromCharCode(i));else if(i>55295&&i<57344){const u=e.charCodeAt(n+1);i<56320&&u>56319&&u<57344?(l=String.fromCharCode(i,u),a=1):l="�"}else l=String.fromCharCode(i);l&&(t.push(e.slice(r,n),encodeURIComponent(l)),r=n+a+1,l=""),a&&(n+=a,a=0)}return t.join("")+e.slice(r)}function lt(e,t,n,r){const a=r?r-1:Number.POSITIVE_INFINITY;let i=0;return l;function l(c){return ut(c)?(e.enter(n),u(c)):t(c)}function u(c){return ut(c)&&i++<a?(e.consume(c),u):(e.exit(n),t(c))}}const wae={tokenize:xae};function xae(e){const t=e.attempt(this.parser.constructs.contentInitial,r,a);let n;return t;function r(u){if(u===null){e.consume(u);return}return e.enter("lineEnding"),e.consume(u),e.exit("lineEnding"),lt(e,t,"linePrefix")}function a(u){return e.enter("paragraph"),i(u)}function i(u){const c=e.enter("chunkText",{contentType:"text",previous:n});return n&&(n.next=c),n=c,l(u)}function l(u){if(u===null){e.exit("chunkText"),e.exit("paragraph"),e.consume(u);return}return $e(u)?(e.consume(u),e.exit("chunkText"),i):(e.consume(u),l)}}const kae={tokenize:Aae},aO={tokenize:Tae};function Aae(e){const t=this,n=[];let r=0,a,i,l;return u;function u(T){if(r<n.length){const C=n[r];return t.containerState=C[1],e.attempt(C[0].continuation,c,f)(T)}return f(T)}function c(T){if(r++,t.containerState._closeFlow){t.containerState._closeFlow=void 0,a&&x();const C=t.events.length;let N=C,_;for(;N--;)if(t.events[N][0]==="exit"&&t.events[N][1].type==="chunkFlow"){_=t.events[N][1].end;break}R(r);let O=C;for(;O<t.events.length;)t.events[O][1].end={..._},O++;return Qn(t.events,N+1,0,t.events.slice(C)),t.events.length=O,f(T)}return u(T)}function f(T){if(r===n.length){if(!a)return b(T);if(a.currentConstruct&&a.currentConstruct.concrete)return S(T);t.interrupt=!!(a.currentConstruct&&!a._gfmTableDynamicInterruptHack)}return t.containerState={},e.check(aO,p,g)(T)}function p(T){return a&&x(),R(r),b(T)}function g(T){return t.parser.lazy[t.now().line]=r!==n.length,l=t.now().offset,S(T)}function b(T){return t.containerState={},e.attempt(aO,m,S)(T)}function m(T){return r++,n.push([t.currentConstruct,t.containerState]),b(T)}function S(T){if(T===null){a&&x(),R(0),e.consume(T);return}return a=a||t.parser.flow(t.now()),e.enter("chunkFlow",{_tokenizer:a,contentType:"flow",previous:i}),v(T)}function v(T){if(T===null){A(e.exit("chunkFlow"),!0),R(0),e.consume(T);return}return $e(T)?(e.consume(T),A(e.exit("chunkFlow")),r=0,t.interrupt=void 0,u):(e.consume(T),v)}function A(T,C){const N=t.sliceStream(T);if(C&&N.push(null),T.previous=i,i&&(i.next=T),i=T,a.defineSkip(T.start),a.write(N),t.parser.lazy[T.start.line]){let _=a.events.length;for(;_--;)if(a.events[_][1].start.offset<l&&(!a.events[_][1].end||a.events[_][1].end.offset>l))return;const O=t.events.length;let z=O,I,M;for(;z--;)if(t.events[z][0]==="exit"&&t.events[z][1].type==="chunkFlow"){if(I){M=t.events[z][1].end;break}I=!0}for(R(r),_=O;_<t.events.length;)t.events[_][1].end={...M},_++;Qn(t.events,z+1,0,t.events.slice(O)),t.events.length=_}}function R(T){let C=n.length;for(;C-- >T;){const N=n[C];t.containerState=N[1],N[0].exit.call(t,e)}n.length=T}function x(){a.write([null]),i=void 0,a=void 0,t.containerState._closeFlow=void 0}}function Tae(e,t,n){return lt(e,e.attempt(this.parser.constructs.document,t,n),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function xl(e){if(e===null||Nt(e)||ui(e))return 1;if(jf(e))return 2}function Gf(e,t,n){const r=[];let a=-1;for(;++a<e.length;){const i=e[a].resolveAll;i&&!r.includes(i)&&(t=i(t,n),r.push(i))}return t}const bk={name:"attention",resolveAll:_ae,tokenize:Rae};function _ae(e,t){let n=-1,r,a,i,l,u,c,f,p;for(;++n<e.length;)if(e[n][0]==="enter"&&e[n][1].type==="attentionSequence"&&e[n][1]._close){for(r=n;r--;)if(e[r][0]==="exit"&&e[r][1].type==="attentionSequence"&&e[r][1]._open&&t.sliceSerialize(e[r][1]).charCodeAt(0)===t.sliceSerialize(e[n][1]).charCodeAt(0)){if((e[r][1]._close||e[n][1]._open)&&(e[n][1].end.offset-e[n][1].start.offset)%3&&!((e[r][1].end.offset-e[r][1].start.offset+e[n][1].end.offset-e[n][1].start.offset)%3))continue;c=e[r][1].end.offset-e[r][1].start.offset>1&&e[n][1].end.offset-e[n][1].start.offset>1?2:1;const g={...e[r][1].end},b={...e[n][1].start};oO(g,-c),oO(b,c),l={type:c>1?"strongSequence":"emphasisSequence",start:g,end:{...e[r][1].end}},u={type:c>1?"strongSequence":"emphasisSequence",start:{...e[n][1].start},end:b},i={type:c>1?"strongText":"emphasisText",start:{...e[r][1].end},end:{...e[n][1].start}},a={type:c>1?"strong":"emphasis",start:{...l.start},end:{...u.end}},e[r][1].end={...l.start},e[n][1].start={...u.end},f=[],e[r][1].end.offset-e[r][1].start.offset&&(f=gr(f,[["enter",e[r][1],t],["exit",e[r][1],t]])),f=gr(f,[["enter",a,t],["enter",l,t],["exit",l,t],["enter",i,t]]),f=gr(f,Gf(t.parser.constructs.insideSpan.null,e.slice(r+1,n),t)),f=gr(f,[["exit",i,t],["enter",u,t],["exit",u,t],["exit",a,t]]),e[n][1].end.offset-e[n][1].start.offset?(p=2,f=gr(f,[["enter",e[n][1],t],["exit",e[n][1],t]])):p=0,Qn(e,r-1,n-r+3,f),n=r+f.length-p-2;break}}for(n=-1;++n<e.length;)e[n][1].type==="attentionSequence"&&(e[n][1].type="data");return e}function Rae(e,t){const n=this.parser.constructs.attentionMarkers.null,r=this.previous,a=xl(r);let i;return l;function l(c){return i=c,e.enter("attentionSequence"),u(c)}function u(c){if(c===i)return e.consume(c),u;const f=e.exit("attentionSequence"),p=xl(c),g=!p||p===2&&a||n.includes(c),b=!a||a===2&&p||n.includes(r);return f._open=!!(i===42?g:g&&(a||!b)),f._close=!!(i===42?b:b&&(p||!g)),t(c)}}function oO(e,t){e.column+=t,e.offset+=t,e._bufferIndex+=t}const Cae={name:"autolink",tokenize:Nae};function Nae(e,t,n){let r=0;return a;function a(m){return e.enter("autolink"),e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.enter("autolinkProtocol"),i}function i(m){return _n(m)?(e.consume(m),l):m===64?n(m):f(m)}function l(m){return m===43||m===45||m===46||Sn(m)?(r=1,u(m)):f(m)}function u(m){return m===58?(e.consume(m),r=0,c):(m===43||m===45||m===46||Sn(m))&&r++<32?(e.consume(m),u):(r=0,f(m))}function c(m){return m===62?(e.exit("autolinkProtocol"),e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.exit("autolink"),t):m===null||m===32||m===60||Qd(m)?n(m):(e.consume(m),c)}function f(m){return m===64?(e.consume(m),p):vae(m)?(e.consume(m),f):n(m)}function p(m){return Sn(m)?g(m):n(m)}function g(m){return m===46?(e.consume(m),r=0,p):m===62?(e.exit("autolinkProtocol").type="autolinkEmail",e.enter("autolinkMarker"),e.consume(m),e.exit("autolinkMarker"),e.exit("autolink"),t):b(m)}function b(m){if((m===45||Sn(m))&&r++<63){const S=m===45?b:g;return e.consume(m),S}return n(m)}}const _u={partial:!0,tokenize:Oae};function Oae(e,t,n){return r;function r(i){return ut(i)?lt(e,a,"linePrefix")(i):a(i)}function a(i){return i===null||$e(i)?t(i):n(i)}}const Wj={continuation:{tokenize:Iae},exit:Lae,name:"blockQuote",tokenize:Dae};function Dae(e,t,n){const r=this;return a;function a(l){if(l===62){const u=r.containerState;return u.open||(e.enter("blockQuote",{_container:!0}),u.open=!0),e.enter("blockQuotePrefix"),e.enter("blockQuoteMarker"),e.consume(l),e.exit("blockQuoteMarker"),i}return n(l)}function i(l){return ut(l)?(e.enter("blockQuotePrefixWhitespace"),e.consume(l),e.exit("blockQuotePrefixWhitespace"),e.exit("blockQuotePrefix"),t):(e.exit("blockQuotePrefix"),t(l))}}function Iae(e,t,n){const r=this;return a;function a(l){return ut(l)?lt(e,i,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(l):i(l)}function i(l){return e.attempt(Wj,t,n)(l)}}function Lae(e){e.exit("blockQuote")}const Yj={name:"characterEscape",tokenize:Mae};function Mae(e,t,n){return r;function r(i){return e.enter("characterEscape"),e.enter("escapeMarker"),e.consume(i),e.exit("escapeMarker"),a}function a(i){return Eae(i)?(e.enter("characterEscapeValue"),e.consume(i),e.exit("characterEscapeValue"),e.exit("characterEscape"),t):n(i)}}const Kj={name:"characterReference",tokenize:Fae};function Fae(e,t,n){const r=this;let a=0,i,l;return u;function u(g){return e.enter("characterReference"),e.enter("characterReferenceMarker"),e.consume(g),e.exit("characterReferenceMarker"),c}function c(g){return g===35?(e.enter("characterReferenceMarkerNumeric"),e.consume(g),e.exit("characterReferenceMarkerNumeric"),f):(e.enter("characterReferenceValue"),i=31,l=Sn,p(g))}function f(g){return g===88||g===120?(e.enter("characterReferenceMarkerHexadecimal"),e.consume(g),e.exit("characterReferenceMarkerHexadecimal"),e.enter("characterReferenceValue"),i=6,l=Sae,p):(e.enter("characterReferenceValue"),i=7,l=mk,p(g))}function p(g){if(g===59&&a){const b=e.exit("characterReferenceValue");return l===Sn&&!K0(r.sliceSerialize(b))?n(g):(e.enter("characterReferenceMarker"),e.consume(g),e.exit("characterReferenceMarker"),e.exit("characterReference"),t)}return l(g)&&a++<i?(e.consume(g),p):n(g)}}const iO={partial:!0,tokenize:Pae},lO={concrete:!0,name:"codeFenced",tokenize:zae};function zae(e,t,n){const r=this,a={partial:!0,tokenize:N};let i=0,l=0,u;return c;function c(_){return f(_)}function f(_){const O=r.events[r.events.length-1];return i=O&&O[1].type==="linePrefix"?O[2].sliceSerialize(O[1],!0).length:0,u=_,e.enter("codeFenced"),e.enter("codeFencedFence"),e.enter("codeFencedFenceSequence"),p(_)}function p(_){return _===u?(l++,e.consume(_),p):l<3?n(_):(e.exit("codeFencedFenceSequence"),ut(_)?lt(e,g,"whitespace")(_):g(_))}function g(_){return _===null||$e(_)?(e.exit("codeFencedFence"),r.interrupt?t(_):e.check(iO,v,C)(_)):(e.enter("codeFencedFenceInfo"),e.enter("chunkString",{contentType:"string"}),b(_))}function b(_){return _===null||$e(_)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),g(_)):ut(_)?(e.exit("chunkString"),e.exit("codeFencedFenceInfo"),lt(e,m,"whitespace")(_)):_===96&&_===u?n(_):(e.consume(_),b)}function m(_){return _===null||$e(_)?g(_):(e.enter("codeFencedFenceMeta"),e.enter("chunkString",{contentType:"string"}),S(_))}function S(_){return _===null||$e(_)?(e.exit("chunkString"),e.exit("codeFencedFenceMeta"),g(_)):_===96&&_===u?n(_):(e.consume(_),S)}function v(_){return e.attempt(a,C,A)(_)}function A(_){return e.enter("lineEnding"),e.consume(_),e.exit("lineEnding"),R}function R(_){return i>0&&ut(_)?lt(e,x,"linePrefix",i+1)(_):x(_)}function x(_){return _===null||$e(_)?e.check(iO,v,C)(_):(e.enter("codeFlowValue"),T(_))}function T(_){return _===null||$e(_)?(e.exit("codeFlowValue"),x(_)):(e.consume(_),T)}function C(_){return e.exit("codeFenced"),t(_)}function N(_,O,z){let I=0;return M;function M(Z){return _.enter("lineEnding"),_.consume(Z),_.exit("lineEnding"),H}function H(Z){return _.enter("codeFencedFence"),ut(Z)?lt(_,q,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(Z):q(Z)}function q(Z){return Z===u?(_.enter("codeFencedFenceSequence"),P(Z)):z(Z)}function P(Z){return Z===u?(I++,_.consume(Z),P):I>=l?(_.exit("codeFencedFenceSequence"),ut(Z)?lt(_,W,"whitespace")(Z):W(Z)):z(Z)}function W(Z){return Z===null||$e(Z)?(_.exit("codeFencedFence"),O(Z)):z(Z)}}}function Pae(e,t,n){const r=this;return a;function a(l){return l===null?n(l):(e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),i)}function i(l){return r.parser.lazy[r.now().line]?n(l):t(l)}}const xm={name:"codeIndented",tokenize:Uae},Bae={partial:!0,tokenize:jae};function Uae(e,t,n){const r=this;return a;function a(f){return e.enter("codeIndented"),lt(e,i,"linePrefix",5)(f)}function i(f){const p=r.events[r.events.length-1];return p&&p[1].type==="linePrefix"&&p[2].sliceSerialize(p[1],!0).length>=4?l(f):n(f)}function l(f){return f===null?c(f):$e(f)?e.attempt(Bae,l,c)(f):(e.enter("codeFlowValue"),u(f))}function u(f){return f===null||$e(f)?(e.exit("codeFlowValue"),l(f)):(e.consume(f),u)}function c(f){return e.exit("codeIndented"),t(f)}}function jae(e,t,n){const r=this;return a;function a(l){return r.parser.lazy[r.now().line]?n(l):$e(l)?(e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),a):lt(e,i,"linePrefix",5)(l)}function i(l){const u=r.events[r.events.length-1];return u&&u[1].type==="linePrefix"&&u[2].sliceSerialize(u[1],!0).length>=4?t(l):$e(l)?a(l):n(l)}}const Gae={name:"codeText",previous:$ae,resolve:Hae,tokenize:qae};function Hae(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="codeTextData"){e[n][1].type="codeTextPadding",e[t][1].type="codeTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="codeTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function $ae(e){return e!==96||this.events[this.events.length-1][1].type==="characterEscape"}function qae(e,t,n){let r=0,a,i;return l;function l(g){return e.enter("codeText"),e.enter("codeTextSequence"),u(g)}function u(g){return g===96?(e.consume(g),r++,u):(e.exit("codeTextSequence"),c(g))}function c(g){return g===null?n(g):g===32?(e.enter("space"),e.consume(g),e.exit("space"),c):g===96?(i=e.enter("codeTextSequence"),a=0,p(g)):$e(g)?(e.enter("lineEnding"),e.consume(g),e.exit("lineEnding"),c):(e.enter("codeTextData"),f(g))}function f(g){return g===null||g===32||g===96||$e(g)?(e.exit("codeTextData"),c(g)):(e.consume(g),f)}function p(g){return g===96?(e.consume(g),a++,p):a===r?(e.exit("codeTextSequence"),e.exit("codeText"),t(g)):(i.type="codeTextData",f(g))}}class Vae{constructor(t){this.left=t?[...t]:[],this.right=[]}get(t){if(t<0||t>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+t+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return t<this.left.length?this.left[t]:this.right[this.right.length-t+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(t,n){const r=n??Number.POSITIVE_INFINITY;return r<this.left.length?this.left.slice(t,r):t>this.left.length?this.right.slice(this.right.length-r+this.left.length,this.right.length-t+this.left.length).reverse():this.left.slice(t).concat(this.right.slice(this.right.length-r+this.left.length).reverse())}splice(t,n,r){const a=n||0;this.setCursor(Math.trunc(t));const i=this.right.splice(this.right.length-a,Number.POSITIVE_INFINITY);return r&&$s(this.left,r),i.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(t){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(t)}pushMany(t){this.setCursor(Number.POSITIVE_INFINITY),$s(this.left,t)}unshift(t){this.setCursor(0),this.right.push(t)}unshiftMany(t){this.setCursor(0),$s(this.right,t.reverse())}setCursor(t){if(!(t===this.left.length||t>this.left.length&&this.right.length===0||t<0&&this.left.length===0))if(t<this.left.length){const n=this.left.splice(t,Number.POSITIVE_INFINITY);$s(this.right,n.reverse())}else{const n=this.right.splice(this.left.length+this.right.length-t,Number.POSITIVE_INFINITY);$s(this.left,n.reverse())}}}function $s(e,t){let n=0;if(t.length<1e4)e.push(...t);else for(;n<t.length;)e.push(...t.slice(n,n+1e4)),n+=1e4}function Xj(e){const t={};let n=-1,r,a,i,l,u,c,f;const p=new Vae(e);for(;++n<p.length;){for(;n in t;)n=t[n];if(r=p.get(n),n&&r[1].type==="chunkFlow"&&p.get(n-1)[1].type==="listItemPrefix"&&(c=r[1]._tokenizer.events,i=0,i<c.length&&c[i][1].type==="lineEndingBlank"&&(i+=2),i<c.length&&c[i][1].type==="content"))for(;++i<c.length&&c[i][1].type!=="content";)c[i][1].type==="chunkText"&&(c[i][1]._isInFirstContentOfListItem=!0,i++);if(r[0]==="enter")r[1].contentType&&(Object.assign(t,Wae(p,n)),n=t[n],f=!0);else if(r[1]._container){for(i=n,a=void 0;i--;)if(l=p.get(i),l[1].type==="lineEnding"||l[1].type==="lineEndingBlank")l[0]==="enter"&&(a&&(p.get(a)[1].type="lineEndingBlank"),l[1].type="lineEnding",a=i);else if(l[1].type!=="linePrefix")break;a&&(r[1].end={...p.get(a)[1].start},u=p.slice(a,n),u.unshift(r),p.splice(a,n-a+1,u))}}return Qn(e,0,Number.POSITIVE_INFINITY,p.slice(0)),!f}function Wae(e,t){const n=e.get(t)[1],r=e.get(t)[2];let a=t-1;const i=[],l=n._tokenizer||r.parser[n.contentType](n.start),u=l.events,c=[],f={};let p,g,b=-1,m=n,S=0,v=0;const A=[v];for(;m;){for(;e.get(++a)[1]!==m;);i.push(a),m._tokenizer||(p=r.sliceStream(m),m.next||p.push(null),g&&l.defineSkip(m.start),m._isInFirstContentOfListItem&&(l._gfmTasklistFirstContentOfListItem=!0),l.write(p),m._isInFirstContentOfListItem&&(l._gfmTasklistFirstContentOfListItem=void 0)),g=m,m=m.next}for(m=n;++b<u.length;)u[b][0]==="exit"&&u[b-1][0]==="enter"&&u[b][1].type===u[b-1][1].type&&u[b][1].start.line!==u[b][1].end.line&&(v=b+1,A.push(v),m._tokenizer=void 0,m.previous=void 0,m=m.next);for(l.events=[],m?(m._tokenizer=void 0,m.previous=void 0):A.pop(),b=A.length;b--;){const R=u.slice(A[b],A[b+1]),x=i.pop();c.push([x,x+R.length-1]),e.splice(x,2,R)}for(c.reverse(),b=-1;++b<c.length;)f[S+c[b][0]]=S+c[b][1],S+=c[b][1]-c[b][0]-1;return f}const Yae={resolve:Xae,tokenize:Zae},Kae={partial:!0,tokenize:Qae};function Xae(e){return Xj(e),e}function Zae(e,t){let n;return r;function r(u){return e.enter("content"),n=e.enter("chunkContent",{contentType:"content"}),a(u)}function a(u){return u===null?i(u):$e(u)?e.check(Kae,l,i)(u):(e.consume(u),a)}function i(u){return e.exit("chunkContent"),e.exit("content"),t(u)}function l(u){return e.consume(u),e.exit("chunkContent"),n.next=e.enter("chunkContent",{contentType:"content",previous:n}),n=n.next,a}}function Qae(e,t,n){const r=this;return a;function a(l){return e.exit("chunkContent"),e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),lt(e,i,"linePrefix")}function i(l){if(l===null||$e(l))return n(l);const u=r.events[r.events.length-1];return!r.parser.constructs.disable.null.includes("codeIndented")&&u&&u[1].type==="linePrefix"&&u[2].sliceSerialize(u[1],!0).length>=4?t(l):e.interrupt(r.parser.constructs.flow,n,t)(l)}}function Zj(e,t,n,r,a,i,l,u,c){const f=c||Number.POSITIVE_INFINITY;let p=0;return g;function g(R){return R===60?(e.enter(r),e.enter(a),e.enter(i),e.consume(R),e.exit(i),b):R===null||R===32||R===41||Qd(R)?n(R):(e.enter(r),e.enter(l),e.enter(u),e.enter("chunkString",{contentType:"string"}),v(R))}function b(R){return R===62?(e.enter(i),e.consume(R),e.exit(i),e.exit(a),e.exit(r),t):(e.enter(u),e.enter("chunkString",{contentType:"string"}),m(R))}function m(R){return R===62?(e.exit("chunkString"),e.exit(u),b(R)):R===null||R===60||$e(R)?n(R):(e.consume(R),R===92?S:m)}function S(R){return R===60||R===62||R===92?(e.consume(R),m):m(R)}function v(R){return!p&&(R===null||R===41||Nt(R))?(e.exit("chunkString"),e.exit(u),e.exit(l),e.exit(r),t(R)):p<f&&R===40?(e.consume(R),p++,v):R===41?(e.consume(R),p--,v):R===null||R===32||R===40||Qd(R)?n(R):(e.consume(R),R===92?A:v)}function A(R){return R===40||R===41||R===92?(e.consume(R),v):v(R)}}function Qj(e,t,n,r,a,i){const l=this;let u=0,c;return f;function f(m){return e.enter(r),e.enter(a),e.consume(m),e.exit(a),e.enter(i),p}function p(m){return u>999||m===null||m===91||m===93&&!c||m===94&&!u&&"_hiddenFootnoteSupport"in l.parser.constructs?n(m):m===93?(e.exit(i),e.enter(a),e.consume(m),e.exit(a),e.exit(r),t):$e(m)?(e.enter("lineEnding"),e.consume(m),e.exit("lineEnding"),p):(e.enter("chunkString",{contentType:"string"}),g(m))}function g(m){return m===null||m===91||m===93||$e(m)||u++>999?(e.exit("chunkString"),p(m)):(e.consume(m),c||(c=!ut(m)),m===92?b:g)}function b(m){return m===91||m===92||m===93?(e.consume(m),u++,g):g(m)}}function Jj(e,t,n,r,a,i){let l;return u;function u(b){return b===34||b===39||b===40?(e.enter(r),e.enter(a),e.consume(b),e.exit(a),l=b===40?41:b,c):n(b)}function c(b){return b===l?(e.enter(a),e.consume(b),e.exit(a),e.exit(r),t):(e.enter(i),f(b))}function f(b){return b===l?(e.exit(i),c(l)):b===null?n(b):$e(b)?(e.enter("lineEnding"),e.consume(b),e.exit("lineEnding"),lt(e,f,"linePrefix")):(e.enter("chunkString",{contentType:"string"}),p(b))}function p(b){return b===l||b===null||$e(b)?(e.exit("chunkString"),f(b)):(e.consume(b),b===92?g:p)}function g(b){return b===l||b===92?(e.consume(b),p):p(b)}}function Zs(e,t){let n;return r;function r(a){return $e(a)?(e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),n=!0,r):ut(a)?lt(e,r,n?"linePrefix":"lineSuffix")(a):t(a)}}const Jae={name:"definition",tokenize:toe},eoe={partial:!0,tokenize:noe};function toe(e,t,n){const r=this;let a;return i;function i(m){return e.enter("definition"),l(m)}function l(m){return Qj.call(r,e,u,n,"definitionLabel","definitionLabelMarker","definitionLabelString")(m)}function u(m){return a=Or(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)),m===58?(e.enter("definitionMarker"),e.consume(m),e.exit("definitionMarker"),c):n(m)}function c(m){return Nt(m)?Zs(e,f)(m):f(m)}function f(m){return Zj(e,p,n,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(m)}function p(m){return e.attempt(eoe,g,g)(m)}function g(m){return ut(m)?lt(e,b,"whitespace")(m):b(m)}function b(m){return m===null||$e(m)?(e.exit("definition"),r.parser.defined.push(a),t(m)):n(m)}}function noe(e,t,n){return r;function r(u){return Nt(u)?Zs(e,a)(u):n(u)}function a(u){return Jj(e,i,n,"definitionTitle","definitionTitleMarker","definitionTitleString")(u)}function i(u){return ut(u)?lt(e,l,"whitespace")(u):l(u)}function l(u){return u===null||$e(u)?t(u):n(u)}}const roe={name:"hardBreakEscape",tokenize:aoe};function aoe(e,t,n){return r;function r(i){return e.enter("hardBreakEscape"),e.consume(i),a}function a(i){return $e(i)?(e.exit("hardBreakEscape"),t(i)):n(i)}}const ooe={name:"headingAtx",resolve:ioe,tokenize:loe};function ioe(e,t){let n=e.length-2,r=3,a,i;return e[r][1].type==="whitespace"&&(r+=2),n-2>r&&e[n][1].type==="whitespace"&&(n-=2),e[n][1].type==="atxHeadingSequence"&&(r===n-1||n-4>r&&e[n-2][1].type==="whitespace")&&(n-=r+1===n?2:4),n>r&&(a={type:"atxHeadingText",start:e[r][1].start,end:e[n][1].end},i={type:"chunkText",start:e[r][1].start,end:e[n][1].end,contentType:"text"},Qn(e,r,n-r+1,[["enter",a,t],["enter",i,t],["exit",i,t],["exit",a,t]])),e}function loe(e,t,n){let r=0;return a;function a(p){return e.enter("atxHeading"),i(p)}function i(p){return e.enter("atxHeadingSequence"),l(p)}function l(p){return p===35&&r++<6?(e.consume(p),l):p===null||Nt(p)?(e.exit("atxHeadingSequence"),u(p)):n(p)}function u(p){return p===35?(e.enter("atxHeadingSequence"),c(p)):p===null||$e(p)?(e.exit("atxHeading"),t(p)):ut(p)?lt(e,u,"whitespace")(p):(e.enter("atxHeadingText"),f(p))}function c(p){return p===35?(e.consume(p),c):(e.exit("atxHeadingSequence"),u(p))}function f(p){return p===null||p===35||Nt(p)?(e.exit("atxHeadingText"),u(p)):(e.consume(p),f)}}const soe=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],sO=["pre","script","style","textarea"],uoe={concrete:!0,name:"htmlFlow",resolveTo:foe,tokenize:poe},coe={partial:!0,tokenize:hoe},doe={partial:!0,tokenize:goe};function foe(e){let t=e.length;for(;t--&&!(e[t][0]==="enter"&&e[t][1].type==="htmlFlow"););return t>1&&e[t-2][1].type==="linePrefix"&&(e[t][1].start=e[t-2][1].start,e[t+1][1].start=e[t-2][1].start,e.splice(t-2,2)),e}function poe(e,t,n){const r=this;let a,i,l,u,c;return f;function f(L){return p(L)}function p(L){return e.enter("htmlFlow"),e.enter("htmlFlowData"),e.consume(L),g}function g(L){return L===33?(e.consume(L),b):L===47?(e.consume(L),i=!0,v):L===63?(e.consume(L),a=3,r.interrupt?t:D):_n(L)?(e.consume(L),l=String.fromCharCode(L),A):n(L)}function b(L){return L===45?(e.consume(L),a=2,m):L===91?(e.consume(L),a=5,u=0,S):_n(L)?(e.consume(L),a=4,r.interrupt?t:D):n(L)}function m(L){return L===45?(e.consume(L),r.interrupt?t:D):n(L)}function S(L){const Y="CDATA[";return L===Y.charCodeAt(u++)?(e.consume(L),u===Y.length?r.interrupt?t:q:S):n(L)}function v(L){return _n(L)?(e.consume(L),l=String.fromCharCode(L),A):n(L)}function A(L){if(L===null||L===47||L===62||Nt(L)){const Y=L===47,Q=l.toLowerCase();return!Y&&!i&&sO.includes(Q)?(a=1,r.interrupt?t(L):q(L)):soe.includes(l.toLowerCase())?(a=6,Y?(e.consume(L),R):r.interrupt?t(L):q(L)):(a=7,r.interrupt&&!r.parser.lazy[r.now().line]?n(L):i?x(L):T(L))}return L===45||Sn(L)?(e.consume(L),l+=String.fromCharCode(L),A):n(L)}function R(L){return L===62?(e.consume(L),r.interrupt?t:q):n(L)}function x(L){return ut(L)?(e.consume(L),x):M(L)}function T(L){return L===47?(e.consume(L),M):L===58||L===95||_n(L)?(e.consume(L),C):ut(L)?(e.consume(L),T):M(L)}function C(L){return L===45||L===46||L===58||L===95||Sn(L)?(e.consume(L),C):N(L)}function N(L){return L===61?(e.consume(L),_):ut(L)?(e.consume(L),N):T(L)}function _(L){return L===null||L===60||L===61||L===62||L===96?n(L):L===34||L===39?(e.consume(L),c=L,O):ut(L)?(e.consume(L),_):z(L)}function O(L){return L===c?(e.consume(L),c=null,I):L===null||$e(L)?n(L):(e.consume(L),O)}function z(L){return L===null||L===34||L===39||L===47||L===60||L===61||L===62||L===96||Nt(L)?N(L):(e.consume(L),z)}function I(L){return L===47||L===62||ut(L)?T(L):n(L)}function M(L){return L===62?(e.consume(L),H):n(L)}function H(L){return L===null||$e(L)?q(L):ut(L)?(e.consume(L),H):n(L)}function q(L){return L===45&&a===2?(e.consume(L),j):L===60&&a===1?(e.consume(L),G):L===62&&a===4?(e.consume(L),V):L===63&&a===3?(e.consume(L),D):L===93&&a===5?(e.consume(L),X):$e(L)&&(a===6||a===7)?(e.exit("htmlFlowData"),e.check(coe,U,P)(L)):L===null||$e(L)?(e.exit("htmlFlowData"),P(L)):(e.consume(L),q)}function P(L){return e.check(doe,W,U)(L)}function W(L){return e.enter("lineEnding"),e.consume(L),e.exit("lineEnding"),Z}function Z(L){return L===null||$e(L)?P(L):(e.enter("htmlFlowData"),q(L))}function j(L){return L===45?(e.consume(L),D):q(L)}function G(L){return L===47?(e.consume(L),l="",B):q(L)}function B(L){if(L===62){const Y=l.toLowerCase();return sO.includes(Y)?(e.consume(L),V):q(L)}return _n(L)&&l.length<8?(e.consume(L),l+=String.fromCharCode(L),B):q(L)}function X(L){return L===93?(e.consume(L),D):q(L)}function D(L){return L===62?(e.consume(L),V):L===45&&a===2?(e.consume(L),D):q(L)}function V(L){return L===null||$e(L)?(e.exit("htmlFlowData"),U(L)):(e.consume(L),V)}function U(L){return e.exit("htmlFlow"),t(L)}}function goe(e,t,n){const r=this;return a;function a(l){return $e(l)?(e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),i):n(l)}function i(l){return r.parser.lazy[r.now().line]?n(l):t(l)}}function hoe(e,t,n){return r;function r(a){return e.enter("lineEnding"),e.consume(a),e.exit("lineEnding"),e.attempt(_u,t,n)}}const moe={name:"htmlText",tokenize:boe};function boe(e,t,n){const r=this;let a,i,l;return u;function u(D){return e.enter("htmlText"),e.enter("htmlTextData"),e.consume(D),c}function c(D){return D===33?(e.consume(D),f):D===47?(e.consume(D),N):D===63?(e.consume(D),T):_n(D)?(e.consume(D),z):n(D)}function f(D){return D===45?(e.consume(D),p):D===91?(e.consume(D),i=0,S):_n(D)?(e.consume(D),x):n(D)}function p(D){return D===45?(e.consume(D),m):n(D)}function g(D){return D===null?n(D):D===45?(e.consume(D),b):$e(D)?(l=g,G(D)):(e.consume(D),g)}function b(D){return D===45?(e.consume(D),m):g(D)}function m(D){return D===62?j(D):D===45?b(D):g(D)}function S(D){const V="CDATA[";return D===V.charCodeAt(i++)?(e.consume(D),i===V.length?v:S):n(D)}function v(D){return D===null?n(D):D===93?(e.consume(D),A):$e(D)?(l=v,G(D)):(e.consume(D),v)}function A(D){return D===93?(e.consume(D),R):v(D)}function R(D){return D===62?j(D):D===93?(e.consume(D),R):v(D)}function x(D){return D===null||D===62?j(D):$e(D)?(l=x,G(D)):(e.consume(D),x)}function T(D){return D===null?n(D):D===63?(e.consume(D),C):$e(D)?(l=T,G(D)):(e.consume(D),T)}function C(D){return D===62?j(D):T(D)}function N(D){return _n(D)?(e.consume(D),_):n(D)}function _(D){return D===45||Sn(D)?(e.consume(D),_):O(D)}function O(D){return $e(D)?(l=O,G(D)):ut(D)?(e.consume(D),O):j(D)}function z(D){return D===45||Sn(D)?(e.consume(D),z):D===47||D===62||Nt(D)?I(D):n(D)}function I(D){return D===47?(e.consume(D),j):D===58||D===95||_n(D)?(e.consume(D),M):$e(D)?(l=I,G(D)):ut(D)?(e.consume(D),I):j(D)}function M(D){return D===45||D===46||D===58||D===95||Sn(D)?(e.consume(D),M):H(D)}function H(D){return D===61?(e.consume(D),q):$e(D)?(l=H,G(D)):ut(D)?(e.consume(D),H):I(D)}function q(D){return D===null||D===60||D===61||D===62||D===96?n(D):D===34||D===39?(e.consume(D),a=D,P):$e(D)?(l=q,G(D)):ut(D)?(e.consume(D),q):(e.consume(D),W)}function P(D){return D===a?(e.consume(D),a=void 0,Z):D===null?n(D):$e(D)?(l=P,G(D)):(e.consume(D),P)}function W(D){return D===null||D===34||D===39||D===60||D===61||D===96?n(D):D===47||D===62||Nt(D)?I(D):(e.consume(D),W)}function Z(D){return D===47||D===62||Nt(D)?I(D):n(D)}function j(D){return D===62?(e.consume(D),e.exit("htmlTextData"),e.exit("htmlText"),t):n(D)}function G(D){return e.exit("htmlTextData"),e.enter("lineEnding"),e.consume(D),e.exit("lineEnding"),B}function B(D){return ut(D)?lt(e,X,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(D):X(D)}function X(D){return e.enter("htmlTextData"),l(D)}}const X0={name:"labelEnd",resolveAll:Eoe,resolveTo:woe,tokenize:xoe},yoe={tokenize:koe},voe={tokenize:Aoe},Soe={tokenize:Toe};function Eoe(e){let t=-1;const n=[];for(;++t<e.length;){const r=e[t][1];if(n.push(e[t]),r.type==="labelImage"||r.type==="labelLink"||r.type==="labelEnd"){const a=r.type==="labelImage"?4:2;r.type="data",t+=a}}return e.length!==n.length&&Qn(e,0,e.length,n),e}function woe(e,t){let n=e.length,r=0,a,i,l,u;for(;n--;)if(a=e[n][1],i){if(a.type==="link"||a.type==="labelLink"&&a._inactive)break;e[n][0]==="enter"&&a.type==="labelLink"&&(a._inactive=!0)}else if(l){if(e[n][0]==="enter"&&(a.type==="labelImage"||a.type==="labelLink")&&!a._balanced&&(i=n,a.type!=="labelLink")){r=2;break}}else a.type==="labelEnd"&&(l=n);const c={type:e[i][1].type==="labelLink"?"link":"image",start:{...e[i][1].start},end:{...e[e.length-1][1].end}},f={type:"label",start:{...e[i][1].start},end:{...e[l][1].end}},p={type:"labelText",start:{...e[i+r+2][1].end},end:{...e[l-2][1].start}};return u=[["enter",c,t],["enter",f,t]],u=gr(u,e.slice(i+1,i+r+3)),u=gr(u,[["enter",p,t]]),u=gr(u,Gf(t.parser.constructs.insideSpan.null,e.slice(i+r+4,l-3),t)),u=gr(u,[["exit",p,t],e[l-2],e[l-1],["exit",f,t]]),u=gr(u,e.slice(l+1)),u=gr(u,[["exit",c,t]]),Qn(e,i,e.length,u),e}function xoe(e,t,n){const r=this;let a=r.events.length,i,l;for(;a--;)if((r.events[a][1].type==="labelImage"||r.events[a][1].type==="labelLink")&&!r.events[a][1]._balanced){i=r.events[a][1];break}return u;function u(b){return i?i._inactive?g(b):(l=r.parser.defined.includes(Or(r.sliceSerialize({start:i.end,end:r.now()}))),e.enter("labelEnd"),e.enter("labelMarker"),e.consume(b),e.exit("labelMarker"),e.exit("labelEnd"),c):n(b)}function c(b){return b===40?e.attempt(yoe,p,l?p:g)(b):b===91?e.attempt(voe,p,l?f:g)(b):l?p(b):g(b)}function f(b){return e.attempt(Soe,p,g)(b)}function p(b){return t(b)}function g(b){return i._balanced=!0,n(b)}}function koe(e,t,n){return r;function r(g){return e.enter("resource"),e.enter("resourceMarker"),e.consume(g),e.exit("resourceMarker"),a}function a(g){return Nt(g)?Zs(e,i)(g):i(g)}function i(g){return g===41?p(g):Zj(e,l,u,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(g)}function l(g){return Nt(g)?Zs(e,c)(g):p(g)}function u(g){return n(g)}function c(g){return g===34||g===39||g===40?Jj(e,f,n,"resourceTitle","resourceTitleMarker","resourceTitleString")(g):p(g)}function f(g){return Nt(g)?Zs(e,p)(g):p(g)}function p(g){return g===41?(e.enter("resourceMarker"),e.consume(g),e.exit("resourceMarker"),e.exit("resource"),t):n(g)}}function Aoe(e,t,n){const r=this;return a;function a(u){return Qj.call(r,e,i,l,"reference","referenceMarker","referenceString")(u)}function i(u){return r.parser.defined.includes(Or(r.sliceSerialize(r.events[r.events.length-1][1]).slice(1,-1)))?t(u):n(u)}function l(u){return n(u)}}function Toe(e,t,n){return r;function r(i){return e.enter("reference"),e.enter("referenceMarker"),e.consume(i),e.exit("referenceMarker"),a}function a(i){return i===93?(e.enter("referenceMarker"),e.consume(i),e.exit("referenceMarker"),e.exit("reference"),t):n(i)}}const _oe={name:"labelStartImage",resolveAll:X0.resolveAll,tokenize:Roe};function Roe(e,t,n){const r=this;return a;function a(u){return e.enter("labelImage"),e.enter("labelImageMarker"),e.consume(u),e.exit("labelImageMarker"),i}function i(u){return u===91?(e.enter("labelMarker"),e.consume(u),e.exit("labelMarker"),e.exit("labelImage"),l):n(u)}function l(u){return u===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(u):t(u)}}const Coe={name:"labelStartLink",resolveAll:X0.resolveAll,tokenize:Noe};function Noe(e,t,n){const r=this;return a;function a(l){return e.enter("labelLink"),e.enter("labelMarker"),e.consume(l),e.exit("labelMarker"),e.exit("labelLink"),i}function i(l){return l===94&&"_hiddenFootnoteSupport"in r.parser.constructs?n(l):t(l)}}const km={name:"lineEnding",tokenize:Ooe};function Ooe(e,t){return n;function n(r){return e.enter("lineEnding"),e.consume(r),e.exit("lineEnding"),lt(e,t,"linePrefix")}}const _d={name:"thematicBreak",tokenize:Doe};function Doe(e,t,n){let r=0,a;return i;function i(f){return e.enter("thematicBreak"),l(f)}function l(f){return a=f,u(f)}function u(f){return f===a?(e.enter("thematicBreakSequence"),c(f)):r>=3&&(f===null||$e(f))?(e.exit("thematicBreak"),t(f)):n(f)}function c(f){return f===a?(e.consume(f),r++,c):(e.exit("thematicBreakSequence"),ut(f)?lt(e,u,"whitespace")(f):u(f))}}const Ln={continuation:{tokenize:Foe},exit:Poe,name:"list",tokenize:Moe},Ioe={partial:!0,tokenize:Boe},Loe={partial:!0,tokenize:zoe};function Moe(e,t,n){const r=this,a=r.events[r.events.length-1];let i=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0,l=0;return u;function u(m){const S=r.containerState.type||(m===42||m===43||m===45?"listUnordered":"listOrdered");if(S==="listUnordered"?!r.containerState.marker||m===r.containerState.marker:mk(m)){if(r.containerState.type||(r.containerState.type=S,e.enter(S,{_container:!0})),S==="listUnordered")return e.enter("listItemPrefix"),m===42||m===45?e.check(_d,n,f)(m):f(m);if(!r.interrupt||m===49)return e.enter("listItemPrefix"),e.enter("listItemValue"),c(m)}return n(m)}function c(m){return mk(m)&&++l<10?(e.consume(m),c):(!r.interrupt||l<2)&&(r.containerState.marker?m===r.containerState.marker:m===41||m===46)?(e.exit("listItemValue"),f(m)):n(m)}function f(m){return e.enter("listItemMarker"),e.consume(m),e.exit("listItemMarker"),r.containerState.marker=r.containerState.marker||m,e.check(_u,r.interrupt?n:p,e.attempt(Ioe,b,g))}function p(m){return r.containerState.initialBlankLine=!0,i++,b(m)}function g(m){return ut(m)?(e.enter("listItemPrefixWhitespace"),e.consume(m),e.exit("listItemPrefixWhitespace"),b):n(m)}function b(m){return r.containerState.size=i+r.sliceSerialize(e.exit("listItemPrefix"),!0).length,t(m)}}function Foe(e,t,n){const r=this;return r.containerState._closeFlow=void 0,e.check(_u,a,i);function a(u){return r.containerState.furtherBlankLines=r.containerState.furtherBlankLines||r.containerState.initialBlankLine,lt(e,t,"listItemIndent",r.containerState.size+1)(u)}function i(u){return r.containerState.furtherBlankLines||!ut(u)?(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,l(u)):(r.containerState.furtherBlankLines=void 0,r.containerState.initialBlankLine=void 0,e.attempt(Loe,t,l)(u))}function l(u){return r.containerState._closeFlow=!0,r.interrupt=void 0,lt(e,e.attempt(Ln,t,n),"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(u)}}function zoe(e,t,n){const r=this;return lt(e,a,"listItemIndent",r.containerState.size+1);function a(i){const l=r.events[r.events.length-1];return l&&l[1].type==="listItemIndent"&&l[2].sliceSerialize(l[1],!0).length===r.containerState.size?t(i):n(i)}}function Poe(e){e.exit(this.containerState.type)}function Boe(e,t,n){const r=this;return lt(e,a,"listItemPrefixWhitespace",r.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function a(i){const l=r.events[r.events.length-1];return!ut(i)&&l&&l[1].type==="listItemPrefixWhitespace"?t(i):n(i)}}const uO={name:"setextUnderline",resolveTo:Uoe,tokenize:joe};function Uoe(e,t){let n=e.length,r,a,i;for(;n--;)if(e[n][0]==="enter"){if(e[n][1].type==="content"){r=n;break}e[n][1].type==="paragraph"&&(a=n)}else e[n][1].type==="content"&&e.splice(n,1),!i&&e[n][1].type==="definition"&&(i=n);const l={type:"setextHeading",start:{...e[a][1].start},end:{...e[e.length-1][1].end}};return e[a][1].type="setextHeadingText",i?(e.splice(a,0,["enter",l,t]),e.splice(i+1,0,["exit",e[r][1],t]),e[r][1].end={...e[i][1].end}):e[r][1]=l,e.push(["exit",l,t]),e}function joe(e,t,n){const r=this;let a;return i;function i(f){let p=r.events.length,g;for(;p--;)if(r.events[p][1].type!=="lineEnding"&&r.events[p][1].type!=="linePrefix"&&r.events[p][1].type!=="content"){g=r.events[p][1].type==="paragraph";break}return!r.parser.lazy[r.now().line]&&(r.interrupt||g)?(e.enter("setextHeadingLine"),a=f,l(f)):n(f)}function l(f){return e.enter("setextHeadingLineSequence"),u(f)}function u(f){return f===a?(e.consume(f),u):(e.exit("setextHeadingLineSequence"),ut(f)?lt(e,c,"lineSuffix")(f):c(f))}function c(f){return f===null||$e(f)?(e.exit("setextHeadingLine"),t(f)):n(f)}}const Goe={tokenize:Hoe};function Hoe(e){const t=this,n=e.attempt(_u,r,e.attempt(this.parser.constructs.flowInitial,a,lt(e,e.attempt(this.parser.constructs.flow,a,e.attempt(Yae,a)),"linePrefix")));return n;function r(i){if(i===null){e.consume(i);return}return e.enter("lineEndingBlank"),e.consume(i),e.exit("lineEndingBlank"),t.currentConstruct=void 0,n}function a(i){if(i===null){e.consume(i);return}return e.enter("lineEnding"),e.consume(i),e.exit("lineEnding"),t.currentConstruct=void 0,n}}const $oe={resolveAll:t5()},qoe=e5("string"),Voe=e5("text");function e5(e){return{resolveAll:t5(e==="text"?Woe:void 0),tokenize:t};function t(n){const r=this,a=this.parser.constructs[e],i=n.attempt(a,l,u);return l;function l(p){return f(p)?i(p):u(p)}function u(p){if(p===null){n.consume(p);return}return n.enter("data"),n.consume(p),c}function c(p){return f(p)?(n.exit("data"),i(p)):(n.consume(p),c)}function f(p){if(p===null)return!0;const g=a[p];let b=-1;if(g)for(;++b<g.length;){const m=g[b];if(!m.previous||m.previous.call(r,r.previous))return!0}return!1}}}function t5(e){return t;function t(n,r){let a=-1,i;for(;++a<=n.length;)i===void 0?n[a]&&n[a][1].type==="data"&&(i=a,a++):(!n[a]||n[a][1].type!=="data")&&(a!==i+2&&(n[i][1].end=n[a-1][1].end,n.splice(i+2,a-i-2),a=i+2),i=void 0);return e?e(n,r):n}}function Woe(e,t){let n=0;for(;++n<=e.length;)if((n===e.length||e[n][1].type==="lineEnding")&&e[n-1][1].type==="data"){const r=e[n-1][1],a=t.sliceStream(r);let i=a.length,l=-1,u=0,c;for(;i--;){const f=a[i];if(typeof f=="string"){for(l=f.length;f.charCodeAt(l-1)===32;)u++,l--;if(l)break;l=-1}else if(f===-2)c=!0,u++;else if(f!==-1){i++;break}}if(u){const f={type:n===e.length||c||u<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:i?l:r.start._bufferIndex+l,_index:r.start._index+i,line:r.end.line,column:r.end.column-u,offset:r.end.offset-u},end:{...r.end}};r.end={...f.start},r.start.offset===r.end.offset?Object.assign(r,f):(e.splice(n,0,["enter",f,t],["exit",f,t]),n+=2)}n++}return e}const Yoe={42:Ln,43:Ln,45:Ln,48:Ln,49:Ln,50:Ln,51:Ln,52:Ln,53:Ln,54:Ln,55:Ln,56:Ln,57:Ln,62:Wj},Koe={91:Jae},Xoe={[-2]:xm,[-1]:xm,32:xm},Zoe={35:ooe,42:_d,45:[uO,_d],60:uoe,61:uO,95:_d,96:lO,126:lO},Qoe={38:Kj,92:Yj},Joe={[-5]:km,[-4]:km,[-3]:km,33:_oe,38:Kj,42:bk,60:[Cae,moe],91:Coe,92:[roe,Yj],93:X0,95:bk,96:Gae},eie={null:[bk,$oe]},tie={null:[42,95]},nie={null:[]},rie=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers:tie,contentInitial:Koe,disable:nie,document:Yoe,flow:Zoe,flowInitial:Xoe,insideSpan:eie,string:Qoe,text:Joe},Symbol.toStringTag,{value:"Module"}));function aie(e,t,n){let r={_bufferIndex:-1,_index:0,line:n&&n.line||1,column:n&&n.column||1,offset:n&&n.offset||0};const a={},i=[];let l=[],u=[];const c={attempt:O(N),check:O(_),consume:x,enter:T,exit:C,interrupt:O(_,{interrupt:!0})},f={code:null,containerState:{},defineSkip:v,events:[],now:S,parser:e,previous:null,sliceSerialize:b,sliceStream:m,write:g};let p=t.tokenize.call(f,c);return t.resolveAll&&i.push(t),f;function g(H){return l=gr(l,H),A(),l[l.length-1]!==null?[]:(z(t,0),f.events=Gf(i,f.events,f),f.events)}function b(H,q){return iie(m(H),q)}function m(H){return oie(l,H)}function S(){const{_bufferIndex:H,_index:q,line:P,column:W,offset:Z}=r;return{_bufferIndex:H,_index:q,line:P,column:W,offset:Z}}function v(H){a[H.line]=H.column,M()}function A(){let H;for(;r._index<l.length;){const q=l[r._index];if(typeof q=="string")for(H=r._index,r._bufferIndex<0&&(r._bufferIndex=0);r._index===H&&r._bufferIndex<q.length;)R(q.charCodeAt(r._bufferIndex));else R(q)}}function R(H){p=p(H)}function x(H){$e(H)?(r.line++,r.column=1,r.offset+=H===-3?2:1,M()):H!==-1&&(r.column++,r.offset++),r._bufferIndex<0?r._index++:(r._bufferIndex++,r._bufferIndex===l[r._index].length&&(r._bufferIndex=-1,r._index++)),f.previous=H}function T(H,q){const P=q||{};return P.type=H,P.start=S(),f.events.push(["enter",P,f]),u.push(P),P}function C(H){const q=u.pop();return q.end=S(),f.events.push(["exit",q,f]),q}function N(H,q){z(H,q.from)}function _(H,q){q.restore()}function O(H,q){return P;function P(W,Z,j){let G,B,X,D;return Array.isArray(W)?U(W):"tokenize"in W?U([W]):V(W);function V(se){return re;function re(le){const Ae=le!==null&&se[le],ae=le!==null&&se.null,we=[...Array.isArray(Ae)?Ae:Ae?[Ae]:[],...Array.isArray(ae)?ae:ae?[ae]:[]];return U(we)(le)}}function U(se){return G=se,B=0,se.length===0?j:L(se[B])}function L(se){return re;function re(le){return D=I(),X=se,se.partial||(f.currentConstruct=se),se.name&&f.parser.constructs.disable.null.includes(se.name)?Q():se.tokenize.call(q?Object.assign(Object.create(f),q):f,c,Y,Q)(le)}}function Y(se){return H(X,D),Z}function Q(se){return D.restore(),++B<G.length?L(G[B]):j}}}function z(H,q){H.resolveAll&&!i.includes(H)&&i.push(H),H.resolve&&Qn(f.events,q,f.events.length-q,H.resolve(f.events.slice(q),f)),H.resolveTo&&(f.events=H.resolveTo(f.events,f))}function I(){const H=S(),q=f.previous,P=f.currentConstruct,W=f.events.length,Z=Array.from(u);return{from:W,restore:j};function j(){r=H,f.previous=q,f.currentConstruct=P,f.events.length=W,u=Z,M()}}function M(){r.line in a&&r.column<2&&(r.column=a[r.line],r.offset+=a[r.line]-1)}}function oie(e,t){const n=t.start._index,r=t.start._bufferIndex,a=t.end._index,i=t.end._bufferIndex;let l;if(n===a)l=[e[n].slice(r,i)];else{if(l=e.slice(n,a),r>-1){const u=l[0];typeof u=="string"?l[0]=u.slice(r):l.shift()}i>0&&l.push(e[a].slice(0,i))}return l}function iie(e,t){let n=-1;const r=[];let a;for(;++n<e.length;){const i=e[n];let l;if(typeof i=="string")l=i;else switch(i){case-5:{l="\r";break}case-4:{l=`
`;break}case-3:{l=`\r
`;break}case-2:{l=t?" ":"	";break}case-1:{if(!t&&a)continue;l=" ";break}default:l=String.fromCharCode(i)}a=i===-2,r.push(l)}return r.join("")}function lie(e){const r={constructs:qj([rie,...(e||{}).extensions||[]]),content:a(wae),defined:[],document:a(kae),flow:a(Goe),lazy:{},string:a(qoe),text:a(Voe)};return r;function a(i){return l;function l(u){return aie(r,i,u)}}}function sie(e){for(;!Xj(e););return e}const cO=/[\0\t\n\r]/g;function uie(){let e=1,t="",n=!0,r;return a;function a(i,l,u){const c=[];let f,p,g,b,m;for(i=t+(typeof i=="string"?i.toString():new TextDecoder(l||void 0).decode(i)),g=0,t="",n&&(i.charCodeAt(0)===65279&&g++,n=void 0);g<i.length;){if(cO.lastIndex=g,f=cO.exec(i),b=f&&f.index!==void 0?f.index:i.length,m=i.charCodeAt(b),!f){t=i.slice(g);break}if(m===10&&g===b&&r)c.push(-3),r=void 0;else switch(r&&(c.push(-5),r=void 0),g<b&&(c.push(i.slice(g,b)),e+=b-g),m){case 0:{c.push(65533),e++;break}case 9:{for(p=Math.ceil(e/4)*4,c.push(-2);e++<p;)c.push(-1);break}case 10:{c.push(-4),e=1;break}default:r=!0,e=1}g=b+1}return u&&(r&&c.push(-5),t&&c.push(t),c.push(null)),c}}const cie=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function die(e){return e.replace(cie,fie)}function fie(e,t,n){if(t)return t;if(n.charCodeAt(0)===35){const a=n.charCodeAt(1),i=a===120||a===88;return Vj(n.slice(i?2:1),i?16:10)}return K0(n)||e}const n5={}.hasOwnProperty;function pie(e,t,n){return typeof t!="string"&&(n=t,t=void 0),gie(n)(sie(lie(n).document().write(uie()(e,t,!0))))}function gie(e){const t={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:i(me),autolinkProtocol:I,autolinkEmail:I,atxHeading:i(Ee),blockQuote:i(ae),characterEscape:I,characterReference:I,codeFenced:i(we),codeFencedFenceInfo:l,codeFencedFenceMeta:l,codeIndented:i(we,l),codeText:i(xe,l),codeTextData:I,data:I,codeFlowValue:I,definition:i(Ie),definitionDestinationString:l,definitionLabelString:l,definitionTitleString:l,emphasis:i(Ce),hardBreakEscape:i(J),hardBreakTrailing:i(J),htmlFlow:i(fe,l),htmlFlowData:I,htmlText:i(fe,l),htmlTextData:I,image:i(ke),label:l,link:i(me),listItem:i(ie),listItemValue:b,listOrdered:i(ve,g),listUnordered:i(ve),paragraph:i(ze),reference:L,referenceString:l,resourceDestinationString:l,resourceTitleString:l,setextHeading:i(Ee),strong:i(Pe),thematicBreak:i(Ne)},exit:{atxHeading:c(),atxHeadingSequence:N,autolink:c(),autolinkEmail:Ae,autolinkProtocol:le,blockQuote:c(),characterEscapeValue:M,characterReferenceMarkerHexadecimal:Q,characterReferenceMarkerNumeric:Q,characterReferenceValue:se,characterReference:re,codeFenced:c(A),codeFencedFence:v,codeFencedFenceInfo:m,codeFencedFenceMeta:S,codeFlowValue:M,codeIndented:c(R),codeText:c(Z),codeTextData:M,data:M,definition:c(),definitionDestinationString:C,definitionLabelString:x,definitionTitleString:T,emphasis:c(),hardBreakEscape:c(q),hardBreakTrailing:c(q),htmlFlow:c(P),htmlFlowData:M,htmlText:c(W),htmlTextData:M,image:c(G),label:X,labelText:B,lineEnding:H,link:c(j),listItem:c(),listOrdered:c(),listUnordered:c(),paragraph:c(),referenceString:Y,resourceDestinationString:D,resourceTitleString:V,resource:U,setextHeading:c(z),setextHeadingLineSequence:O,setextHeadingText:_,strong:c(),thematicBreak:c()}};r5(t,(e||{}).mdastExtensions||[]);const n={};return r;function r(ee){let ce={type:"root",children:[]};const Re={stack:[ce],tokenStack:[],config:t,enter:u,exit:f,buffer:l,resume:p,data:n},Fe=[];let qe=-1;for(;++qe<ee.length;)if(ee[qe][1].type==="listOrdered"||ee[qe][1].type==="listUnordered")if(ee[qe][0]==="enter")Fe.push(qe);else{const mt=Fe.pop();qe=a(ee,mt,qe)}for(qe=-1;++qe<ee.length;){const mt=t[ee[qe][0]];n5.call(mt,ee[qe][1].type)&&mt[ee[qe][1].type].call(Object.assign({sliceSerialize:ee[qe][2].sliceSerialize},Re),ee[qe][1])}if(Re.tokenStack.length>0){const mt=Re.tokenStack[Re.tokenStack.length-1];(mt[1]||dO).call(Re,void 0,mt[0])}for(ce.position={start:uo(ee.length>0?ee[0][1].start:{line:1,column:1,offset:0}),end:uo(ee.length>0?ee[ee.length-2][1].end:{line:1,column:1,offset:0})},qe=-1;++qe<t.transforms.length;)ce=t.transforms[qe](ce)||ce;return ce}function a(ee,ce,Re){let Fe=ce-1,qe=-1,mt=!1,St,pt,Je,wt;for(;++Fe<=Re;){const rt=ee[Fe];switch(rt[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{rt[0]==="enter"?qe++:qe--,wt=void 0;break}case"lineEndingBlank":{rt[0]==="enter"&&(St&&!wt&&!qe&&!Je&&(Je=Fe),wt=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:wt=void 0}if(!qe&&rt[0]==="enter"&&rt[1].type==="listItemPrefix"||qe===-1&&rt[0]==="exit"&&(rt[1].type==="listUnordered"||rt[1].type==="listOrdered")){if(St){let bt=Fe;for(pt=void 0;bt--;){const Bt=ee[bt];if(Bt[1].type==="lineEnding"||Bt[1].type==="lineEndingBlank"){if(Bt[0]==="exit")continue;pt&&(ee[pt][1].type="lineEndingBlank",mt=!0),Bt[1].type="lineEnding",pt=bt}else if(!(Bt[1].type==="linePrefix"||Bt[1].type==="blockQuotePrefix"||Bt[1].type==="blockQuotePrefixWhitespace"||Bt[1].type==="blockQuoteMarker"||Bt[1].type==="listItemIndent"))break}Je&&(!pt||Je<pt)&&(St._spread=!0),St.end=Object.assign({},pt?ee[pt][1].start:rt[1].end),ee.splice(pt||Fe,0,["exit",St,rt[2]]),Fe++,Re++}if(rt[1].type==="listItemPrefix"){const bt={type:"listItem",_spread:!1,start:Object.assign({},rt[1].start),end:void 0};St=bt,ee.splice(Fe,0,["enter",bt,rt[2]]),Fe++,Re++,Je=void 0,wt=!0}}}return ee[ce][1]._spread=mt,Re}function i(ee,ce){return Re;function Re(Fe){u.call(this,ee(Fe),Fe),ce&&ce.call(this,Fe)}}function l(){this.stack.push({type:"fragment",children:[]})}function u(ee,ce,Re){this.stack[this.stack.length-1].children.push(ee),this.stack.push(ee),this.tokenStack.push([ce,Re||void 0]),ee.position={start:uo(ce.start),end:void 0}}function c(ee){return ce;function ce(Re){ee&&ee.call(this,Re),f.call(this,Re)}}function f(ee,ce){const Re=this.stack.pop(),Fe=this.tokenStack.pop();if(Fe)Fe[0].type!==ee.type&&(ce?ce.call(this,ee,Fe[0]):(Fe[1]||dO).call(this,ee,Fe[0]));else throw new Error("Cannot close `"+ee.type+"` ("+Xs({start:ee.start,end:ee.end})+"): it’s not open");Re.position.end=uo(ee.end)}function p(){return Y0(this.stack.pop())}function g(){this.data.expectingFirstListItemValue=!0}function b(ee){if(this.data.expectingFirstListItemValue){const ce=this.stack[this.stack.length-2];ce.start=Number.parseInt(this.sliceSerialize(ee),10),this.data.expectingFirstListItemValue=void 0}}function m(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.lang=ee}function S(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.meta=ee}function v(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function A(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.value=ee.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function R(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.value=ee.replace(/(\r?\n|\r)$/g,"")}function x(ee){const ce=this.resume(),Re=this.stack[this.stack.length-1];Re.label=ce,Re.identifier=Or(this.sliceSerialize(ee)).toLowerCase()}function T(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.title=ee}function C(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.url=ee}function N(ee){const ce=this.stack[this.stack.length-1];if(!ce.depth){const Re=this.sliceSerialize(ee).length;ce.depth=Re}}function _(){this.data.setextHeadingSlurpLineEnding=!0}function O(ee){const ce=this.stack[this.stack.length-1];ce.depth=this.sliceSerialize(ee).codePointAt(0)===61?1:2}function z(){this.data.setextHeadingSlurpLineEnding=void 0}function I(ee){const Re=this.stack[this.stack.length-1].children;let Fe=Re[Re.length-1];(!Fe||Fe.type!=="text")&&(Fe=he(),Fe.position={start:uo(ee.start),end:void 0},Re.push(Fe)),this.stack.push(Fe)}function M(ee){const ce=this.stack.pop();ce.value+=this.sliceSerialize(ee),ce.position.end=uo(ee.end)}function H(ee){const ce=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Re=ce.children[ce.children.length-1];Re.position.end=uo(ee.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&t.canContainEols.includes(ce.type)&&(I.call(this,ee),M.call(this,ee))}function q(){this.data.atHardBreak=!0}function P(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.value=ee}function W(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.value=ee}function Z(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.value=ee}function j(){const ee=this.stack[this.stack.length-1];if(this.data.inReference){const ce=this.data.referenceType||"shortcut";ee.type+="Reference",ee.referenceType=ce,delete ee.url,delete ee.title}else delete ee.identifier,delete ee.label;this.data.referenceType=void 0}function G(){const ee=this.stack[this.stack.length-1];if(this.data.inReference){const ce=this.data.referenceType||"shortcut";ee.type+="Reference",ee.referenceType=ce,delete ee.url,delete ee.title}else delete ee.identifier,delete ee.label;this.data.referenceType=void 0}function B(ee){const ce=this.sliceSerialize(ee),Re=this.stack[this.stack.length-2];Re.label=die(ce),Re.identifier=Or(ce).toLowerCase()}function X(){const ee=this.stack[this.stack.length-1],ce=this.resume(),Re=this.stack[this.stack.length-1];if(this.data.inReference=!0,Re.type==="link"){const Fe=ee.children;Re.children=Fe}else Re.alt=ce}function D(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.url=ee}function V(){const ee=this.resume(),ce=this.stack[this.stack.length-1];ce.title=ee}function U(){this.data.inReference=void 0}function L(){this.data.referenceType="collapsed"}function Y(ee){const ce=this.resume(),Re=this.stack[this.stack.length-1];Re.label=ce,Re.identifier=Or(this.sliceSerialize(ee)).toLowerCase(),this.data.referenceType="full"}function Q(ee){this.data.characterReferenceType=ee.type}function se(ee){const ce=this.sliceSerialize(ee),Re=this.data.characterReferenceType;let Fe;Re?(Fe=Vj(ce,Re==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):Fe=K0(ce);const qe=this.stack[this.stack.length-1];qe.value+=Fe}function re(ee){const ce=this.stack.pop();ce.position.end=uo(ee.end)}function le(ee){M.call(this,ee);const ce=this.stack[this.stack.length-1];ce.url=this.sliceSerialize(ee)}function Ae(ee){M.call(this,ee);const ce=this.stack[this.stack.length-1];ce.url="mailto:"+this.sliceSerialize(ee)}function ae(){return{type:"blockquote",children:[]}}function we(){return{type:"code",lang:null,meta:null,value:""}}function xe(){return{type:"inlineCode",value:""}}function Ie(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function Ce(){return{type:"emphasis",children:[]}}function Ee(){return{type:"heading",depth:0,children:[]}}function J(){return{type:"break"}}function fe(){return{type:"html",value:""}}function ke(){return{type:"image",title:null,url:"",alt:null}}function me(){return{type:"link",title:null,url:"",children:[]}}function ve(ee){return{type:"list",ordered:ee.type==="listOrdered",start:null,spread:ee._spread,children:[]}}function ie(ee){return{type:"listItem",spread:ee._spread,checked:null,children:[]}}function ze(){return{type:"paragraph",children:[]}}function Pe(){return{type:"strong",children:[]}}function he(){return{type:"text",value:""}}function Ne(){return{type:"thematicBreak"}}}function uo(e){return{line:e.line,column:e.column,offset:e.offset}}function r5(e,t){let n=-1;for(;++n<t.length;){const r=t[n];Array.isArray(r)?r5(e,r):hie(e,r)}}function hie(e,t){let n;for(n in t)if(n5.call(t,n))switch(n){case"canContainEols":{const r=t[n];r&&e[n].push(...r);break}case"transforms":{const r=t[n];r&&e[n].push(...r);break}case"enter":case"exit":{const r=t[n];r&&Object.assign(e[n],r);break}}}function dO(e,t){throw e?new Error("Cannot close `"+e.type+"` ("+Xs({start:e.start,end:e.end})+"): a different token (`"+t.type+"`, "+Xs({start:t.start,end:t.end})+") is open"):new Error("Cannot close document, a token (`"+t.type+"`, "+Xs({start:t.start,end:t.end})+") is still open")}function mie(e){const t=this;t.parser=n;function n(r){return pie(r,{...t.data("settings"),...e,extensions:t.data("micromarkExtensions")||[],mdastExtensions:t.data("fromMarkdownExtensions")||[]})}}function bie(e,t){const n={type:"element",tagName:"blockquote",properties:{},children:e.wrap(e.all(t),!0)};return e.patch(t,n),e.applyData(t,n)}function yie(e,t){const n={type:"element",tagName:"br",properties:{},children:[]};return e.patch(t,n),[e.applyData(t,n),{type:"text",value:`
`}]}function vie(e,t){const n=t.value?t.value+`
`:"",r={};t.lang&&(r.className=["language-"+t.lang]);let a={type:"element",tagName:"code",properties:r,children:[{type:"text",value:n}]};return t.meta&&(a.data={meta:t.meta}),e.patch(t,a),a=e.applyData(t,a),a={type:"element",tagName:"pre",properties:{},children:[a]},e.patch(t,a),a}function Sie(e,t){const n={type:"element",tagName:"del",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Eie(e,t){const n={type:"element",tagName:"em",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function wie(e,t){const n=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",r=String(t.identifier).toUpperCase(),a=Bl(r.toLowerCase()),i=e.footnoteOrder.indexOf(r);let l,u=e.footnoteCounts.get(r);u===void 0?(u=0,e.footnoteOrder.push(r),l=e.footnoteOrder.length):l=i+1,u+=1,e.footnoteCounts.set(r,u);const c={type:"element",tagName:"a",properties:{href:"#"+n+"fn-"+a,id:n+"fnref-"+a+(u>1?"-"+u:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(l)}]};e.patch(t,c);const f={type:"element",tagName:"sup",properties:{},children:[c]};return e.patch(t,f),e.applyData(t,f)}function xie(e,t){const n={type:"element",tagName:"h"+t.depth,properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function kie(e,t){if(e.options.allowDangerousHtml){const n={type:"raw",value:t.value};return e.patch(t,n),e.applyData(t,n)}}function a5(e,t){const n=t.referenceType;let r="]";if(n==="collapsed"?r+="[]":n==="full"&&(r+="["+(t.label||t.identifier)+"]"),t.type==="imageReference")return[{type:"text",value:"!["+t.alt+r}];const a=e.all(t),i=a[0];i&&i.type==="text"?i.value="["+i.value:a.unshift({type:"text",value:"["});const l=a[a.length-1];return l&&l.type==="text"?l.value+=r:a.push({type:"text",value:r}),a}function Aie(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return a5(e,t);const a={src:Bl(r.url||""),alt:t.alt};r.title!==null&&r.title!==void 0&&(a.title=r.title);const i={type:"element",tagName:"img",properties:a,children:[]};return e.patch(t,i),e.applyData(t,i)}function Tie(e,t){const n={src:Bl(t.url)};t.alt!==null&&t.alt!==void 0&&(n.alt=t.alt),t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"img",properties:n,children:[]};return e.patch(t,r),e.applyData(t,r)}function _ie(e,t){const n={type:"text",value:t.value.replace(/\r?\n|\r/g," ")};e.patch(t,n);const r={type:"element",tagName:"code",properties:{},children:[n]};return e.patch(t,r),e.applyData(t,r)}function Rie(e,t){const n=String(t.identifier).toUpperCase(),r=e.definitionById.get(n);if(!r)return a5(e,t);const a={href:Bl(r.url||"")};r.title!==null&&r.title!==void 0&&(a.title=r.title);const i={type:"element",tagName:"a",properties:a,children:e.all(t)};return e.patch(t,i),e.applyData(t,i)}function Cie(e,t){const n={href:Bl(t.url)};t.title!==null&&t.title!==void 0&&(n.title=t.title);const r={type:"element",tagName:"a",properties:n,children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function Nie(e,t,n){const r=e.all(t),a=n?Oie(n):o5(t),i={},l=[];if(typeof t.checked=="boolean"){const p=r[0];let g;p&&p.type==="element"&&p.tagName==="p"?g=p:(g={type:"element",tagName:"p",properties:{},children:[]},r.unshift(g)),g.children.length>0&&g.children.unshift({type:"text",value:" "}),g.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:t.checked,disabled:!0},children:[]}),i.className=["task-list-item"]}let u=-1;for(;++u<r.length;){const p=r[u];(a||u!==0||p.type!=="element"||p.tagName!=="p")&&l.push({type:"text",value:`
`}),p.type==="element"&&p.tagName==="p"&&!a?l.push(...p.children):l.push(p)}const c=r[r.length-1];c&&(a||c.type!=="element"||c.tagName!=="p")&&l.push({type:"text",value:`
`});const f={type:"element",tagName:"li",properties:i,children:l};return e.patch(t,f),e.applyData(t,f)}function Oie(e){let t=!1;if(e.type==="list"){t=e.spread||!1;const n=e.children;let r=-1;for(;!t&&++r<n.length;)t=o5(n[r])}return t}function o5(e){const t=e.spread;return t??e.children.length>1}function Die(e,t){const n={},r=e.all(t);let a=-1;for(typeof t.start=="number"&&t.start!==1&&(n.start=t.start);++a<r.length;){const l=r[a];if(l.type==="element"&&l.tagName==="li"&&l.properties&&Array.isArray(l.properties.className)&&l.properties.className.includes("task-list-item")){n.className=["contains-task-list"];break}}const i={type:"element",tagName:t.ordered?"ol":"ul",properties:n,children:e.wrap(r,!0)};return e.patch(t,i),e.applyData(t,i)}function Iie(e,t){const n={type:"element",tagName:"p",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Lie(e,t){const n={type:"root",children:e.wrap(e.all(t))};return e.patch(t,n),e.applyData(t,n)}function Mie(e,t){const n={type:"element",tagName:"strong",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}function Fie(e,t){const n=e.all(t),r=n.shift(),a=[];if(r){const l={type:"element",tagName:"thead",properties:{},children:e.wrap([r],!0)};e.patch(t.children[0],l),a.push(l)}if(n.length>0){const l={type:"element",tagName:"tbody",properties:{},children:e.wrap(n,!0)},u=$0(t.children[1]),c=zj(t.children[t.children.length-1]);u&&c&&(l.position={start:u,end:c}),a.push(l)}const i={type:"element",tagName:"table",properties:{},children:e.wrap(a,!0)};return e.patch(t,i),e.applyData(t,i)}function zie(e,t,n){const r=n?n.children:void 0,i=(r?r.indexOf(t):1)===0?"th":"td",l=n&&n.type==="table"?n.align:void 0,u=l?l.length:t.children.length;let c=-1;const f=[];for(;++c<u;){const g=t.children[c],b={},m=l?l[c]:void 0;m&&(b.align=m);let S={type:"element",tagName:i,properties:b,children:[]};g&&(S.children=e.all(g),e.patch(g,S),S=e.applyData(g,S)),f.push(S)}const p={type:"element",tagName:"tr",properties:{},children:e.wrap(f,!0)};return e.patch(t,p),e.applyData(t,p)}function Pie(e,t){const n={type:"element",tagName:"td",properties:{},children:e.all(t)};return e.patch(t,n),e.applyData(t,n)}const fO=9,pO=32;function Bie(e){const t=String(e),n=/\r?\n|\r/g;let r=n.exec(t),a=0;const i=[];for(;r;)i.push(gO(t.slice(a,r.index),a>0,!0),r[0]),a=r.index+r[0].length,r=n.exec(t);return i.push(gO(t.slice(a),a>0,!1)),i.join("")}function gO(e,t,n){let r=0,a=e.length;if(t){let i=e.codePointAt(r);for(;i===fO||i===pO;)r++,i=e.codePointAt(r)}if(n){let i=e.codePointAt(a-1);for(;i===fO||i===pO;)a--,i=e.codePointAt(a-1)}return a>r?e.slice(r,a):""}function Uie(e,t){const n={type:"text",value:Bie(String(t.value))};return e.patch(t,n),e.applyData(t,n)}function jie(e,t){const n={type:"element",tagName:"hr",properties:{},children:[]};return e.patch(t,n),e.applyData(t,n)}const Gie={blockquote:bie,break:yie,code:vie,delete:Sie,emphasis:Eie,footnoteReference:wie,heading:xie,html:kie,imageReference:Aie,image:Tie,inlineCode:_ie,linkReference:Rie,link:Cie,listItem:Nie,list:Die,paragraph:Iie,root:Lie,strong:Mie,table:Fie,tableCell:Pie,tableRow:zie,text:Uie,thematicBreak:jie,toml:id,yaml:id,definition:id,footnoteDefinition:id};function id(){}const i5=-1,Hf=0,Qs=1,Jd=2,Z0=3,Q0=4,J0=5,eA=6,l5=7,s5=8,hO=typeof self=="object"?self:globalThis,Hie=(e,t)=>{const n=(a,i)=>(e.set(i,a),a),r=a=>{if(e.has(a))return e.get(a);const[i,l]=t[a];switch(i){case Hf:case i5:return n(l,a);case Qs:{const u=n([],a);for(const c of l)u.push(r(c));return u}case Jd:{const u=n({},a);for(const[c,f]of l)u[r(c)]=r(f);return u}case Z0:return n(new Date(l),a);case Q0:{const{source:u,flags:c}=l;return n(new RegExp(u,c),a)}case J0:{const u=n(new Map,a);for(const[c,f]of l)u.set(r(c),r(f));return u}case eA:{const u=n(new Set,a);for(const c of l)u.add(r(c));return u}case l5:{const{name:u,message:c}=l;return n(new hO[u](c),a)}case s5:return n(BigInt(l),a);case"BigInt":return n(Object(BigInt(l)),a);case"ArrayBuffer":return n(new Uint8Array(l).buffer,l);case"DataView":{const{buffer:u}=new Uint8Array(l);return n(new DataView(u),l)}}return n(new hO[i](l),a)};return r},mO=e=>Hie(new Map,e)(0),rl="",{toString:$ie}={},{keys:qie}=Object,qs=e=>{const t=typeof e;if(t!=="object"||!e)return[Hf,t];const n=$ie.call(e).slice(8,-1);switch(n){case"Array":return[Qs,rl];case"Object":return[Jd,rl];case"Date":return[Z0,rl];case"RegExp":return[Q0,rl];case"Map":return[J0,rl];case"Set":return[eA,rl];case"DataView":return[Qs,n]}return n.includes("Array")?[Qs,n]:n.includes("Error")?[l5,n]:[Jd,n]},ld=([e,t])=>e===Hf&&(t==="function"||t==="symbol"),Vie=(e,t,n,r)=>{const a=(l,u)=>{const c=r.push(l)-1;return n.set(u,c),c},i=l=>{if(n.has(l))return n.get(l);let[u,c]=qs(l);switch(u){case Hf:{let p=l;switch(c){case"bigint":u=s5,p=l.toString();break;case"function":case"symbol":if(e)throw new TypeError("unable to serialize "+c);p=null;break;case"undefined":return a([i5],l)}return a([u,p],l)}case Qs:{if(c){let b=l;return c==="DataView"?b=new Uint8Array(l.buffer):c==="ArrayBuffer"&&(b=new Uint8Array(l)),a([c,[...b]],l)}const p=[],g=a([u,p],l);for(const b of l)p.push(i(b));return g}case Jd:{if(c)switch(c){case"BigInt":return a([c,l.toString()],l);case"Boolean":case"Number":case"String":return a([c,l.valueOf()],l)}if(t&&"toJSON"in l)return i(l.toJSON());const p=[],g=a([u,p],l);for(const b of qie(l))(e||!ld(qs(l[b])))&&p.push([i(b),i(l[b])]);return g}case Z0:return a([u,l.toISOString()],l);case Q0:{const{source:p,flags:g}=l;return a([u,{source:p,flags:g}],l)}case J0:{const p=[],g=a([u,p],l);for(const[b,m]of l)(e||!(ld(qs(b))||ld(qs(m))))&&p.push([i(b),i(m)]);return g}case eA:{const p=[],g=a([u,p],l);for(const b of l)(e||!ld(qs(b)))&&p.push(i(b));return g}}const{message:f}=l;return a([u,{name:c,message:f}],l)};return i},bO=(e,{json:t,lossy:n}={})=>{const r=[];return Vie(!(t||n),!!t,new Map,r)(e),r},ef=typeof structuredClone=="function"?(e,t)=>t&&("json"in t||"lossy"in t)?mO(bO(e,t)):structuredClone(e):(e,t)=>mO(bO(e,t));function Wie(e,t){const n=[{type:"text",value:"↩"}];return t>1&&n.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(t)}]}),n}function Yie(e,t){return"Back to reference "+(e+1)+(t>1?"-"+t:"")}function Kie(e){const t=typeof e.options.clobberPrefix=="string"?e.options.clobberPrefix:"user-content-",n=e.options.footnoteBackContent||Wie,r=e.options.footnoteBackLabel||Yie,a=e.options.footnoteLabel||"Footnotes",i=e.options.footnoteLabelTagName||"h2",l=e.options.footnoteLabelProperties||{className:["sr-only"]},u=[];let c=-1;for(;++c<e.footnoteOrder.length;){const f=e.footnoteById.get(e.footnoteOrder[c]);if(!f)continue;const p=e.all(f),g=String(f.identifier).toUpperCase(),b=Bl(g.toLowerCase());let m=0;const S=[],v=e.footnoteCounts.get(g);for(;v!==void 0&&++m<=v;){S.length>0&&S.push({type:"text",value:" "});let x=typeof n=="string"?n:n(c,m);typeof x=="string"&&(x={type:"text",value:x}),S.push({type:"element",tagName:"a",properties:{href:"#"+t+"fnref-"+b+(m>1?"-"+m:""),dataFootnoteBackref:"",ariaLabel:typeof r=="string"?r:r(c,m),className:["data-footnote-backref"]},children:Array.isArray(x)?x:[x]})}const A=p[p.length-1];if(A&&A.type==="element"&&A.tagName==="p"){const x=A.children[A.children.length-1];x&&x.type==="text"?x.value+=" ":A.children.push({type:"text",value:" "}),A.children.push(...S)}else p.push(...S);const R={type:"element",tagName:"li",properties:{id:t+"fn-"+b},children:e.wrap(p,!0)};e.patch(f,R),u.push(R)}if(u.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:i,properties:{...ef(l),id:"footnote-label"},children:[{type:"text",value:a}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:e.wrap(u,!0)},{type:"text",value:`
`}]}}const $f=function(e){if(e==null)return Jie;if(typeof e=="function")return qf(e);if(typeof e=="object")return Array.isArray(e)?Xie(e):Zie(e);if(typeof e=="string")return Qie(e);throw new Error("Expected function, string, or object as test")};function Xie(e){const t=[];let n=-1;for(;++n<e.length;)t[n]=$f(e[n]);return qf(r);function r(...a){let i=-1;for(;++i<t.length;)if(t[i].apply(this,a))return!0;return!1}}function Zie(e){const t=e;return qf(n);function n(r){const a=r;let i;for(i in e)if(a[i]!==t[i])return!1;return!0}}function Qie(e){return qf(t);function t(n){return n&&n.type===e}}function qf(e){return t;function t(n,r,a){return!!(ele(n)&&e.call(this,n,typeof r=="number"?r:void 0,a||void 0))}}function Jie(){return!0}function ele(e){return e!==null&&typeof e=="object"&&"type"in e}const u5=[],tle=!0,yk=!1,nle="skip";function c5(e,t,n,r){let a;typeof t=="function"&&typeof n!="function"?(r=n,n=t):a=t;const i=$f(a),l=r?-1:1;u(e,void 0,[])();function u(c,f,p){const g=c&&typeof c=="object"?c:{};if(typeof g.type=="string"){const m=typeof g.tagName=="string"?g.tagName:typeof g.name=="string"?g.name:void 0;Object.defineProperty(b,"name",{value:"node ("+(c.type+(m?"<"+m+">":""))+")"})}return b;function b(){let m=u5,S,v,A;if((!t||i(c,f,p[p.length-1]||void 0))&&(m=rle(n(c,p)),m[0]===yk))return m;if("children"in c&&c.children){const R=c;if(R.children&&m[0]!==nle)for(v=(r?R.children.length:-1)+l,A=p.concat(R);v>-1&&v<R.children.length;){const x=R.children[v];if(S=u(x,v,A)(),S[0]===yk)return S;v=typeof S[1]=="number"?S[1]:v+l}}return m}}}function rle(e){return Array.isArray(e)?e:typeof e=="number"?[tle,e]:e==null?u5:[e]}function tA(e,t,n,r){let a,i,l;typeof t=="function"?(i=void 0,l=t,a=n):(i=t,l=n,a=r),c5(e,i,u,a);function u(c,f){const p=f[f.length-1],g=p?p.children.indexOf(c):void 0;return l(c,g,p)}}const vk={}.hasOwnProperty,ale={};function ole(e,t){const n=t||ale,r=new Map,a=new Map,i=new Map,l={...Gie,...n.handlers},u={all:f,applyData:lle,definitionById:r,footnoteById:a,footnoteCounts:i,footnoteOrder:[],handlers:l,one:c,options:n,patch:ile,wrap:ule};return tA(e,function(p){if(p.type==="definition"||p.type==="footnoteDefinition"){const g=p.type==="definition"?r:a,b=String(p.identifier).toUpperCase();g.has(b)||g.set(b,p)}}),u;function c(p,g){const b=p.type,m=u.handlers[b];if(vk.call(u.handlers,b)&&m)return m(u,p,g);if(u.options.passThrough&&u.options.passThrough.includes(b)){if("children"in p){const{children:v,...A}=p,R=ef(A);return R.children=u.all(p),R}return ef(p)}return(u.options.unknownHandler||sle)(u,p,g)}function f(p){const g=[];if("children"in p){const b=p.children;let m=-1;for(;++m<b.length;){const S=u.one(b[m],p);if(S){if(m&&b[m-1].type==="break"&&(!Array.isArray(S)&&S.type==="text"&&(S.value=yO(S.value)),!Array.isArray(S)&&S.type==="element")){const v=S.children[0];v&&v.type==="text"&&(v.value=yO(v.value))}Array.isArray(S)?g.push(...S):g.push(S)}}}return g}}function ile(e,t){e.position&&(t.position=Wre(e))}function lle(e,t){let n=t;if(e&&e.data){const r=e.data.hName,a=e.data.hChildren,i=e.data.hProperties;if(typeof r=="string")if(n.type==="element")n.tagName=r;else{const l="children"in n?n.children:[n];n={type:"element",tagName:r,properties:{},children:l}}n.type==="element"&&i&&Object.assign(n.properties,ef(i)),"children"in n&&n.children&&a!==null&&a!==void 0&&(n.children=a)}return n}function sle(e,t){const n=t.data||{},r="value"in t&&!(vk.call(n,"hProperties")||vk.call(n,"hChildren"))?{type:"text",value:t.value}:{type:"element",tagName:"div",properties:{},children:e.all(t)};return e.patch(t,r),e.applyData(t,r)}function ule(e,t){const n=[];let r=-1;for(t&&n.push({type:"text",value:`
`});++r<e.length;)r&&n.push({type:"text",value:`
`}),n.push(e[r]);return t&&e.length>0&&n.push({type:"text",value:`
`}),n}function yO(e){let t=0,n=e.charCodeAt(t);for(;n===9||n===32;)t++,n=e.charCodeAt(t);return e.slice(t)}function vO(e,t){const n=ole(e,t),r=n.one(e,void 0),a=Kie(n),i=Array.isArray(r)?{type:"root",children:r}:r||{type:"root",children:[]};return a&&i.children.push({type:"text",value:`
`},a),i}function cle(e,t){return e&&"run"in e?async function(n,r){const a=vO(n,{file:r,...t});await e.run(a,r)}:function(n,r){return vO(n,{file:r,...e||t})}}function SO(e){if(e)throw e}var Am,EO;function dle(){if(EO)return Am;EO=1;var e=Object.prototype.hasOwnProperty,t=Object.prototype.toString,n=Object.defineProperty,r=Object.getOwnPropertyDescriptor,a=function(f){return typeof Array.isArray=="function"?Array.isArray(f):t.call(f)==="[object Array]"},i=function(f){if(!f||t.call(f)!=="[object Object]")return!1;var p=e.call(f,"constructor"),g=f.constructor&&f.constructor.prototype&&e.call(f.constructor.prototype,"isPrototypeOf");if(f.constructor&&!p&&!g)return!1;var b;for(b in f);return typeof b>"u"||e.call(f,b)},l=function(f,p){n&&p.name==="__proto__"?n(f,p.name,{enumerable:!0,configurable:!0,value:p.newValue,writable:!0}):f[p.name]=p.newValue},u=function(f,p){if(p==="__proto__")if(e.call(f,p)){if(r)return r(f,p).value}else return;return f[p]};return Am=function c(){var f,p,g,b,m,S,v=arguments[0],A=1,R=arguments.length,x=!1;for(typeof v=="boolean"&&(x=v,v=arguments[1]||{},A=2),(v==null||typeof v!="object"&&typeof v!="function")&&(v={});A<R;++A)if(f=arguments[A],f!=null)for(p in f)g=u(v,p),b=u(f,p),v!==b&&(x&&b&&(i(b)||(m=a(b)))?(m?(m=!1,S=g&&a(g)?g:[]):S=g&&i(g)?g:{},l(v,{name:p,newValue:c(x,S,b)})):typeof b<"u"&&l(v,{name:p,newValue:b}));return v},Am}var fle=dle();const Tm=an(fle);function Sk(e){if(typeof e!="object"||e===null)return!1;const t=Object.getPrototypeOf(e);return(t===null||t===Object.prototype||Object.getPrototypeOf(t)===null)&&!(Symbol.toStringTag in e)&&!(Symbol.iterator in e)}function ple(){const e=[],t={run:n,use:r};return t;function n(...a){let i=-1;const l=a.pop();if(typeof l!="function")throw new TypeError("Expected function as last argument, not "+l);u(null,...a);function u(c,...f){const p=e[++i];let g=-1;if(c){l(c);return}for(;++g<a.length;)(f[g]===null||f[g]===void 0)&&(f[g]=a[g]);a=f,p?gle(p,u)(...f):l(null,...f)}}function r(a){if(typeof a!="function")throw new TypeError("Expected `middelware` to be a function, not "+a);return e.push(a),t}}function gle(e,t){let n;return r;function r(...l){const u=e.length>l.length;let c;u&&l.push(a);try{c=e.apply(this,l)}catch(f){const p=f;if(u&&n)throw p;return a(p)}u||(c&&c.then&&typeof c.then=="function"?c.then(i,a):c instanceof Error?a(c):i(c))}function a(l,...u){n||(n=!0,t(l,...u))}function i(l){a(null,l)}}const qr={basename:hle,dirname:mle,extname:ble,join:yle,sep:"/"};function hle(e,t){if(t!==void 0&&typeof t!="string")throw new TypeError('"ext" argument must be a string');Ru(e);let n=0,r=-1,a=e.length,i;if(t===void 0||t.length===0||t.length>e.length){for(;a--;)if(e.codePointAt(a)===47){if(i){n=a+1;break}}else r<0&&(i=!0,r=a+1);return r<0?"":e.slice(n,r)}if(t===e)return"";let l=-1,u=t.length-1;for(;a--;)if(e.codePointAt(a)===47){if(i){n=a+1;break}}else l<0&&(i=!0,l=a+1),u>-1&&(e.codePointAt(a)===t.codePointAt(u--)?u<0&&(r=a):(u=-1,r=l));return n===r?r=l:r<0&&(r=e.length),e.slice(n,r)}function mle(e){if(Ru(e),e.length===0)return".";let t=-1,n=e.length,r;for(;--n;)if(e.codePointAt(n)===47){if(r){t=n;break}}else r||(r=!0);return t<0?e.codePointAt(0)===47?"/":".":t===1&&e.codePointAt(0)===47?"//":e.slice(0,t)}function ble(e){Ru(e);let t=e.length,n=-1,r=0,a=-1,i=0,l;for(;t--;){const u=e.codePointAt(t);if(u===47){if(l){r=t+1;break}continue}n<0&&(l=!0,n=t+1),u===46?a<0?a=t:i!==1&&(i=1):a>-1&&(i=-1)}return a<0||n<0||i===0||i===1&&a===n-1&&a===r+1?"":e.slice(a,n)}function yle(...e){let t=-1,n;for(;++t<e.length;)Ru(e[t]),e[t]&&(n=n===void 0?e[t]:n+"/"+e[t]);return n===void 0?".":vle(n)}function vle(e){Ru(e);const t=e.codePointAt(0)===47;let n=Sle(e,!t);return n.length===0&&!t&&(n="."),n.length>0&&e.codePointAt(e.length-1)===47&&(n+="/"),t?"/"+n:n}function Sle(e,t){let n="",r=0,a=-1,i=0,l=-1,u,c;for(;++l<=e.length;){if(l<e.length)u=e.codePointAt(l);else{if(u===47)break;u=47}if(u===47){if(!(a===l-1||i===1))if(a!==l-1&&i===2){if(n.length<2||r!==2||n.codePointAt(n.length-1)!==46||n.codePointAt(n.length-2)!==46){if(n.length>2){if(c=n.lastIndexOf("/"),c!==n.length-1){c<0?(n="",r=0):(n=n.slice(0,c),r=n.length-1-n.lastIndexOf("/")),a=l,i=0;continue}}else if(n.length>0){n="",r=0,a=l,i=0;continue}}t&&(n=n.length>0?n+"/..":"..",r=2)}else n.length>0?n+="/"+e.slice(a+1,l):n=e.slice(a+1,l),r=l-a-1;a=l,i=0}else u===46&&i>-1?i++:i=-1}return n}function Ru(e){if(typeof e!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(e))}const Ele={cwd:wle};function wle(){return"/"}function Ek(e){return!!(e!==null&&typeof e=="object"&&"href"in e&&e.href&&"protocol"in e&&e.protocol&&e.auth===void 0)}function xle(e){if(typeof e=="string")e=new URL(e);else if(!Ek(e)){const t=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+e+"`");throw t.code="ERR_INVALID_ARG_TYPE",t}if(e.protocol!=="file:"){const t=new TypeError("The URL must be of scheme file");throw t.code="ERR_INVALID_URL_SCHEME",t}return kle(e)}function kle(e){if(e.hostname!==""){const r=new TypeError('File URL host must be "localhost" or empty on darwin');throw r.code="ERR_INVALID_FILE_URL_HOST",r}const t=e.pathname;let n=-1;for(;++n<t.length;)if(t.codePointAt(n)===37&&t.codePointAt(n+1)===50){const r=t.codePointAt(n+2);if(r===70||r===102){const a=new TypeError("File URL path must not include encoded / characters");throw a.code="ERR_INVALID_FILE_URL_PATH",a}}return decodeURIComponent(t)}const _m=["history","path","basename","stem","extname","dirname"];class d5{constructor(t){let n;t?Ek(t)?n={path:t}:typeof t=="string"||Ale(t)?n={value:t}:n=t:n={},this.cwd="cwd"in n?"":Ele.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let r=-1;for(;++r<_m.length;){const i=_m[r];i in n&&n[i]!==void 0&&n[i]!==null&&(this[i]=i==="history"?[...n[i]]:n[i])}let a;for(a in n)_m.includes(a)||(this[a]=n[a])}get basename(){return typeof this.path=="string"?qr.basename(this.path):void 0}set basename(t){Cm(t,"basename"),Rm(t,"basename"),this.path=qr.join(this.dirname||"",t)}get dirname(){return typeof this.path=="string"?qr.dirname(this.path):void 0}set dirname(t){wO(this.basename,"dirname"),this.path=qr.join(t||"",this.basename)}get extname(){return typeof this.path=="string"?qr.extname(this.path):void 0}set extname(t){if(Rm(t,"extname"),wO(this.dirname,"extname"),t){if(t.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(t.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=qr.join(this.dirname,this.stem+(t||""))}get path(){return this.history[this.history.length-1]}set path(t){Ek(t)&&(t=xle(t)),Cm(t,"path"),this.path!==t&&this.history.push(t)}get stem(){return typeof this.path=="string"?qr.basename(this.path,this.extname):void 0}set stem(t){Cm(t,"stem"),Rm(t,"stem"),this.path=qr.join(this.dirname||"",t+(this.extname||""))}fail(t,n,r){const a=this.message(t,n,r);throw a.fatal=!0,a}info(t,n,r){const a=this.message(t,n,r);return a.fatal=void 0,a}message(t,n,r){const a=new xn(t,n,r);return this.path&&(a.name=this.path+":"+a.name,a.file=this.path),a.fatal=!1,this.messages.push(a),a}toString(t){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(t||void 0).decode(this.value)}}function Rm(e,t){if(e&&e.includes(qr.sep))throw new Error("`"+t+"` cannot be a path: did not expect `"+qr.sep+"`")}function Cm(e,t){if(!e)throw new Error("`"+t+"` cannot be empty")}function wO(e,t){if(!e)throw new Error("Setting `"+t+"` requires `path` to be set too")}function Ale(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const Tle=function(e){const r=this.constructor.prototype,a=r[e],i=function(){return a.apply(i,arguments)};return Object.setPrototypeOf(i,r),i},_le={}.hasOwnProperty;class nA extends Tle{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=ple()}copy(){const t=new nA;let n=-1;for(;++n<this.attachers.length;){const r=this.attachers[n];t.use(...r)}return t.data(Tm(!0,{},this.namespace)),t}data(t,n){return typeof t=="string"?arguments.length===2?(Dm("data",this.frozen),this.namespace[t]=n,this):_le.call(this.namespace,t)&&this.namespace[t]||void 0:t?(Dm("data",this.frozen),this.namespace=t,this):this.namespace}freeze(){if(this.frozen)return this;const t=this;for(;++this.freezeIndex<this.attachers.length;){const[n,...r]=this.attachers[this.freezeIndex];if(r[0]===!1)continue;r[0]===!0&&(r[0]=void 0);const a=n.call(t,...r);typeof a=="function"&&this.transformers.use(a)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(t){this.freeze();const n=sd(t),r=this.parser||this.Parser;return Nm("parse",r),r(String(n),n)}process(t,n){const r=this;return this.freeze(),Nm("process",this.parser||this.Parser),Om("process",this.compiler||this.Compiler),n?a(void 0,n):new Promise(a);function a(i,l){const u=sd(t),c=r.parse(u);r.run(c,u,function(p,g,b){if(p||!g||!b)return f(p);const m=g,S=r.stringify(m,b);Nle(S)?b.value=S:b.result=S,f(p,b)});function f(p,g){p||!g?l(p):i?i(g):n(void 0,g)}}}processSync(t){let n=!1,r;return this.freeze(),Nm("processSync",this.parser||this.Parser),Om("processSync",this.compiler||this.Compiler),this.process(t,a),kO("processSync","process",n),r;function a(i,l){n=!0,SO(i),r=l}}run(t,n,r){xO(t),this.freeze();const a=this.transformers;return!r&&typeof n=="function"&&(r=n,n=void 0),r?i(void 0,r):new Promise(i);function i(l,u){const c=sd(n);a.run(t,c,f);function f(p,g,b){const m=g||t;p?u(p):l?l(m):r(void 0,m,b)}}}runSync(t,n){let r=!1,a;return this.run(t,n,i),kO("runSync","run",r),a;function i(l,u){SO(l),a=u,r=!0}}stringify(t,n){this.freeze();const r=sd(n),a=this.compiler||this.Compiler;return Om("stringify",a),xO(t),a(t,r)}use(t,...n){const r=this.attachers,a=this.namespace;if(Dm("use",this.frozen),t!=null)if(typeof t=="function")c(t,n);else if(typeof t=="object")Array.isArray(t)?u(t):l(t);else throw new TypeError("Expected usable value, not `"+t+"`");return this;function i(f){if(typeof f=="function")c(f,[]);else if(typeof f=="object")if(Array.isArray(f)){const[p,...g]=f;c(p,g)}else l(f);else throw new TypeError("Expected usable value, not `"+f+"`")}function l(f){if(!("plugins"in f)&&!("settings"in f))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");u(f.plugins),f.settings&&(a.settings=Tm(!0,a.settings,f.settings))}function u(f){let p=-1;if(f!=null)if(Array.isArray(f))for(;++p<f.length;){const g=f[p];i(g)}else throw new TypeError("Expected a list of plugins, not `"+f+"`")}function c(f,p){let g=-1,b=-1;for(;++g<r.length;)if(r[g][0]===f){b=g;break}if(b===-1)r.push([f,...p]);else if(p.length>0){let[m,...S]=p;const v=r[b][1];Sk(v)&&Sk(m)&&(m=Tm(!0,v,m)),r[b]=[f,m,...S]}}}}const Rle=new nA().freeze();function Nm(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `parser`")}function Om(e,t){if(typeof t!="function")throw new TypeError("Cannot `"+e+"` without `compiler`")}function Dm(e,t){if(t)throw new Error("Cannot call `"+e+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function xO(e){if(!Sk(e)||typeof e.type!="string")throw new TypeError("Expected node, got `"+e+"`")}function kO(e,t,n){if(!n)throw new Error("`"+e+"` finished async. Use `"+t+"` instead")}function sd(e){return Cle(e)?e:new d5(e)}function Cle(e){return!!(e&&typeof e=="object"&&"message"in e&&"messages"in e)}function Nle(e){return typeof e=="string"||Ole(e)}function Ole(e){return!!(e&&typeof e=="object"&&"byteLength"in e&&"byteOffset"in e)}const Dle="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",AO=[],TO={allowDangerousHtml:!0},Ile=/^(https?|ircs?|mailto|xmpp)$/i,Lle=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function Mle(e){const t=Fle(e),n=zle(e);return Ple(t.runSync(t.parse(n),n),e)}function Fle(e){const t=e.rehypePlugins||AO,n=e.remarkPlugins||AO,r=e.remarkRehypeOptions?{...e.remarkRehypeOptions,...TO}:TO;return Rle().use(mie).use(n).use(cle,r).use(t)}function zle(e){const t=e.children||"",n=new d5;return typeof t=="string"&&(n.value=t),n}function Ple(e,t){const n=t.allowedElements,r=t.allowElement,a=t.components,i=t.disallowedElements,l=t.skipHtml,u=t.unwrapDisallowed,c=t.urlTransform||Ble;for(const p of Lle)Object.hasOwn(t,p.from)&&(""+p.from+(p.to?"use `"+p.to+"` instead":"remove it")+Dle+p.id,void 0);return t.className&&(e={type:"element",tagName:"div",properties:{className:t.className},children:e.type==="root"?e.children:[e]}),tA(e,f),Uj(e,{Fragment:w.Fragment,components:a,ignoreInvalidStyle:!0,jsx:w.jsx,jsxs:w.jsxs,passKeys:!0,passNode:!0});function f(p,g,b){if(p.type==="raw"&&b&&typeof g=="number")return l?b.children.splice(g,1):b.children[g]={type:"text",value:p.value},g;if(p.type==="element"){let m;for(m in wm)if(Object.hasOwn(wm,m)&&Object.hasOwn(p.properties,m)){const S=p.properties[m],v=wm[m];(v===null||v.includes(p.tagName))&&(p.properties[m]=c(String(S||""),m,p))}}if(p.type==="element"){let m=n?!n.includes(p.tagName):i?i.includes(p.tagName):!1;if(!m&&r&&typeof g=="number"&&(m=!r(p,g,b)),m&&b&&typeof g=="number")return u&&p.children?b.children.splice(g,1,...p.children):b.children.splice(g,1),g}}}function Ble(e){const t=e.indexOf(":"),n=e.indexOf("?"),r=e.indexOf("#"),a=e.indexOf("/");return t===-1||a!==-1&&t>a||n!==-1&&t>n||r!==-1&&t>r||Ile.test(e.slice(0,t))?e:""}function _O(e,t){const n=String(e);if(typeof t!="string")throw new TypeError("Expected character");let r=0,a=n.indexOf(t);for(;a!==-1;)r++,a=n.indexOf(t,a+t.length);return r}function Ule(e){if(typeof e!="string")throw new TypeError("Expected a string");return e.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function jle(e,t,n){const a=$f((n||{}).ignore||[]),i=Gle(t);let l=-1;for(;++l<i.length;)c5(e,"text",u);function u(f,p){let g=-1,b;for(;++g<p.length;){const m=p[g],S=b?b.children:void 0;if(a(m,S?S.indexOf(m):void 0,b))return;b=m}if(b)return c(f,p)}function c(f,p){const g=p[p.length-1],b=i[l][0],m=i[l][1];let S=0;const A=g.children.indexOf(f);let R=!1,x=[];b.lastIndex=0;let T=b.exec(f.value);for(;T;){const C=T.index,N={index:T.index,input:T.input,stack:[...p,f]};let _=m(...T,N);if(typeof _=="string"&&(_=_.length>0?{type:"text",value:_}:void 0),_===!1?b.lastIndex=C+1:(S!==C&&x.push({type:"text",value:f.value.slice(S,C)}),Array.isArray(_)?x.push(..._):_&&x.push(_),S=C+T[0].length,R=!0),!b.global)break;T=b.exec(f.value)}return R?(S<f.value.length&&x.push({type:"text",value:f.value.slice(S)}),g.children.splice(A,1,...x)):x=[f],A+x.length}}function Gle(e){const t=[];if(!Array.isArray(e))throw new TypeError("Expected find and replace tuple or list of tuples");const n=!e[0]||Array.isArray(e[0])?e:[e];let r=-1;for(;++r<n.length;){const a=n[r];t.push([Hle(a[0]),$le(a[1])])}return t}function Hle(e){return typeof e=="string"?new RegExp(Ule(e),"g"):e}function $le(e){return typeof e=="function"?e:function(){return e}}const Im="phrasing",Lm=["autolink","link","image","label"];function qle(){return{transforms:[Qle],enter:{literalAutolink:Wle,literalAutolinkEmail:Mm,literalAutolinkHttp:Mm,literalAutolinkWww:Mm},exit:{literalAutolink:Zle,literalAutolinkEmail:Xle,literalAutolinkHttp:Yle,literalAutolinkWww:Kle}}}function Vle(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct:Im,notInConstruct:Lm},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct:Im,notInConstruct:Lm},{character:":",before:"[ps]",after:"\\/",inConstruct:Im,notInConstruct:Lm}]}}function Wle(e){this.enter({type:"link",title:null,url:"",children:[]},e)}function Mm(e){this.config.enter.autolinkProtocol.call(this,e)}function Yle(e){this.config.exit.autolinkProtocol.call(this,e)}function Kle(e){this.config.exit.data.call(this,e);const t=this.stack[this.stack.length-1];t.type,t.url="http://"+this.sliceSerialize(e)}function Xle(e){this.config.exit.autolinkEmail.call(this,e)}function Zle(e){this.exit(e)}function Qle(e){jle(e,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,Jle],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),ese]],{ignore:["link","linkReference"]})}function Jle(e,t,n,r,a){let i="";if(!f5(a)||(/^w/i.test(t)&&(n=t+n,t="",i="http://"),!tse(n)))return!1;const l=nse(n+r);if(!l[0])return!1;const u={type:"link",title:null,url:i+t+l[0],children:[{type:"text",value:t+l[0]}]};return l[1]?[u,{type:"text",value:l[1]}]:u}function ese(e,t,n,r){return!f5(r,!0)||/[-\d_]$/.test(n)?!1:{type:"link",title:null,url:"mailto:"+t+"@"+n,children:[{type:"text",value:t+"@"+n}]}}function tse(e){const t=e.split(".");return!(t.length<2||t[t.length-1]&&(/_/.test(t[t.length-1])||!/[a-zA-Z\d]/.test(t[t.length-1]))||t[t.length-2]&&(/_/.test(t[t.length-2])||!/[a-zA-Z\d]/.test(t[t.length-2])))}function nse(e){const t=/[!"&'),.:;<>?\]}]+$/.exec(e);if(!t)return[e,void 0];e=e.slice(0,t.index);let n=t[0],r=n.indexOf(")");const a=_O(e,"(");let i=_O(e,")");for(;r!==-1&&a>i;)e+=n.slice(0,r+1),n=n.slice(r+1),r=n.indexOf(")"),i++;return[e,n]}function f5(e,t){const n=e.input.charCodeAt(e.index-1);return(e.index===0||ui(n)||jf(n))&&(!t||n!==47)}p5.peek=dse;function rse(){this.buffer()}function ase(e){this.enter({type:"footnoteReference",identifier:"",label:""},e)}function ose(){this.buffer()}function ise(e){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},e)}function lse(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Or(this.sliceSerialize(e)).toLowerCase(),n.label=t}function sse(e){this.exit(e)}function use(e){const t=this.resume(),n=this.stack[this.stack.length-1];n.type,n.identifier=Or(this.sliceSerialize(e)).toLowerCase(),n.label=t}function cse(e){this.exit(e)}function dse(){return"["}function p5(e,t,n,r){const a=n.createTracker(r);let i=a.move("[^");const l=n.enter("footnoteReference"),u=n.enter("reference");return i+=a.move(n.safe(n.associationId(e),{after:"]",before:i})),u(),l(),i+=a.move("]"),i}function fse(){return{enter:{gfmFootnoteCallString:rse,gfmFootnoteCall:ase,gfmFootnoteDefinitionLabelString:ose,gfmFootnoteDefinition:ise},exit:{gfmFootnoteCallString:lse,gfmFootnoteCall:sse,gfmFootnoteDefinitionLabelString:use,gfmFootnoteDefinition:cse}}}function pse(e){let t=!1;return e&&e.firstLineBlank&&(t=!0),{handlers:{footnoteDefinition:n,footnoteReference:p5},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function n(r,a,i,l){const u=i.createTracker(l);let c=u.move("[^");const f=i.enter("footnoteDefinition"),p=i.enter("label");return c+=u.move(i.safe(i.associationId(r),{before:c,after:"]"})),p(),c+=u.move("]:"),r.children&&r.children.length>0&&(u.shift(4),c+=u.move((t?`
`:" ")+i.indentLines(i.containerFlow(r,u.current()),t?g5:gse))),f(),c}}function gse(e,t,n){return t===0?e:g5(e,t,n)}function g5(e,t,n){return(n?"":"    ")+e}const hse=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];h5.peek=Sse;function mse(){return{canContainEols:["delete"],enter:{strikethrough:yse},exit:{strikethrough:vse}}}function bse(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:hse}],handlers:{delete:h5}}}function yse(e){this.enter({type:"delete",children:[]},e)}function vse(e){this.exit(e)}function h5(e,t,n,r){const a=n.createTracker(r),i=n.enter("strikethrough");let l=a.move("~~");return l+=n.containerPhrasing(e,{...a.current(),before:l,after:"~"}),l+=a.move("~~"),i(),l}function Sse(){return"~"}function Ese(e){return e.length}function wse(e,t){const n=t||{},r=(n.align||[]).concat(),a=n.stringLength||Ese,i=[],l=[],u=[],c=[];let f=0,p=-1;for(;++p<e.length;){const v=[],A=[];let R=-1;for(e[p].length>f&&(f=e[p].length);++R<e[p].length;){const x=xse(e[p][R]);if(n.alignDelimiters!==!1){const T=a(x);A[R]=T,(c[R]===void 0||T>c[R])&&(c[R]=T)}v.push(x)}l[p]=v,u[p]=A}let g=-1;if(typeof r=="object"&&"length"in r)for(;++g<f;)i[g]=RO(r[g]);else{const v=RO(r);for(;++g<f;)i[g]=v}g=-1;const b=[],m=[];for(;++g<f;){const v=i[g];let A="",R="";v===99?(A=":",R=":"):v===108?A=":":v===114&&(R=":");let x=n.alignDelimiters===!1?1:Math.max(1,c[g]-A.length-R.length);const T=A+"-".repeat(x)+R;n.alignDelimiters!==!1&&(x=A.length+x+R.length,x>c[g]&&(c[g]=x),m[g]=x),b[g]=T}l.splice(1,0,b),u.splice(1,0,m),p=-1;const S=[];for(;++p<l.length;){const v=l[p],A=u[p];g=-1;const R=[];for(;++g<f;){const x=v[g]||"";let T="",C="";if(n.alignDelimiters!==!1){const N=c[g]-(A[g]||0),_=i[g];_===114?T=" ".repeat(N):_===99?N%2?(T=" ".repeat(N/2+.5),C=" ".repeat(N/2-.5)):(T=" ".repeat(N/2),C=T):C=" ".repeat(N)}n.delimiterStart!==!1&&!g&&R.push("|"),n.padding!==!1&&!(n.alignDelimiters===!1&&x==="")&&(n.delimiterStart!==!1||g)&&R.push(" "),n.alignDelimiters!==!1&&R.push(T),R.push(x),n.alignDelimiters!==!1&&R.push(C),n.padding!==!1&&R.push(" "),(n.delimiterEnd!==!1||g!==f-1)&&R.push("|")}S.push(n.delimiterEnd===!1?R.join("").replace(/ +$/,""):R.join(""))}return S.join(`
`)}function xse(e){return e==null?"":String(e)}function RO(e){const t=typeof e=="string"?e.codePointAt(0):0;return t===67||t===99?99:t===76||t===108?108:t===82||t===114?114:0}function kse(e,t,n,r){const a=n.enter("blockquote"),i=n.createTracker(r);i.move("> "),i.shift(2);const l=n.indentLines(n.containerFlow(e,i.current()),Ase);return a(),l}function Ase(e,t,n){return">"+(n?"":" ")+e}function Tse(e,t){return CO(e,t.inConstruct,!0)&&!CO(e,t.notInConstruct,!1)}function CO(e,t,n){if(typeof t=="string"&&(t=[t]),!t||t.length===0)return n;let r=-1;for(;++r<t.length;)if(e.includes(t[r]))return!0;return!1}function NO(e,t,n,r){let a=-1;for(;++a<n.unsafe.length;)if(n.unsafe[a].character===`
`&&Tse(n.stack,n.unsafe[a]))return/[ \t]/.test(r.before)?"":" ";return`\\
`}function m5(e,t){const n=String(e);let r=n.indexOf(t),a=r,i=0,l=0;if(typeof t!="string")throw new TypeError("Expected substring");for(;r!==-1;)r===a?++i>l&&(l=i):i=1,a=r+t.length,r=n.indexOf(t,a);return l}function _se(e,t){return!!(t.options.fences===!1&&e.value&&!e.lang&&/[^ \r\n]/.test(e.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(e.value))}function Rse(e){const t=e.options.fence||"`";if(t!=="`"&&t!=="~")throw new Error("Cannot serialize code with `"+t+"` for `options.fence`, expected `` ` `` or `~`");return t}function Cse(e,t,n,r){const a=Rse(n),i=e.value||"",l=a==="`"?"GraveAccent":"Tilde";if(_se(e,n)){const g=n.enter("codeIndented"),b=n.indentLines(i,Nse);return g(),b}const u=n.createTracker(r),c=a.repeat(Math.max(m5(i,a)+1,3)),f=n.enter("codeFenced");let p=u.move(c);if(e.lang){const g=n.enter(`codeFencedLang${l}`);p+=u.move(n.safe(e.lang,{before:p,after:" ",encode:["`"],...u.current()})),g()}if(e.lang&&e.meta){const g=n.enter(`codeFencedMeta${l}`);p+=u.move(" "),p+=u.move(n.safe(e.meta,{before:p,after:`
`,encode:["`"],...u.current()})),g()}return p+=u.move(`
`),i&&(p+=u.move(i+`
`)),p+=u.move(c),f(),p}function Nse(e,t,n){return(n?"":"    ")+e}function rA(e){const t=e.options.quote||'"';if(t!=='"'&&t!=="'")throw new Error("Cannot serialize title with `"+t+"` for `options.quote`, expected `\"`, or `'`");return t}function Ose(e,t,n,r){const a=rA(n),i=a==='"'?"Quote":"Apostrophe",l=n.enter("definition");let u=n.enter("label");const c=n.createTracker(r);let f=c.move("[");return f+=c.move(n.safe(n.associationId(e),{before:f,after:"]",...c.current()})),f+=c.move("]: "),u(),!e.url||/[\0- \u007F]/.test(e.url)?(u=n.enter("destinationLiteral"),f+=c.move("<"),f+=c.move(n.safe(e.url,{before:f,after:">",...c.current()})),f+=c.move(">")):(u=n.enter("destinationRaw"),f+=c.move(n.safe(e.url,{before:f,after:e.title?" ":`
`,...c.current()}))),u(),e.title&&(u=n.enter(`title${i}`),f+=c.move(" "+a),f+=c.move(n.safe(e.title,{before:f,after:a,...c.current()})),f+=c.move(a),u()),l(),f}function Dse(e){const t=e.options.emphasis||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize emphasis with `"+t+"` for `options.emphasis`, expected `*`, or `_`");return t}function du(e){return"&#x"+e.toString(16).toUpperCase()+";"}function tf(e,t,n){const r=xl(e),a=xl(t);return r===void 0?a===void 0?n==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:r===1?a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:a===void 0?{inside:!1,outside:!1}:a===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}b5.peek=Ise;function b5(e,t,n,r){const a=Dse(n),i=n.enter("emphasis"),l=n.createTracker(r),u=l.move(a);let c=l.move(n.containerPhrasing(e,{after:a,before:u,...l.current()}));const f=c.charCodeAt(0),p=tf(r.before.charCodeAt(r.before.length-1),f,a);p.inside&&(c=du(f)+c.slice(1));const g=c.charCodeAt(c.length-1),b=tf(r.after.charCodeAt(0),g,a);b.inside&&(c=c.slice(0,-1)+du(g));const m=l.move(a);return i(),n.attentionEncodeSurroundingInfo={after:b.outside,before:p.outside},u+c+m}function Ise(e,t,n){return n.options.emphasis||"*"}function Lse(e,t){let n=!1;return tA(e,function(r){if("value"in r&&/\r?\n|\r/.test(r.value)||r.type==="break")return n=!0,yk}),!!((!e.depth||e.depth<3)&&Y0(e)&&(t.options.setext||n))}function Mse(e,t,n,r){const a=Math.max(Math.min(6,e.depth||1),1),i=n.createTracker(r);if(Lse(e,n)){const p=n.enter("headingSetext"),g=n.enter("phrasing"),b=n.containerPhrasing(e,{...i.current(),before:`
`,after:`
`});return g(),p(),b+`
`+(a===1?"=":"-").repeat(b.length-(Math.max(b.lastIndexOf("\r"),b.lastIndexOf(`
`))+1))}const l="#".repeat(a),u=n.enter("headingAtx"),c=n.enter("phrasing");i.move(l+" ");let f=n.containerPhrasing(e,{before:"# ",after:`
`,...i.current()});return/^[\t ]/.test(f)&&(f=du(f.charCodeAt(0))+f.slice(1)),f=f?l+" "+f:l,n.options.closeAtx&&(f+=" "+l),c(),u(),f}y5.peek=Fse;function y5(e){return e.value||""}function Fse(){return"<"}v5.peek=zse;function v5(e,t,n,r){const a=rA(n),i=a==='"'?"Quote":"Apostrophe",l=n.enter("image");let u=n.enter("label");const c=n.createTracker(r);let f=c.move("![");return f+=c.move(n.safe(e.alt,{before:f,after:"]",...c.current()})),f+=c.move("]("),u(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(u=n.enter("destinationLiteral"),f+=c.move("<"),f+=c.move(n.safe(e.url,{before:f,after:">",...c.current()})),f+=c.move(">")):(u=n.enter("destinationRaw"),f+=c.move(n.safe(e.url,{before:f,after:e.title?" ":")",...c.current()}))),u(),e.title&&(u=n.enter(`title${i}`),f+=c.move(" "+a),f+=c.move(n.safe(e.title,{before:f,after:a,...c.current()})),f+=c.move(a),u()),f+=c.move(")"),l(),f}function zse(){return"!"}S5.peek=Pse;function S5(e,t,n,r){const a=e.referenceType,i=n.enter("imageReference");let l=n.enter("label");const u=n.createTracker(r);let c=u.move("![");const f=n.safe(e.alt,{before:c,after:"]",...u.current()});c+=u.move(f+"]["),l();const p=n.stack;n.stack=[],l=n.enter("reference");const g=n.safe(n.associationId(e),{before:c,after:"]",...u.current()});return l(),n.stack=p,i(),a==="full"||!f||f!==g?c+=u.move(g+"]"):a==="shortcut"?c=c.slice(0,-1):c+=u.move("]"),c}function Pse(){return"!"}E5.peek=Bse;function E5(e,t,n){let r=e.value||"",a="`",i=-1;for(;new RegExp("(^|[^`])"+a+"([^`]|$)").test(r);)a+="`";for(/[^ \r\n]/.test(r)&&(/^[ \r\n]/.test(r)&&/[ \r\n]$/.test(r)||/^`|`$/.test(r))&&(r=" "+r+" ");++i<n.unsafe.length;){const l=n.unsafe[i],u=n.compilePattern(l);let c;if(l.atBreak)for(;c=u.exec(r);){let f=c.index;r.charCodeAt(f)===10&&r.charCodeAt(f-1)===13&&f--,r=r.slice(0,f)+" "+r.slice(c.index+1)}}return a+r+a}function Bse(){return"`"}function w5(e,t){const n=Y0(e);return!!(!t.options.resourceLink&&e.url&&!e.title&&e.children&&e.children.length===1&&e.children[0].type==="text"&&(n===e.url||"mailto:"+n===e.url)&&/^[a-z][a-z+.-]+:/i.test(e.url)&&!/[\0- <>\u007F]/.test(e.url))}x5.peek=Use;function x5(e,t,n,r){const a=rA(n),i=a==='"'?"Quote":"Apostrophe",l=n.createTracker(r);let u,c;if(w5(e,n)){const p=n.stack;n.stack=[],u=n.enter("autolink");let g=l.move("<");return g+=l.move(n.containerPhrasing(e,{before:g,after:">",...l.current()})),g+=l.move(">"),u(),n.stack=p,g}u=n.enter("link"),c=n.enter("label");let f=l.move("[");return f+=l.move(n.containerPhrasing(e,{before:f,after:"](",...l.current()})),f+=l.move("]("),c(),!e.url&&e.title||/[\0- \u007F]/.test(e.url)?(c=n.enter("destinationLiteral"),f+=l.move("<"),f+=l.move(n.safe(e.url,{before:f,after:">",...l.current()})),f+=l.move(">")):(c=n.enter("destinationRaw"),f+=l.move(n.safe(e.url,{before:f,after:e.title?" ":")",...l.current()}))),c(),e.title&&(c=n.enter(`title${i}`),f+=l.move(" "+a),f+=l.move(n.safe(e.title,{before:f,after:a,...l.current()})),f+=l.move(a),c()),f+=l.move(")"),u(),f}function Use(e,t,n){return w5(e,n)?"<":"["}k5.peek=jse;function k5(e,t,n,r){const a=e.referenceType,i=n.enter("linkReference");let l=n.enter("label");const u=n.createTracker(r);let c=u.move("[");const f=n.containerPhrasing(e,{before:c,after:"]",...u.current()});c+=u.move(f+"]["),l();const p=n.stack;n.stack=[],l=n.enter("reference");const g=n.safe(n.associationId(e),{before:c,after:"]",...u.current()});return l(),n.stack=p,i(),a==="full"||!f||f!==g?c+=u.move(g+"]"):a==="shortcut"?c=c.slice(0,-1):c+=u.move("]"),c}function jse(){return"["}function aA(e){const t=e.options.bullet||"*";if(t!=="*"&&t!=="+"&&t!=="-")throw new Error("Cannot serialize items with `"+t+"` for `options.bullet`, expected `*`, `+`, or `-`");return t}function Gse(e){const t=aA(e),n=e.options.bulletOther;if(!n)return t==="*"?"-":"*";if(n!=="*"&&n!=="+"&&n!=="-")throw new Error("Cannot serialize items with `"+n+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(n===t)throw new Error("Expected `bullet` (`"+t+"`) and `bulletOther` (`"+n+"`) to be different");return n}function Hse(e){const t=e.options.bulletOrdered||".";if(t!=="."&&t!==")")throw new Error("Cannot serialize items with `"+t+"` for `options.bulletOrdered`, expected `.` or `)`");return t}function A5(e){const t=e.options.rule||"*";if(t!=="*"&&t!=="-"&&t!=="_")throw new Error("Cannot serialize rules with `"+t+"` for `options.rule`, expected `*`, `-`, or `_`");return t}function $se(e,t,n,r){const a=n.enter("list"),i=n.bulletCurrent;let l=e.ordered?Hse(n):aA(n);const u=e.ordered?l==="."?")":".":Gse(n);let c=t&&n.bulletLastUsed?l===n.bulletLastUsed:!1;if(!e.ordered){const p=e.children?e.children[0]:void 0;if((l==="*"||l==="-")&&p&&(!p.children||!p.children[0])&&n.stack[n.stack.length-1]==="list"&&n.stack[n.stack.length-2]==="listItem"&&n.stack[n.stack.length-3]==="list"&&n.stack[n.stack.length-4]==="listItem"&&n.indexStack[n.indexStack.length-1]===0&&n.indexStack[n.indexStack.length-2]===0&&n.indexStack[n.indexStack.length-3]===0&&(c=!0),A5(n)===l&&p){let g=-1;for(;++g<e.children.length;){const b=e.children[g];if(b&&b.type==="listItem"&&b.children&&b.children[0]&&b.children[0].type==="thematicBreak"){c=!0;break}}}}c&&(l=u),n.bulletCurrent=l;const f=n.containerFlow(e,r);return n.bulletLastUsed=l,n.bulletCurrent=i,a(),f}function qse(e){const t=e.options.listItemIndent||"one";if(t!=="tab"&&t!=="one"&&t!=="mixed")throw new Error("Cannot serialize items with `"+t+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return t}function Vse(e,t,n,r){const a=qse(n);let i=n.bulletCurrent||aA(n);t&&t.type==="list"&&t.ordered&&(i=(typeof t.start=="number"&&t.start>-1?t.start:1)+(n.options.incrementListMarker===!1?0:t.children.indexOf(e))+i);let l=i.length+1;(a==="tab"||a==="mixed"&&(t&&t.type==="list"&&t.spread||e.spread))&&(l=Math.ceil(l/4)*4);const u=n.createTracker(r);u.move(i+" ".repeat(l-i.length)),u.shift(l);const c=n.enter("listItem"),f=n.indentLines(n.containerFlow(e,u.current()),p);return c(),f;function p(g,b,m){return b?(m?"":" ".repeat(l))+g:(m?i:i+" ".repeat(l-i.length))+g}}function Wse(e,t,n,r){const a=n.enter("paragraph"),i=n.enter("phrasing"),l=n.containerPhrasing(e,r);return i(),a(),l}const Yse=$f(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function Kse(e,t,n,r){return(e.children.some(function(l){return Yse(l)})?n.containerPhrasing:n.containerFlow).call(n,e,r)}function Xse(e){const t=e.options.strong||"*";if(t!=="*"&&t!=="_")throw new Error("Cannot serialize strong with `"+t+"` for `options.strong`, expected `*`, or `_`");return t}T5.peek=Zse;function T5(e,t,n,r){const a=Xse(n),i=n.enter("strong"),l=n.createTracker(r),u=l.move(a+a);let c=l.move(n.containerPhrasing(e,{after:a,before:u,...l.current()}));const f=c.charCodeAt(0),p=tf(r.before.charCodeAt(r.before.length-1),f,a);p.inside&&(c=du(f)+c.slice(1));const g=c.charCodeAt(c.length-1),b=tf(r.after.charCodeAt(0),g,a);b.inside&&(c=c.slice(0,-1)+du(g));const m=l.move(a+a);return i(),n.attentionEncodeSurroundingInfo={after:b.outside,before:p.outside},u+c+m}function Zse(e,t,n){return n.options.strong||"*"}function Qse(e,t,n,r){return n.safe(e.value,r)}function Jse(e){const t=e.options.ruleRepetition||3;if(t<3)throw new Error("Cannot serialize rules with repetition `"+t+"` for `options.ruleRepetition`, expected `3` or more");return t}function eue(e,t,n){const r=(A5(n)+(n.options.ruleSpaces?" ":"")).repeat(Jse(n));return n.options.ruleSpaces?r.slice(0,-1):r}const _5={blockquote:kse,break:NO,code:Cse,definition:Ose,emphasis:b5,hardBreak:NO,heading:Mse,html:y5,image:v5,imageReference:S5,inlineCode:E5,link:x5,linkReference:k5,list:$se,listItem:Vse,paragraph:Wse,root:Kse,strong:T5,text:Qse,thematicBreak:eue};function tue(){return{enter:{table:nue,tableData:OO,tableHeader:OO,tableRow:aue},exit:{codeText:oue,table:rue,tableData:Fm,tableHeader:Fm,tableRow:Fm}}}function nue(e){const t=e._align;this.enter({type:"table",align:t.map(function(n){return n==="none"?null:n}),children:[]},e),this.data.inTable=!0}function rue(e){this.exit(e),this.data.inTable=void 0}function aue(e){this.enter({type:"tableRow",children:[]},e)}function Fm(e){this.exit(e)}function OO(e){this.enter({type:"tableCell",children:[]},e)}function oue(e){let t=this.resume();this.data.inTable&&(t=t.replace(/\\([\\|])/g,iue));const n=this.stack[this.stack.length-1];n.type,n.value=t,this.exit(e)}function iue(e,t){return t==="|"?t:e}function lue(e){const t=e||{},n=t.tableCellPadding,r=t.tablePipeAlign,a=t.stringLength,i=n?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:b,table:l,tableCell:c,tableRow:u}};function l(m,S,v,A){return f(p(m,v,A),m.align)}function u(m,S,v,A){const R=g(m,v,A),x=f([R]);return x.slice(0,x.indexOf(`
`))}function c(m,S,v,A){const R=v.enter("tableCell"),x=v.enter("phrasing"),T=v.containerPhrasing(m,{...A,before:i,after:i});return x(),R(),T}function f(m,S){return wse(m,{align:S,alignDelimiters:r,padding:n,stringLength:a})}function p(m,S,v){const A=m.children;let R=-1;const x=[],T=S.enter("table");for(;++R<A.length;)x[R]=g(A[R],S,v);return T(),x}function g(m,S,v){const A=m.children;let R=-1;const x=[],T=S.enter("tableRow");for(;++R<A.length;)x[R]=c(A[R],m,S,v);return T(),x}function b(m,S,v){let A=_5.inlineCode(m,S,v);return v.stack.includes("tableCell")&&(A=A.replace(/\|/g,"\\$&")),A}}function sue(){return{exit:{taskListCheckValueChecked:DO,taskListCheckValueUnchecked:DO,paragraph:cue}}}function uue(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:due}}}function DO(e){const t=this.stack[this.stack.length-2];t.type,t.checked=e.type==="taskListCheckValueChecked"}function cue(e){const t=this.stack[this.stack.length-2];if(t&&t.type==="listItem"&&typeof t.checked=="boolean"){const n=this.stack[this.stack.length-1];n.type;const r=n.children[0];if(r&&r.type==="text"){const a=t.children;let i=-1,l;for(;++i<a.length;){const u=a[i];if(u.type==="paragraph"){l=u;break}}l===n&&(r.value=r.value.slice(1),r.value.length===0?n.children.shift():n.position&&r.position&&typeof r.position.start.offset=="number"&&(r.position.start.column++,r.position.start.offset++,n.position.start=Object.assign({},r.position.start)))}}this.exit(e)}function due(e,t,n,r){const a=e.children[0],i=typeof e.checked=="boolean"&&a&&a.type==="paragraph",l="["+(e.checked?"x":" ")+"] ",u=n.createTracker(r);i&&u.move(l);let c=_5.listItem(e,t,n,{...r,...u.current()});return i&&(c=c.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,f)),c;function f(p){return p+l}}function fue(){return[qle(),fse(),mse(),tue(),sue()]}function pue(e){return{extensions:[Vle(),pse(e),bse(),lue(e),uue()]}}const gue={tokenize:Sue,partial:!0},R5={tokenize:Eue,partial:!0},C5={tokenize:wue,partial:!0},N5={tokenize:xue,partial:!0},hue={tokenize:kue,partial:!0},O5={name:"wwwAutolink",tokenize:yue,previous:I5},D5={name:"protocolAutolink",tokenize:vue,previous:L5},Fa={name:"emailAutolink",tokenize:bue,previous:M5},ta={};function mue(){return{text:ta}}let Zo=48;for(;Zo<123;)ta[Zo]=Fa,Zo++,Zo===58?Zo=65:Zo===91&&(Zo=97);ta[43]=Fa;ta[45]=Fa;ta[46]=Fa;ta[95]=Fa;ta[72]=[Fa,D5];ta[104]=[Fa,D5];ta[87]=[Fa,O5];ta[119]=[Fa,O5];function bue(e,t,n){const r=this;let a,i;return l;function l(g){return!wk(g)||!M5.call(r,r.previous)||oA(r.events)?n(g):(e.enter("literalAutolink"),e.enter("literalAutolinkEmail"),u(g))}function u(g){return wk(g)?(e.consume(g),u):g===64?(e.consume(g),c):n(g)}function c(g){return g===46?e.check(hue,p,f)(g):g===45||g===95||Sn(g)?(i=!0,e.consume(g),c):p(g)}function f(g){return e.consume(g),a=!0,c}function p(g){return i&&a&&_n(r.previous)?(e.exit("literalAutolinkEmail"),e.exit("literalAutolink"),t(g)):n(g)}}function yue(e,t,n){const r=this;return a;function a(l){return l!==87&&l!==119||!I5.call(r,r.previous)||oA(r.events)?n(l):(e.enter("literalAutolink"),e.enter("literalAutolinkWww"),e.check(gue,e.attempt(R5,e.attempt(C5,i),n),n)(l))}function i(l){return e.exit("literalAutolinkWww"),e.exit("literalAutolink"),t(l)}}function vue(e,t,n){const r=this;let a="",i=!1;return l;function l(g){return(g===72||g===104)&&L5.call(r,r.previous)&&!oA(r.events)?(e.enter("literalAutolink"),e.enter("literalAutolinkHttp"),a+=String.fromCodePoint(g),e.consume(g),u):n(g)}function u(g){if(_n(g)&&a.length<5)return a+=String.fromCodePoint(g),e.consume(g),u;if(g===58){const b=a.toLowerCase();if(b==="http"||b==="https")return e.consume(g),c}return n(g)}function c(g){return g===47?(e.consume(g),i?f:(i=!0,c)):n(g)}function f(g){return g===null||Qd(g)||Nt(g)||ui(g)||jf(g)?n(g):e.attempt(R5,e.attempt(C5,p),n)(g)}function p(g){return e.exit("literalAutolinkHttp"),e.exit("literalAutolink"),t(g)}}function Sue(e,t,n){let r=0;return a;function a(l){return(l===87||l===119)&&r<3?(r++,e.consume(l),a):l===46&&r===3?(e.consume(l),i):n(l)}function i(l){return l===null?n(l):t(l)}}function Eue(e,t,n){let r,a,i;return l;function l(f){return f===46||f===95?e.check(N5,c,u)(f):f===null||Nt(f)||ui(f)||f!==45&&jf(f)?c(f):(i=!0,e.consume(f),l)}function u(f){return f===95?r=!0:(a=r,r=void 0),e.consume(f),l}function c(f){return a||r||!i?n(f):t(f)}}function wue(e,t){let n=0,r=0;return a;function a(l){return l===40?(n++,e.consume(l),a):l===41&&r<n?i(l):l===33||l===34||l===38||l===39||l===41||l===42||l===44||l===46||l===58||l===59||l===60||l===63||l===93||l===95||l===126?e.check(N5,t,i)(l):l===null||Nt(l)||ui(l)?t(l):(e.consume(l),a)}function i(l){return l===41&&r++,e.consume(l),a}}function xue(e,t,n){return r;function r(u){return u===33||u===34||u===39||u===41||u===42||u===44||u===46||u===58||u===59||u===63||u===95||u===126?(e.consume(u),r):u===38?(e.consume(u),i):u===93?(e.consume(u),a):u===60||u===null||Nt(u)||ui(u)?t(u):n(u)}function a(u){return u===null||u===40||u===91||Nt(u)||ui(u)?t(u):r(u)}function i(u){return _n(u)?l(u):n(u)}function l(u){return u===59?(e.consume(u),r):_n(u)?(e.consume(u),l):n(u)}}function kue(e,t,n){return r;function r(i){return e.consume(i),a}function a(i){return Sn(i)?n(i):t(i)}}function I5(e){return e===null||e===40||e===42||e===95||e===91||e===93||e===126||Nt(e)}function L5(e){return!_n(e)}function M5(e){return!(e===47||wk(e))}function wk(e){return e===43||e===45||e===46||e===95||Sn(e)}function oA(e){let t=e.length,n=!1;for(;t--;){const r=e[t][1];if((r.type==="labelLink"||r.type==="labelImage")&&!r._balanced){n=!0;break}if(r._gfmAutolinkLiteralWalkedInto){n=!1;break}}return e.length>0&&!n&&(e[e.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),n}const Aue={tokenize:Iue,partial:!0};function Tue(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:Nue,continuation:{tokenize:Oue},exit:Due}},text:{91:{name:"gfmFootnoteCall",tokenize:Cue},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:_ue,resolveTo:Rue}}}}function _ue(e,t,n){const r=this;let a=r.events.length;const i=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let l;for(;a--;){const c=r.events[a][1];if(c.type==="labelImage"){l=c;break}if(c.type==="gfmFootnoteCall"||c.type==="labelLink"||c.type==="label"||c.type==="image"||c.type==="link")break}return u;function u(c){if(!l||!l._balanced)return n(c);const f=Or(r.sliceSerialize({start:l.end,end:r.now()}));return f.codePointAt(0)!==94||!i.includes(f.slice(1))?n(c):(e.enter("gfmFootnoteCallLabelMarker"),e.consume(c),e.exit("gfmFootnoteCallLabelMarker"),t(c))}}function Rue(e,t){let n=e.length;for(;n--;)if(e[n][1].type==="labelImage"&&e[n][0]==="enter"){e[n][1];break}e[n+1][1].type="data",e[n+3][1].type="gfmFootnoteCallLabelMarker";const r={type:"gfmFootnoteCall",start:Object.assign({},e[n+3][1].start),end:Object.assign({},e[e.length-1][1].end)},a={type:"gfmFootnoteCallMarker",start:Object.assign({},e[n+3][1].end),end:Object.assign({},e[n+3][1].end)};a.end.column++,a.end.offset++,a.end._bufferIndex++;const i={type:"gfmFootnoteCallString",start:Object.assign({},a.end),end:Object.assign({},e[e.length-1][1].start)},l={type:"chunkString",contentType:"string",start:Object.assign({},i.start),end:Object.assign({},i.end)},u=[e[n+1],e[n+2],["enter",r,t],e[n+3],e[n+4],["enter",a,t],["exit",a,t],["enter",i,t],["enter",l,t],["exit",l,t],["exit",i,t],e[e.length-2],e[e.length-1],["exit",r,t]];return e.splice(n,e.length-n+1,...u),e}function Cue(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let i=0,l;return u;function u(g){return e.enter("gfmFootnoteCall"),e.enter("gfmFootnoteCallLabelMarker"),e.consume(g),e.exit("gfmFootnoteCallLabelMarker"),c}function c(g){return g!==94?n(g):(e.enter("gfmFootnoteCallMarker"),e.consume(g),e.exit("gfmFootnoteCallMarker"),e.enter("gfmFootnoteCallString"),e.enter("chunkString").contentType="string",f)}function f(g){if(i>999||g===93&&!l||g===null||g===91||Nt(g))return n(g);if(g===93){e.exit("chunkString");const b=e.exit("gfmFootnoteCallString");return a.includes(Or(r.sliceSerialize(b)))?(e.enter("gfmFootnoteCallLabelMarker"),e.consume(g),e.exit("gfmFootnoteCallLabelMarker"),e.exit("gfmFootnoteCall"),t):n(g)}return Nt(g)||(l=!0),i++,e.consume(g),g===92?p:f}function p(g){return g===91||g===92||g===93?(e.consume(g),i++,f):f(g)}}function Nue(e,t,n){const r=this,a=r.parser.gfmFootnotes||(r.parser.gfmFootnotes=[]);let i,l=0,u;return c;function c(S){return e.enter("gfmFootnoteDefinition")._container=!0,e.enter("gfmFootnoteDefinitionLabel"),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(S),e.exit("gfmFootnoteDefinitionLabelMarker"),f}function f(S){return S===94?(e.enter("gfmFootnoteDefinitionMarker"),e.consume(S),e.exit("gfmFootnoteDefinitionMarker"),e.enter("gfmFootnoteDefinitionLabelString"),e.enter("chunkString").contentType="string",p):n(S)}function p(S){if(l>999||S===93&&!u||S===null||S===91||Nt(S))return n(S);if(S===93){e.exit("chunkString");const v=e.exit("gfmFootnoteDefinitionLabelString");return i=Or(r.sliceSerialize(v)),e.enter("gfmFootnoteDefinitionLabelMarker"),e.consume(S),e.exit("gfmFootnoteDefinitionLabelMarker"),e.exit("gfmFootnoteDefinitionLabel"),b}return Nt(S)||(u=!0),l++,e.consume(S),S===92?g:p}function g(S){return S===91||S===92||S===93?(e.consume(S),l++,p):p(S)}function b(S){return S===58?(e.enter("definitionMarker"),e.consume(S),e.exit("definitionMarker"),a.includes(i)||a.push(i),lt(e,m,"gfmFootnoteDefinitionWhitespace")):n(S)}function m(S){return t(S)}}function Oue(e,t,n){return e.check(_u,t,e.attempt(Aue,t,n))}function Due(e){e.exit("gfmFootnoteDefinition")}function Iue(e,t,n){const r=this;return lt(e,a,"gfmFootnoteDefinitionIndent",5);function a(i){const l=r.events[r.events.length-1];return l&&l[1].type==="gfmFootnoteDefinitionIndent"&&l[2].sliceSerialize(l[1],!0).length===4?t(i):n(i)}}function Lue(e){let n=(e||{}).singleTilde;const r={name:"strikethrough",tokenize:i,resolveAll:a};return n==null&&(n=!0),{text:{126:r},insideSpan:{null:[r]},attentionMarkers:{null:[126]}};function a(l,u){let c=-1;for(;++c<l.length;)if(l[c][0]==="enter"&&l[c][1].type==="strikethroughSequenceTemporary"&&l[c][1]._close){let f=c;for(;f--;)if(l[f][0]==="exit"&&l[f][1].type==="strikethroughSequenceTemporary"&&l[f][1]._open&&l[c][1].end.offset-l[c][1].start.offset===l[f][1].end.offset-l[f][1].start.offset){l[c][1].type="strikethroughSequence",l[f][1].type="strikethroughSequence";const p={type:"strikethrough",start:Object.assign({},l[f][1].start),end:Object.assign({},l[c][1].end)},g={type:"strikethroughText",start:Object.assign({},l[f][1].end),end:Object.assign({},l[c][1].start)},b=[["enter",p,u],["enter",l[f][1],u],["exit",l[f][1],u],["enter",g,u]],m=u.parser.constructs.insideSpan.null;m&&Qn(b,b.length,0,Gf(m,l.slice(f+1,c),u)),Qn(b,b.length,0,[["exit",g,u],["enter",l[c][1],u],["exit",l[c][1],u],["exit",p,u]]),Qn(l,f-1,c-f+3,b),c=f+b.length-2;break}}for(c=-1;++c<l.length;)l[c][1].type==="strikethroughSequenceTemporary"&&(l[c][1].type="data");return l}function i(l,u,c){const f=this.previous,p=this.events;let g=0;return b;function b(S){return f===126&&p[p.length-1][1].type!=="characterEscape"?c(S):(l.enter("strikethroughSequenceTemporary"),m(S))}function m(S){const v=xl(f);if(S===126)return g>1?c(S):(l.consume(S),g++,m);if(g<2&&!n)return c(S);const A=l.exit("strikethroughSequenceTemporary"),R=xl(S);return A._open=!R||R===2&&!!v,A._close=!v||v===2&&!!R,u(S)}}}class Mue{constructor(){this.map=[]}add(t,n,r){Fue(this,t,n,r)}consume(t){if(this.map.sort(function(i,l){return i[0]-l[0]}),this.map.length===0)return;let n=this.map.length;const r=[];for(;n>0;)n-=1,r.push(t.slice(this.map[n][0]+this.map[n][1]),this.map[n][2]),t.length=this.map[n][0];r.push(t.slice()),t.length=0;let a=r.pop();for(;a;){for(const i of a)t.push(i);a=r.pop()}this.map.length=0}}function Fue(e,t,n,r){let a=0;if(!(n===0&&r.length===0)){for(;a<e.map.length;){if(e.map[a][0]===t){e.map[a][1]+=n,e.map[a][2].push(...r);return}a+=1}e.map.push([t,n,r])}}function zue(e,t){let n=!1;const r=[];for(;t<e.length;){const a=e[t];if(n){if(a[0]==="enter")a[1].type==="tableContent"&&r.push(e[t+1][1].type==="tableDelimiterMarker"?"left":"none");else if(a[1].type==="tableContent"){if(e[t-1][1].type==="tableDelimiterMarker"){const i=r.length-1;r[i]=r[i]==="left"?"center":"right"}}else if(a[1].type==="tableDelimiterRow")break}else a[0]==="enter"&&a[1].type==="tableDelimiterRow"&&(n=!0);t+=1}return r}function Pue(){return{flow:{null:{name:"table",tokenize:Bue,resolveAll:Uue}}}}function Bue(e,t,n){const r=this;let a=0,i=0,l;return u;function u(M){let H=r.events.length-1;for(;H>-1;){const W=r.events[H][1].type;if(W==="lineEnding"||W==="linePrefix")H--;else break}const q=H>-1?r.events[H][1].type:null,P=q==="tableHead"||q==="tableRow"?_:c;return P===_&&r.parser.lazy[r.now().line]?n(M):P(M)}function c(M){return e.enter("tableHead"),e.enter("tableRow"),f(M)}function f(M){return M===124||(l=!0,i+=1),p(M)}function p(M){return M===null?n(M):$e(M)?i>1?(i=0,r.interrupt=!0,e.exit("tableRow"),e.enter("lineEnding"),e.consume(M),e.exit("lineEnding"),m):n(M):ut(M)?lt(e,p,"whitespace")(M):(i+=1,l&&(l=!1,a+=1),M===124?(e.enter("tableCellDivider"),e.consume(M),e.exit("tableCellDivider"),l=!0,p):(e.enter("data"),g(M)))}function g(M){return M===null||M===124||Nt(M)?(e.exit("data"),p(M)):(e.consume(M),M===92?b:g)}function b(M){return M===92||M===124?(e.consume(M),g):g(M)}function m(M){return r.interrupt=!1,r.parser.lazy[r.now().line]?n(M):(e.enter("tableDelimiterRow"),l=!1,ut(M)?lt(e,S,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(M):S(M))}function S(M){return M===45||M===58?A(M):M===124?(l=!0,e.enter("tableCellDivider"),e.consume(M),e.exit("tableCellDivider"),v):N(M)}function v(M){return ut(M)?lt(e,A,"whitespace")(M):A(M)}function A(M){return M===58?(i+=1,l=!0,e.enter("tableDelimiterMarker"),e.consume(M),e.exit("tableDelimiterMarker"),R):M===45?(i+=1,R(M)):M===null||$e(M)?C(M):N(M)}function R(M){return M===45?(e.enter("tableDelimiterFiller"),x(M)):N(M)}function x(M){return M===45?(e.consume(M),x):M===58?(l=!0,e.exit("tableDelimiterFiller"),e.enter("tableDelimiterMarker"),e.consume(M),e.exit("tableDelimiterMarker"),T):(e.exit("tableDelimiterFiller"),T(M))}function T(M){return ut(M)?lt(e,C,"whitespace")(M):C(M)}function C(M){return M===124?S(M):M===null||$e(M)?!l||a!==i?N(M):(e.exit("tableDelimiterRow"),e.exit("tableHead"),t(M)):N(M)}function N(M){return n(M)}function _(M){return e.enter("tableRow"),O(M)}function O(M){return M===124?(e.enter("tableCellDivider"),e.consume(M),e.exit("tableCellDivider"),O):M===null||$e(M)?(e.exit("tableRow"),t(M)):ut(M)?lt(e,O,"whitespace")(M):(e.enter("data"),z(M))}function z(M){return M===null||M===124||Nt(M)?(e.exit("data"),O(M)):(e.consume(M),M===92?I:z)}function I(M){return M===92||M===124?(e.consume(M),z):z(M)}}function Uue(e,t){let n=-1,r=!0,a=0,i=[0,0,0,0],l=[0,0,0,0],u=!1,c=0,f,p,g;const b=new Mue;for(;++n<e.length;){const m=e[n],S=m[1];m[0]==="enter"?S.type==="tableHead"?(u=!1,c!==0&&(IO(b,t,c,f,p),p=void 0,c=0),f={type:"table",start:Object.assign({},S.start),end:Object.assign({},S.end)},b.add(n,0,[["enter",f,t]])):S.type==="tableRow"||S.type==="tableDelimiterRow"?(r=!0,g=void 0,i=[0,0,0,0],l=[0,n+1,0,0],u&&(u=!1,p={type:"tableBody",start:Object.assign({},S.start),end:Object.assign({},S.end)},b.add(n,0,[["enter",p,t]])),a=S.type==="tableDelimiterRow"?2:p?3:1):a&&(S.type==="data"||S.type==="tableDelimiterMarker"||S.type==="tableDelimiterFiller")?(r=!1,l[2]===0&&(i[1]!==0&&(l[0]=l[1],g=ud(b,t,i,a,void 0,g),i=[0,0,0,0]),l[2]=n)):S.type==="tableCellDivider"&&(r?r=!1:(i[1]!==0&&(l[0]=l[1],g=ud(b,t,i,a,void 0,g)),i=l,l=[i[1],n,0,0])):S.type==="tableHead"?(u=!0,c=n):S.type==="tableRow"||S.type==="tableDelimiterRow"?(c=n,i[1]!==0?(l[0]=l[1],g=ud(b,t,i,a,n,g)):l[1]!==0&&(g=ud(b,t,l,a,n,g)),a=0):a&&(S.type==="data"||S.type==="tableDelimiterMarker"||S.type==="tableDelimiterFiller")&&(l[3]=n)}for(c!==0&&IO(b,t,c,f,p),b.consume(t.events),n=-1;++n<t.events.length;){const m=t.events[n];m[0]==="enter"&&m[1].type==="table"&&(m[1]._align=zue(t.events,n))}return e}function ud(e,t,n,r,a,i){const l=r===1?"tableHeader":r===2?"tableDelimiter":"tableData",u="tableContent";n[0]!==0&&(i.end=Object.assign({},sl(t.events,n[0])),e.add(n[0],0,[["exit",i,t]]));const c=sl(t.events,n[1]);if(i={type:l,start:Object.assign({},c),end:Object.assign({},c)},e.add(n[1],0,[["enter",i,t]]),n[2]!==0){const f=sl(t.events,n[2]),p=sl(t.events,n[3]),g={type:u,start:Object.assign({},f),end:Object.assign({},p)};if(e.add(n[2],0,[["enter",g,t]]),r!==2){const b=t.events[n[2]],m=t.events[n[3]];if(b[1].end=Object.assign({},m[1].end),b[1].type="chunkText",b[1].contentType="text",n[3]>n[2]+1){const S=n[2]+1,v=n[3]-n[2]-1;e.add(S,v,[])}}e.add(n[3]+1,0,[["exit",g,t]])}return a!==void 0&&(i.end=Object.assign({},sl(t.events,a)),e.add(a,0,[["exit",i,t]]),i=void 0),i}function IO(e,t,n,r,a){const i=[],l=sl(t.events,n);a&&(a.end=Object.assign({},l),i.push(["exit",a,t])),r.end=Object.assign({},l),i.push(["exit",r,t]),e.add(n+1,0,i)}function sl(e,t){const n=e[t],r=n[0]==="enter"?"start":"end";return n[1][r]}const jue={name:"tasklistCheck",tokenize:Hue};function Gue(){return{text:{91:jue}}}function Hue(e,t,n){const r=this;return a;function a(c){return r.previous!==null||!r._gfmTasklistFirstContentOfListItem?n(c):(e.enter("taskListCheck"),e.enter("taskListCheckMarker"),e.consume(c),e.exit("taskListCheckMarker"),i)}function i(c){return Nt(c)?(e.enter("taskListCheckValueUnchecked"),e.consume(c),e.exit("taskListCheckValueUnchecked"),l):c===88||c===120?(e.enter("taskListCheckValueChecked"),e.consume(c),e.exit("taskListCheckValueChecked"),l):n(c)}function l(c){return c===93?(e.enter("taskListCheckMarker"),e.consume(c),e.exit("taskListCheckMarker"),e.exit("taskListCheck"),u):n(c)}function u(c){return $e(c)?t(c):ut(c)?e.check({tokenize:$ue},t,n)(c):n(c)}}function $ue(e,t,n){return lt(e,r,"whitespace");function r(a){return a===null?n(a):t(a)}}function que(e){return qj([mue(),Tue(),Lue(e),Pue(),Gue()])}const Vue={};function Wue(e){const t=this,n=e||Vue,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),i=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),l=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(que(n)),i.push(fue()),l.push(pue(n))}function Yue(e){const t=this;t.compiler=n;function n(r,a){return Uj(r,{filePath:a.path,...e})}}function Kue(){return{enter:{mathFlow:e,mathFlowFenceMeta:t,mathText:i},exit:{mathFlow:a,mathFlowFence:r,mathFlowFenceMeta:n,mathFlowValue:u,mathText:l,mathTextData:u}};function e(c){const f={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[f]}},c)}function t(){this.buffer()}function n(){const c=this.resume(),f=this.stack[this.stack.length-1];f.type,f.meta=c}function r(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function a(c){const f=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),p=this.stack[this.stack.length-1];p.type,this.exit(c),p.value=f;const g=p.data.hChildren[0];g.type,g.tagName,g.children.push({type:"text",value:f}),this.data.mathFlowInside=void 0}function i(c){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},c),this.buffer()}function l(c){const f=this.resume(),p=this.stack[this.stack.length-1];p.type,this.exit(c),p.value=f,p.data.hChildren.push({type:"text",value:f})}function u(c){this.config.enter.data.call(this,c),this.config.exit.data.call(this,c)}}function Xue(e){let t=(e||{}).singleDollarTextMath;return t==null&&(t=!0),r.peek=a,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:t?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:n,inlineMath:r}};function n(i,l,u,c){const f=i.value||"",p=u.createTracker(c),g="$".repeat(Math.max(m5(f,"$")+1,2)),b=u.enter("mathFlow");let m=p.move(g);if(i.meta){const S=u.enter("mathFlowMeta");m+=p.move(u.safe(i.meta,{after:`
`,before:m,encode:["$"],...p.current()})),S()}return m+=p.move(`
`),f&&(m+=p.move(f+`
`)),m+=p.move(g),b(),m}function r(i,l,u){let c=i.value||"",f=1;for(t||f++;new RegExp("(^|[^$])"+"\\$".repeat(f)+"([^$]|$)").test(c);)f++;const p="$".repeat(f);/[^ \r\n]/.test(c)&&(/^[ \r\n]/.test(c)&&/[ \r\n]$/.test(c)||/^\$|\$$/.test(c))&&(c=" "+c+" ");let g=-1;for(;++g<u.unsafe.length;){const b=u.unsafe[g];if(!b.atBreak)continue;const m=u.compilePattern(b);let S;for(;S=m.exec(c);){let v=S.index;c.codePointAt(v)===10&&c.codePointAt(v-1)===13&&v--,c=c.slice(0,v)+" "+c.slice(S.index+1)}}return p+c+p}function a(){return"$"}}const Zue={tokenize:Que,concrete:!0,name:"mathFlow"},LO={tokenize:Jue,partial:!0};function Que(e,t,n){const r=this,a=r.events[r.events.length-1],i=a&&a[1].type==="linePrefix"?a[2].sliceSerialize(a[1],!0).length:0;let l=0;return u;function u(x){return e.enter("mathFlow"),e.enter("mathFlowFence"),e.enter("mathFlowFenceSequence"),c(x)}function c(x){return x===36?(e.consume(x),l++,c):l<2?n(x):(e.exit("mathFlowFenceSequence"),lt(e,f,"whitespace")(x))}function f(x){return x===null||$e(x)?g(x):(e.enter("mathFlowFenceMeta"),e.enter("chunkString",{contentType:"string"}),p(x))}function p(x){return x===null||$e(x)?(e.exit("chunkString"),e.exit("mathFlowFenceMeta"),g(x)):x===36?n(x):(e.consume(x),p)}function g(x){return e.exit("mathFlowFence"),r.interrupt?t(x):e.attempt(LO,b,A)(x)}function b(x){return e.attempt({tokenize:R,partial:!0},A,m)(x)}function m(x){return(i?lt(e,S,"linePrefix",i+1):S)(x)}function S(x){return x===null?A(x):$e(x)?e.attempt(LO,b,A)(x):(e.enter("mathFlowValue"),v(x))}function v(x){return x===null||$e(x)?(e.exit("mathFlowValue"),S(x)):(e.consume(x),v)}function A(x){return e.exit("mathFlow"),t(x)}function R(x,T,C){let N=0;return lt(x,_,"linePrefix",r.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function _(I){return x.enter("mathFlowFence"),x.enter("mathFlowFenceSequence"),O(I)}function O(I){return I===36?(N++,x.consume(I),O):N<l?C(I):(x.exit("mathFlowFenceSequence"),lt(x,z,"whitespace")(I))}function z(I){return I===null||$e(I)?(x.exit("mathFlowFence"),T(I)):C(I)}}}function Jue(e,t,n){const r=this;return a;function a(l){return l===null?t(l):(e.enter("lineEnding"),e.consume(l),e.exit("lineEnding"),i)}function i(l){return r.parser.lazy[r.now().line]?n(l):t(l)}}function ece(e){let n=(e||{}).singleDollarTextMath;return n==null&&(n=!0),{tokenize:r,resolve:tce,previous:nce,name:"mathText"};function r(a,i,l){let u=0,c,f;return p;function p(v){return a.enter("mathText"),a.enter("mathTextSequence"),g(v)}function g(v){return v===36?(a.consume(v),u++,g):u<2&&!n?l(v):(a.exit("mathTextSequence"),b(v))}function b(v){return v===null?l(v):v===36?(f=a.enter("mathTextSequence"),c=0,S(v)):v===32?(a.enter("space"),a.consume(v),a.exit("space"),b):$e(v)?(a.enter("lineEnding"),a.consume(v),a.exit("lineEnding"),b):(a.enter("mathTextData"),m(v))}function m(v){return v===null||v===32||v===36||$e(v)?(a.exit("mathTextData"),b(v)):(a.consume(v),m)}function S(v){return v===36?(a.consume(v),c++,S):c===u?(a.exit("mathTextSequence"),a.exit("mathText"),i(v)):(f.type="mathTextData",m(v))}}}function tce(e){let t=e.length-4,n=3,r,a;if((e[n][1].type==="lineEnding"||e[n][1].type==="space")&&(e[t][1].type==="lineEnding"||e[t][1].type==="space")){for(r=n;++r<t;)if(e[r][1].type==="mathTextData"){e[t][1].type="mathTextPadding",e[n][1].type="mathTextPadding",n+=2,t-=2;break}}for(r=n-1,t++;++r<=t;)a===void 0?r!==t&&e[r][1].type!=="lineEnding"&&(a=r):(r===t||e[r][1].type==="lineEnding")&&(e[a][1].type="mathTextData",r!==a+2&&(e[a][1].end=e[r-1][1].end,e.splice(a+2,r-a-2),t-=r-a-2,r=a+2),a=void 0);return e}function nce(e){return e!==36||this.events[this.events.length-1][1].type==="characterEscape"}function rce(e){return{flow:{36:Zue},text:{36:ece(e)}}}const ace={};function oce(e){const t=this,n=e||ace,r=t.data(),a=r.micromarkExtensions||(r.micromarkExtensions=[]),i=r.fromMarkdownExtensions||(r.fromMarkdownExtensions=[]),l=r.toMarkdownExtensions||(r.toMarkdownExtensions=[]);a.push(rce(n)),i.push(Kue()),l.push(Xue(n))}function MO(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function ul(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?MO(Object(n),!0).forEach(function(r){n4(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):MO(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}function ice(e){var t=e.length;if(t===0||t===1)return e;if(t===2)return[e[0],e[1],"".concat(e[0],".").concat(e[1]),"".concat(e[1],".").concat(e[0])];if(t===3)return[e[0],e[1],e[2],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0])];if(t>=4)return[e[0],e[1],e[2],e[3],"".concat(e[0],".").concat(e[1]),"".concat(e[0],".").concat(e[2]),"".concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[0]),"".concat(e[1],".").concat(e[2]),"".concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[1]),"".concat(e[2],".").concat(e[3]),"".concat(e[3],".").concat(e[0]),"".concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[0]),"".concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[0],".").concat(e[1],".").concat(e[2],".").concat(e[3]),"".concat(e[0],".").concat(e[1],".").concat(e[3],".").concat(e[2]),"".concat(e[0],".").concat(e[2],".").concat(e[1],".").concat(e[3]),"".concat(e[0],".").concat(e[2],".").concat(e[3],".").concat(e[1]),"".concat(e[0],".").concat(e[3],".").concat(e[1],".").concat(e[2]),"".concat(e[0],".").concat(e[3],".").concat(e[2],".").concat(e[1]),"".concat(e[1],".").concat(e[0],".").concat(e[2],".").concat(e[3]),"".concat(e[1],".").concat(e[0],".").concat(e[3],".").concat(e[2]),"".concat(e[1],".").concat(e[2],".").concat(e[0],".").concat(e[3]),"".concat(e[1],".").concat(e[2],".").concat(e[3],".").concat(e[0]),"".concat(e[1],".").concat(e[3],".").concat(e[0],".").concat(e[2]),"".concat(e[1],".").concat(e[3],".").concat(e[2],".").concat(e[0]),"".concat(e[2],".").concat(e[0],".").concat(e[1],".").concat(e[3]),"".concat(e[2],".").concat(e[0],".").concat(e[3],".").concat(e[1]),"".concat(e[2],".").concat(e[1],".").concat(e[0],".").concat(e[3]),"".concat(e[2],".").concat(e[1],".").concat(e[3],".").concat(e[0]),"".concat(e[2],".").concat(e[3],".").concat(e[0],".").concat(e[1]),"".concat(e[2],".").concat(e[3],".").concat(e[1],".").concat(e[0]),"".concat(e[3],".").concat(e[0],".").concat(e[1],".").concat(e[2]),"".concat(e[3],".").concat(e[0],".").concat(e[2],".").concat(e[1]),"".concat(e[3],".").concat(e[1],".").concat(e[0],".").concat(e[2]),"".concat(e[3],".").concat(e[1],".").concat(e[2],".").concat(e[0]),"".concat(e[3],".").concat(e[2],".").concat(e[0],".").concat(e[1]),"".concat(e[3],".").concat(e[2],".").concat(e[1],".").concat(e[0])]}var zm={};function lce(e){if(e.length===0||e.length===1)return e;var t=e.join(".");return zm[t]||(zm[t]=ice(e)),zm[t]}function sce(e){var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},n=arguments.length>2?arguments[2]:void 0,r=e.filter(function(i){return i!=="token"}),a=lce(r);return a.reduce(function(i,l){return ul(ul({},i),n[l])},t)}function FO(e){return e.join(" ")}function uce(e,t){var n=0;return function(r){return n+=1,r.map(function(a,i){return F5({node:a,stylesheet:e,useInlineStyles:t,key:"code-segment-".concat(n,"-").concat(i)})})}}function F5(e){var t=e.node,n=e.stylesheet,r=e.style,a=r===void 0?{}:r,i=e.useInlineStyles,l=e.key,u=t.properties,c=t.type,f=t.tagName,p=t.value;if(c==="text")return p;if(f){var g=uce(n,i),b;if(!i)b=ul(ul({},u),{},{className:FO(u.className)});else{var m=Object.keys(n).reduce(function(R,x){return x.split(".").forEach(function(T){R.includes(T)||R.push(T)}),R},[]),S=u.className&&u.className.includes("token")?["token"]:[],v=u.className&&S.concat(u.className.filter(function(R){return!m.includes(R)}));b=ul(ul({},u),{},{className:FO(v)||void 0,style:sce(u.className,Object.assign({},u.style,a),n)})}var A=g(t.children);return ye.createElement(f,Yx({key:l},b),A)}}const cce=function(e,t){var n=e.listLanguages();return n.indexOf(t)!==-1};var dce=["language","children","style","customStyle","codeTagProps","useInlineStyles","showLineNumbers","showInlineLineNumbers","startingLineNumber","lineNumberContainerStyle","lineNumberStyle","wrapLines","wrapLongLines","lineProps","renderer","PreTag","CodeTag","code","astGenerator"];function zO(e,t){var n=Object.keys(e);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(e);t&&(r=r.filter(function(a){return Object.getOwnPropertyDescriptor(e,a).enumerable})),n.push.apply(n,r)}return n}function go(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?arguments[t]:{};t%2?zO(Object(n),!0).forEach(function(r){n4(e,r,n[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(e,Object.getOwnPropertyDescriptors(n)):zO(Object(n)).forEach(function(r){Object.defineProperty(e,r,Object.getOwnPropertyDescriptor(n,r))})}return e}var fce=/\n/g;function pce(e){return e.match(fce)}function gce(e){var t=e.lines,n=e.startingLineNumber,r=e.style;return t.map(function(a,i){var l=i+n;return ye.createElement("span",{key:"line-".concat(i),className:"react-syntax-highlighter-line-number",style:typeof r=="function"?r(l):r},"".concat(l,`
`))})}function hce(e){var t=e.codeString,n=e.codeStyle,r=e.containerStyle,a=r===void 0?{float:"left",paddingRight:"10px"}:r,i=e.numberStyle,l=i===void 0?{}:i,u=e.startingLineNumber;return ye.createElement("code",{style:Object.assign({},n,a)},gce({lines:t.replace(/\n$/,"").split(`
`),style:l,startingLineNumber:u}))}function mce(e){return"".concat(e.toString().length,".25em")}function z5(e,t){return{type:"element",tagName:"span",properties:{key:"line-number--".concat(e),className:["comment","linenumber","react-syntax-highlighter-line-number"],style:t},children:[{type:"text",value:e}]}}function P5(e,t,n){var r={display:"inline-block",minWidth:mce(n),paddingRight:"1em",textAlign:"right",userSelect:"none"},a=typeof e=="function"?e(t):e,i=go(go({},r),a);return i}function Rd(e){var t=e.children,n=e.lineNumber,r=e.lineNumberStyle,a=e.largestLineNumber,i=e.showInlineLineNumbers,l=e.lineProps,u=l===void 0?{}:l,c=e.className,f=c===void 0?[]:c,p=e.showLineNumbers,g=e.wrapLongLines,b=e.wrapLines,m=b===void 0?!1:b,S=m?go({},typeof u=="function"?u(n):u):{};if(S.className=S.className?[].concat(Xx(S.className.trim().split(/\s+/)),Xx(f)):f,n&&i){var v=P5(r,n,a);t.unshift(z5(n,v))}return g&p&&(S.style=go({display:"flex"},S.style)),{type:"element",tagName:"span",properties:S,children:t}}function B5(e){for(var t=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],n=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[],r=0;r<e.length;r++){var a=e[r];if(a.type==="text")n.push(Rd({children:[a],className:Xx(new Set(t))}));else if(a.children){var i=t.concat(a.properties.className);B5(a.children,i).forEach(function(l){return n.push(l)})}}return n}function bce(e,t,n,r,a,i,l,u,c){var f,p=B5(e.value),g=[],b=-1,m=0;function S(N,_){var O=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return Rd({children:N,lineNumber:_,lineNumberStyle:u,largestLineNumber:l,showInlineLineNumbers:a,lineProps:n,className:O,showLineNumbers:r,wrapLongLines:c,wrapLines:t})}function v(N,_){if(r&&_&&a){var O=P5(u,_,l);N.unshift(z5(_,O))}return N}function A(N,_){var O=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];return t||O.length>0?S(N,_,O):v(N,_)}for(var R=function(){var _=p[m],O=_.children[0].value,z=pce(O);if(z){var I=O.split(`
`);I.forEach(function(M,H){var q=r&&g.length+i,P={type:"text",value:"".concat(M,`
`)};if(H===0){var W=p.slice(b+1,m).concat(Rd({children:[P],className:_.properties.className})),Z=A(W,q);g.push(Z)}else if(H===I.length-1){var j=p[m+1]&&p[m+1].children&&p[m+1].children[0],G={type:"text",value:"".concat(M)};if(j){var B=Rd({children:[G],className:_.properties.className});p.splice(m+1,0,B)}else{var X=[G],D=A(X,q,_.properties.className);g.push(D)}}else{var V=[P],U=A(V,q,_.properties.className);g.push(U)}}),b=m}m++};m<p.length;)R();if(b!==p.length-1){var x=p.slice(b+1,p.length);if(x&&x.length){var T=r&&g.length+i,C=A(x,T);g.push(C)}}return t?g:(f=[]).concat.apply(f,g)}function yce(e){var t=e.rows,n=e.stylesheet,r=e.useInlineStyles;return t.map(function(a,i){return F5({node:a,stylesheet:n,useInlineStyles:r,key:"code-segement".concat(i)})})}function U5(e){return e&&typeof e.highlightAuto<"u"}function vce(e){var t=e.astGenerator,n=e.language,r=e.code,a=e.defaultCodeValue;if(U5(t)){var i=cce(t,n);return n==="text"?{value:a,language:"text"}:i?t.highlight(n,r):t.highlightAuto(r)}try{return n&&n!=="text"?{value:t.highlight(r,n)}:{value:a}}catch{return{value:a}}}function Sce(e,t){return function(r){var a=r.language,i=r.children,l=r.style,u=l===void 0?t:l,c=r.customStyle,f=c===void 0?{}:c,p=r.codeTagProps,g=p===void 0?{className:a?"language-".concat(a):void 0,style:go(go({},u['code[class*="language-"]']),u['code[class*="language-'.concat(a,'"]')])}:p,b=r.useInlineStyles,m=b===void 0?!0:b,S=r.showLineNumbers,v=S===void 0?!1:S,A=r.showInlineLineNumbers,R=A===void 0?!0:A,x=r.startingLineNumber,T=x===void 0?1:x,C=r.lineNumberContainerStyle,N=r.lineNumberStyle,_=N===void 0?{}:N,O=r.wrapLines,z=r.wrapLongLines,I=z===void 0?!1:z,M=r.lineProps,H=M===void 0?{}:M,q=r.renderer,P=r.PreTag,W=P===void 0?"pre":P,Z=r.CodeTag,j=Z===void 0?"code":Z,G=r.code,B=G===void 0?(Array.isArray(i)?i[0]:i)||"":G,X=r.astGenerator,D=Nee(r,dce);X=X||e;var V=v?ye.createElement(hce,{containerStyle:C,codeStyle:g.style||{},numberStyle:_,startingLineNumber:T,codeString:B}):null,U=u.hljs||u['pre[class*="language-"]']||{backgroundColor:"#fff"},L=U5(X)?"hljs":"prismjs",Y=m?Object.assign({},D,{style:Object.assign({},U,f)}):Object.assign({},D,{className:D.className?"".concat(L," ").concat(D.className):L,style:Object.assign({},f)});if(I?g.style=go({whiteSpace:"pre-wrap"},g.style):g.style=go({whiteSpace:"pre"},g.style),!X)return ye.createElement(W,Y,V,ye.createElement(j,g,B));(O===void 0&&q||I)&&(O=!0),q=q||yce;var Q=[{type:"text",value:B}],se=vce({astGenerator:X,language:a,code:B,defaultCodeValue:Q});se.language===null&&(se.value=Q);var re=se.value.length;re===1&&se.value[0].type==="text"&&(re=se.value[0].value.split(`
`).length);var le=re+T,Ae=bce(se,O,H,v,R,T,le,_,I);return ye.createElement(W,Y,ye.createElement(j,g,!R&&V,q({rows:Ae,stylesheet:u,useInlineStyles:m})))}}const Ece=["abap","abnf","actionscript","ada","agda","al","antlr4","apacheconf","apex","apl","applescript","aql","arduino","arff","asciidoc","asm6502","asmatmel","aspnet","autohotkey","autoit","avisynth","avro-idl","bash","basic","batch","bbcode","bicep","birb","bison","bnf","brainfuck","brightscript","bro","bsl","c","cfscript","chaiscript","cil","clike","clojure","cmake","cobol","coffeescript","concurnas","coq","cpp","crystal","csharp","cshtml","csp","css-extras","css","csv","cypher","d","dart","dataweave","dax","dhall","diff","django","dns-zone-file","docker","dot","ebnf","editorconfig","eiffel","ejs","elixir","elm","erb","erlang","etlua","excel-formula","factor","false","firestore-security-rules","flow","fortran","fsharp","ftl","gap","gcode","gdscript","gedcom","gherkin","git","glsl","gml","gn","go-module","go","graphql","groovy","haml","handlebars","haskell","haxe","hcl","hlsl","hoon","hpkp","hsts","http","ichigojam","icon","icu-message-format","idris","iecst","ignore","inform7","ini","io","j","java","javadoc","javadoclike","javascript","javastacktrace","jexl","jolie","jq","js-extras","js-templates","jsdoc","json","json5","jsonp","jsstacktrace","jsx","julia","keepalived","keyman","kotlin","kumir","kusto","latex","latte","less","lilypond","liquid","lisp","livescript","llvm","log","lolcode","lua","magma","makefile","markdown","markup-templating","markup","matlab","maxscript","mel","mermaid","mizar","mongodb","monkey","moonscript","n1ql","n4js","nand2tetris-hdl","naniscript","nasm","neon","nevod","nginx","nim","nix","nsis","objectivec","ocaml","opencl","openqasm","oz","parigp","parser","pascal","pascaligo","pcaxis","peoplecode","perl","php-extras","php","phpdoc","plsql","powerquery","powershell","processing","prolog","promql","properties","protobuf","psl","pug","puppet","pure","purebasic","purescript","python","q","qml","qore","qsharp","r","racket","reason","regex","rego","renpy","rest","rip","roboconf","robotframework","ruby","rust","sas","sass","scala","scheme","scss","shell-session","smali","smalltalk","smarty","sml","solidity","solution-file","soy","sparql","splunk-spl","sqf","sql","squirrel","stan","stylus","swift","systemd","t4-cs","t4-templating","t4-vb","tap","tcl","textile","toml","tremor","tsx","tt2","turtle","twig","typescript","typoscript","unrealscript","uorazor","uri","v","vala","vbnet","velocity","verilog","vhdl","vim","visual-basic","warpscript","wasm","web-idl","wiki","wolfram","wren","xeora","xml-doc","xojo","xquery","yaml","yang","zig"];var Pm,PO;function wce(){if(PO)return Pm;PO=1,Pm=t;var e=Object.prototype.hasOwnProperty;function t(){for(var n={},r=0;r<arguments.length;r++){var a=arguments[r];for(var i in a)e.call(a,i)&&(n[i]=a[i])}return n}return Pm}var Bm,BO;function j5(){if(BO)return Bm;BO=1,Bm=t;var e=t.prototype;e.space=null,e.normal={},e.property={};function t(n,r,a){this.property=n,this.normal=r,a&&(this.space=a)}return Bm}var Um,UO;function xce(){if(UO)return Um;UO=1;var e=wce(),t=j5();Um=n;function n(r){for(var a=r.length,i=[],l=[],u=-1,c,f;++u<a;)c=r[u],i.push(c.property),l.push(c.normal),f=c.space;return new t(e.apply(null,i),e.apply(null,l),f)}return Um}var jm,jO;function iA(){if(jO)return jm;jO=1,jm=e;function e(t){return t.toLowerCase()}return jm}var Gm,GO;function G5(){if(GO)return Gm;GO=1,Gm=t;var e=t.prototype;e.space=null,e.attribute=null,e.property=null,e.boolean=!1,e.booleanish=!1,e.overloadedBoolean=!1,e.number=!1,e.commaSeparated=!1,e.spaceSeparated=!1,e.commaOrSpaceSeparated=!1,e.mustUseProperty=!1,e.defined=!1;function t(n,r){this.property=n,this.attribute=r}return Gm}var ka={},HO;function lA(){if(HO)return ka;HO=1;var e=0;ka.boolean=t(),ka.booleanish=t(),ka.overloadedBoolean=t(),ka.number=t(),ka.spaceSeparated=t(),ka.commaSeparated=t(),ka.commaOrSpaceSeparated=t();function t(){return Math.pow(2,++e)}return ka}var Hm,$O;function H5(){if($O)return Hm;$O=1;var e=G5(),t=lA();Hm=a,a.prototype=new e,a.prototype.defined=!0;var n=["boolean","booleanish","overloadedBoolean","number","commaSeparated","spaceSeparated","commaOrSpaceSeparated"],r=n.length;function a(l,u,c,f){var p=-1,g;for(i(this,"space",f),e.call(this,l,u);++p<r;)g=n[p],i(this,g,(c&t[g])===t[g])}function i(l,u,c){c&&(l[u]=c)}return Hm}var $m,qO;function Cu(){if(qO)return $m;qO=1;var e=iA(),t=j5(),n=H5();$m=r;function r(a){var i=a.space,l=a.mustUseProperty||[],u=a.attributes||{},c=a.properties,f=a.transform,p={},g={},b,m;for(b in c)m=new n(b,f(u,b),c[b],i),l.indexOf(b)!==-1&&(m.mustUseProperty=!0),p[b]=m,g[e(b)]=b,g[e(m.attribute)]=b;return new t(p,g,i)}return $m}var qm,VO;function kce(){if(VO)return qm;VO=1;var e=Cu();qm=e({space:"xlink",transform:t,properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null}});function t(n,r){return"xlink:"+r.slice(5).toLowerCase()}return qm}var Vm,WO;function Ace(){if(WO)return Vm;WO=1;var e=Cu();Vm=e({space:"xml",transform:t,properties:{xmlLang:null,xmlBase:null,xmlSpace:null}});function t(n,r){return"xml:"+r.slice(3).toLowerCase()}return Vm}var Wm,YO;function Tce(){if(YO)return Wm;YO=1,Wm=e;function e(t,n){return n in t?t[n]:n}return Wm}var Ym,KO;function $5(){if(KO)return Ym;KO=1;var e=Tce();Ym=t;function t(n,r){return e(n,r.toLowerCase())}return Ym}var Km,XO;function _ce(){if(XO)return Km;XO=1;var e=Cu(),t=$5();return Km=e({space:"xmlns",attributes:{xmlnsxlink:"xmlns:xlink"},transform:t,properties:{xmlns:null,xmlnsXLink:null}}),Km}var Xm,ZO;function Rce(){if(ZO)return Xm;ZO=1;var e=lA(),t=Cu(),n=e.booleanish,r=e.number,a=e.spaceSeparated;Xm=t({transform:i,properties:{ariaActiveDescendant:null,ariaAtomic:n,ariaAutoComplete:null,ariaBusy:n,ariaChecked:n,ariaColCount:r,ariaColIndex:r,ariaColSpan:r,ariaControls:a,ariaCurrent:null,ariaDescribedBy:a,ariaDetails:null,ariaDisabled:n,ariaDropEffect:a,ariaErrorMessage:null,ariaExpanded:n,ariaFlowTo:a,ariaGrabbed:n,ariaHasPopup:null,ariaHidden:n,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:a,ariaLevel:r,ariaLive:null,ariaModal:n,ariaMultiLine:n,ariaMultiSelectable:n,ariaOrientation:null,ariaOwns:a,ariaPlaceholder:null,ariaPosInSet:r,ariaPressed:n,ariaReadOnly:n,ariaRelevant:null,ariaRequired:n,ariaRoleDescription:a,ariaRowCount:r,ariaRowIndex:r,ariaRowSpan:r,ariaSelected:n,ariaSetSize:r,ariaSort:null,ariaValueMax:r,ariaValueMin:r,ariaValueNow:r,ariaValueText:null,role:null}});function i(l,u){return u==="role"?u:"aria-"+u.slice(4).toLowerCase()}return Xm}var Zm,QO;function Cce(){if(QO)return Zm;QO=1;var e=lA(),t=Cu(),n=$5(),r=e.boolean,a=e.overloadedBoolean,i=e.booleanish,l=e.number,u=e.spaceSeparated,c=e.commaSeparated;return Zm=t({space:"html",attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},transform:n,mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:c,acceptCharset:u,accessKey:u,action:null,allow:null,allowFullScreen:r,allowPaymentRequest:r,allowUserMedia:r,alt:null,as:null,async:r,autoCapitalize:null,autoComplete:u,autoFocus:r,autoPlay:r,capture:r,charSet:null,checked:r,cite:null,className:u,cols:l,colSpan:null,content:null,contentEditable:i,controls:r,controlsList:u,coords:l|c,crossOrigin:null,data:null,dateTime:null,decoding:null,default:r,defer:r,dir:null,dirName:null,disabled:r,download:a,draggable:i,encType:null,enterKeyHint:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:r,formTarget:null,headers:u,height:l,hidden:r,high:l,href:null,hrefLang:null,htmlFor:u,httpEquiv:u,id:null,imageSizes:null,imageSrcSet:c,inputMode:null,integrity:null,is:null,isMap:r,itemId:null,itemProp:u,itemRef:u,itemScope:r,itemType:u,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:r,low:l,manifest:null,max:null,maxLength:l,media:null,method:null,min:null,minLength:l,multiple:r,muted:r,name:null,nonce:null,noModule:r,noValidate:r,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforePrint:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextMenu:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:r,optimum:l,pattern:null,ping:u,placeholder:null,playsInline:r,poster:null,preload:null,readOnly:r,referrerPolicy:null,rel:u,required:r,reversed:r,rows:l,rowSpan:l,sandbox:u,scope:null,scoped:r,seamless:r,selected:r,shape:null,size:l,sizes:null,slot:null,span:l,spellCheck:i,src:null,srcDoc:null,srcLang:null,srcSet:c,start:l,step:null,style:null,tabIndex:l,target:null,title:null,translate:null,type:null,typeMustMatch:r,useMap:null,value:i,width:l,wrap:null,align:null,aLink:null,archive:u,axis:null,background:null,bgColor:null,border:l,borderColor:null,bottomMargin:l,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:r,declare:r,event:null,face:null,frame:null,frameBorder:null,hSpace:l,leftMargin:l,link:null,longDesc:null,lowSrc:null,marginHeight:l,marginWidth:l,noResize:r,noHref:r,noShade:r,noWrap:r,object:null,profile:null,prompt:null,rev:null,rightMargin:l,rules:null,scheme:null,scrolling:i,standby:null,summary:null,text:null,topMargin:l,valueType:null,version:null,vAlign:null,vLink:null,vSpace:l,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:r,disableRemotePlayback:r,prefix:null,property:null,results:l,security:null,unselectable:null}}),Zm}var Qm,JO;function Nce(){if(JO)return Qm;JO=1;var e=xce(),t=kce(),n=Ace(),r=_ce(),a=Rce(),i=Cce();return Qm=e([n,t,r,a,i]),Qm}var Jm,eD;function Oce(){if(eD)return Jm;eD=1;var e=iA(),t=H5(),n=G5(),r="data";Jm=u;var a=/^data[-\w.:]+$/i,i=/-[a-z]/g,l=/[A-Z]/g;function u(b,m){var S=e(m),v=m,A=n;return S in b.normal?b.property[b.normal[S]]:(S.length>4&&S.slice(0,4)===r&&a.test(m)&&(m.charAt(4)==="-"?v=c(m):m=f(m),A=t),new A(v,m))}function c(b){var m=b.slice(5).replace(i,g);return r+m.charAt(0).toUpperCase()+m.slice(1)}function f(b){var m=b.slice(4);return i.test(m)?b:(m=m.replace(l,p),m.charAt(0)!=="-"&&(m="-"+m),r+m)}function p(b){return"-"+b.toLowerCase()}function g(b){return b.charAt(1).toUpperCase()}return Jm}var eb,tD;function Dce(){if(tD)return eb;tD=1,eb=t;var e=/[#.]/g;function t(n,r){for(var a=n||"",i=r||"div",l={},u=0,c,f,p;u<a.length;)e.lastIndex=u,p=e.exec(a),c=a.slice(u,p?p.index:a.length),c&&(f?f==="#"?l.id=c:l.className?l.className.push(c):l.className=[c]:i=c,u+=c.length),p&&(f=p[0],u++);return{type:"element",tagName:i,properties:l,children:[]}}return eb}var cd={},nD;function Ice(){if(nD)return cd;nD=1,cd.parse=r,cd.stringify=a;var e="",t=" ",n=/[ \t\n\r\f]+/g;function r(i){var l=String(i||e).trim();return l===e?[]:l.split(n)}function a(i){return i.join(t).trim()}return cd}var dd={},rD;function Lce(){if(rD)return dd;rD=1,dd.parse=r,dd.stringify=a;var e=",",t=" ",n="";function r(i){for(var l=[],u=String(i||n),c=u.indexOf(e),f=0,p=!1,g;!p;)c===-1&&(c=u.length,p=!0),g=u.slice(f,c).trim(),(g||!p)&&l.push(g),f=c+1,c=u.indexOf(e,f);return l}function a(i,l){var u=l||{},c=u.padLeft===!1?n:t,f=u.padRight?t:n;return i[i.length-1]===n&&(i=i.concat(n)),i.join(f+e+c).trim()}return dd}var tb,aD;function Mce(){if(aD)return tb;aD=1;var e=Oce(),t=iA(),n=Dce(),r=Ice().parse,a=Lce().parse;tb=l;var i={}.hasOwnProperty;function l(S,v,A){var R=A?m(A):null;return x;function x(C,N){var _=n(C,v),O=Array.prototype.slice.call(arguments,2),z=_.tagName.toLowerCase(),I;if(_.tagName=R&&i.call(R,z)?R[z]:z,N&&u(N,_)&&(O.unshift(N),N=null),N)for(I in N)T(_.properties,I,N[I]);return f(_.children,O),_.tagName==="template"&&(_.content={type:"root",children:_.children},_.children=[]),_}function T(C,N,_){var O,z,I;_==null||_!==_||(O=e(S,N),z=O.property,I=_,typeof I=="string"&&(O.spaceSeparated?I=r(I):O.commaSeparated?I=a(I):O.commaOrSpaceSeparated&&(I=r(a(I).join(" ")))),z==="style"&&typeof _!="string"&&(I=b(I)),z==="className"&&C.className&&(I=C.className.concat(I)),C[z]=p(O,z,I))}}function u(S,v){return typeof S=="string"||"length"in S||c(v.tagName,S)}function c(S,v){var A=v.type;return S==="input"||!A||typeof A!="string"?!1:typeof v.children=="object"&&"length"in v.children?!0:(A=A.toLowerCase(),S==="button"?A!=="menu"&&A!=="submit"&&A!=="reset"&&A!=="button":"value"in v)}function f(S,v){var A,R;if(typeof v=="string"||typeof v=="number"){S.push({type:"text",value:String(v)});return}if(typeof v=="object"&&"length"in v){for(A=-1,R=v.length;++A<R;)f(S,v[A]);return}if(typeof v!="object"||!("type"in v))throw new Error("Expected node, nodes, or string, got `"+v+"`");S.push(v)}function p(S,v,A){var R,x,T;if(typeof A!="object"||!("length"in A))return g(S,v,A);for(x=A.length,R=-1,T=[];++R<x;)T[R]=g(S,v,A[R]);return T}function g(S,v,A){var R=A;return S.number||S.positiveNumber?!isNaN(R)&&R!==""&&(R=Number(R)):(S.boolean||S.overloadedBoolean)&&typeof R=="string"&&(R===""||t(A)===t(v))&&(R=!0),R}function b(S){var v=[],A;for(A in S)v.push([A,S[A]].join(": "));return v.join("; ")}function m(S){for(var v=S.length,A=-1,R={},x;++A<v;)x=S[A],R[x.toLowerCase()]=x;return R}return tb}var nb,oD;function Fce(){if(oD)return nb;oD=1;var e=Nce(),t=Mce(),n=t(e,"div");return n.displayName="html",nb=n,nb}var rb,iD;function zce(){return iD||(iD=1,rb=Fce()),rb}const Pce="Æ",Bce="&",Uce="Á",jce="Â",Gce="À",Hce="Å",$ce="Ã",qce="Ä",Vce="©",Wce="Ç",Yce="Ð",Kce="É",Xce="Ê",Zce="È",Qce="Ë",Jce=">",ede="Í",tde="Î",nde="Ì",rde="Ï",ade="<",ode="Ñ",ide="Ó",lde="Ô",sde="Ò",ude="Ø",cde="Õ",dde="Ö",fde='"',pde="®",gde="Þ",hde="Ú",mde="Û",bde="Ù",yde="Ü",vde="Ý",Sde="á",Ede="â",wde="´",xde="æ",kde="à",Ade="&",Tde="å",_de="ã",Rde="ä",Cde="¦",Nde="ç",Ode="¸",Dde="¢",Ide="©",Lde="¤",Mde="°",Fde="÷",zde="é",Pde="ê",Bde="è",Ude="ð",jde="ë",Gde="½",Hde="¼",$de="¾",qde=">",Vde="í",Wde="î",Yde="¡",Kde="ì",Xde="¿",Zde="ï",Qde="«",Jde="<",efe="¯",tfe="µ",nfe="·",rfe=" ",afe="¬",ofe="ñ",ife="ó",lfe="ô",sfe="ò",ufe="ª",cfe="º",dfe="ø",ffe="õ",pfe="ö",gfe="¶",hfe="±",mfe="£",bfe='"',yfe="»",vfe="®",Sfe="§",Efe="­",wfe="¹",xfe="²",kfe="³",Afe="ß",Tfe="þ",_fe="×",Rfe="ú",Cfe="û",Nfe="ù",Ofe="¨",Dfe="ü",Ife="ý",Lfe="¥",Mfe="ÿ",Ffe={AElig:Pce,AMP:Bce,Aacute:Uce,Acirc:jce,Agrave:Gce,Aring:Hce,Atilde:$ce,Auml:qce,COPY:Vce,Ccedil:Wce,ETH:Yce,Eacute:Kce,Ecirc:Xce,Egrave:Zce,Euml:Qce,GT:Jce,Iacute:ede,Icirc:tde,Igrave:nde,Iuml:rde,LT:ade,Ntilde:ode,Oacute:ide,Ocirc:lde,Ograve:sde,Oslash:ude,Otilde:cde,Ouml:dde,QUOT:fde,REG:pde,THORN:gde,Uacute:hde,Ucirc:mde,Ugrave:bde,Uuml:yde,Yacute:vde,aacute:Sde,acirc:Ede,acute:wde,aelig:xde,agrave:kde,amp:Ade,aring:Tde,atilde:_de,auml:Rde,brvbar:Cde,ccedil:Nde,cedil:Ode,cent:Dde,copy:Ide,curren:Lde,deg:Mde,divide:Fde,eacute:zde,ecirc:Pde,egrave:Bde,eth:Ude,euml:jde,frac12:Gde,frac14:Hde,frac34:$de,gt:qde,iacute:Vde,icirc:Wde,iexcl:Yde,igrave:Kde,iquest:Xde,iuml:Zde,laquo:Qde,lt:Jde,macr:efe,micro:tfe,middot:nfe,nbsp:rfe,not:afe,ntilde:ofe,oacute:ife,ocirc:lfe,ograve:sfe,ordf:ufe,ordm:cfe,oslash:dfe,otilde:ffe,ouml:pfe,para:gfe,plusmn:hfe,pound:mfe,quot:bfe,raquo:yfe,reg:vfe,sect:Sfe,shy:Efe,sup1:wfe,sup2:xfe,sup3:kfe,szlig:Afe,thorn:Tfe,times:_fe,uacute:Rfe,ucirc:Cfe,ugrave:Nfe,uml:Ofe,uuml:Dfe,yacute:Ife,yen:Lfe,yuml:Mfe},zfe={0:"�",128:"€",130:"‚",131:"ƒ",132:"„",133:"…",134:"†",135:"‡",136:"ˆ",137:"‰",138:"Š",139:"‹",140:"Œ",142:"Ž",145:"‘",146:"’",147:"“",148:"”",149:"•",150:"–",151:"—",152:"˜",153:"™",154:"š",155:"›",156:"œ",158:"ž",159:"Ÿ"};var ab,lD;function q5(){if(lD)return ab;lD=1,ab=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=48&&n<=57}return ab}var ob,sD;function Pfe(){if(sD)return ob;sD=1,ob=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=97&&n<=102||n>=65&&n<=70||n>=48&&n<=57}return ob}var ib,uD;function Bfe(){if(uD)return ib;uD=1,ib=e;function e(t){var n=typeof t=="string"?t.charCodeAt(0):t;return n>=97&&n<=122||n>=65&&n<=90}return ib}var lb,cD;function Ufe(){if(cD)return lb;cD=1;var e=Bfe(),t=q5();lb=n;function n(r){return e(r)||t(r)}return lb}var sb,dD;function jfe(){if(dD)return sb;dD=1;var e,t=59;sb=n;function n(r){var a="&"+r+";",i;return e=e||document.createElement("i"),e.innerHTML=a,i=e.textContent,i.charCodeAt(i.length-1)===t&&r!=="semi"||i===a?!1:i}return sb}var ub,fD;function Gfe(){if(fD)return ub;fD=1;var e=Ffe,t=zfe,n=q5(),r=Pfe(),a=Ufe(),i=jfe();ub=X;var l={}.hasOwnProperty,u=String.fromCharCode,c=Function.prototype,f={warning:null,reference:null,text:null,warningContext:null,referenceContext:null,textContext:null,position:{},additional:null,attribute:!1,nonTerminated:!0},p=9,g=10,b=12,m=32,S=38,v=59,A=60,R=61,x=35,T=88,C=120,N=65533,_="named",O="hexadecimal",z="decimal",I={};I[O]=16,I[z]=10;var M={};M[_]=a,M[z]=n,M[O]=r;var H=1,q=2,P=3,W=4,Z=5,j=6,G=7,B={};B[H]="Named character references must be terminated by a semicolon",B[q]="Numeric character references must be terminated by a semicolon",B[P]="Named character references cannot be empty",B[W]="Numeric character references cannot be empty",B[Z]="Named character references must be known",B[j]="Numeric character references cannot be disallowed",B[G]="Numeric character references cannot be outside the permissible Unicode range";function X(L,Y){var Q={},se,re;Y||(Y={});for(re in f)se=Y[re],Q[re]=se??f[re];return(Q.position.indent||Q.position.start)&&(Q.indent=Q.position.indent||[],Q.position=Q.position.start),D(L,Q)}function D(L,Y){var Q=Y.additional,se=Y.nonTerminated,re=Y.text,le=Y.reference,Ae=Y.warning,ae=Y.textContext,we=Y.referenceContext,xe=Y.warningContext,Ie=Y.position,Ce=Y.indent||[],Ee=L.length,J=0,fe=-1,ke=Ie.column||1,me=Ie.line||1,ve="",ie=[],ze,Pe,he,Ne,ee,ce,Re,Fe,qe,mt,St,pt,Je,wt,rt,bt,Bt,sn,Mt;for(typeof Q=="string"&&(Q=Q.charCodeAt(0)),bt=er(),Fe=Ae?zr:c,J--,Ee++;++J<Ee;)if(ee===g&&(ke=Ce[fe]||1),ee=L.charCodeAt(J),ee===S){if(Re=L.charCodeAt(J+1),Re===p||Re===g||Re===b||Re===m||Re===S||Re===A||Re!==Re||Q&&Re===Q){ve+=u(ee),ke++;continue}for(Je=J+1,pt=Je,Mt=Je,Re===x?(Mt=++pt,Re=L.charCodeAt(Mt),Re===T||Re===C?(wt=O,Mt=++pt):wt=z):wt=_,ze="",St="",Ne="",rt=M[wt],Mt--;++Mt<Ee&&(Re=L.charCodeAt(Mt),!!rt(Re));)Ne+=u(Re),wt===_&&l.call(e,Ne)&&(ze=Ne,St=e[Ne]);he=L.charCodeAt(Mt)===v,he&&(Mt++,Pe=wt===_?i(Ne):!1,Pe&&(ze=Ne,St=Pe)),sn=1+Mt-Je,!he&&!se||(Ne?wt===_?(he&&!St?Fe(Z,1):(ze!==Ne&&(Mt=pt+ze.length,sn=1+Mt-pt,he=!1),he||(qe=ze?H:P,Y.attribute?(Re=L.charCodeAt(Mt),Re===R?(Fe(qe,sn),St=null):a(Re)?St=null:Fe(qe,sn)):Fe(qe,sn))),ce=St):(he||Fe(q,sn),ce=parseInt(Ne,I[wt]),V(ce)?(Fe(G,sn),ce=u(N)):ce in t?(Fe(j,sn),ce=t[ce]):(mt="",U(ce)&&Fe(j,sn),ce>65535&&(ce-=65536,mt+=u(ce>>>10|55296),ce=56320|ce&1023),ce=mt+u(ce))):wt!==_&&Fe(W,sn)),ce?(Kt(),bt=er(),J=Mt-1,ke+=Mt-Je+1,ie.push(ce),Bt=er(),Bt.offset++,le&&le.call(we,ce,{start:bt,end:Bt},L.slice(Je-1,Mt)),bt=Bt):(Ne=L.slice(Je-1,Mt),ve+=Ne,ke+=Ne.length,J=Mt-1)}else ee===10&&(me++,fe++,ke=0),ee===ee?(ve+=u(ee),ke++):Kt();return ie.join("");function er(){return{line:me,column:ke,offset:J+(Ie.offset||0)}}function zr(na,Ke){var gt=er();gt.column+=Ke,gt.offset+=Ke,Ae.call(xe,B[na],gt,na)}function Kt(){ve&&(ie.push(ve),re&&re.call(ae,ve,{start:bt,end:er()}),ve="")}}function V(L){return L>=55296&&L<=57343||L>1114111}function U(L){return L>=1&&L<=8||L===11||L>=13&&L<=31||L>=127&&L<=159||L>=64976&&L<=65007||(L&65535)===65535||(L&65535)===65534}return ub}var cb={exports:{}},pD;function Hfe(){return pD||(pD=1,function(e){var t=typeof window<"u"?window:typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope?self:{};/**
 * Prism: Lightweight, robust, elegant syntax highlighting
 *
 * @license MIT <https://opensource.org/licenses/MIT>
 * @author Lea Verou <https://lea.verou.me>
 * @namespace
 * @public
 */var n=function(r){var a=/(?:^|\s)lang(?:uage)?-([\w-]+)(?=\s|$)/i,i=0,l={},u={manual:r.Prism&&r.Prism.manual,disableWorkerMessageHandler:r.Prism&&r.Prism.disableWorkerMessageHandler,util:{encode:function x(T){return T instanceof c?new c(T.type,x(T.content),T.alias):Array.isArray(T)?T.map(x):T.replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/\u00a0/g," ")},type:function(x){return Object.prototype.toString.call(x).slice(8,-1)},objId:function(x){return x.__id||Object.defineProperty(x,"__id",{value:++i}),x.__id},clone:function x(T,C){C=C||{};var N,_;switch(u.util.type(T)){case"Object":if(_=u.util.objId(T),C[_])return C[_];N={},C[_]=N;for(var O in T)T.hasOwnProperty(O)&&(N[O]=x(T[O],C));return N;case"Array":return _=u.util.objId(T),C[_]?C[_]:(N=[],C[_]=N,T.forEach(function(z,I){N[I]=x(z,C)}),N);default:return T}},getLanguage:function(x){for(;x;){var T=a.exec(x.className);if(T)return T[1].toLowerCase();x=x.parentElement}return"none"},setLanguage:function(x,T){x.className=x.className.replace(RegExp(a,"gi"),""),x.classList.add("language-"+T)},currentScript:function(){if(typeof document>"u")return null;if("currentScript"in document)return document.currentScript;try{throw new Error}catch(N){var x=(/at [^(\r\n]*\((.*):[^:]+:[^:]+\)$/i.exec(N.stack)||[])[1];if(x){var T=document.getElementsByTagName("script");for(var C in T)if(T[C].src==x)return T[C]}return null}},isActive:function(x,T,C){for(var N="no-"+T;x;){var _=x.classList;if(_.contains(T))return!0;if(_.contains(N))return!1;x=x.parentElement}return!!C}},languages:{plain:l,plaintext:l,text:l,txt:l,extend:function(x,T){var C=u.util.clone(u.languages[x]);for(var N in T)C[N]=T[N];return C},insertBefore:function(x,T,C,N){N=N||u.languages;var _=N[x],O={};for(var z in _)if(_.hasOwnProperty(z)){if(z==T)for(var I in C)C.hasOwnProperty(I)&&(O[I]=C[I]);C.hasOwnProperty(z)||(O[z]=_[z])}var M=N[x];return N[x]=O,u.languages.DFS(u.languages,function(H,q){q===M&&H!=x&&(this[H]=O)}),O},DFS:function x(T,C,N,_){_=_||{};var O=u.util.objId;for(var z in T)if(T.hasOwnProperty(z)){C.call(T,z,T[z],N||z);var I=T[z],M=u.util.type(I);M==="Object"&&!_[O(I)]?(_[O(I)]=!0,x(I,C,null,_)):M==="Array"&&!_[O(I)]&&(_[O(I)]=!0,x(I,C,z,_))}}},plugins:{},highlightAll:function(x,T){u.highlightAllUnder(document,x,T)},highlightAllUnder:function(x,T,C){var N={callback:C,container:x,selector:'code[class*="language-"], [class*="language-"] code, code[class*="lang-"], [class*="lang-"] code'};u.hooks.run("before-highlightall",N),N.elements=Array.prototype.slice.apply(N.container.querySelectorAll(N.selector)),u.hooks.run("before-all-elements-highlight",N);for(var _=0,O;O=N.elements[_++];)u.highlightElement(O,T===!0,N.callback)},highlightElement:function(x,T,C){var N=u.util.getLanguage(x),_=u.languages[N];u.util.setLanguage(x,N);var O=x.parentElement;O&&O.nodeName.toLowerCase()==="pre"&&u.util.setLanguage(O,N);var z=x.textContent,I={element:x,language:N,grammar:_,code:z};function M(q){I.highlightedCode=q,u.hooks.run("before-insert",I),I.element.innerHTML=I.highlightedCode,u.hooks.run("after-highlight",I),u.hooks.run("complete",I),C&&C.call(I.element)}if(u.hooks.run("before-sanity-check",I),O=I.element.parentElement,O&&O.nodeName.toLowerCase()==="pre"&&!O.hasAttribute("tabindex")&&O.setAttribute("tabindex","0"),!I.code){u.hooks.run("complete",I),C&&C.call(I.element);return}if(u.hooks.run("before-highlight",I),!I.grammar){M(u.util.encode(I.code));return}if(T&&r.Worker){var H=new Worker(u.filename);H.onmessage=function(q){M(q.data)},H.postMessage(JSON.stringify({language:I.language,code:I.code,immediateClose:!0}))}else M(u.highlight(I.code,I.grammar,I.language))},highlight:function(x,T,C){var N={code:x,grammar:T,language:C};if(u.hooks.run("before-tokenize",N),!N.grammar)throw new Error('The language "'+N.language+'" has no grammar.');return N.tokens=u.tokenize(N.code,N.grammar),u.hooks.run("after-tokenize",N),c.stringify(u.util.encode(N.tokens),N.language)},tokenize:function(x,T){var C=T.rest;if(C){for(var N in C)T[N]=C[N];delete T.rest}var _=new g;return b(_,_.head,x),p(x,_,T,_.head,0),S(_)},hooks:{all:{},add:function(x,T){var C=u.hooks.all;C[x]=C[x]||[],C[x].push(T)},run:function(x,T){var C=u.hooks.all[x];if(!(!C||!C.length))for(var N=0,_;_=C[N++];)_(T)}},Token:c};r.Prism=u;function c(x,T,C,N){this.type=x,this.content=T,this.alias=C,this.length=(N||"").length|0}c.stringify=function x(T,C){if(typeof T=="string")return T;if(Array.isArray(T)){var N="";return T.forEach(function(M){N+=x(M,C)}),N}var _={type:T.type,content:x(T.content,C),tag:"span",classes:["token",T.type],attributes:{},language:C},O=T.alias;O&&(Array.isArray(O)?Array.prototype.push.apply(_.classes,O):_.classes.push(O)),u.hooks.run("wrap",_);var z="";for(var I in _.attributes)z+=" "+I+'="'+(_.attributes[I]||"").replace(/"/g,"&quot;")+'"';return"<"+_.tag+' class="'+_.classes.join(" ")+'"'+z+">"+_.content+"</"+_.tag+">"};function f(x,T,C,N){x.lastIndex=T;var _=x.exec(C);if(_&&N&&_[1]){var O=_[1].length;_.index+=O,_[0]=_[0].slice(O)}return _}function p(x,T,C,N,_,O){for(var z in C)if(!(!C.hasOwnProperty(z)||!C[z])){var I=C[z];I=Array.isArray(I)?I:[I];for(var M=0;M<I.length;++M){if(O&&O.cause==z+","+M)return;var H=I[M],q=H.inside,P=!!H.lookbehind,W=!!H.greedy,Z=H.alias;if(W&&!H.pattern.global){var j=H.pattern.toString().match(/[imsuy]*$/)[0];H.pattern=RegExp(H.pattern.source,j+"g")}for(var G=H.pattern||H,B=N.next,X=_;B!==T.tail&&!(O&&X>=O.reach);X+=B.value.length,B=B.next){var D=B.value;if(T.length>x.length)return;if(!(D instanceof c)){var V=1,U;if(W){if(U=f(G,X,x,P),!U||U.index>=x.length)break;var se=U.index,L=U.index+U[0].length,Y=X;for(Y+=B.value.length;se>=Y;)B=B.next,Y+=B.value.length;if(Y-=B.value.length,X=Y,B.value instanceof c)continue;for(var Q=B;Q!==T.tail&&(Y<L||typeof Q.value=="string");Q=Q.next)V++,Y+=Q.value.length;V--,D=x.slice(X,Y),U.index-=X}else if(U=f(G,0,D,P),!U)continue;var se=U.index,re=U[0],le=D.slice(0,se),Ae=D.slice(se+re.length),ae=X+D.length;O&&ae>O.reach&&(O.reach=ae);var we=B.prev;le&&(we=b(T,we,le),X+=le.length),m(T,we,V);var xe=new c(z,q?u.tokenize(re,q):re,Z,re);if(B=b(T,we,xe),Ae&&b(T,B,Ae),V>1){var Ie={cause:z+","+M,reach:ae};p(x,T,C,B.prev,X,Ie),O&&Ie.reach>O.reach&&(O.reach=Ie.reach)}}}}}}function g(){var x={value:null,prev:null,next:null},T={value:null,prev:x,next:null};x.next=T,this.head=x,this.tail=T,this.length=0}function b(x,T,C){var N=T.next,_={value:C,prev:T,next:N};return T.next=_,N.prev=_,x.length++,_}function m(x,T,C){for(var N=T.next,_=0;_<C&&N!==x.tail;_++)N=N.next;T.next=N,N.prev=T,x.length-=_}function S(x){for(var T=[],C=x.head.next;C!==x.tail;)T.push(C.value),C=C.next;return T}if(!r.document)return r.addEventListener&&(u.disableWorkerMessageHandler||r.addEventListener("message",function(x){var T=JSON.parse(x.data),C=T.language,N=T.code,_=T.immediateClose;r.postMessage(u.highlight(N,u.languages[C],C)),_&&r.close()},!1)),u;var v=u.util.currentScript();v&&(u.filename=v.src,v.hasAttribute("data-manual")&&(u.manual=!0));function A(){u.manual||u.highlightAll()}if(!u.manual){var R=document.readyState;R==="loading"||R==="interactive"&&v&&v.defer?document.addEventListener("DOMContentLoaded",A):window.requestAnimationFrame?window.requestAnimationFrame(A):window.setTimeout(A,16)}return u}(t);e.exports&&(e.exports=n),typeof Cd<"u"&&(Cd.Prism=n)}(cb)),cb.exports}var db,gD;function $fe(){if(gD)return db;gD=1,db=e,e.displayName="markup",e.aliases=["html","mathml","svg","xml","ssml","atom","rss"];function e(t){t.languages.markup={comment:{pattern:/<!--(?:(?!<!--)[\s\S])*?-->/,greedy:!0},prolog:{pattern:/<\?[\s\S]+?\?>/,greedy:!0},doctype:{pattern:/<!DOCTYPE(?:[^>"'[\]]|"[^"]*"|'[^']*')+(?:\[(?:[^<"'\]]|"[^"]*"|'[^']*'|<(?!!--)|<!--(?:[^-]|-(?!->))*-->)*\]\s*)?>/i,greedy:!0,inside:{"internal-subset":{pattern:/(^[^\[]*\[)[\s\S]+(?=\]>$)/,lookbehind:!0,greedy:!0,inside:null},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},punctuation:/^<!|>$|[[\]]/,"doctype-tag":/^DOCTYPE/i,name:/[^\s<>'"]+/}},cdata:{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,greedy:!0},tag:{pattern:/<\/?(?!\d)[^\s>\/=$<%]+(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?\s*\/?>/,greedy:!0,inside:{tag:{pattern:/^<\/?[^\s>\/]+/,inside:{punctuation:/^<\/?/,namespace:/^[^\s>\/:]+:/}},"special-attr":[],"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+)/,inside:{punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}},punctuation:/\/?>/,"attr-name":{pattern:/[^\s>\/]+/,inside:{namespace:/^[^\s>\/:]+:/}}}},entity:[{pattern:/&[\da-z]{1,8};/i,alias:"named-entity"},/&#x?[\da-f]{1,8};/i]},t.languages.markup.tag.inside["attr-value"].inside.entity=t.languages.markup.entity,t.languages.markup.doctype.inside["internal-subset"].inside=t.languages.markup,t.hooks.add("wrap",function(n){n.type==="entity"&&(n.attributes.title=n.content.value.replace(/&amp;/,"&"))}),Object.defineProperty(t.languages.markup.tag,"addInlined",{value:function(r,a){var i={};i["language-"+a]={pattern:/(^<!\[CDATA\[)[\s\S]+?(?=\]\]>$)/i,lookbehind:!0,inside:t.languages[a]},i.cdata=/^<!\[CDATA\[|\]\]>$/i;var l={"included-cdata":{pattern:/<!\[CDATA\[[\s\S]*?\]\]>/i,inside:i}};l["language-"+a]={pattern:/[\s\S]+/,inside:t.languages[a]};var u={};u[r]={pattern:RegExp(/(<__[^>]*>)(?:<!\[CDATA\[(?:[^\]]|\](?!\]>))*\]\]>|(?!<!\[CDATA\[)[\s\S])*?(?=<\/__>)/.source.replace(/__/g,function(){return r}),"i"),lookbehind:!0,greedy:!0,inside:l},t.languages.insertBefore("markup","cdata",u)}}),Object.defineProperty(t.languages.markup.tag,"addAttribute",{value:function(n,r){t.languages.markup.tag.inside["special-attr"].push({pattern:RegExp(/(^|["'\s])/.source+"(?:"+n+")"+/\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))/.source,"i"),lookbehind:!0,inside:{"attr-name":/^[^\s=]+/,"attr-value":{pattern:/=[\s\S]+/,inside:{value:{pattern:/(^=\s*(["']|(?!["'])))\S[\s\S]*(?=\2$)/,lookbehind:!0,alias:[r,"language-"+r],inside:t.languages[r]},punctuation:[{pattern:/^=/,alias:"attr-equals"},/"|'/]}}}})}}),t.languages.html=t.languages.markup,t.languages.mathml=t.languages.markup,t.languages.svg=t.languages.markup,t.languages.xml=t.languages.extend("markup",{}),t.languages.ssml=t.languages.xml,t.languages.atom=t.languages.xml,t.languages.rss=t.languages.xml}return db}var fb,hD;function qfe(){if(hD)return fb;hD=1,fb=e,e.displayName="css",e.aliases=[];function e(t){(function(n){var r=/(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/;n.languages.css={comment:/\/\*[\s\S]*?\*\//,atrule:{pattern:/@[\w-](?:[^;{\s]|\s+(?![\s{]))*(?:;|(?=\s*\{))/,inside:{rule:/^@[\w-]+/,"selector-function-argument":{pattern:/(\bselector\s*\(\s*(?![\s)]))(?:[^()\s]|\s+(?![\s)])|\((?:[^()]|\([^()]*\))*\))+(?=\s*\))/,lookbehind:!0,alias:"selector"},keyword:{pattern:/(^|[^\w-])(?:and|not|only|or)(?![\w-])/,lookbehind:!0}}},url:{pattern:RegExp("\\burl\\((?:"+r.source+"|"+/(?:[^\\\r\n()"']|\\[\s\S])*/.source+")\\)","i"),greedy:!0,inside:{function:/^url/i,punctuation:/^\(|\)$/,string:{pattern:RegExp("^"+r.source+"$"),alias:"url"}}},selector:{pattern:RegExp(`(^|[{}\\s])[^{}\\s](?:[^{};"'\\s]|\\s+(?![\\s{])|`+r.source+")*(?=\\s*\\{)"),lookbehind:!0},string:{pattern:r,greedy:!0},property:{pattern:/(^|[^-\w\xA0-\uFFFF])(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*(?=\s*:)/i,lookbehind:!0},important:/!important\b/i,function:{pattern:/(^|[^-a-z0-9])[-a-z0-9]+(?=\()/i,lookbehind:!0},punctuation:/[(){};:,]/},n.languages.css.atrule.inside.rest=n.languages.css;var a=n.languages.markup;a&&(a.tag.addInlined("style","css"),a.tag.addAttribute("style","css"))})(t)}return fb}var pb,mD;function Vfe(){if(mD)return pb;mD=1,pb=e,e.displayName="clike",e.aliases=[];function e(t){t.languages.clike={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|trait)\s+|\bcatch\s+\()[\w.\\]+/i,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:break|catch|continue|do|else|finally|for|function|if|in|instanceof|new|null|return|throw|try|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b\w+(?=\()/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/,punctuation:/[{}[\];(),.:]/}}return pb}var gb,bD;function Wfe(){if(bD)return gb;bD=1,gb=e,e.displayName="javascript",e.aliases=["js"];function e(t){t.languages.javascript=t.languages.extend("clike",{"class-name":[t.languages.clike["class-name"],{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$A-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\.(?:constructor|prototype))/,lookbehind:!0}],keyword:[{pattern:/((?:^|\})\s*)catch\b/,lookbehind:!0},{pattern:/(^|[^.]|\.\.\.\s*)\b(?:as|assert(?=\s*\{)|async(?=\s*(?:function\b|\(|[$\w\xA0-\uFFFF]|$))|await|break|case|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally(?=\s*(?:\{|$))|for|from(?=\s*(?:['"]|$))|function|(?:get|set)(?=\s*(?:[#\[$\w\xA0-\uFFFF]|$))|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)\b/,lookbehind:!0}],function:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*(?:\.\s*(?:apply|bind|call)\s*)?\()/,number:{pattern:RegExp(/(^|[^\w$])/.source+"(?:"+(/NaN|Infinity/.source+"|"+/0[bB][01]+(?:_[01]+)*n?/.source+"|"+/0[oO][0-7]+(?:_[0-7]+)*n?/.source+"|"+/0[xX][\dA-Fa-f]+(?:_[\dA-Fa-f]+)*n?/.source+"|"+/\d+(?:_\d+)*n/.source+"|"+/(?:\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[Ee][+-]?\d+(?:_\d+)*)?/.source)+")"+/(?![\w$])/.source),lookbehind:!0},operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/}),t.languages.javascript["class-name"][0].pattern=/(\b(?:class|extends|implements|instanceof|interface|new)\s+)[\w.\\]+/,t.languages.insertBefore("javascript","keyword",{regex:{pattern:/((?:^|[^$\w\xA0-\uFFFF."'\])\s]|\b(?:return|yield))\s*)\/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[dgimyus]{0,7}(?=(?:\s|\/\*(?:[^*]|\*(?!\/))*\*\/)*(?:$|[\r\n,.;:})\]]|\/\/))/,lookbehind:!0,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^\/|\/$/,"regex-flags":/^[a-z]+$/}},"function-variable":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:async\s*)?(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"},parameter:[{pattern:/(function(?:\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)?\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\))/,lookbehind:!0,inside:t.languages.javascript},{pattern:/(^|[^$\w\xA0-\uFFFF])(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=>)/i,lookbehind:!0,inside:t.languages.javascript},{pattern:/(\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*=>)/,lookbehind:!0,inside:t.languages.javascript},{pattern:/((?:\b|\s|^)(?!(?:as|async|await|break|case|catch|class|const|continue|debugger|default|delete|do|else|enum|export|extends|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|new|null|of|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|undefined|var|void|while|with|yield)(?![$\w\xA0-\uFFFF]))(?:(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*)\(\s*|\]\s*\(\s*)(?!\s)(?:[^()\s]|\s+(?![\s)])|\([^()]*\))+(?=\s*\)\s*\{)/,lookbehind:!0,inside:t.languages.javascript}],constant:/\b[A-Z](?:[A-Z_]|\dx?)*\b/}),t.languages.insertBefore("javascript","string",{hashbang:{pattern:/^#!.*/,greedy:!0,alias:"comment"},"template-string":{pattern:/`(?:\\[\s\S]|\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}|(?!\$\{)[^\\`])*`/,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:t.languages.javascript}},string:/[\s\S]+/}},"string-property":{pattern:/((?:^|[,{])[ \t]*)(["'])(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2(?=\s*:)/m,lookbehind:!0,greedy:!0,alias:"property"}}),t.languages.insertBefore("javascript","operator",{"literal-property":{pattern:/((?:^|[,{])[ \t]*)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/m,lookbehind:!0,alias:"property"}}),t.languages.markup&&(t.languages.markup.tag.addInlined("script","javascript"),t.languages.markup.tag.addAttribute(/on(?:abort|blur|change|click|composition(?:end|start|update)|dblclick|error|focus(?:in|out)?|key(?:down|up)|load|mouse(?:down|enter|leave|move|out|over|up)|reset|resize|scroll|select|slotchange|submit|unload|wheel)/.source,"javascript")),t.languages.js=t.languages.javascript}return gb}var hb,yD;function Yfe(){if(yD)return hb;yD=1;var e=typeof globalThis=="object"?globalThis:typeof self=="object"?self:typeof window=="object"?window:typeof Cd=="object"?Cd:{},t=N();e.Prism={manual:!0,disableWorkerMessageHandler:!0};var n=zce(),r=Gfe(),a=Hfe(),i=$fe(),l=qfe(),u=Vfe(),c=Wfe();t();var f={}.hasOwnProperty;function p(){}p.prototype=a;var g=new p;hb=g,g.highlight=S,g.register=b,g.alias=m,g.registered=v,g.listLanguages=A,b(i),b(l),b(u),b(c),g.util.encode=T,g.Token.stringify=R;function b(_){if(typeof _!="function"||!_.displayName)throw new Error("Expected `function` for `grammar`, got `"+_+"`");g.languages[_.displayName]===void 0&&_(g)}function m(_,O){var z=g.languages,I=_,M,H,q,P;O&&(I={},I[_]=O);for(M in I)for(H=I[M],H=typeof H=="string"?[H]:H,q=H.length,P=-1;++P<q;)z[H[P]]=z[M]}function S(_,O){var z=a.highlight,I;if(typeof _!="string")throw new Error("Expected `string` for `value`, got `"+_+"`");if(g.util.type(O)==="Object")I=O,O=null;else{if(typeof O!="string")throw new Error("Expected `string` for `name`, got `"+O+"`");if(f.call(g.languages,O))I=g.languages[O];else throw new Error("Unknown language: `"+O+"` is not registered")}return z.call(this,_,I,O)}function v(_){if(typeof _!="string")throw new Error("Expected `string` for `language`, got `"+_+"`");return f.call(g.languages,_)}function A(){var _=g.languages,O=[],z;for(z in _)f.call(_,z)&&typeof _[z]=="object"&&O.push(z);return O}function R(_,O,z){var I;return typeof _=="string"?{type:"text",value:_}:g.util.type(_)==="Array"?x(_,O):(I={type:_.type,content:g.Token.stringify(_.content,O,z),tag:"span",classes:["token",_.type],attributes:{},language:O,parent:z},_.alias&&(I.classes=I.classes.concat(_.alias)),g.hooks.run("wrap",I),n(I.tag+"."+I.classes.join("."),C(I.attributes),I.content))}function x(_,O){for(var z=[],I=_.length,M=-1,H;++M<I;)H=_[M],H!==""&&H!==null&&H!==void 0&&z.push(H);for(M=-1,I=z.length;++M<I;)H=z[M],z[M]=g.Token.stringify(H,O,z);return z}function T(_){return _}function C(_){var O;for(O in _)_[O]=r(_[O]);return _}function N(){var _="Prism"in e,O=_?e.Prism:void 0;return z;function z(){_?e.Prism=O:delete e.Prism,_=void 0,O=void 0}}return hb}const Kfe={'code[class*="language-"]':{color:"black",background:"none",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"#f5f2f0",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{background:"#f5f2f0",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"slategray"},prolog:{color:"slategray"},doctype:{color:"slategray"},cdata:{color:"slategray"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#905"},tag:{color:"#905"},boolean:{color:"#905"},number:{color:"#905"},constant:{color:"#905"},symbol:{color:"#905"},deleted:{color:"#905"},selector:{color:"#690"},"attr-name":{color:"#690"},string:{color:"#690"},char:{color:"#690"},builtin:{color:"#690"},inserted:{color:"#690"},operator:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},entity:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)",cursor:"help"},url:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".language-css .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".style .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},atrule:{color:"#07a"},"attr-value":{color:"#07a"},keyword:{color:"#07a"},function:{color:"#DD4A68"},"class-name":{color:"#DD4A68"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},variable:{color:"#e90"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}};var mb,vD;function Xfe(){if(vD)return mb;vD=1,mb=e,e.displayName="abap",e.aliases=[];function e(t){t.languages.abap={comment:/^\*.*/m,string:/(`|')(?:\\.|(?!\1)[^\\\r\n])*\1/,"string-template":{pattern:/([|}])(?:\\.|[^\\|{\r\n])*(?=[|{])/,lookbehind:!0,alias:"string"},"eol-comment":{pattern:/(^|\s)".*/m,lookbehind:!0,alias:"comment"},keyword:{pattern:/(\s|\.|^)(?:SCIENTIFIC_WITH_LEADING_ZERO|SCALE_PRESERVING_SCIENTIFIC|RMC_COMMUNICATION_FAILURE|END-ENHANCEMENT-SECTION|MULTIPLY-CORRESPONDING|SUBTRACT-CORRESPONDING|VERIFICATION-MESSAGE|DIVIDE-CORRESPONDING|ENHANCEMENT-SECTION|CURRENCY_CONVERSION|RMC_SYSTEM_FAILURE|START-OF-SELECTION|MOVE-CORRESPONDING|RMC_INVALID_STATUS|CUSTOMER-FUNCTION|END-OF-DEFINITION|ENHANCEMENT-POINT|SYSTEM-EXCEPTIONS|ADD-CORRESPONDING|SCALE_PRESERVING|SELECTION-SCREEN|CURSOR-SELECTION|END-OF-SELECTION|LOAD-OF-PROGRAM|SCROLL-BOUNDARY|SELECTION-TABLE|EXCEPTION-TABLE|IMPLEMENTATIONS|PARAMETER-TABLE|RIGHT-JUSTIFIED|UNIT_CONVERSION|AUTHORITY-CHECK|LIST-PROCESSING|SIGN_AS_POSTFIX|COL_BACKGROUND|IMPLEMENTATION|INTERFACE-POOL|TRANSFORMATION|IDENTIFICATION|ENDENHANCEMENT|LINE-SELECTION|INITIALIZATION|LEFT-JUSTIFIED|SELECT-OPTIONS|SELECTION-SETS|COMMUNICATION|CORRESPONDING|DECIMAL_SHIFT|PRINT-CONTROL|VALUE-REQUEST|CHAIN-REQUEST|FUNCTION-POOL|FIELD-SYMBOLS|FUNCTIONALITY|INVERTED-DATE|SELECTION-SET|CLASS-METHODS|OUTPUT-LENGTH|CLASS-CODING|COL_NEGATIVE|ERRORMESSAGE|FIELD-GROUPS|HELP-REQUEST|NO-EXTENSION|NO-TOPOFPAGE|REDEFINITION|DISPLAY-MODE|ENDINTERFACE|EXIT-COMMAND|FIELD-SYMBOL|NO-SCROLLING|SHORTDUMP-ID|ACCESSPOLICY|CLASS-EVENTS|COL_POSITIVE|DECLARATIONS|ENHANCEMENTS|FILTER-TABLE|SWITCHSTATES|SYNTAX-CHECK|TRANSPORTING|ASYNCHRONOUS|SYNTAX-TRACE|TOKENIZATION|USER-COMMAND|WITH-HEADING|ABAP-SOURCE|BREAK-POINT|CHAIN-INPUT|COMPRESSION|FIXED-POINT|NEW-SECTION|NON-UNICODE|OCCURRENCES|RESPONSIBLE|SYSTEM-CALL|TRACE-TABLE|ABBREVIATED|CHAR-TO-HEX|END-OF-FILE|ENDFUNCTION|ENVIRONMENT|ASSOCIATION|COL_HEADING|EDITOR-CALL|END-OF-PAGE|ENGINEERING|IMPLEMENTED|INTENSIFIED|RADIOBUTTON|SYSTEM-EXIT|TOP-OF-PAGE|TRANSACTION|APPLICATION|CONCATENATE|DESTINATION|ENHANCEMENT|IMMEDIATELY|NO-GROUPING|PRECOMPILED|REPLACEMENT|TITLE-LINES|ACTIVATION|BYTE-ORDER|CLASS-POOL|CONNECTION|CONVERSION|DEFINITION|DEPARTMENT|EXPIRATION|INHERITING|MESSAGE-ID|NO-HEADING|PERFORMING|QUEUE-ONLY|RIGHTSPACE|SCIENTIFIC|STATUSINFO|STRUCTURES|SYNCPOINTS|WITH-TITLE|ATTRIBUTES|BOUNDARIES|CLASS-DATA|COL_NORMAL|DD\/MM\/YYYY|DESCENDING|INTERFACES|LINE-COUNT|MM\/DD\/YYYY|NON-UNIQUE|PRESERVING|SELECTIONS|STATEMENTS|SUBROUTINE|TRUNCATION|TYPE-POOLS|ARITHMETIC|BACKGROUND|ENDPROVIDE|EXCEPTIONS|IDENTIFIER|INDEX-LINE|OBLIGATORY|PARAMETERS|PERCENTAGE|PUSHBUTTON|RESOLUTION|COMPONENTS|DEALLOCATE|DISCONNECT|DUPLICATES|FIRST-LINE|HEAD-LINES|NO-DISPLAY|OCCURRENCE|RESPECTING|RETURNCODE|SUBMATCHES|TRACE-FILE|ASCENDING|BYPASSING|ENDMODULE|EXCEPTION|EXCLUDING|EXPORTING|INCREMENT|MATCHCODE|PARAMETER|PARTIALLY|PREFERRED|REFERENCE|REPLACING|RETURNING|SELECTION|SEPARATED|SPECIFIED|STATEMENT|TIMESTAMP|TYPE-POOL|ACCEPTING|APPENDAGE|ASSIGNING|COL_GROUP|COMPARING|CONSTANTS|DANGEROUS|IMPORTING|INSTANCES|LEFTSPACE|LOG-POINT|QUICKINFO|READ-ONLY|SCROLLING|SQLSCRIPT|STEP-LOOP|TOP-LINES|TRANSLATE|APPENDING|AUTHORITY|CHARACTER|COMPONENT|CONDITION|DIRECTORY|DUPLICATE|MESSAGING|RECEIVING|SUBSCREEN|ACCORDING|COL_TOTAL|END-LINES|ENDMETHOD|ENDSELECT|EXPANDING|EXTENSION|INCLUDING|INFOTYPES|INTERFACE|INTERVALS|LINE-SIZE|PF-STATUS|PROCEDURE|PROTECTED|REQUESTED|RESUMABLE|RIGHTPLUS|SAP-SPOOL|SECONDARY|STRUCTURE|SUBSTRING|TABLEVIEW|NUMOFCHAR|ADJACENT|ANALYSIS|ASSIGNED|BACKWARD|CHANNELS|CHECKBOX|CONTINUE|CRITICAL|DATAINFO|DD\/MM\/YY|DURATION|ENCODING|ENDCLASS|FUNCTION|LEFTPLUS|LINEFEED|MM\/DD\/YY|OVERFLOW|RECEIVED|SKIPPING|SORTABLE|STANDARD|SUBTRACT|SUPPRESS|TABSTRIP|TITLEBAR|TRUNCATE|UNASSIGN|WHENEVER|ANALYZER|COALESCE|COMMENTS|CONDENSE|DECIMALS|DEFERRED|ENDWHILE|EXPLICIT|KEYWORDS|MESSAGES|POSITION|PRIORITY|RECEIVER|RENAMING|TIMEZONE|TRAILING|ALLOCATE|CENTERED|CIRCULAR|CONTROLS|CURRENCY|DELETING|DESCRIBE|DISTANCE|ENDCATCH|EXPONENT|EXTENDED|GENERATE|IGNORING|INCLUDES|INTERNAL|MAJOR-ID|MODIFIER|NEW-LINE|OPTIONAL|PROPERTY|ROLLBACK|STARTING|SUPPLIED|ABSTRACT|CHANGING|CONTEXTS|CREATING|CUSTOMER|DATABASE|DAYLIGHT|DEFINING|DISTINCT|DIVISION|ENABLING|ENDCHAIN|ESCAPING|HARMLESS|IMPLICIT|INACTIVE|LANGUAGE|MINOR-ID|MULTIPLY|NEW-PAGE|NO-TITLE|POS_HIGH|SEPARATE|TEXTPOOL|TRANSFER|SELECTOR|DBMAXLEN|ITERATOR|ARCHIVE|BIT-XOR|BYTE-CO|COLLECT|COMMENT|CURRENT|DEFAULT|DISPLAY|ENDFORM|EXTRACT|LEADING|LISTBOX|LOCATOR|MEMBERS|METHODS|NESTING|POS_LOW|PROCESS|PROVIDE|RAISING|RESERVE|SECONDS|SUMMARY|VISIBLE|BETWEEN|BIT-AND|BYTE-CS|CLEANUP|COMPUTE|CONTROL|CONVERT|DATASET|ENDCASE|FORWARD|HEADERS|HOTSPOT|INCLUDE|INVERSE|KEEPING|NO-ZERO|OBJECTS|OVERLAY|PADDING|PATTERN|PROGRAM|REFRESH|SECTION|SUMMING|TESTING|VERSION|WINDOWS|WITHOUT|BIT-NOT|BYTE-CA|BYTE-NA|CASTING|CONTEXT|COUNTRY|DYNAMIC|ENABLED|ENDLOOP|EXECUTE|FRIENDS|HANDLER|HEADING|INITIAL|\*-INPUT|LOGFILE|MAXIMUM|MINIMUM|NO-GAPS|NO-SIGN|PRAGMAS|PRIMARY|PRIVATE|REDUCED|REPLACE|REQUEST|RESULTS|UNICODE|WARNING|ALIASES|BYTE-CN|BYTE-NS|CALLING|COL_KEY|COLUMNS|CONNECT|ENDEXEC|ENTRIES|EXCLUDE|FILTERS|FURTHER|HELP-ID|LOGICAL|MAPPING|MESSAGE|NAMETAB|OPTIONS|PACKAGE|PERFORM|RECEIVE|STATICS|VARYING|BINDING|CHARLEN|GREATER|XSTRLEN|ACCEPT|APPEND|DETAIL|ELSEIF|ENDING|ENDTRY|FORMAT|FRAMES|GIVING|HASHED|HEADER|IMPORT|INSERT|MARGIN|MODULE|NATIVE|OBJECT|OFFSET|REMOTE|RESUME|SAVING|SIMPLE|SUBMIT|TABBED|TOKENS|UNIQUE|UNPACK|UPDATE|WINDOW|YELLOW|ACTUAL|ASPECT|CENTER|CURSOR|DELETE|DIALOG|DIVIDE|DURING|ERRORS|EVENTS|EXTEND|FILTER|HANDLE|HAVING|IGNORE|LITTLE|MEMORY|NO-GAP|OCCURS|OPTION|PERSON|PLACES|PUBLIC|REDUCE|REPORT|RESULT|SINGLE|SORTED|SWITCH|SYNTAX|TARGET|VALUES|WRITER|ASSERT|BLOCKS|BOUNDS|BUFFER|CHANGE|COLUMN|COMMIT|CONCAT|COPIES|CREATE|DDMMYY|DEFINE|ENDIAN|ESCAPE|EXPAND|KERNEL|LAYOUT|LEGACY|LEVELS|MMDDYY|NUMBER|OUTPUT|RANGES|READER|RETURN|SCREEN|SEARCH|SELECT|SHARED|SOURCE|STABLE|STATIC|SUBKEY|SUFFIX|TABLES|UNWIND|YYMMDD|ASSIGN|BACKUP|BEFORE|BINARY|BIT-OR|BLANKS|CLIENT|CODING|COMMON|DEMAND|DYNPRO|EXCEPT|EXISTS|EXPORT|FIELDS|GLOBAL|GROUPS|LENGTH|LOCALE|MEDIUM|METHOD|MODIFY|NESTED|OTHERS|REJECT|SCROLL|SUPPLY|SYMBOL|ENDFOR|STRLEN|ALIGN|BEGIN|BOUND|ENDAT|ENTRY|EVENT|FINAL|FLUSH|GRANT|INNER|SHORT|USING|WRITE|AFTER|BLACK|BLOCK|CLOCK|COLOR|COUNT|DUMMY|EMPTY|ENDDO|ENDON|GREEN|INDEX|INOUT|LEAVE|LEVEL|LINES|MODIF|ORDER|OUTER|RANGE|RESET|RETRY|RIGHT|SMART|SPLIT|STYLE|TABLE|THROW|UNDER|UNTIL|UPPER|UTF-8|WHERE|ALIAS|BLANK|CLEAR|CLOSE|EXACT|FETCH|FIRST|FOUND|GROUP|LLANG|LOCAL|OTHER|REGEX|SPOOL|TITLE|TYPES|VALID|WHILE|ALPHA|BOXED|CATCH|CHAIN|CHECK|CLASS|COVER|ENDIF|EQUIV|FIELD|FLOOR|FRAME|INPUT|LOWER|MATCH|NODES|PAGES|PRINT|RAISE|ROUND|SHIFT|SPACE|SPOTS|STAMP|STATE|TASKS|TIMES|TRMAC|ULINE|UNION|VALUE|WIDTH|EQUAL|LOG10|TRUNC|BLOB|CASE|CEIL|CLOB|COND|EXIT|FILE|GAPS|HOLD|INCL|INTO|KEEP|KEYS|LAST|LINE|LONG|LPAD|MAIL|MODE|OPEN|PINK|READ|ROWS|TEST|THEN|ZERO|AREA|BACK|BADI|BYTE|CAST|EDIT|EXEC|FAIL|FIND|FKEQ|FONT|FREE|GKEQ|HIDE|INIT|ITNO|LATE|LOOP|MAIN|MARK|MOVE|NEXT|NULL|RISK|ROLE|UNIT|WAIT|ZONE|BASE|CALL|CODE|DATA|DATE|FKGE|GKGE|HIGH|KIND|LEFT|LIST|MASK|MESH|NAME|NODE|PACK|PAGE|POOL|SEND|SIGN|SIZE|SOME|STOP|TASK|TEXT|TIME|USER|VARY|WITH|WORD|BLUE|CONV|COPY|DEEP|ELSE|FORM|FROM|HINT|ICON|JOIN|LIKE|LOAD|ONLY|PART|SCAN|SKIP|SORT|TYPE|UNIX|VIEW|WHEN|WORK|ACOS|ASIN|ATAN|COSH|EACH|FRAC|LESS|RTTI|SINH|SQRT|TANH|AVG|BIT|DIV|ISO|LET|OUT|PAD|SQL|ALL|CI_|CPI|END|LOB|LPI|MAX|MIN|NEW|OLE|RUN|SET|\?TO|YES|ABS|ADD|AND|BIG|FOR|HDB|JOB|LOW|NOT|SAP|TRY|VIA|XML|ANY|GET|IDS|KEY|MOD|OFF|PUT|RAW|RED|REF|SUM|TAB|XSD|CNT|COS|EXP|LOG|SIN|TAN|XOR|AT|CO|CP|DO|GT|ID|IF|NS|OR|BT|CA|CS|GE|NA|NB|EQ|IN|LT|NE|NO|OF|ON|PF|TO|AS|BY|CN|IS|LE|NP|UP|E|I|M|O|Z|C|X)\b/i,lookbehind:!0},number:/\b\d+\b/,operator:{pattern:/(\s)(?:\*\*?|<[=>]?|>=?|\?=|[-+\/=])(?=\s)/,lookbehind:!0},"string-operator":{pattern:/(\s)&&?(?=\s)/,lookbehind:!0,alias:"keyword"},"token-operator":[{pattern:/(\w)(?:->?|=>|[~|{}])(?=\w)/,lookbehind:!0,alias:"punctuation"},{pattern:/[|{}]/,alias:"punctuation"}],punctuation:/[,.:()]/}}return mb}var bb,SD;function Zfe(){if(SD)return bb;SD=1,bb=e,e.displayName="abnf",e.aliases=[];function e(t){(function(n){var r="(?:ALPHA|BIT|CHAR|CR|CRLF|CTL|DIGIT|DQUOTE|HEXDIG|HTAB|LF|LWSP|OCTET|SP|VCHAR|WSP)";n.languages.abnf={comment:/;.*/,string:{pattern:/(?:%[is])?"[^"\n\r]*"/,greedy:!0,inside:{punctuation:/^%[is]/}},range:{pattern:/%(?:b[01]+-[01]+|d\d+-\d+|x[A-F\d]+-[A-F\d]+)/i,alias:"number"},terminal:{pattern:/%(?:b[01]+(?:\.[01]+)*|d\d+(?:\.\d+)*|x[A-F\d]+(?:\.[A-F\d]+)*)/i,alias:"number"},repetition:{pattern:/(^|[^\w-])(?:\d*\*\d*|\d+)/,lookbehind:!0,alias:"operator"},definition:{pattern:/(^[ \t]*)(?:[a-z][\w-]*|<[^<>\r\n]*>)(?=\s*=)/m,lookbehind:!0,alias:"keyword",inside:{punctuation:/<|>/}},"core-rule":{pattern:RegExp("(?:(^|[^<\\w-])"+r+"|<"+r+">)(?![\\w-])","i"),lookbehind:!0,alias:["rule","constant"],inside:{punctuation:/<|>/}},rule:{pattern:/(^|[^<\w-])[a-z][\w-]*|<[^<>\r\n]*>/i,lookbehind:!0,inside:{punctuation:/<|>/}},operator:/=\/?|\//,punctuation:/[()\[\]]/}})(t)}return bb}var yb,ED;function Qfe(){if(ED)return yb;ED=1,yb=e,e.displayName="actionscript",e.aliases=[];function e(t){t.languages.actionscript=t.languages.extend("javascript",{keyword:/\b(?:as|break|case|catch|class|const|default|delete|do|dynamic|each|else|extends|final|finally|for|function|get|if|implements|import|in|include|instanceof|interface|internal|is|namespace|native|new|null|override|package|private|protected|public|return|set|static|super|switch|this|throw|try|typeof|use|var|void|while|with)\b/,operator:/\+\+|--|(?:[+\-*\/%^]|&&?|\|\|?|<<?|>>?>?|[!=]=?)=?|[~?@]/}),t.languages.actionscript["class-name"].alias="function",delete t.languages.actionscript.parameter,delete t.languages.actionscript["literal-property"],t.languages.markup&&t.languages.insertBefore("actionscript","string",{xml:{pattern:/(^|[^.])<\/?\w+(?:\s+[^\s>\/=]+=("|')(?:\\[\s\S]|(?!\2)[^\\])*\2)*\s*\/?>/,lookbehind:!0,inside:t.languages.markup}})}return yb}var vb,wD;function Jfe(){if(wD)return vb;wD=1,vb=e,e.displayName="ada",e.aliases=[];function e(t){t.languages.ada={comment:/--.*/,string:/"(?:""|[^"\r\f\n])*"/,number:[{pattern:/\b\d(?:_?\d)*#[\dA-F](?:_?[\dA-F])*(?:\.[\dA-F](?:_?[\dA-F])*)?#(?:E[+-]?\d(?:_?\d)*)?/i},{pattern:/\b\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:E[+-]?\d(?:_?\d)*)?\b/i}],"attr-name":/\b'\w+/,keyword:/\b(?:abort|abs|abstract|accept|access|aliased|all|and|array|at|begin|body|case|constant|declare|delay|delta|digits|do|else|elsif|end|entry|exception|exit|for|function|generic|goto|if|in|interface|is|limited|loop|mod|new|not|null|of|others|out|overriding|package|pragma|private|procedure|protected|raise|range|record|rem|renames|requeue|return|reverse|select|separate|some|subtype|synchronized|tagged|task|terminate|then|type|until|use|when|while|with|xor)\b/i,boolean:/\b(?:false|true)\b/i,operator:/<[=>]?|>=?|=>?|:=|\/=?|\*\*?|[&+-]/,punctuation:/\.\.?|[,;():]/,char:/'.'/,variable:/\b[a-z](?:\w)*\b/i}}return vb}var Sb,xD;function epe(){if(xD)return Sb;xD=1,Sb=e,e.displayName="agda",e.aliases=[];function e(t){(function(n){n.languages.agda={comment:/\{-[\s\S]*?(?:-\}|$)|--.*/,string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},punctuation:/[(){}⦃⦄.;@]/,"class-name":{pattern:/((?:data|record) +)\S+/,lookbehind:!0},function:{pattern:/(^[ \t]*)(?!\s)[^:\r\n]+(?=:)/m,lookbehind:!0},operator:{pattern:/(^\s*|\s)(?:[=|:∀→λ\\?_]|->)(?=\s)/,lookbehind:!0},keyword:/\b(?:Set|abstract|constructor|data|eta-equality|field|forall|hiding|import|in|inductive|infix|infixl|infixr|instance|let|macro|module|mutual|no-eta-equality|open|overlap|pattern|postulate|primitive|private|public|quote|quoteContext|quoteGoal|quoteTerm|record|renaming|rewrite|syntax|tactic|unquote|unquoteDecl|unquoteDef|using|variable|where|with)\b/}})(t)}return Sb}var Eb,kD;function tpe(){if(kD)return Eb;kD=1,Eb=e,e.displayName="al",e.aliases=[];function e(t){t.languages.al={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},function:{pattern:/(\b(?:event|procedure|trigger)\s+|(?:^|[^.])\.\s*)[a-z_]\w*(?=\s*\()/i,lookbehind:!0},keyword:[/\b(?:array|asserterror|begin|break|case|do|downto|else|end|event|exit|for|foreach|function|if|implements|in|indataset|interface|internal|local|of|procedure|program|protected|repeat|runonclient|securityfiltering|suppressdispose|temporary|then|to|trigger|until|var|while|with|withevents)\b/i,/\b(?:action|actions|addafter|addbefore|addfirst|addlast|area|assembly|chartpart|codeunit|column|controladdin|cuegroup|customizes|dataitem|dataset|dotnet|elements|enum|enumextension|extends|field|fieldattribute|fieldelement|fieldgroup|fieldgroups|fields|filter|fixed|grid|group|key|keys|label|labels|layout|modify|moveafter|movebefore|movefirst|movelast|page|pagecustomization|pageextension|part|profile|query|repeater|report|requestpage|schema|separator|systempart|table|tableelement|tableextension|textattribute|textelement|type|usercontrol|value|xmlport)\b/i],number:/\b(?:0x[\da-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)(?:F|LL?|U(?:LL?)?)?\b/i,boolean:/\b(?:false|true)\b/i,variable:/\b(?:Curr(?:FieldNo|Page|Report)|x?Rec|RequestOptionsPage)\b/,"class-name":/\b(?:automation|biginteger|bigtext|blob|boolean|byte|char|clienttype|code|completiontriggererrorlevel|connectiontype|database|dataclassification|datascope|date|dateformula|datetime|decimal|defaultlayout|dialog|dictionary|dotnetassembly|dotnettypedeclaration|duration|errorinfo|errortype|executioncontext|executionmode|fieldclass|fieldref|fieldtype|file|filterpagebuilder|guid|httpclient|httpcontent|httpheaders|httprequestmessage|httpresponsemessage|instream|integer|joker|jsonarray|jsonobject|jsontoken|jsonvalue|keyref|list|moduledependencyinfo|moduleinfo|none|notification|notificationscope|objecttype|option|outstream|pageresult|record|recordid|recordref|reportformat|securityfilter|sessionsettings|tableconnectiontype|tablefilter|testaction|testfield|testfilterfield|testpage|testpermissions|testrequestpage|text|textbuilder|textconst|textencoding|time|transactionmodel|transactiontype|variant|verbosity|version|view|views|webserviceactioncontext|webserviceactionresultcode|xmlattribute|xmlattributecollection|xmlcdata|xmlcomment|xmldeclaration|xmldocument|xmldocumenttype|xmlelement|xmlnamespacemanager|xmlnametable|xmlnode|xmlnodelist|xmlprocessinginstruction|xmlreadoptions|xmltext|xmlwriteoptions)\b/i,operator:/\.\.|:[=:]|[-+*/]=?|<>|[<>]=?|=|\b(?:and|div|mod|not|or|xor)\b/i,punctuation:/[()\[\]{}:.;,]/}}return Eb}var wb,AD;function npe(){if(AD)return wb;AD=1,wb=e,e.displayName="antlr4",e.aliases=["g4"];function e(t){t.languages.antlr4={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,string:{pattern:/'(?:\\.|[^\\'\r\n])*'/,greedy:!0},"character-class":{pattern:/\[(?:\\.|[^\\\]\r\n])*\]/,greedy:!0,alias:"regex",inside:{range:{pattern:/([^[]|(?:^|[^\\])(?:\\\\)*\\\[)-(?!\])/,lookbehind:!0,alias:"punctuation"},escape:/\\(?:u(?:[a-fA-F\d]{4}|\{[a-fA-F\d]+\})|[pP]\{[=\w-]+\}|[^\r\nupP])/,punctuation:/[\[\]]/}},action:{pattern:/\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\}/,greedy:!0,inside:{content:{pattern:/(\{)[\s\S]+(?=\})/,lookbehind:!0},punctuation:/[{}]/}},command:{pattern:/(->\s*(?!\s))(?:\s*(?:,\s*)?\b[a-z]\w*(?:\s*\([^()\r\n]*\))?)+(?=\s*;)/i,lookbehind:!0,inside:{function:/\b\w+(?=\s*(?:[,(]|$))/,punctuation:/[,()]/}},annotation:{pattern:/@\w+(?:::\w+)*/,alias:"keyword"},label:{pattern:/#[ \t]*\w+/,alias:"punctuation"},keyword:/\b(?:catch|channels|finally|fragment|grammar|import|lexer|locals|mode|options|parser|returns|throws|tokens)\b/,definition:[{pattern:/\b[a-z]\w*(?=\s*:)/,alias:["rule","class-name"]},{pattern:/\b[A-Z]\w*(?=\s*:)/,alias:["token","constant"]}],constant:/\b[A-Z][A-Z_]*\b/,operator:/\.\.|->|[|~]|[*+?]\??/,punctuation:/[;:()=]/},t.languages.g4=t.languages.antlr4}return wb}var xb,TD;function rpe(){if(TD)return xb;TD=1,xb=e,e.displayName="apacheconf",e.aliases=[];function e(t){t.languages.apacheconf={comment:/#.*/,"directive-inline":{pattern:/(^[\t ]*)\b(?:AcceptFilter|AcceptPathInfo|AccessFileName|Action|Add(?:Alt|AltByEncoding|AltByType|Charset|DefaultCharset|Description|Encoding|Handler|Icon|IconByEncoding|IconByType|InputFilter|Language|ModuleInfo|OutputFilter|OutputFilterByType|Type)|Alias|AliasMatch|Allow(?:CONNECT|EncodedSlashes|Methods|Override|OverrideList)?|Anonymous(?:_LogEmail|_MustGiveEmail|_NoUserID|_VerifyEmail)?|AsyncRequestWorkerFactor|Auth(?:BasicAuthoritative|BasicFake|BasicProvider|BasicUseDigestAlgorithm|DBDUserPWQuery|DBDUserRealmQuery|DBMGroupFile|DBMType|DBMUserFile|Digest(?:Algorithm|Domain|NonceLifetime|Provider|Qop|ShmemSize)|Form(?:Authoritative|Body|DisableNoStore|FakeBasicAuth|Location|LoginRequiredLocation|LoginSuccessLocation|LogoutLocation|Method|Mimetype|Password|Provider|SitePassphrase|Size|Username)|GroupFile|LDAP(?:AuthorizePrefix|BindAuthoritative|BindDN|BindPassword|CharsetConfig|CompareAsUser|CompareDNOnServer|DereferenceAliases|GroupAttribute|GroupAttributeIsDN|InitialBindAsUser|InitialBindPattern|MaxSubGroupDepth|RemoteUserAttribute|RemoteUserIsDN|SearchAsUser|SubGroupAttribute|SubGroupClass|Url)|Merging|Name|nCache(?:Context|Enable|ProvideFor|SOCache|Timeout)|nzFcgiCheckAuthnProvider|nzFcgiDefineProvider|Type|UserFile|zDBDLoginToReferer|zDBDQuery|zDBDRedirectQuery|zDBMType|zSendForbiddenOnFailure)|BalancerGrowth|BalancerInherit|BalancerMember|BalancerPersist|BrowserMatch|BrowserMatchNoCase|BufferedLogs|BufferSize|Cache(?:DefaultExpire|DetailHeader|DirLength|DirLevels|Disable|Enable|File|Header|IgnoreCacheControl|IgnoreHeaders|IgnoreNoLastMod|IgnoreQueryString|IgnoreURLSessionIdentifiers|KeyBaseURL|LastModifiedFactor|Lock|LockMaxAge|LockPath|MaxExpire|MaxFileSize|MinExpire|MinFileSize|NegotiatedDocs|QuickHandler|ReadSize|ReadTime|Root|Socache(?:MaxSize|MaxTime|MinTime|ReadSize|ReadTime)?|StaleOnError|StoreExpired|StoreNoStore|StorePrivate)|CGIDScriptTimeout|CGIMapExtension|CharsetDefault|CharsetOptions|CharsetSourceEnc|CheckCaseOnly|CheckSpelling|ChrootDir|ContentDigest|CookieDomain|CookieExpires|CookieName|CookieStyle|CookieTracking|CoreDumpDirectory|CustomLog|Dav|DavDepthInfinity|DavGenericLockDB|DavLockDB|DavMinTimeout|DBDExptime|DBDInitSQL|DBDKeep|DBDMax|DBDMin|DBDParams|DBDPersist|DBDPrepareSQL|DBDriver|DefaultIcon|DefaultLanguage|DefaultRuntimeDir|DefaultType|Define|Deflate(?:BufferSize|CompressionLevel|FilterNote|InflateLimitRequestBody|InflateRatio(?:Burst|Limit)|MemLevel|WindowSize)|Deny|DirectoryCheckHandler|DirectoryIndex|DirectoryIndexRedirect|DirectorySlash|DocumentRoot|DTracePrivileges|DumpIOInput|DumpIOOutput|EnableExceptionHook|EnableMMAP|EnableSendfile|Error|ErrorDocument|ErrorLog|ErrorLogFormat|Example|ExpiresActive|ExpiresByType|ExpiresDefault|ExtendedStatus|ExtFilterDefine|ExtFilterOptions|FallbackResource|FileETag|FilterChain|FilterDeclare|FilterProtocol|FilterProvider|FilterTrace|ForceLanguagePriority|ForceType|ForensicLog|GprofDir|GracefulShutdownTimeout|Group|Header|HeaderName|Heartbeat(?:Address|Listen|MaxServers|Storage)|HostnameLookups|IdentityCheck|IdentityCheckTimeout|ImapBase|ImapDefault|ImapMenu|Include|IncludeOptional|Index(?:HeadInsert|Ignore|IgnoreReset|Options|OrderDefault|StyleSheet)|InputSed|ISAPI(?:AppendLogToErrors|AppendLogToQuery|CacheFile|FakeAsync|LogNotSupported|ReadAheadBuffer)|KeepAlive|KeepAliveTimeout|KeptBodySize|LanguagePriority|LDAP(?:CacheEntries|CacheTTL|ConnectionPoolTTL|ConnectionTimeout|LibraryDebug|OpCacheEntries|OpCacheTTL|ReferralHopLimit|Referrals|Retries|RetryDelay|SharedCacheFile|SharedCacheSize|Timeout|TrustedClientCert|TrustedGlobalCert|TrustedMode|VerifyServerCert)|Limit(?:InternalRecursion|Request(?:Body|Fields|FieldSize|Line)|XMLRequestBody)|Listen|ListenBackLog|LoadFile|LoadModule|LogFormat|LogLevel|LogMessage|LuaAuthzProvider|LuaCodeCache|Lua(?:Hook(?:AccessChecker|AuthChecker|CheckUserID|Fixups|InsertFilter|Log|MapToStorage|TranslateName|TypeChecker)|Inherit|InputFilter|MapHandler|OutputFilter|PackageCPath|PackagePath|QuickHandler|Root|Scope)|Max(?:ConnectionsPerChild|KeepAliveRequests|MemFree|RangeOverlaps|RangeReversals|Ranges|RequestWorkers|SpareServers|SpareThreads|Threads)|MergeTrailers|MetaDir|MetaFiles|MetaSuffix|MimeMagicFile|MinSpareServers|MinSpareThreads|MMapFile|ModemStandard|ModMimeUsePathInfo|MultiviewsMatch|Mutex|NameVirtualHost|NoProxy|NWSSLTrustedCerts|NWSSLUpgradeable|Options|Order|OutputSed|PassEnv|PidFile|PrivilegesMode|Protocol|ProtocolEcho|Proxy(?:AddHeaders|BadHeader|Block|Domain|ErrorOverride|ExpressDBMFile|ExpressDBMType|ExpressEnable|FtpDirCharset|FtpEscapeWildcards|FtpListOnWildcard|HTML(?:BufSize|CharsetOut|DocType|Enable|Events|Extended|Fixups|Interp|Links|Meta|StripComments|URLMap)|IOBufferSize|MaxForwards|Pass(?:Inherit|InterpolateEnv|Match|Reverse|ReverseCookieDomain|ReverseCookiePath)?|PreserveHost|ReceiveBufferSize|Remote|RemoteMatch|Requests|SCGIInternalRedirect|SCGISendfile|Set|SourceAddress|Status|Timeout|Via)|ReadmeName|ReceiveBufferSize|Redirect|RedirectMatch|RedirectPermanent|RedirectTemp|ReflectorHeader|RemoteIP(?:Header|InternalProxy|InternalProxyList|ProxiesHeader|TrustedProxy|TrustedProxyList)|RemoveCharset|RemoveEncoding|RemoveHandler|RemoveInputFilter|RemoveLanguage|RemoveOutputFilter|RemoveType|RequestHeader|RequestReadTimeout|Require|Rewrite(?:Base|Cond|Engine|Map|Options|Rule)|RLimitCPU|RLimitMEM|RLimitNPROC|Satisfy|ScoreBoardFile|Script(?:Alias|AliasMatch|InterpreterSource|Log|LogBuffer|LogLength|Sock)?|SecureListen|SeeRequestTail|SendBufferSize|Server(?:Admin|Alias|Limit|Name|Path|Root|Signature|Tokens)|Session(?:Cookie(?:Name|Name2|Remove)|Crypto(?:Cipher|Driver|Passphrase|PassphraseFile)|DBD(?:CookieName|CookieName2|CookieRemove|DeleteLabel|InsertLabel|PerUser|SelectLabel|UpdateLabel)|Env|Exclude|Header|Include|MaxAge)?|SetEnv|SetEnvIf|SetEnvIfExpr|SetEnvIfNoCase|SetHandler|SetInputFilter|SetOutputFilter|SSIEndTag|SSIErrorMsg|SSIETag|SSILastModified|SSILegacyExprParser|SSIStartTag|SSITimeFormat|SSIUndefinedEcho|SSL(?:CACertificateFile|CACertificatePath|CADNRequestFile|CADNRequestPath|CARevocationCheck|CARevocationFile|CARevocationPath|CertificateChainFile|CertificateFile|CertificateKeyFile|CipherSuite|Compression|CryptoDevice|Engine|FIPS|HonorCipherOrder|InsecureRenegotiation|OCSP(?:DefaultResponder|Enable|OverrideResponder|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|UseRequestNonce)|OpenSSLConfCmd|Options|PassPhraseDialog|Protocol|Proxy(?:CACertificateFile|CACertificatePath|CARevocation(?:Check|File|Path)|CheckPeer(?:CN|Expire|Name)|CipherSuite|Engine|MachineCertificate(?:ChainFile|File|Path)|Protocol|Verify|VerifyDepth)|RandomSeed|RenegBufferSize|Require|RequireSSL|Session(?:Cache|CacheTimeout|TicketKeyFile|Tickets)|SRPUnknownUserSeed|SRPVerifierFile|Stapling(?:Cache|ErrorCacheTimeout|FakeTryLater|ForceURL|ResponderTimeout|ResponseMaxAge|ResponseTimeSkew|ReturnResponderErrors|StandardCacheTimeout)|StrictSNIVHostCheck|UserName|UseStapling|VerifyClient|VerifyDepth)|StartServers|StartThreads|Substitute|Suexec|SuexecUserGroup|ThreadLimit|ThreadsPerChild|ThreadStackSize|TimeOut|TraceEnable|TransferLog|TypesConfig|UnDefine|UndefMacro|UnsetEnv|Use|UseCanonicalName|UseCanonicalPhysicalPort|User|UserDir|VHostCGIMode|VHostCGIPrivs|VHostGroup|VHostPrivs|VHostSecure|VHostUser|Virtual(?:DocumentRoot|ScriptAlias)(?:IP)?|WatchdogInterval|XBitHack|xml2EncAlias|xml2EncDefault|xml2StartParse)\b/im,lookbehind:!0,alias:"property"},"directive-block":{pattern:/<\/?\b(?:Auth[nz]ProviderAlias|Directory|DirectoryMatch|Else|ElseIf|Files|FilesMatch|If|IfDefine|IfModule|IfVersion|Limit|LimitExcept|Location|LocationMatch|Macro|Proxy|Require(?:All|Any|None)|VirtualHost)\b.*>/i,inside:{"directive-block":{pattern:/^<\/?\w+/,inside:{punctuation:/^<\/?/},alias:"tag"},"directive-block-parameter":{pattern:/.*[^>]/,inside:{punctuation:/:/,string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}}},alias:"attr-value"},punctuation:/>/},alias:"tag"},"directive-flags":{pattern:/\[(?:[\w=],?)+\]/,alias:"keyword"},string:{pattern:/("|').*\1/,inside:{variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/}},variable:/[$%]\{?(?:\w\.?[-+:]?)+\}?/,regex:/\^?.*\$|\^.*\$?/}}return xb}var kb,_D;function sA(){if(_D)return kb;_D=1,kb=e,e.displayName="sql",e.aliases=[];function e(t){t.languages.sql={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},variable:[{pattern:/@(["'`])(?:\\[\s\S]|(?!\1)[^\\])+\1/,greedy:!0},/@[\w.$]+/],string:{pattern:/(^|[^@\\])("|')(?:\\[\s\S]|(?!\2)[^\\]|\2\2)*\2/,greedy:!0,lookbehind:!0},identifier:{pattern:/(^|[^@\\])`(?:\\[\s\S]|[^`\\]|``)*`/,greedy:!0,lookbehind:!0,inside:{punctuation:/^`|`$/}},function:/\b(?:AVG|COUNT|FIRST|FORMAT|LAST|LCASE|LEN|MAX|MID|MIN|MOD|NOW|ROUND|SUM|UCASE)(?=\s*\()/i,keyword:/\b(?:ACTION|ADD|AFTER|ALGORITHM|ALL|ALTER|ANALYZE|ANY|APPLY|AS|ASC|AUTHORIZATION|AUTO_INCREMENT|BACKUP|BDB|BEGIN|BERKELEYDB|BIGINT|BINARY|BIT|BLOB|BOOL|BOOLEAN|BREAK|BROWSE|BTREE|BULK|BY|CALL|CASCADED?|CASE|CHAIN|CHAR(?:ACTER|SET)?|CHECK(?:POINT)?|CLOSE|CLUSTERED|COALESCE|COLLATE|COLUMNS?|COMMENT|COMMIT(?:TED)?|COMPUTE|CONNECT|CONSISTENT|CONSTRAINT|CONTAINS(?:TABLE)?|CONTINUE|CONVERT|CREATE|CROSS|CURRENT(?:_DATE|_TIME|_TIMESTAMP|_USER)?|CURSOR|CYCLE|DATA(?:BASES?)?|DATE(?:TIME)?|DAY|DBCC|DEALLOCATE|DEC|DECIMAL|DECLARE|DEFAULT|DEFINER|DELAYED|DELETE|DELIMITERS?|DENY|DESC|DESCRIBE|DETERMINISTIC|DISABLE|DISCARD|DISK|DISTINCT|DISTINCTROW|DISTRIBUTED|DO|DOUBLE|DROP|DUMMY|DUMP(?:FILE)?|DUPLICATE|ELSE(?:IF)?|ENABLE|ENCLOSED|END|ENGINE|ENUM|ERRLVL|ERRORS|ESCAPED?|EXCEPT|EXEC(?:UTE)?|EXISTS|EXIT|EXPLAIN|EXTENDED|FETCH|FIELDS|FILE|FILLFACTOR|FIRST|FIXED|FLOAT|FOLLOWING|FOR(?: EACH ROW)?|FORCE|FOREIGN|FREETEXT(?:TABLE)?|FROM|FULL|FUNCTION|GEOMETRY(?:COLLECTION)?|GLOBAL|GOTO|GRANT|GROUP|HANDLER|HASH|HAVING|HOLDLOCK|HOUR|IDENTITY(?:COL|_INSERT)?|IF|IGNORE|IMPORT|INDEX|INFILE|INNER|INNODB|INOUT|INSERT|INT|INTEGER|INTERSECT|INTERVAL|INTO|INVOKER|ISOLATION|ITERATE|JOIN|KEYS?|KILL|LANGUAGE|LAST|LEAVE|LEFT|LEVEL|LIMIT|LINENO|LINES|LINESTRING|LOAD|LOCAL|LOCK|LONG(?:BLOB|TEXT)|LOOP|MATCH(?:ED)?|MEDIUM(?:BLOB|INT|TEXT)|MERGE|MIDDLEINT|MINUTE|MODE|MODIFIES|MODIFY|MONTH|MULTI(?:LINESTRING|POINT|POLYGON)|NATIONAL|NATURAL|NCHAR|NEXT|NO|NONCLUSTERED|NULLIF|NUMERIC|OFF?|OFFSETS?|ON|OPEN(?:DATASOURCE|QUERY|ROWSET)?|OPTIMIZE|OPTION(?:ALLY)?|ORDER|OUT(?:ER|FILE)?|OVER|PARTIAL|PARTITION|PERCENT|PIVOT|PLAN|POINT|POLYGON|PRECEDING|PRECISION|PREPARE|PREV|PRIMARY|PRINT|PRIVILEGES|PROC(?:EDURE)?|PUBLIC|PURGE|QUICK|RAISERROR|READS?|REAL|RECONFIGURE|REFERENCES|RELEASE|RENAME|REPEAT(?:ABLE)?|REPLACE|REPLICATION|REQUIRE|RESIGNAL|RESTORE|RESTRICT|RETURN(?:ING|S)?|REVOKE|RIGHT|ROLLBACK|ROUTINE|ROW(?:COUNT|GUIDCOL|S)?|RTREE|RULE|SAVE(?:POINT)?|SCHEMA|SECOND|SELECT|SERIAL(?:IZABLE)?|SESSION(?:_USER)?|SET(?:USER)?|SHARE|SHOW|SHUTDOWN|SIMPLE|SMALLINT|SNAPSHOT|SOME|SONAME|SQL|START(?:ING)?|STATISTICS|STATUS|STRIPED|SYSTEM_USER|TABLES?|TABLESPACE|TEMP(?:ORARY|TABLE)?|TERMINATED|TEXT(?:SIZE)?|THEN|TIME(?:STAMP)?|TINY(?:BLOB|INT|TEXT)|TOP?|TRAN(?:SACTIONS?)?|TRIGGER|TRUNCATE|TSEQUAL|TYPES?|UNBOUNDED|UNCOMMITTED|UNDEFINED|UNION|UNIQUE|UNLOCK|UNPIVOT|UNSIGNED|UPDATE(?:TEXT)?|USAGE|USE|USER|USING|VALUES?|VAR(?:BINARY|CHAR|CHARACTER|YING)|VIEW|WAITFOR|WARNINGS|WHEN|WHERE|WHILE|WITH(?: ROLLUP|IN)?|WORK|WRITE(?:TEXT)?|YEAR)\b/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/i,number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/=%^~]|&&?|\|\|?|!=?|<(?:=>?|<|>)?|>[>=]?|\b(?:AND|BETWEEN|DIV|ILIKE|IN|IS|LIKE|NOT|OR|REGEXP|RLIKE|SOUNDS LIKE|XOR)\b/i,punctuation:/[;[\]()`,.]/}}return kb}var Ab,RD;function ape(){if(RD)return Ab;RD=1;var e=sA();Ab=t,t.displayName="apex",t.aliases=[];function t(n){n.register(e),function(r){var a=/\b(?:(?:after|before)(?=\s+[a-z])|abstract|activate|and|any|array|as|asc|autonomous|begin|bigdecimal|blob|boolean|break|bulk|by|byte|case|cast|catch|char|class|collect|commit|const|continue|currency|date|datetime|decimal|default|delete|desc|do|double|else|end|enum|exception|exit|export|extends|final|finally|float|for|from|get(?=\s*[{};])|global|goto|group|having|hint|if|implements|import|in|inner|insert|instanceof|int|integer|interface|into|join|like|limit|list|long|loop|map|merge|new|not|null|nulls|number|object|of|on|or|outer|override|package|parallel|pragma|private|protected|public|retrieve|return|rollback|select|set|short|sObject|sort|static|string|super|switch|synchronized|system|testmethod|then|this|throw|time|transaction|transient|trigger|try|undelete|update|upsert|using|virtual|void|webservice|when|where|while|(?:inherited|with|without)\s+sharing)\b/i,i=/\b(?:(?=[a-z_]\w*\s*[<\[])|(?!<keyword>))[A-Z_]\w*(?:\s*\.\s*[A-Z_]\w*)*\b(?:\s*(?:\[\s*\]|<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>))*/.source.replace(/<keyword>/g,function(){return a.source});function l(c){return RegExp(c.replace(/<CLASS-NAME>/g,function(){return i}),"i")}var u={keyword:a,punctuation:/[()\[\]{};,:.<>]/};r.languages.apex={comment:r.languages.clike.comment,string:r.languages.clike.string,sql:{pattern:/((?:[=,({:]|\breturn)\s*)\[[^\[\]]*\]/i,lookbehind:!0,greedy:!0,alias:"language-sql",inside:r.languages.sql},annotation:{pattern:/@\w+\b/,alias:"punctuation"},"class-name":[{pattern:l(/(\b(?:class|enum|extends|implements|instanceof|interface|new|trigger\s+\w+\s+on)\s+)<CLASS-NAME>/.source),lookbehind:!0,inside:u},{pattern:l(/(\(\s*)<CLASS-NAME>(?=\s*\)\s*[\w(])/.source),lookbehind:!0,inside:u},{pattern:l(/<CLASS-NAME>(?=\s*\w+\s*[;=,(){:])/.source),inside:u}],trigger:{pattern:/(\btrigger\s+)\w+\b/i,lookbehind:!0,alias:"class-name"},keyword:a,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/(?:\B\.\d+|\b\d+(?:\.\d+|L)?)\b/i,operator:/[!=](?:==?)?|\?\.?|&&|\|\||--|\+\+|[-+*/^&|]=?|:|<<?=?|>{1,3}=?/,punctuation:/[()\[\]{};,.]/}}(n)}return Ab}var Tb,CD;function ope(){if(CD)return Tb;CD=1,Tb=e,e.displayName="apl",e.aliases=[];function e(t){t.languages.apl={comment:/(?:⍝|#[! ]).*$/m,string:{pattern:/'(?:[^'\r\n]|'')*'/,greedy:!0},number:/¯?(?:\d*\.?\b\d+(?:e[+¯]?\d+)?|¯|∞)(?:j¯?(?:(?:\d+(?:\.\d+)?|\.\d+)(?:e[+¯]?\d+)?|¯|∞))?/i,statement:/:[A-Z][a-z][A-Za-z]*\b/,"system-function":{pattern:/⎕[A-Z]+/i,alias:"function"},constant:/[⍬⌾#⎕⍞]/,function:/[-+×÷⌈⌊∣|⍳⍸?*⍟○!⌹<≤=>≥≠≡≢∊⍷∪∩~∨∧⍱⍲⍴,⍪⌽⊖⍉↑↓⊂⊃⊆⊇⌷⍋⍒⊤⊥⍕⍎⊣⊢⍁⍂≈⍯↗¤→]/,"monadic-operator":{pattern:/[\\\/⌿⍀¨⍨⌶&∥]/,alias:"operator"},"dyadic-operator":{pattern:/[.⍣⍠⍤∘⌸@⌺⍥]/,alias:"operator"},assignment:{pattern:/←/,alias:"keyword"},punctuation:/[\[;\]()◇⋄]/,dfn:{pattern:/[{}⍺⍵⍶⍹∇⍫:]/,alias:"builtin"}}}return Tb}var _b,ND;function ipe(){if(ND)return _b;ND=1,_b=e,e.displayName="applescript",e.aliases=[];function e(t){t.languages.applescript={comment:[/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,/--.+/,/#.+/],string:/"(?:\\.|[^"\\\r\n])*"/,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?\b/i,operator:[/[&=≠≤≥*+\-\/÷^]|[<>]=?/,/\b(?:(?:begin|end|start)s? with|(?:contains?|(?:does not|doesn't) contain)|(?:is|isn't|is not) (?:contained by|in)|(?:(?:is|isn't|is not) )?(?:greater|less) than(?: or equal)?(?: to)?|(?:comes|(?:does not|doesn't) come) (?:after|before)|(?:is|isn't|is not) equal(?: to)?|(?:(?:does not|doesn't) equal|equal to|equals|is not|isn't)|(?:a )?(?:ref(?: to)?|reference to)|(?:and|as|div|mod|not|or))\b/],keyword:/\b(?:about|above|after|against|apart from|around|aside from|at|back|before|beginning|behind|below|beneath|beside|between|but|by|considering|continue|copy|does|eighth|else|end|equal|error|every|exit|false|fifth|first|for|fourth|from|front|get|given|global|if|ignoring|in|instead of|into|is|it|its|last|local|me|middle|my|ninth|of|on|onto|out of|over|prop|property|put|repeat|return|returning|second|set|seventh|since|sixth|some|tell|tenth|that|the|then|third|through|thru|timeout|times|to|transaction|true|try|until|where|while|whose|with|without)\b/,"class-name":/\b(?:POSIX file|RGB color|alias|application|boolean|centimeters|centimetres|class|constant|cubic centimeters|cubic centimetres|cubic feet|cubic inches|cubic meters|cubic metres|cubic yards|date|degrees Celsius|degrees Fahrenheit|degrees Kelvin|feet|file|gallons|grams|inches|integer|kilograms|kilometers|kilometres|list|liters|litres|meters|metres|miles|number|ounces|pounds|quarts|real|record|reference|script|square feet|square kilometers|square kilometres|square meters|square metres|square miles|square yards|text|yards)\b/,punctuation:/[{}():,¬«»《》]/}}return _b}var Rb,OD;function lpe(){if(OD)return Rb;OD=1,Rb=e,e.displayName="aql",e.aliases=[];function e(t){t.languages.aql={comment:/\/\/.*|\/\*[\s\S]*?\*\//,property:{pattern:/([{,]\s*)(?:(?!\d)\w+|(["'´`])(?:(?!\2)[^\\\r\n]|\\.)*\2)(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},identifier:{pattern:/([´`])(?:(?!\1)[^\\\r\n]|\\.)*\1/,greedy:!0},variable:/@@?\w+/,keyword:[{pattern:/(\bWITH\s+)COUNT(?=\s+INTO\b)/i,lookbehind:!0},/\b(?:AGGREGATE|ALL|AND|ANY|ASC|COLLECT|DESC|DISTINCT|FILTER|FOR|GRAPH|IN|INBOUND|INSERT|INTO|K_PATHS|K_SHORTEST_PATHS|LET|LIKE|LIMIT|NONE|NOT|NULL|OR|OUTBOUND|REMOVE|REPLACE|RETURN|SHORTEST_PATH|SORT|UPDATE|UPSERT|WINDOW|WITH)\b/i,{pattern:/(^|[^\w.[])(?:KEEP|PRUNE|SEARCH|TO)\b/i,lookbehind:!0},{pattern:/(^|[^\w.[])(?:CURRENT|NEW|OLD)\b/,lookbehind:!0},{pattern:/\bOPTIONS(?=\s*\{)/i}],function:/\b(?!\d)\w+(?=\s*\()/,boolean:/\b(?:false|true)\b/i,range:{pattern:/\.\./,alias:"operator"},number:[/\b0b[01]+/i,/\b0x[0-9a-f]+/i,/(?:\B\.\d+|\b(?:0|[1-9]\d*)(?:\.\d+)?)(?:e[+-]?\d+)?/i],operator:/\*{2,}|[=!]~|[!=<>]=?|&&|\|\||[-+*/%]/,punctuation:/::|[?.:,;()[\]{}]/}}return Rb}var Cb,DD;function fi(){if(DD)return Cb;DD=1,Cb=e,e.displayName="c",e.aliases=[];function e(t){t.languages.c=t.languages.extend("clike",{comment:{pattern:/\/\/(?:[^\r\n\\]|\\(?:\r\n?|\n|(?![\r\n])))*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"class-name":{pattern:/(\b(?:enum|struct)\s+(?:__attribute__\s*\(\([\s\S]*?\)\)\s*)?)\w+|\b[a-z]\w*_t\b/,lookbehind:!0},keyword:/\b(?:_Alignas|_Alignof|_Atomic|_Bool|_Complex|_Generic|_Imaginary|_Noreturn|_Static_assert|_Thread_local|__attribute__|asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|inline|int|long|register|return|short|signed|sizeof|static|struct|switch|typedef|typeof|union|unsigned|void|volatile|while)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ful]{0,4}/i,operator:/>>=?|<<=?|->|([-+&|:])\1|[?:~]|[-+*/%&|^!=<>]=?/}),t.languages.insertBefore("c","string",{char:{pattern:/'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n]){0,32}'/,greedy:!0}}),t.languages.insertBefore("c","string",{macro:{pattern:/(^[\t ]*)#\s*[a-z](?:[^\r\n\\/]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{string:[{pattern:/^(#\s*include\s*)<[^>]+>/,lookbehind:!0},t.languages.c.string],char:t.languages.c.char,comment:t.languages.c.comment,"macro-name":[{pattern:/(^#\s*define\s+)\w+\b(?!\()/i,lookbehind:!0},{pattern:/(^#\s*define\s+)\w+\b(?=\()/i,lookbehind:!0,alias:"function"}],directive:{pattern:/^(#\s*)[a-z]+/,lookbehind:!0,alias:"keyword"},"directive-hash":/^#/,punctuation:/##|\\(?=[\r\n])/,expression:{pattern:/\S[\s\S]*/,inside:t.languages.c}}}}),t.languages.insertBefore("c","function",{constant:/\b(?:EOF|NULL|SEEK_CUR|SEEK_END|SEEK_SET|__DATE__|__FILE__|__LINE__|__TIMESTAMP__|__TIME__|__func__|stderr|stdin|stdout)\b/}),delete t.languages.c.boolean}return Cb}var Nb,ID;function uA(){if(ID)return Nb;ID=1;var e=fi();Nb=t,t.displayName="cpp",t.aliases=[];function t(n){n.register(e),function(r){var a=/\b(?:alignas|alignof|asm|auto|bool|break|case|catch|char|char16_t|char32_t|char8_t|class|co_await|co_return|co_yield|compl|concept|const|const_cast|consteval|constexpr|constinit|continue|decltype|default|delete|do|double|dynamic_cast|else|enum|explicit|export|extern|final|float|for|friend|goto|if|import|inline|int|int16_t|int32_t|int64_t|int8_t|long|module|mutable|namespace|new|noexcept|nullptr|operator|override|private|protected|public|register|reinterpret_cast|requires|return|short|signed|sizeof|static|static_assert|static_cast|struct|switch|template|this|thread_local|throw|try|typedef|typeid|typename|uint16_t|uint32_t|uint64_t|uint8_t|union|unsigned|using|virtual|void|volatile|wchar_t|while)\b/,i=/\b(?!<keyword>)\w+(?:\s*\.\s*\w+)*\b/.source.replace(/<keyword>/g,function(){return a.source});r.languages.cpp=r.languages.extend("c",{"class-name":[{pattern:RegExp(/(\b(?:class|concept|enum|struct|typename)\s+)(?!<keyword>)\w+/.source.replace(/<keyword>/g,function(){return a.source})),lookbehind:!0},/\b[A-Z]\w*(?=\s*::\s*\w+\s*\()/,/\b[A-Z_]\w*(?=\s*::\s*~\w+\s*\()/i,/\b\w+(?=\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>\s*::\s*\w+\s*\()/],keyword:a,number:{pattern:/(?:\b0b[01']+|\b0x(?:[\da-f']+(?:\.[\da-f']*)?|\.[\da-f']+)(?:p[+-]?[\d']+)?|(?:\b[\d']+(?:\.[\d']*)?|\B\.[\d']+)(?:e[+-]?[\d']+)?)[ful]{0,4}/i,greedy:!0},operator:/>>=?|<<=?|->|--|\+\+|&&|\|\||[?:~]|<=>|[-+*/%&|^!=<>]=?|\b(?:and|and_eq|bitand|bitor|not|not_eq|or|or_eq|xor|xor_eq)\b/,boolean:/\b(?:false|true)\b/}),r.languages.insertBefore("cpp","string",{module:{pattern:RegExp(/(\b(?:import|module)\s+)/.source+"(?:"+/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|<[^<>\r\n]*>/.source+"|"+/<mod-name>(?:\s*:\s*<mod-name>)?|:\s*<mod-name>/.source.replace(/<mod-name>/g,function(){return i})+")"),lookbehind:!0,greedy:!0,inside:{string:/^[<"][\s\S]+/,operator:/:/,punctuation:/\./}},"raw-string":{pattern:/R"([^()\\ ]{0,16})\([\s\S]*?\)\1"/,alias:"string",greedy:!0}}),r.languages.insertBefore("cpp","keyword",{"generic-function":{pattern:/\b(?!operator\b)[a-z_]\w*\s*<(?:[^<>]|<[^<>]*>)*>(?=\s*\()/i,inside:{function:/^\w+/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:r.languages.cpp}}}}),r.languages.insertBefore("cpp","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}}),r.languages.insertBefore("cpp","class-name",{"base-clause":{pattern:/(\b(?:class|struct)\s+\w+\s*:\s*)[^;{}"'\s]+(?:\s+[^;{}"'\s]+)*(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:r.languages.extend("cpp",{})}}),r.languages.insertBefore("inside","double-colon",{"class-name":/\b[a-z_]\w*\b(?!\s*::)/i},r.languages.cpp["base-clause"])}(n)}return Nb}var Ob,LD;function spe(){if(LD)return Ob;LD=1;var e=uA();Ob=t,t.displayName="arduino",t.aliases=["ino"];function t(n){n.register(e),n.languages.arduino=n.languages.extend("cpp",{keyword:/\b(?:String|array|bool|boolean|break|byte|case|catch|continue|default|do|double|else|finally|for|function|goto|if|in|instanceof|int|integer|long|loop|new|null|return|setup|string|switch|throw|try|void|while|word)\b/,constant:/\b(?:ANALOG_MESSAGE|DEFAULT|DIGITAL_MESSAGE|EXTERNAL|FIRMATA_STRING|HIGH|INPUT|INPUT_PULLUP|INTERNAL|INTERNAL1V1|INTERNAL2V56|LED_BUILTIN|LOW|OUTPUT|REPORT_ANALOG|REPORT_DIGITAL|SET_PIN_MODE|SYSEX_START|SYSTEM_RESET)\b/,builtin:/\b(?:Audio|BSSID|Bridge|Client|Console|EEPROM|Esplora|EsploraTFT|Ethernet|EthernetClient|EthernetServer|EthernetUDP|File|FileIO|FileSystem|Firmata|GPRS|GSM|GSMBand|GSMClient|GSMModem|GSMPIN|GSMScanner|GSMServer|GSMVoiceCall|GSM_SMS|HttpClient|IPAddress|IRread|Keyboard|KeyboardController|LiquidCrystal|LiquidCrystal_I2C|Mailbox|Mouse|MouseController|PImage|Process|RSSI|RobotControl|RobotMotor|SD|SPI|SSID|Scheduler|Serial|Server|Servo|SoftwareSerial|Stepper|Stream|TFT|Task|USBHost|WiFi|WiFiClient|WiFiServer|WiFiUDP|Wire|YunClient|YunServer|abs|addParameter|analogRead|analogReadResolution|analogReference|analogWrite|analogWriteResolution|answerCall|attach|attachGPRS|attachInterrupt|attached|autoscroll|available|background|beep|begin|beginPacket|beginSD|beginSMS|beginSpeaker|beginTFT|beginTransmission|beginWrite|bit|bitClear|bitRead|bitSet|bitWrite|blink|blinkVersion|buffer|changePIN|checkPIN|checkPUK|checkReg|circle|cityNameRead|cityNameWrite|clear|clearScreen|click|close|compassRead|config|connect|connected|constrain|cos|countryNameRead|countryNameWrite|createChar|cursor|debugPrint|delay|delayMicroseconds|detach|detachInterrupt|digitalRead|digitalWrite|disconnect|display|displayLogos|drawBMP|drawCompass|encryptionType|end|endPacket|endSMS|endTransmission|endWrite|exists|exitValue|fill|find|findUntil|flush|gatewayIP|get|getAsynchronously|getBand|getButton|getCurrentCarrier|getIMEI|getKey|getModifiers|getOemKey|getPINUsed|getResult|getSignalStrength|getSocket|getVoiceCallStatus|getXChange|getYChange|hangCall|height|highByte|home|image|interrupts|isActionDone|isDirectory|isListening|isPIN|isPressed|isValid|keyPressed|keyReleased|keyboardRead|knobRead|leftToRight|line|lineFollowConfig|listen|listenOnLocalhost|loadImage|localIP|lowByte|macAddress|maintain|map|max|messageAvailable|micros|millis|min|mkdir|motorsStop|motorsWrite|mouseDragged|mouseMoved|mousePressed|mouseReleased|move|noAutoscroll|noBlink|noBuffer|noCursor|noDisplay|noFill|noInterrupts|noListenOnLocalhost|noStroke|noTone|onReceive|onRequest|open|openNextFile|overflow|parseCommand|parseFloat|parseInt|parsePacket|pauseMode|peek|pinMode|playFile|playMelody|point|pointTo|position|pow|prepare|press|print|printFirmwareVersion|printVersion|println|process|processInput|pulseIn|put|random|randomSeed|read|readAccelerometer|readBlue|readButton|readBytes|readBytesUntil|readGreen|readJoystickButton|readJoystickSwitch|readJoystickX|readJoystickY|readLightSensor|readMessage|readMicrophone|readNetworks|readRed|readSlider|readString|readStringUntil|readTemperature|ready|rect|release|releaseAll|remoteIP|remoteNumber|remotePort|remove|requestFrom|retrieveCallingNumber|rewindDirectory|rightToLeft|rmdir|robotNameRead|robotNameWrite|run|runAsynchronously|runShellCommand|runShellCommandAsynchronously|running|scanNetworks|scrollDisplayLeft|scrollDisplayRight|seek|sendAnalog|sendDigitalPortPair|sendDigitalPorts|sendString|sendSysex|serialEvent|setBand|setBitOrder|setClockDivider|setCursor|setDNS|setDataMode|setFirmwareVersion|setMode|setPINUsed|setSpeed|setTextSize|setTimeout|shiftIn|shiftOut|shutdown|sin|size|sqrt|startLoop|step|stop|stroke|subnetMask|switchPIN|tan|tempoWrite|text|tone|transfer|tuneWrite|turn|updateIR|userNameRead|userNameWrite|voiceCall|waitContinue|width|write|writeBlue|writeGreen|writeJSON|writeMessage|writeMicroseconds|writeRGB|writeRed|yield)\b/}),n.languages.ino=n.languages.arduino}return Ob}var Db,MD;function upe(){if(MD)return Db;MD=1,Db=e,e.displayName="arff",e.aliases=[];function e(t){t.languages.arff={comment:/%.*/,string:{pattern:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/@(?:attribute|data|end|relation)\b/i,number:/\b\d+(?:\.\d+)?\b/,punctuation:/[{},]/}}return Db}var Ib,FD;function cpe(){if(FD)return Ib;FD=1,Ib=e,e.displayName="asciidoc",e.aliases=["adoc"];function e(t){(function(n){var r={pattern:/(^[ \t]*)\[(?!\[)(?:(["'$`])(?:(?!\2)[^\\]|\\.)*\2|\[(?:[^\[\]\\]|\\.)*\]|[^\[\]\\"'$`]|\\.)*\]/m,lookbehind:!0,inside:{quoted:{pattern:/([$`])(?:(?!\1)[^\\]|\\.)*\1/,inside:{punctuation:/^[$`]|[$`]$/}},interpreted:{pattern:/'(?:[^'\\]|\\.)*'/,inside:{punctuation:/^'|'$/}},string:/"(?:[^"\\]|\\.)*"/,variable:/\w+(?==)/,punctuation:/^\[|\]$|,/,operator:/=/,"attr-value":/(?!^\s+$).+/}},a=n.languages.asciidoc={"comment-block":{pattern:/^(\/{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1/m,alias:"comment"},table:{pattern:/^\|={3,}(?:(?:\r?\n|\r(?!\n)).*)*?(?:\r?\n|\r)\|={3,}$/m,inside:{specifiers:{pattern:/(?:(?:(?:\d+(?:\.\d+)?|\.\d+)[+*](?:[<^>](?:\.[<^>])?|\.[<^>])?|[<^>](?:\.[<^>])?|\.[<^>])[a-z]*|[a-z]+)(?=\|)/,alias:"attr-value"},punctuation:{pattern:/(^|[^\\])[|!]=*/,lookbehind:!0}}},"passthrough-block":{pattern:/^(\+{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^\++|\++$/}},"literal-block":{pattern:/^(-{4,}|\.{4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^(?:-+|\.+)|(?:-+|\.+)$/}},"other-block":{pattern:/^(--|\*{4,}|_{4,}|={4,})(?:\r?\n|\r)(?:[\s\S]*(?:\r?\n|\r))??\1$/m,inside:{punctuation:/^(?:-+|\*+|_+|=+)|(?:-+|\*+|_+|=+)$/}},"list-punctuation":{pattern:/(^[ \t]*)(?:-|\*{1,5}|\.{1,5}|(?:[a-z]|\d+)\.|[xvi]+\))(?= )/im,lookbehind:!0,alias:"punctuation"},"list-label":{pattern:/(^[ \t]*)[a-z\d].+(?::{2,4}|;;)(?=\s)/im,lookbehind:!0,alias:"symbol"},"indented-block":{pattern:/((\r?\n|\r)\2)([ \t]+)\S.*(?:(?:\r?\n|\r)\3.+)*(?=\2{2}|$)/,lookbehind:!0},comment:/^\/\/.*/m,title:{pattern:/^.+(?:\r?\n|\r)(?:={3,}|-{3,}|~{3,}|\^{3,}|\+{3,})$|^={1,5} .+|^\.(?![\s.]).*/m,alias:"important",inside:{punctuation:/^(?:\.|=+)|(?:=+|-+|~+|\^+|\++)$/}},"attribute-entry":{pattern:/^:[^:\r\n]+:(?: .*?(?: \+(?:\r?\n|\r).*?)*)?$/m,alias:"tag"},attributes:r,hr:{pattern:/^'{3,}$/m,alias:"punctuation"},"page-break":{pattern:/^<{3,}$/m,alias:"punctuation"},admonition:{pattern:/^(?:CAUTION|IMPORTANT|NOTE|TIP|WARNING):/m,alias:"keyword"},callout:[{pattern:/(^[ \t]*)<?\d*>/m,lookbehind:!0,alias:"symbol"},{pattern:/<\d+>/,alias:"symbol"}],macro:{pattern:/\b[a-z\d][a-z\d-]*::?(?:[^\s\[\]]*\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:{function:/^[a-z\d-]+(?=:)/,punctuation:/^::?/,attributes:{pattern:/(?:\[(?:[^\]\\"']|(["'])(?:(?!\1)[^\\]|\\.)*\1|\\.)*\])/,inside:r.inside}}},inline:{pattern:/(^|[^\\])(?:(?:\B\[(?:[^\]\\"']|(["'])(?:(?!\2)[^\\]|\\.)*\2|\\.)*\])?(?:\b_(?!\s)(?: _|[^_\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: _|[^_\\\r\n]|\\.)+)*_\b|\B``(?!\s).+?(?:(?:\r?\n|\r).+?)*''\B|\B`(?!\s)(?:[^`'\s]|\s+\S)+['`]\B|\B(['*+#])(?!\s)(?: \3|(?!\3)[^\\\r\n]|\\.)+(?:(?:\r?\n|\r)(?: \3|(?!\3)[^\\\r\n]|\\.)+)*\3\B)|(?:\[(?:[^\]\\"']|(["'])(?:(?!\4)[^\\]|\\.)*\4|\\.)*\])?(?:(__|\*\*|\+\+\+?|##|\$\$|[~^]).+?(?:(?:\r?\n|\r).+?)*\5|\{[^}\r\n]+\}|\[\[\[?.+?(?:(?:\r?\n|\r).+?)*\]?\]\]|<<.+?(?:(?:\r?\n|\r).+?)*>>|\(\(\(?.+?(?:(?:\r?\n|\r).+?)*\)?\)\)))/m,lookbehind:!0,inside:{attributes:r,url:{pattern:/^(?:\[\[\[?.+?\]?\]\]|<<.+?>>)$/,inside:{punctuation:/^(?:\[\[\[?|<<)|(?:\]\]\]?|>>)$/}},"attribute-ref":{pattern:/^\{.+\}$/,inside:{variable:{pattern:/(^\{)[a-z\d,+_-]+/,lookbehind:!0},operator:/^[=?!#%@$]|!(?=[:}])/,punctuation:/^\{|\}$|::?/}},italic:{pattern:/^(['_])[\s\S]+\1$/,inside:{punctuation:/^(?:''?|__?)|(?:''?|__?)$/}},bold:{pattern:/^\*[\s\S]+\*$/,inside:{punctuation:/^\*\*?|\*\*?$/}},punctuation:/^(?:``?|\+{1,3}|##?|\$\$|[~^]|\(\(\(?)|(?:''?|\+{1,3}|##?|\$\$|[~^`]|\)?\)\))$/}},replacement:{pattern:/\((?:C|R|TM)\)/,alias:"builtin"},entity:/&#?[\da-z]{1,8};/i,"line-continuation":{pattern:/(^| )\+$/m,lookbehind:!0,alias:"punctuation"}};function i(l){l=l.split(" ");for(var u={},c=0,f=l.length;c<f;c++)u[l[c]]=a[l[c]];return u}r.inside.interpreted.inside.rest=i("macro inline replacement entity"),a["passthrough-block"].inside.rest=i("macro"),a["literal-block"].inside.rest=i("callout"),a.table.inside.rest=i("comment-block passthrough-block literal-block other-block list-punctuation indented-block comment title attribute-entry attributes hr page-break admonition list-label callout macro inline replacement entity line-continuation"),a["other-block"].inside.rest=i("table list-punctuation indented-block comment attribute-entry attributes hr page-break admonition list-label macro inline replacement entity line-continuation"),a.title.inside.rest=i("macro inline replacement entity"),n.hooks.add("wrap",function(l){l.type==="entity"&&(l.attributes.title=l.content.value.replace(/&amp;/,"&"))}),n.languages.adoc=n.languages.asciidoc})(t)}return Ib}var Lb,zD;function dpe(){if(zD)return Lb;zD=1,Lb=e,e.displayName="asm6502",e.aliases=[];function e(t){t.languages.asm6502={comment:/;.*/,directive:{pattern:/\.\w+(?= )/,alias:"property"},string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,"op-code":{pattern:/\b(?:ADC|AND|ASL|BCC|BCS|BEQ|BIT|BMI|BNE|BPL|BRK|BVC|BVS|CLC|CLD|CLI|CLV|CMP|CPX|CPY|DEC|DEX|DEY|EOR|INC|INX|INY|JMP|JSR|LDA|LDX|LDY|LSR|NOP|ORA|PHA|PHP|PLA|PLP|ROL|ROR|RTI|RTS|SBC|SEC|SED|SEI|STA|STX|STY|TAX|TAY|TSX|TXA|TXS|TYA|adc|and|asl|bcc|bcs|beq|bit|bmi|bne|bpl|brk|bvc|bvs|clc|cld|cli|clv|cmp|cpx|cpy|dec|dex|dey|eor|inc|inx|iny|jmp|jsr|lda|ldx|ldy|lsr|nop|ora|pha|php|pla|plp|rol|ror|rti|rts|sbc|sec|sed|sei|sta|stx|sty|tax|tay|tsx|txa|txs|tya)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{1,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[xya]\b/i,alias:"variable"},punctuation:/[(),:]/}}return Lb}var Mb,PD;function fpe(){if(PD)return Mb;PD=1,Mb=e,e.displayName="asmatmel",e.aliases=[];function e(t){t.languages.asmatmel={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},constant:/\b(?:PORT[A-Z]|DDR[A-Z]|(?:DD|P)[A-Z](?:\d|[0-2]\d|3[01]))\b/,directive:{pattern:/\.\w+(?= )/,alias:"property"},"r-register":{pattern:/\br(?:\d|[12]\d|3[01])\b/,alias:"variable"},"op-code":{pattern:/\b(?:ADC|ADD|ADIW|AND|ANDI|ASR|BCLR|BLD|BRBC|BRBS|BRCC|BRCS|BREAK|BREQ|BRGE|BRHC|BRHS|BRID|BRIE|BRLO|BRLT|BRMI|BRNE|BRPL|BRSH|BRTC|BRTS|BRVC|BRVS|BSET|BST|CALL|CBI|CBR|CLC|CLH|CLI|CLN|CLR|CLS|CLT|CLV|CLZ|COM|CP|CPC|CPI|CPSE|DEC|DES|EICALL|EIJMP|ELPM|EOR|FMUL|FMULS|FMULSU|ICALL|IJMP|IN|INC|JMP|LAC|LAS|LAT|LD|LD[A-Za-z0-9]|LPM|LSL|LSR|MOV|MOVW|MUL|MULS|MULSU|NEG|NOP|OR|ORI|OUT|POP|PUSH|RCALL|RET|RETI|RJMP|ROL|ROR|SBC|SBCI|SBI|SBIC|SBIS|SBIW|SBR|SBRC|SBRS|SEC|SEH|SEI|SEN|SER|SES|SET|SEV|SEZ|SLEEP|SPM|ST|ST[A-Z0-9]|SUB|SUBI|SWAP|TST|WDR|XCH|adc|add|adiw|and|andi|asr|bclr|bld|brbc|brbs|brcc|brcs|break|breq|brge|brhc|brhs|brid|brie|brlo|brlt|brmi|brne|brpl|brsh|brtc|brts|brvc|brvs|bset|bst|call|cbi|cbr|clc|clh|cli|cln|clr|cls|clt|clv|clz|com|cp|cpc|cpi|cpse|dec|des|eicall|eijmp|elpm|eor|fmul|fmuls|fmulsu|icall|ijmp|in|inc|jmp|lac|las|lat|ld|ld[a-z0-9]|lpm|lsl|lsr|mov|movw|mul|muls|mulsu|neg|nop|or|ori|out|pop|push|rcall|ret|reti|rjmp|rol|ror|sbc|sbci|sbi|sbic|sbis|sbiw|sbr|sbrc|sbrs|sec|seh|sei|sen|ser|ses|set|sev|sez|sleep|spm|st|st[a-zA-Z0-9]|sub|subi|swap|tst|wdr|xch)\b/,alias:"keyword"},"hex-number":{pattern:/#?\$[\da-f]{2,4}\b/i,alias:"number"},"binary-number":{pattern:/#?%[01]+\b/,alias:"number"},"decimal-number":{pattern:/#?\b\d+\b/,alias:"number"},register:{pattern:/\b[acznvshtixy]\b/i,alias:"variable"},operator:/>>=?|<<=?|&&?|\|\|?|[-+*/%&|^!=<>?]=?/,punctuation:/[(),:]/}}return Mb}var Fb,BD;function Vf(){if(BD)return Fb;BD=1,Fb=e,e.displayName="csharp",e.aliases=["dotnet","cs"];function e(t){(function(n){function r(V,U){return V.replace(/<<(\d+)>>/g,function(L,Y){return"(?:"+U[+Y]+")"})}function a(V,U,L){return RegExp(r(V,U),"")}function i(V,U){for(var L=0;L<U;L++)V=V.replace(/<<self>>/g,function(){return"(?:"+V+")"});return V.replace(/<<self>>/g,"[^\\s\\S]")}var l={type:"bool byte char decimal double dynamic float int long object sbyte short string uint ulong ushort var void",typeDeclaration:"class enum interface record struct",contextual:"add alias and ascending async await by descending from(?=\\s*(?:\\w|$)) get global group into init(?=\\s*;) join let nameof not notnull on or orderby partial remove select set unmanaged value when where with(?=\\s*{)",other:"abstract as base break case catch checked const continue default delegate do else event explicit extern finally fixed for foreach goto if implicit in internal is lock namespace new null operator out override params private protected public readonly ref return sealed sizeof stackalloc static switch this throw try typeof unchecked unsafe using virtual volatile while yield"};function u(V){return"\\b(?:"+V.trim().replace(/ /g,"|")+")\\b"}var c=u(l.typeDeclaration),f=RegExp(u(l.type+" "+l.typeDeclaration+" "+l.contextual+" "+l.other)),p=u(l.typeDeclaration+" "+l.contextual+" "+l.other),g=u(l.type+" "+l.typeDeclaration+" "+l.other),b=i(/<(?:[^<>;=+\-*/%&|^]|<<self>>)*>/.source,2),m=i(/\((?:[^()]|<<self>>)*\)/.source,2),S=/@?\b[A-Za-z_]\w*\b/.source,v=r(/<<0>>(?:\s*<<1>>)?/.source,[S,b]),A=r(/(?!<<0>>)<<1>>(?:\s*\.\s*<<1>>)*/.source,[p,v]),R=/\[\s*(?:,\s*)*\]/.source,x=r(/<<0>>(?:\s*(?:\?\s*)?<<1>>)*(?:\s*\?)?/.source,[A,R]),T=r(/[^,()<>[\];=+\-*/%&|^]|<<0>>|<<1>>|<<2>>/.source,[b,m,R]),C=r(/\(<<0>>+(?:,<<0>>+)+\)/.source,[T]),N=r(/(?:<<0>>|<<1>>)(?:\s*(?:\?\s*)?<<2>>)*(?:\s*\?)?/.source,[C,A,R]),_={keyword:f,punctuation:/[<>()?,.:[\]]/},O=/'(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'/.source,z=/"(?:\\.|[^\\"\r\n])*"/.source,I=/@"(?:""|\\[\s\S]|[^\\"])*"(?!")/.source;n.languages.csharp=n.languages.extend("clike",{string:[{pattern:a(/(^|[^$\\])<<0>>/.source,[I]),lookbehind:!0,greedy:!0},{pattern:a(/(^|[^@$\\])<<0>>/.source,[z]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:a(/(\busing\s+static\s+)<<0>>(?=\s*;)/.source,[A]),lookbehind:!0,inside:_},{pattern:a(/(\busing\s+<<0>>\s*=\s*)<<1>>(?=\s*;)/.source,[S,N]),lookbehind:!0,inside:_},{pattern:a(/(\busing\s+)<<0>>(?=\s*=)/.source,[S]),lookbehind:!0},{pattern:a(/(\b<<0>>\s+)<<1>>/.source,[c,v]),lookbehind:!0,inside:_},{pattern:a(/(\bcatch\s*\(\s*)<<0>>/.source,[A]),lookbehind:!0,inside:_},{pattern:a(/(\bwhere\s+)<<0>>/.source,[S]),lookbehind:!0},{pattern:a(/(\b(?:is(?:\s+not)?|as)\s+)<<0>>/.source,[x]),lookbehind:!0,inside:_},{pattern:a(/\b<<0>>(?=\s+(?!<<1>>|with\s*\{)<<2>>(?:\s*[=,;:{)\]]|\s+(?:in|when)\b))/.source,[N,g,S]),inside:_}],keyword:f,number:/(?:\b0(?:x[\da-f_]*[\da-f]|b[01_]*[01])|(?:\B\.\d+(?:_+\d+)*|\b\d+(?:_+\d+)*(?:\.\d+(?:_+\d+)*)?)(?:e[-+]?\d+(?:_+\d+)*)?)(?:[dflmu]|lu|ul)?\b/i,operator:/>>=?|<<=?|[-=]>|([-+&|])\1|~|\?\?=?|[-+*/%&|^!=<>]=?/,punctuation:/\?\.?|::|[{}[\];(),.:]/}),n.languages.insertBefore("csharp","number",{range:{pattern:/\.\./,alias:"operator"}}),n.languages.insertBefore("csharp","punctuation",{"named-parameter":{pattern:a(/([(,]\s*)<<0>>(?=\s*:)/.source,[S]),lookbehind:!0,alias:"punctuation"}}),n.languages.insertBefore("csharp","class-name",{namespace:{pattern:a(/(\b(?:namespace|using)\s+)<<0>>(?:\s*\.\s*<<0>>)*(?=\s*[;{])/.source,[S]),lookbehind:!0,inside:{punctuation:/\./}},"type-expression":{pattern:a(/(\b(?:default|sizeof|typeof)\s*\(\s*(?!\s))(?:[^()\s]|\s(?!\s)|<<0>>)*(?=\s*\))/.source,[m]),lookbehind:!0,alias:"class-name",inside:_},"return-type":{pattern:a(/<<0>>(?=\s+(?:<<1>>\s*(?:=>|[({]|\.\s*this\s*\[)|this\s*\[))/.source,[N,A]),inside:_,alias:"class-name"},"constructor-invocation":{pattern:a(/(\bnew\s+)<<0>>(?=\s*[[({])/.source,[N]),lookbehind:!0,inside:_,alias:"class-name"},"generic-method":{pattern:a(/<<0>>\s*<<1>>(?=\s*\()/.source,[S,b]),inside:{function:a(/^<<0>>/.source,[S]),generic:{pattern:RegExp(b),alias:"class-name",inside:_}}},"type-list":{pattern:a(/\b((?:<<0>>\s+<<1>>|record\s+<<1>>\s*<<5>>|where\s+<<2>>)\s*:\s*)(?:<<3>>|<<4>>|<<1>>\s*<<5>>|<<6>>)(?:\s*,\s*(?:<<3>>|<<4>>|<<6>>))*(?=\s*(?:where|[{;]|=>|$))/.source,[c,v,S,N,f.source,m,/\bnew\s*\(\s*\)/.source]),lookbehind:!0,inside:{"record-arguments":{pattern:a(/(^(?!new\s*\()<<0>>\s*)<<1>>/.source,[v,m]),lookbehind:!0,greedy:!0,inside:n.languages.csharp},keyword:f,"class-name":{pattern:RegExp(N),greedy:!0,inside:_},punctuation:/[,()]/}},preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(#)\b(?:define|elif|else|endif|endregion|error|if|line|nullable|pragma|region|undef|warning)\b/,lookbehind:!0,alias:"keyword"}}}});var M=z+"|"+O,H=r(/\/(?![*/])|\/\/[^\r\n]*[\r\n]|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>/.source,[M]),q=i(r(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[H]),2),P=/\b(?:assembly|event|field|method|module|param|property|return|type)\b/.source,W=r(/<<0>>(?:\s*\(<<1>>*\))?/.source,[A,q]);n.languages.insertBefore("csharp","class-name",{attribute:{pattern:a(/((?:^|[^\s\w>)?])\s*\[\s*)(?:<<0>>\s*:\s*)?<<1>>(?:\s*,\s*<<1>>)*(?=\s*\])/.source,[P,W]),lookbehind:!0,greedy:!0,inside:{target:{pattern:a(/^<<0>>(?=\s*:)/.source,[P]),alias:"keyword"},"attribute-arguments":{pattern:a(/\(<<0>>*\)/.source,[q]),inside:n.languages.csharp},"class-name":{pattern:RegExp(A),inside:{punctuation:/\./}},punctuation:/[:,]/}}});var Z=/:[^}\r\n]+/.source,j=i(r(/[^"'/()]|<<0>>|\(<<self>>*\)/.source,[H]),2),G=r(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[j,Z]),B=i(r(/[^"'/()]|\/(?!\*)|\/\*(?:[^*]|\*(?!\/))*\*\/|<<0>>|\(<<self>>*\)/.source,[M]),2),X=r(/\{(?!\{)(?:(?![}:])<<0>>)*<<1>>?\}/.source,[B,Z]);function D(V,U){return{interpolation:{pattern:a(/((?:^|[^{])(?:\{\{)*)<<0>>/.source,[V]),lookbehind:!0,inside:{"format-string":{pattern:a(/(^\{(?:(?![}:])<<0>>)*)<<1>>(?=\}$)/.source,[U,Z]),lookbehind:!0,inside:{punctuation:/^:/}},punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-csharp",inside:n.languages.csharp}}},string:/[\s\S]+/}}n.languages.insertBefore("csharp","string",{"interpolation-string":[{pattern:a(/(^|[^\\])(?:\$@|@\$)"(?:""|\\[\s\S]|\{\{|<<0>>|[^\\{"])*"/.source,[G]),lookbehind:!0,greedy:!0,inside:D(G,j)},{pattern:a(/(^|[^@\\])\$"(?:\\.|\{\{|<<0>>|[^\\"{])*"/.source,[X]),lookbehind:!0,greedy:!0,inside:D(X,B)}],char:{pattern:RegExp(O),greedy:!0}}),n.languages.dotnet=n.languages.cs=n.languages.csharp})(t)}return Fb}var zb,UD;function ppe(){if(UD)return zb;UD=1;var e=Vf();zb=t,t.displayName="aspnet",t.aliases=[];function t(n){n.register(e),n.languages.aspnet=n.languages.extend("markup",{"page-directive":{pattern:/<%\s*@.*%>/,alias:"tag",inside:{"page-directive":{pattern:/<%\s*@\s*(?:Assembly|Control|Implements|Import|Master(?:Type)?|OutputCache|Page|PreviousPageType|Reference|Register)?|%>/i,alias:"tag"},rest:n.languages.markup.tag.inside}},directive:{pattern:/<%.*%>/,alias:"tag",inside:{directive:{pattern:/<%\s*?[$=%#:]{0,2}|%>/,alias:"tag"},rest:n.languages.csharp}}}),n.languages.aspnet.tag.pattern=/<(?!%)\/?[^\s>\/]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,n.languages.insertBefore("inside","punctuation",{directive:n.languages.aspnet.directive},n.languages.aspnet.tag.inside["attr-value"]),n.languages.insertBefore("aspnet","comment",{"asp-comment":{pattern:/<%--[\s\S]*?--%>/,alias:["asp","comment"]}}),n.languages.insertBefore("aspnet",n.languages.javascript?"script":"tag",{"asp-script":{pattern:/(<script(?=.*runat=['"]?server\b)[^>]*>)[\s\S]*?(?=<\/script>)/i,lookbehind:!0,alias:["asp","script"],inside:n.languages.csharp||{}}})}return zb}var Pb,jD;function gpe(){if(jD)return Pb;jD=1,Pb=e,e.displayName="autohotkey",e.aliases=[];function e(t){t.languages.autohotkey={comment:[{pattern:/(^|\s);.*/,lookbehind:!0},{pattern:/(^[\t ]*)\/\*(?:[\r\n](?![ \t]*\*\/)|[^\r\n])*(?:[\r\n][ \t]*\*\/)?/m,lookbehind:!0,greedy:!0}],tag:{pattern:/^([ \t]*)[^\s,`":]+(?=:[ \t]*$)/m,lookbehind:!0},string:/"(?:[^"\n\r]|"")*"/,variable:/%\w+%/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/\?|\/\/?=?|:=|\|[=|]?|&[=&]?|\+[=+]?|-[=-]?|\*[=*]?|<(?:<=?|>|=)?|>>?=?|[.^!=~]=?|\b(?:AND|NOT|OR)\b/,boolean:/\b(?:false|true)\b/,selector:/\b(?:AutoTrim|BlockInput|Break|Click|ClipWait|Continue|Control|ControlClick|ControlFocus|ControlGet|ControlGetFocus|ControlGetPos|ControlGetText|ControlMove|ControlSend|ControlSendRaw|ControlSetText|CoordMode|Critical|DetectHiddenText|DetectHiddenWindows|Drive|DriveGet|DriveSpaceFree|EnvAdd|EnvDiv|EnvGet|EnvMult|EnvSet|EnvSub|EnvUpdate|Exit|ExitApp|FileAppend|FileCopy|FileCopyDir|FileCreateDir|FileCreateShortcut|FileDelete|FileEncoding|FileGetAttrib|FileGetShortcut|FileGetSize|FileGetTime|FileGetVersion|FileInstall|FileMove|FileMoveDir|FileRead|FileReadLine|FileRecycle|FileRecycleEmpty|FileRemoveDir|FileSelectFile|FileSelectFolder|FileSetAttrib|FileSetTime|FormatTime|GetKeyState|Gosub|Goto|GroupActivate|GroupAdd|GroupClose|GroupDeactivate|Gui|GuiControl|GuiControlGet|Hotkey|ImageSearch|IniDelete|IniRead|IniWrite|Input|InputBox|KeyWait|ListHotkeys|ListLines|ListVars|Loop|Menu|MouseClick|MouseClickDrag|MouseGetPos|MouseMove|MsgBox|OnExit|OutputDebug|Pause|PixelGetColor|PixelSearch|PostMessage|Process|Progress|Random|RegDelete|RegRead|RegWrite|Reload|Repeat|Return|Run|RunAs|RunWait|Send|SendEvent|SendInput|SendMessage|SendMode|SendPlay|SendRaw|SetBatchLines|SetCapslockState|SetControlDelay|SetDefaultMouseSpeed|SetEnv|SetFormat|SetKeyDelay|SetMouseDelay|SetNumlockState|SetRegView|SetScrollLockState|SetStoreCapslockMode|SetTimer|SetTitleMatchMode|SetWinDelay|SetWorkingDir|Shutdown|Sleep|Sort|SoundBeep|SoundGet|SoundGetWaveVolume|SoundPlay|SoundSet|SoundSetWaveVolume|SplashImage|SplashTextOff|SplashTextOn|SplitPath|StatusBarGetText|StatusBarWait|StringCaseSense|StringGetPos|StringLeft|StringLen|StringLower|StringMid|StringReplace|StringRight|StringSplit|StringTrimLeft|StringTrimRight|StringUpper|Suspend|SysGet|Thread|ToolTip|Transform|TrayTip|URLDownloadToFile|WinActivate|WinActivateBottom|WinClose|WinGet|WinGetActiveStats|WinGetActiveTitle|WinGetClass|WinGetPos|WinGetText|WinGetTitle|WinHide|WinKill|WinMaximize|WinMenuSelectItem|WinMinimize|WinMinimizeAll|WinMinimizeAllUndo|WinMove|WinRestore|WinSet|WinSetTitle|WinShow|WinWait|WinWaitActive|WinWaitClose|WinWaitNotActive)\b/i,constant:/\b(?:a_ahkpath|a_ahkversion|a_appdata|a_appdatacommon|a_autotrim|a_batchlines|a_caretx|a_carety|a_computername|a_controldelay|a_cursor|a_dd|a_ddd|a_dddd|a_defaultmousespeed|a_desktop|a_desktopcommon|a_detecthiddentext|a_detecthiddenwindows|a_endchar|a_eventinfo|a_exitreason|a_fileencoding|a_formatfloat|a_formatinteger|a_gui|a_guicontrol|a_guicontrolevent|a_guievent|a_guiheight|a_guiwidth|a_guix|a_guiy|a_hour|a_iconfile|a_iconhidden|a_iconnumber|a_icontip|a_index|a_ipaddress1|a_ipaddress2|a_ipaddress3|a_ipaddress4|a_is64bitos|a_isadmin|a_iscompiled|a_iscritical|a_ispaused|a_issuspended|a_isunicode|a_keydelay|a_language|a_lasterror|a_linefile|a_linenumber|a_loopfield|a_loopfileattrib|a_loopfiledir|a_loopfileext|a_loopfilefullpath|a_loopfilelongpath|a_loopfilename|a_loopfileshortname|a_loopfileshortpath|a_loopfilesize|a_loopfilesizekb|a_loopfilesizemb|a_loopfiletimeaccessed|a_loopfiletimecreated|a_loopfiletimemodified|a_loopreadline|a_loopregkey|a_loopregname|a_loopregsubkey|a_loopregtimemodified|a_loopregtype|a_mday|a_min|a_mm|a_mmm|a_mmmm|a_mon|a_mousedelay|a_msec|a_mydocuments|a_now|a_nowutc|a_numbatchlines|a_ostype|a_osversion|a_priorhotkey|a_priorkey|a_programfiles|a_programs|a_programscommon|a_ptrsize|a_regview|a_screendpi|a_screenheight|a_screenwidth|a_scriptdir|a_scriptfullpath|a_scripthwnd|a_scriptname|a_sec|a_space|a_startmenu|a_startmenucommon|a_startup|a_startupcommon|a_stringcasesense|a_tab|a_temp|a_thisfunc|a_thishotkey|a_thislabel|a_thismenu|a_thismenuitem|a_thismenuitempos|a_tickcount|a_timeidle|a_timeidlephysical|a_timesincepriorhotkey|a_timesincethishotkey|a_titlematchmode|a_titlematchmodespeed|a_username|a_wday|a_windelay|a_windir|a_workingdir|a_yday|a_year|a_yweek|a_yyyy|clipboard|clipboardall|comspec|errorlevel|programfiles)\b/i,builtin:/\b(?:abs|acos|asc|asin|atan|ceil|chr|class|comobjactive|comobjarray|comobjconnect|comobjcreate|comobjerror|comobjflags|comobjget|comobjquery|comobjtype|comobjvalue|cos|dllcall|exp|fileexist|Fileopen|floor|format|il_add|il_create|il_destroy|instr|isfunc|islabel|IsObject|ln|log|ltrim|lv_add|lv_delete|lv_deletecol|lv_getcount|lv_getnext|lv_gettext|lv_insert|lv_insertcol|lv_modify|lv_modifycol|lv_setimagelist|mod|numget|numput|onmessage|regexmatch|regexreplace|registercallback|round|rtrim|sb_seticon|sb_setparts|sb_settext|sin|sqrt|strlen|strreplace|strsplit|substr|tan|tv_add|tv_delete|tv_get|tv_getchild|tv_getcount|tv_getnext|tv_getparent|tv_getprev|tv_getselection|tv_gettext|tv_modify|varsetcapacity|winactive|winexist|__Call|__Get|__New|__Set)\b/i,symbol:/\b(?:alt|altdown|altup|appskey|backspace|browser_back|browser_favorites|browser_forward|browser_home|browser_refresh|browser_search|browser_stop|bs|capslock|ctrl|ctrlbreak|ctrldown|ctrlup|del|delete|down|end|enter|esc|escape|f1|f10|f11|f12|f13|f14|f15|f16|f17|f18|f19|f2|f20|f21|f22|f23|f24|f3|f4|f5|f6|f7|f8|f9|home|ins|insert|joy1|joy10|joy11|joy12|joy13|joy14|joy15|joy16|joy17|joy18|joy19|joy2|joy20|joy21|joy22|joy23|joy24|joy25|joy26|joy27|joy28|joy29|joy3|joy30|joy31|joy32|joy4|joy5|joy6|joy7|joy8|joy9|joyaxes|joybuttons|joyinfo|joyname|joypov|joyr|joyu|joyv|joyx|joyy|joyz|lalt|launch_app1|launch_app2|launch_mail|launch_media|lbutton|lcontrol|lctrl|left|lshift|lwin|lwindown|lwinup|mbutton|media_next|media_play_pause|media_prev|media_stop|numlock|numpad0|numpad1|numpad2|numpad3|numpad4|numpad5|numpad6|numpad7|numpad8|numpad9|numpadadd|numpadclear|numpaddel|numpaddiv|numpaddot|numpaddown|numpadend|numpadenter|numpadhome|numpadins|numpadleft|numpadmult|numpadpgdn|numpadpgup|numpadright|numpadsub|numpadup|pgdn|pgup|printscreen|ralt|rbutton|rcontrol|rctrl|right|rshift|rwin|rwindown|rwinup|scrolllock|shift|shiftdown|shiftup|space|tab|up|volume_down|volume_mute|volume_up|wheeldown|wheelleft|wheelright|wheelup|xbutton1|xbutton2)\b/i,important:/#\b(?:AllowSameLineComments|ClipboardTimeout|CommentFlag|DerefChar|ErrorStdOut|EscapeChar|HotkeyInterval|HotkeyModifierTimeout|Hotstring|If|IfTimeout|IfWinActive|IfWinExist|IfWinNotActive|IfWinNotExist|Include|IncludeAgain|InputLevel|InstallKeybdHook|InstallMouseHook|KeyHistory|MaxHotkeysPerInterval|MaxMem|MaxThreads|MaxThreadsBuffer|MaxThreadsPerHotkey|MenuMaskKey|NoEnv|NoTrayIcon|Persistent|SingleInstance|UseHook|Warn|WinActivateForce)\b/i,keyword:/\b(?:Abort|AboveNormal|Add|ahk_class|ahk_exe|ahk_group|ahk_id|ahk_pid|All|Alnum|Alpha|AltSubmit|AltTab|AltTabAndMenu|AltTabMenu|AltTabMenuDismiss|AlwaysOnTop|AutoSize|Background|BackgroundTrans|BelowNormal|between|BitAnd|BitNot|BitOr|BitShiftLeft|BitShiftRight|BitXOr|Bold|Border|Button|ByRef|Catch|Checkbox|Checked|CheckedGray|Choose|ChooseString|Close|Color|ComboBox|Contains|ControlList|Count|Date|DateTime|Days|DDL|Default|DeleteAll|Delimiter|Deref|Destroy|Digit|Disable|Disabled|DropDownList|Edit|Eject|Else|Enable|Enabled|Error|Exist|Expand|ExStyle|FileSystem|Finally|First|Flash|Float|FloatFast|Focus|Font|for|global|Grid|Group|GroupBox|GuiClose|GuiContextMenu|GuiDropFiles|GuiEscape|GuiSize|Hdr|Hidden|Hide|High|HKCC|HKCR|HKCU|HKEY_CLASSES_ROOT|HKEY_CURRENT_CONFIG|HKEY_CURRENT_USER|HKEY_LOCAL_MACHINE|HKEY_USERS|HKLM|HKU|Hours|HScroll|Icon|IconSmall|ID|IDLast|If|IfEqual|IfExist|IfGreater|IfGreaterOrEqual|IfInString|IfLess|IfLessOrEqual|IfMsgBox|IfNotEqual|IfNotExist|IfNotInString|IfWinActive|IfWinExist|IfWinNotActive|IfWinNotExist|Ignore|ImageList|in|Integer|IntegerFast|Interrupt|is|italic|Join|Label|LastFound|LastFoundExist|Limit|Lines|List|ListBox|ListView|local|Lock|Logoff|Low|Lower|Lowercase|MainWindow|Margin|Maximize|MaximizeBox|MaxSize|Minimize|MinimizeBox|MinMax|MinSize|Minutes|MonthCal|Mouse|Move|Multi|NA|No|NoActivate|NoDefault|NoHide|NoIcon|NoMainWindow|norm|Normal|NoSort|NoSortHdr|NoStandard|Not|NoTab|NoTimers|Number|Off|Ok|On|OwnDialogs|Owner|Parse|Password|Picture|Pixel|Pos|Pow|Priority|ProcessName|Radio|Range|Read|ReadOnly|Realtime|Redraw|Region|REG_BINARY|REG_DWORD|REG_EXPAND_SZ|REG_MULTI_SZ|REG_SZ|Relative|Rename|Report|Resize|Restore|Retry|RGB|Screen|Seconds|Section|Serial|SetLabel|ShiftAltTab|Show|Single|Slider|SortDesc|Standard|static|Status|StatusBar|StatusCD|strike|Style|Submit|SysMenu|Tab2|TabStop|Text|Theme|Throw|Tile|ToggleCheck|ToggleEnable|ToolWindow|Top|Topmost|TransColor|Transparent|Tray|TreeView|Try|TryAgain|Type|UnCheck|underline|Unicode|Unlock|Until|UpDown|Upper|Uppercase|UseErrorLevel|Vis|VisFirst|Visible|VScroll|Wait|WaitClose|WantCtrlA|WantF2|WantReturn|While|Wrap|Xdigit|xm|xp|xs|Yes|ym|yp|ys)\b/i,function:/[^(); \t,\n+*\-=?>:\\\/<&%\[\]]+(?=\()/,punctuation:/[{}[\]():,]/}}return Pb}var Bb,GD;function hpe(){if(GD)return Bb;GD=1,Bb=e,e.displayName="autoit",e.aliases=[];function e(t){t.languages.autoit={comment:[/;.*/,{pattern:/(^[\t ]*)#(?:comments-start|cs)[\s\S]*?^[ \t]*#(?:ce|comments-end)/m,lookbehind:!0}],url:{pattern:/(^[\t ]*#include\s+)(?:<[^\r\n>]+>|"[^\r\n"]+")/m,lookbehind:!0},string:{pattern:/(["'])(?:\1\1|(?!\1)[^\r\n])*\1/,greedy:!0,inside:{variable:/([%$@])\w+\1/}},directive:{pattern:/(^[\t ]*)#[\w-]+/m,lookbehind:!0,alias:"keyword"},function:/\b\w+(?=\()/,variable:/[$@]\w+/,keyword:/\b(?:Case|Const|Continue(?:Case|Loop)|Default|Dim|Do|Else(?:If)?|End(?:Func|If|Select|Switch|With)|Enum|Exit(?:Loop)?|For|Func|Global|If|In|Local|Next|Null|ReDim|Select|Static|Step|Switch|Then|To|Until|Volatile|WEnd|While|With)\b/i,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,boolean:/\b(?:False|True)\b/i,operator:/<[=>]?|[-+*\/=&>]=?|[?^]|\b(?:And|Not|Or)\b/i,punctuation:/[\[\]().,:]/}}return Bb}var Ub,HD;function mpe(){if(HD)return Ub;HD=1,Ub=e,e.displayName="avisynth",e.aliases=["avs"];function e(t){(function(n){function r(p,g){return p.replace(/<<(\d+)>>/g,function(b,m){return g[+m]})}function a(p,g,b){return RegExp(r(p,g),b)}var i=/bool|clip|float|int|string|val/.source,l=[/is(?:bool|clip|float|int|string)|defined|(?:(?:internal)?function|var)?exists?/.source,/apply|assert|default|eval|import|nop|select|undefined/.source,/opt_(?:allowfloataudio|avipadscanlines|dwchannelmask|enable_(?:b64a|planartopackedrgb|v210|y3_10_10|y3_10_16)|usewaveextensible|vdubplanarhack)|set(?:cachemode|maxcpu|memorymax|planarlegacyalignment|workingdir)/.source,/hex(?:value)?|value/.source,/abs|ceil|continued(?:denominator|numerator)?|exp|floor|fmod|frac|log(?:10)?|max|min|muldiv|pi|pow|rand|round|sign|spline|sqrt/.source,/a?sinh?|a?cosh?|a?tan[2h]?/.source,/(?:bit(?:and|not|x?or|[lr]?shift[aslu]?|sh[lr]|sa[lr]|[lr]rotatel?|ro[rl]|te?st|set(?:count)?|cl(?:ea)?r|ch(?:an)?ge?))/.source,/average(?:[bgr]|chroma[uv]|luma)|(?:[rgb]|chroma[uv]|luma|rgb|[yuv](?=difference(?:fromprevious|tonext)))difference(?:fromprevious|tonext)?|[yuvrgb]plane(?:median|min|max|minmaxdifference)/.source,/getprocessinfo|logmsg|script(?:dir(?:utf8)?|file(?:utf8)?|name(?:utf8)?)|setlogparams/.source,/chr|(?:fill|find|left|mid|replace|rev|right)str|format|[lu]case|ord|str(?:cmpi?|fromutf8|len|toutf8)|time|trim(?:all|left|right)/.source,/isversionorgreater|version(?:number|string)/.source,/buildpixeltype|colorspacenametopixeltype/.source,/addautoloaddir|on(?:cpu|cuda)|prefetch|setfiltermtmode/.source].join("|"),u=[/has(?:audio|video)/.source,/height|width/.source,/frame(?:count|rate)|framerate(?:denominator|numerator)/.source,/getparity|is(?:field|frame)based/.source,/bitspercomponent|componentsize|hasalpha|is(?:planar(?:rgba?)?|interleaved|rgb(?:24|32|48|64)?|y(?:8|u(?:va?|y2))?|yv(?:12|16|24|411)|420|422|444|packedrgb)|numcomponents|pixeltype/.source,/audio(?:bits|channels|duration|length(?:[fs]|hi|lo)?|rate)|isaudio(?:float|int)/.source].join("|"),c=[/avi(?:file)?source|directshowsource|image(?:reader|source|sourceanim)|opendmlsource|segmented(?:avisource|directshowsource)|wavsource/.source,/coloryuv|convertbacktoyuy2|convertto(?:RGB(?:24|32|48|64)|(?:planar)?RGBA?|Y8?|YV(?:12|16|24|411)|YUVA?(?:411|420|422|444)|YUY2)|fixluminance|gr[ae]yscale|invert|levels|limiter|mergea?rgb|merge(?:chroma|luma)|rgbadjust|show(?:alpha|blue|green|red)|swapuv|tweak|[uv]toy8?|ytouv/.source,/(?:colorkey|reset)mask|layer|mask(?:hs)?|merge|overlay|subtract/.source,/addborders|(?:bicubic|bilinear|blackman|gauss|lanczos4|lanczos|point|sinc|spline(?:16|36|64))resize|crop(?:bottom)?|flip(?:horizontal|vertical)|(?:horizontal|vertical)?reduceby2|letterbox|skewrows|turn(?:180|left|right)/.source,/blur|fixbrokenchromaupsampling|generalconvolution|(?:spatial|temporal)soften|sharpen/.source,/trim|(?:un)?alignedsplice|(?:assume|assumescaled|change|convert)FPS|(?:delete|duplicate)frame|dissolve|fade(?:in|io|out)[02]?|freezeframe|interleave|loop|reverse|select(?:even|odd|(?:range)?every)/.source,/assume[bt]ff|assume(?:field|frame)based|bob|complementparity|doubleweave|peculiarblend|pulldown|separate(?:columns|fields|rows)|swapfields|weave(?:columns|rows)?/.source,/amplify(?:db)?|assumesamplerate|audiodub(?:ex)?|audiotrim|convertaudioto(?:(?:8|16|24|32)bit|float)|converttomono|delayaudio|ensurevbrmp3sync|get(?:left|right)?channel|kill(?:audio|video)|mergechannels|mixaudio|monotostereo|normalize|resampleaudio|ssrc|supereq|timestretch/.source,/animate|applyrange|conditional(?:filter|reader|select)|frameevaluate|scriptclip|tcp(?:server|source)|writefile(?:end|if|start)?/.source,/imagewriter/.source,/blackness|blankclip|colorbars(?:hd)?|compare|dumpfiltergraph|echo|histogram|info|messageclip|preroll|setgraphanalysis|show(?:framenumber|smpte|time)|showfiveversions|stack(?:horizontal|vertical)|subtitle|tone|version/.source].join("|"),f=[l,u,c].join("|");n.languages.avisynth={comment:[{pattern:/(^|[^\\])\[\*(?:[^\[*]|\[(?!\*)|\*(?!\])|\[\*(?:[^\[*]|\[(?!\*)|\*(?!\]))*\*\])*\*\]/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],argument:{pattern:a(/\b(?:<<0>>)\s+("?)\w+\1/.source,[i],"i"),inside:{keyword:/^\w+/}},"argument-label":{pattern:/([,(][\s\\]*)\w+\s*=(?!=)/,lookbehind:!0,inside:{"argument-name":{pattern:/^\w+/,alias:"punctuation"},punctuation:/=$/}},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0,inside:{constant:{pattern:/\b(?:DEFAULT_MT_MODE|(?:MAINSCRIPT|PROGRAM|SCRIPT)DIR|(?:MACHINE|USER)_(?:CLASSIC|PLUS)_PLUGINS)\b/}}}],variable:/\b(?:last)\b/i,boolean:/\b(?:false|no|true|yes)\b/i,keyword:/\b(?:catch|else|for|function|global|if|return|try|while|__END__)\b/i,constant:/\bMT_(?:MULTI_INSTANCE|NICE_FILTER|SERIALIZED|SPECIAL_MT)\b/,"builtin-function":{pattern:a(/\b(?:<<0>>)\b/.source,[f],"i"),alias:"function"},"type-cast":{pattern:a(/\b(?:<<0>>)(?=\s*\()/.source,[i],"i"),alias:"keyword"},function:{pattern:/\b[a-z_]\w*(?=\s*\()|(\.)[a-z_]\w*\b/i,lookbehind:!0},"line-continuation":{pattern:/(^[ \t]*)\\|\\(?=[ \t]*$)/m,lookbehind:!0,alias:"punctuation"},number:/\B\$(?:[\da-f]{6}|[\da-f]{8})\b|(?:(?:\b|\B-)\d+(?:\.\d*)?\b|\B\.\d+\b)/i,operator:/\+\+?|[!=<>]=?|&&|\|\||[?:*/%-]/,punctuation:/[{}\[\]();,.]/},n.languages.avs=n.languages.avisynth})(t)}return Ub}var jb,$D;function bpe(){if($D)return jb;$D=1,jb=e,e.displayName="avroIdl",e.aliases=[];function e(t){t.languages["avro-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0},annotation:{pattern:/@(?:[$\w.-]|`[^\r\n`]+`)+/,greedy:!0,alias:"function"},"function-identifier":{pattern:/`[^\r\n`]+`(?=\s*\()/,greedy:!0,alias:"function"},identifier:{pattern:/`[^\r\n`]+`/,greedy:!0},"class-name":{pattern:/(\b(?:enum|error|protocol|record|throws)\b\s+)[$\w]+/,lookbehind:!0,greedy:!0},keyword:/\b(?:array|boolean|bytes|date|decimal|double|enum|error|false|fixed|float|idl|import|int|local_timestamp_ms|long|map|null|oneway|protocol|record|schema|string|throws|time_ms|timestamp_ms|true|union|uuid|void)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:[{pattern:/(^|[^\w.])-?(?:(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|0x(?:[a-f0-9]+(?:\.[a-f0-9]*)?|\.[a-f0-9]+)(?:p[+-]?\d+)?)[dfl]?(?![\w.])/i,lookbehind:!0},/-?\b(?:Infinity|NaN)\b/],operator:/=/,punctuation:/[()\[\]{}<>.:,;-]/},t.languages.avdl=t.languages["avro-idl"]}return jb}var Gb,qD;function V5(){if(qD)return Gb;qD=1,Gb=e,e.displayName="bash",e.aliases=["shell"];function e(t){(function(n){var r="\\b(?:BASH|BASHOPTS|BASH_ALIASES|BASH_ARGC|BASH_ARGV|BASH_CMDS|BASH_COMPLETION_COMPAT_DIR|BASH_LINENO|BASH_REMATCH|BASH_SOURCE|BASH_VERSINFO|BASH_VERSION|COLORTERM|COLUMNS|COMP_WORDBREAKS|DBUS_SESSION_BUS_ADDRESS|DEFAULTS_PATH|DESKTOP_SESSION|DIRSTACK|DISPLAY|EUID|GDMSESSION|GDM_LANG|GNOME_KEYRING_CONTROL|GNOME_KEYRING_PID|GPG_AGENT_INFO|GROUPS|HISTCONTROL|HISTFILE|HISTFILESIZE|HISTSIZE|HOME|HOSTNAME|HOSTTYPE|IFS|INSTANCE|JOB|LANG|LANGUAGE|LC_ADDRESS|LC_ALL|LC_IDENTIFICATION|LC_MEASUREMENT|LC_MONETARY|LC_NAME|LC_NUMERIC|LC_PAPER|LC_TELEPHONE|LC_TIME|LESSCLOSE|LESSOPEN|LINES|LOGNAME|LS_COLORS|MACHTYPE|MAILCHECK|MANDATORY_PATH|NO_AT_BRIDGE|OLDPWD|OPTERR|OPTIND|ORBIT_SOCKETDIR|OSTYPE|PAPERSIZE|PATH|PIPESTATUS|PPID|PS1|PS2|PS3|PS4|PWD|RANDOM|REPLY|SECONDS|SELINUX_INIT|SESSION|SESSIONTYPE|SESSION_MANAGER|SHELL|SHELLOPTS|SHLVL|SSH_AUTH_SOCK|TERM|UID|UPSTART_EVENTS|UPSTART_INSTANCE|UPSTART_JOB|UPSTART_SESSION|USER|WINDOWID|XAUTHORITY|XDG_CONFIG_DIRS|XDG_CURRENT_DESKTOP|XDG_DATA_DIRS|XDG_GREETER_DATA_DIR|XDG_MENU_PREFIX|XDG_RUNTIME_DIR|XDG_SEAT|XDG_SEAT_PATH|XDG_SESSION_DESKTOP|XDG_SESSION_ID|XDG_SESSION_PATH|XDG_SESSION_TYPE|XDG_VTNR|XMODIFIERS)\\b",a={pattern:/(^(["']?)\w+\2)[ \t]+\S.*/,lookbehind:!0,alias:"punctuation",inside:null},i={bash:a,environment:{pattern:RegExp("\\$"+r),alias:"constant"},variable:[{pattern:/\$?\(\([\s\S]+?\)\)/,greedy:!0,inside:{variable:[{pattern:/(^\$\(\([\s\S]+)\)\)/,lookbehind:!0},/^\$\(\(/],number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--|\+\+|\*\*=?|<<=?|>>=?|&&|\|\||[=!+\-*/%<>^&|]=?|[?~:]/,punctuation:/\(\(?|\)\)?|,|;/}},{pattern:/\$\((?:\([^)]+\)|[^()])+\)|`[^`]+`/,greedy:!0,inside:{variable:/^\$\(|^`|\)$|`$/}},{pattern:/\$\{[^}]+\}/,greedy:!0,inside:{operator:/:[-=?+]?|[!\/]|##?|%%?|\^\^?|,,?/,punctuation:/[\[\]]/,environment:{pattern:RegExp("(\\{)"+r),lookbehind:!0,alias:"constant"}}},/\$(?:\w+|[#?*!@$])/],entity:/\\(?:[abceEfnrtv\\"]|O?[0-7]{1,3}|U[0-9a-fA-F]{8}|u[0-9a-fA-F]{4}|x[0-9a-fA-F]{1,2})/};n.languages.bash={shebang:{pattern:/^#!\s*\/.*/,alias:"important"},comment:{pattern:/(^|[^"{\\$])#.*/,lookbehind:!0},"function-name":[{pattern:/(\bfunction\s+)[\w-]+(?=(?:\s*\(?:\s*\))?\s*\{)/,lookbehind:!0,alias:"function"},{pattern:/\b[\w-]+(?=\s*\(\s*\)\s*\{)/,alias:"function"}],"for-or-select":{pattern:/(\b(?:for|select)\s+)\w+(?=\s+in\s)/,alias:"variable",lookbehind:!0},"assign-left":{pattern:/(^|[\s;|&]|[<>]\()\w+(?=\+?=)/,inside:{environment:{pattern:RegExp("(^|[\\s;|&]|[<>]\\()"+r),lookbehind:!0,alias:"constant"}},alias:"variable",lookbehind:!0},string:[{pattern:/((?:^|[^<])<<-?\s*)(\w+)\s[\s\S]*?(?:\r?\n|\r)\2/,lookbehind:!0,greedy:!0,inside:i},{pattern:/((?:^|[^<])<<-?\s*)(["'])(\w+)\2\s[\s\S]*?(?:\r?\n|\r)\3/,lookbehind:!0,greedy:!0,inside:{bash:a}},{pattern:/(^|[^\\](?:\\\\)*)"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/,lookbehind:!0,greedy:!0,inside:i},{pattern:/(^|[^$\\])'[^']*'/,lookbehind:!0,greedy:!0},{pattern:/\$'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{entity:i.entity}}],environment:{pattern:RegExp("\\$?"+r),alias:"constant"},variable:i.variable,function:{pattern:/(^|[\s;|&]|[<>]\()(?:add|apropos|apt|apt-cache|apt-get|aptitude|aspell|automysqlbackup|awk|basename|bash|bc|bconsole|bg|bzip2|cal|cat|cfdisk|chgrp|chkconfig|chmod|chown|chroot|cksum|clear|cmp|column|comm|composer|cp|cron|crontab|csplit|curl|cut|date|dc|dd|ddrescue|debootstrap|df|diff|diff3|dig|dir|dircolors|dirname|dirs|dmesg|docker|docker-compose|du|egrep|eject|env|ethtool|expand|expect|expr|fdformat|fdisk|fg|fgrep|file|find|fmt|fold|format|free|fsck|ftp|fuser|gawk|git|gparted|grep|groupadd|groupdel|groupmod|groups|grub-mkconfig|gzip|halt|head|hg|history|host|hostname|htop|iconv|id|ifconfig|ifdown|ifup|import|install|ip|jobs|join|kill|killall|less|link|ln|locate|logname|logrotate|look|lpc|lpr|lprint|lprintd|lprintq|lprm|ls|lsof|lynx|make|man|mc|mdadm|mkconfig|mkdir|mke2fs|mkfifo|mkfs|mkisofs|mknod|mkswap|mmv|more|most|mount|mtools|mtr|mutt|mv|nano|nc|netstat|nice|nl|node|nohup|notify-send|npm|nslookup|op|open|parted|passwd|paste|pathchk|ping|pkill|pnpm|podman|podman-compose|popd|pr|printcap|printenv|ps|pushd|pv|quota|quotacheck|quotactl|ram|rar|rcp|reboot|remsync|rename|renice|rev|rm|rmdir|rpm|rsync|scp|screen|sdiff|sed|sendmail|seq|service|sftp|sh|shellcheck|shuf|shutdown|sleep|slocate|sort|split|ssh|stat|strace|su|sudo|sum|suspend|swapon|sync|tac|tail|tar|tee|time|timeout|top|touch|tr|traceroute|tsort|tty|umount|uname|unexpand|uniq|units|unrar|unshar|unzip|update-grub|uptime|useradd|userdel|usermod|users|uudecode|uuencode|v|vcpkg|vdir|vi|vim|virsh|vmstat|wait|watch|wc|wget|whereis|which|who|whoami|write|xargs|xdg-open|yarn|yes|zenity|zip|zsh|zypper)(?=$|[)\s;|&])/,lookbehind:!0},keyword:{pattern:/(^|[\s;|&]|[<>]\()(?:case|do|done|elif|else|esac|fi|for|function|if|in|select|then|until|while)(?=$|[)\s;|&])/,lookbehind:!0},builtin:{pattern:/(^|[\s;|&]|[<>]\()(?:\.|:|alias|bind|break|builtin|caller|cd|command|continue|declare|echo|enable|eval|exec|exit|export|getopts|hash|help|let|local|logout|mapfile|printf|pwd|read|readarray|readonly|return|set|shift|shopt|source|test|times|trap|type|typeset|ulimit|umask|unalias|unset)(?=$|[)\s;|&])/,lookbehind:!0,alias:"class-name"},boolean:{pattern:/(^|[\s;|&]|[<>]\()(?:false|true)(?=$|[)\s;|&])/,lookbehind:!0},"file-descriptor":{pattern:/\B&\d\b/,alias:"important"},operator:{pattern:/\d?<>|>\||\+=|=[=~]?|!=?|<<[<-]?|[&\d]?>>|\d[<>]&?|[<>][&=]?|&[>&]?|\|[&|]?/,inside:{"file-descriptor":{pattern:/^\d/,alias:"important"}}},punctuation:/\$?\(\(?|\)\)?|\.\.|[{}[\];\\]/,number:{pattern:/(^|\s)(?:[1-9]\d*|0)(?:[.,]\d+)?\b/,lookbehind:!0}},a.inside=n.languages.bash;for(var l=["comment","function-name","for-or-select","assign-left","string","environment","function","keyword","builtin","boolean","file-descriptor","operator","punctuation","number"],u=i.variable[1].inside,c=0;c<l.length;c++)u[l[c]]=n.languages.bash[l[c]];n.languages.shell=n.languages.bash})(t)}return Gb}var Hb,VD;function W5(){if(VD)return Hb;VD=1,Hb=e,e.displayName="basic",e.aliases=[];function e(t){t.languages.basic={comment:{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:AS|BEEP|BLOAD|BSAVE|CALL(?: ABSOLUTE)?|CASE|CHAIN|CHDIR|CLEAR|CLOSE|CLS|COM|COMMON|CONST|DATA|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DIM|DO|DOUBLE|ELSE|ELSEIF|END|ENVIRON|ERASE|ERROR|EXIT|FIELD|FILES|FOR|FUNCTION|GET|GOSUB|GOTO|IF|INPUT|INTEGER|IOCTL|KEY|KILL|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|MKDIR|NAME|NEXT|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPTION BASE|OUT|POKE|PUT|READ|REDIM|REM|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SELECT CASE|SHARED|SHELL|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|SUB|SWAP|SYSTEM|THEN|TIMER|TO|TROFF|TRON|TYPE|UNLOCK|UNTIL|USING|VIEW PRINT|WAIT|WEND|WHILE|WRITE)(?:\$|\b)/i,function:/\b(?:ABS|ACCESS|ACOS|ANGLE|AREA|ARITHMETIC|ARRAY|ASIN|ASK|AT|ATN|BASE|BEGIN|BREAK|CAUSE|CEIL|CHR|CLIP|COLLATE|COLOR|CON|COS|COSH|COT|CSC|DATE|DATUM|DEBUG|DECIMAL|DEF|DEG|DEGREES|DELETE|DET|DEVICE|DISPLAY|DOT|ELAPSED|EPS|ERASABLE|EXLINE|EXP|EXTERNAL|EXTYPE|FILETYPE|FIXED|FP|GO|GRAPH|HANDLER|IDN|IMAGE|IN|INT|INTERNAL|IP|IS|KEYED|LBOUND|LCASE|LEFT|LEN|LENGTH|LET|LINE|LINES|LOG|LOG10|LOG2|LTRIM|MARGIN|MAT|MAX|MAXNUM|MID|MIN|MISSING|MOD|NATIVE|NUL|NUMERIC|OF|OPTION|ORD|ORGANIZATION|OUTIN|OUTPUT|PI|POINT|POINTER|POINTS|POS|PRINT|PROGRAM|PROMPT|RAD|RADIANS|RANDOMIZE|RECORD|RECSIZE|RECTYPE|RELATIVE|REMAINDER|REPEAT|REST|RETRY|REWRITE|RIGHT|RND|ROUND|RTRIM|SAME|SEC|SELECT|SEQUENTIAL|SET|SETTER|SGN|SIN|SINH|SIZE|SKIP|SQR|STANDARD|STATUS|STR|STREAM|STYLE|TAB|TAN|TANH|TEMPLATE|TEXT|THERE|TIME|TIMEOUT|TRACE|TRANSFORM|TRUNCATE|UBOUND|UCASE|USE|VAL|VARIABLE|VIEWPORT|WHEN|WINDOW|WITH|ZER|ZONEWIDTH)(?:\$|\b)/i,operator:/<[=>]?|>=?|[+\-*\/^=&]|\b(?:AND|EQV|IMP|NOT|OR|XOR)\b/i,punctuation:/[,;:()]/}}return Hb}var $b,WD;function ype(){if(WD)return $b;WD=1,$b=e,e.displayName="batch",e.aliases=[];function e(t){(function(n){var r=/%%?[~:\w]+%?|!\S+!/,a={pattern:/\/[a-z?]+(?=[ :]|$):?|-[a-z]\b|--[a-z-]+\b/im,alias:"attr-name",inside:{punctuation:/:/}},i=/"(?:[\\"]"|[^"])*"(?!")/,l=/(?:\b|-)\d+\b/;n.languages.batch={comment:[/^::.*/m,{pattern:/((?:^|[&(])[ \t]*)rem\b(?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0}],label:{pattern:/^:.*/m,alias:"property"},command:[{pattern:/((?:^|[&(])[ \t]*)for(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* \S+ in \([^)]+\) do/im,lookbehind:!0,inside:{keyword:/\b(?:do|in)\b|^for\b/i,string:i,parameter:a,variable:r,number:l,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*)if(?: \/[a-z?](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:not )?(?:cmdextversion \d+|defined \w+|errorlevel \d+|exist \S+|(?:"[^"]*"|(?!")(?:(?!==)\S)+)?(?:==| (?:equ|geq|gtr|leq|lss|neq) )(?:"[^"]*"|[^\s"]\S*))/im,lookbehind:!0,inside:{keyword:/\b(?:cmdextversion|defined|errorlevel|exist|not)\b|^if\b/i,string:i,parameter:a,variable:r,number:l,operator:/\^|==|\b(?:equ|geq|gtr|leq|lss|neq)\b/i}},{pattern:/((?:^|[&()])[ \t]*)else\b/im,lookbehind:!0,inside:{keyword:/^else\b/i}},{pattern:/((?:^|[&(])[ \t]*)set(?: \/[a-z](?:[ :](?:"[^"]*"|[^\s"/]\S*))?)* (?:[^^&)\r\n]|\^(?:\r\n|[\s\S]))*/im,lookbehind:!0,inside:{keyword:/^set\b/i,string:i,parameter:a,variable:[r,/\w+(?=(?:[*\/%+\-&^|]|<<|>>)?=)/],number:l,operator:/[*\/%+\-&^|]=?|<<=?|>>=?|[!~_=]/,punctuation:/[()',]/}},{pattern:/((?:^|[&(])[ \t]*@?)\w+\b(?:"(?:[\\"]"|[^"])*"(?!")|[^"^&)\r\n]|\^(?:\r\n|[\s\S]))*/m,lookbehind:!0,inside:{keyword:/^\w+\b/,string:i,parameter:a,label:{pattern:/(^\s*):\S+/m,lookbehind:!0,alias:"property"},variable:r,number:l,operator:/\^/}}],operator:/[&@]/,punctuation:/[()']/}})(t)}return $b}var qb,YD;function vpe(){if(YD)return qb;YD=1,qb=e,e.displayName="bbcode",e.aliases=["shortcode"];function e(t){t.languages.bbcode={tag:{pattern:/\[\/?[^\s=\]]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))?(?:\s+[^\s=\]]+\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+))*\s*\]/,inside:{tag:{pattern:/^\[\/?[^\s=\]]+/,inside:{punctuation:/^\[\/?/}},"attr-value":{pattern:/=\s*(?:"[^"]*"|'[^']*'|[^\s'"\]=]+)/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}]}},punctuation:/\]/,"attr-name":/[^\s=\]]+/}}},t.languages.shortcode=t.languages.bbcode}return qb}var Vb,KD;function Spe(){if(KD)return Vb;KD=1,Vb=e,e.displayName="bicep",e.aliases=[];function e(t){t.languages.bicep={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],property:[{pattern:/([\r\n][ \t]*)[a-z_]\w*(?=[ \t]*:)/i,lookbehind:!0},{pattern:/([\r\n][ \t]*)'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'(?=[ \t]*:)/,lookbehind:!0,greedy:!0}],string:[{pattern:/'''[^'][\s\S]*?'''/,greedy:!0},{pattern:/(^|[^\\'])'(?:\\.|\$(?!\{)|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0}],"interpolated-string":{pattern:/(^|[^\\'])'(?:\\.|\$(?:(?!\{)|\{[^{}\r\n]*\})|[^'\\\r\n$])*'/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}\r\n]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0},punctuation:/^\$\{|\}$/}},string:/[\s\S]+/}},datatype:{pattern:/(\b(?:output|param)\b[ \t]+\w+[ \t]+)\w+\b/,lookbehind:!0,alias:"class-name"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:existing|for|if|in|module|null|output|param|resource|targetScope|var)\b/,decorator:/@\w+\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,operator:/--|\+\+|\*\*=?|=>|&&=?|\|\|=?|[!=]==|<<=?|>>>?=?|[-+*/%&|^!=<>]=?|\.{3}|\?\?=?|\?\.?|[~:]/,punctuation:/[{}[\];(),.:]/},t.languages.bicep["interpolated-string"].inside.interpolation.inside.expression.inside=t.languages.bicep}return Vb}var Wb,XD;function Epe(){if(XD)return Wb;XD=1,Wb=e,e.displayName="birb",e.aliases=[];function e(t){t.languages.birb=t.languages.extend("clike",{string:{pattern:/r?("|')(?:\\.|(?!\1)[^\\])*\1/,greedy:!0},"class-name":[/\b[A-Z](?:[\d_]*[a-zA-Z]\w*)?\b/,/\b(?:[A-Z]\w*|(?!(?:var|void)\b)[a-z]\w*)(?=\s+\w+\s*[;,=()])/],keyword:/\b(?:assert|break|case|class|const|default|else|enum|final|follows|for|grab|if|nest|new|next|noSeeb|return|static|switch|throw|var|void|while)\b/,operator:/\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?|:/,variable:/\b[a-z_]\w*\b/}),t.languages.insertBefore("birb","function",{metadata:{pattern:/<\w+>/,greedy:!0,alias:"symbol"}})}return Wb}var Yb,ZD;function wpe(){if(ZD)return Yb;ZD=1;var e=fi();Yb=t,t.displayName="bison",t.aliases=[];function t(n){n.register(e),n.languages.bison=n.languages.extend("c",{}),n.languages.insertBefore("bison","comment",{bison:{pattern:/^(?:[^%]|%(?!%))*%%[\s\S]*?%%/,inside:{c:{pattern:/%\{[\s\S]*?%\}|\{(?:\{[^}]*\}|[^{}])*\}/,inside:{delimiter:{pattern:/^%?\{|%?\}$/,alias:"punctuation"},"bison-variable":{pattern:/[$@](?:<[^\s>]+>)?[\w$]+/,alias:"variable",inside:{punctuation:/<|>/}},rest:n.languages.c}},comment:n.languages.c.comment,string:n.languages.c.string,property:/\S+(?=:)/,keyword:/%\w+/,number:{pattern:/(^|[^@])\b(?:0x[\da-f]+|\d+)/i,lookbehind:!0},punctuation:/%[%?]|[|:;\[\]<>]/}}})}return Yb}var Kb,QD;function xpe(){if(QD)return Kb;QD=1,Kb=e,e.displayName="bnf",e.aliases=["rbnf"];function e(t){t.languages.bnf={string:{pattern:/"[^\r\n"]*"|'[^\r\n']*'/},definition:{pattern:/<[^<>\r\n\t]+>(?=\s*::=)/,alias:["rule","keyword"],inside:{punctuation:/^<|>$/}},rule:{pattern:/<[^<>\r\n\t]+>/,inside:{punctuation:/^<|>$/}},operator:/::=|[|()[\]{}*+?]|\.{3}/},t.languages.rbnf=t.languages.bnf}return Kb}var Xb,JD;function kpe(){if(JD)return Xb;JD=1,Xb=e,e.displayName="brainfuck",e.aliases=[];function e(t){t.languages.brainfuck={pointer:{pattern:/<|>/,alias:"keyword"},increment:{pattern:/\+/,alias:"inserted"},decrement:{pattern:/-/,alias:"deleted"},branching:{pattern:/\[|\]/,alias:"important"},operator:/[.,]/,comment:/\S+/}}return Xb}var Zb,eI;function Ape(){if(eI)return Zb;eI=1,Zb=e,e.displayName="brightscript",e.aliases=[];function e(t){t.languages.brightscript={comment:/(?:\brem|').*/i,"directive-statement":{pattern:/(^[\t ]*)#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if).*/im,lookbehind:!0,alias:"property",inside:{"error-message":{pattern:/(^#error).+/,lookbehind:!0},directive:{pattern:/^#(?:const|else(?:[\t ]+if)?|end[\t ]+if|error|if)/,alias:"keyword"},expression:{pattern:/[\s\S]+/,inside:null}}},property:{pattern:/([\r\n{,][\t ]*)(?:(?!\d)\w+|"(?:[^"\r\n]|"")*"(?!"))(?=[ \t]*:)/,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},"class-name":{pattern:/(\bAs[\t ]+)\w+/i,lookbehind:!0},keyword:/\b(?:As|Dim|Each|Else|Elseif|End|Exit|For|Function|Goto|If|In|Print|Return|Step|Stop|Sub|Then|To|While)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?!\d)\w+(?=[\t ]*\()/,number:/(?:\b\d+(?:\.\d+)?(?:[ed][+-]\d+)?|&h[a-f\d]+)\b[%&!#]?/i,operator:/--|\+\+|>>=?|<<=?|<>|[-+*/\\<>]=?|[:^=?]|\b(?:and|mod|not|or)\b/i,punctuation:/[.,;()[\]{}]/,constant:/\b(?:LINE_NUM)\b/i},t.languages.brightscript["directive-statement"].inside.expression.inside=t.languages.brightscript}return Zb}var Qb,tI;function Tpe(){if(tI)return Qb;tI=1,Qb=e,e.displayName="bro",e.aliases=[];function e(t){t.languages.bro={comment:{pattern:/(^|[^\\$])#.*/,lookbehind:!0,inside:{italic:/\b(?:FIXME|TODO|XXX)\b/}},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},boolean:/\b[TF]\b/,function:{pattern:/(\b(?:event|function|hook)[ \t]+)\w+(?:::\w+)?/,lookbehind:!0},builtin:/(?:@(?:load(?:-(?:plugin|sigs))?|unload|prefixes|ifn?def|else|(?:end)?if|DIR|FILENAME))|(?:&?(?:add_func|create_expire|default|delete_func|encrypt|error_handler|expire_func|group|log|mergeable|optional|persistent|priority|raw_output|read_expire|redef|rotate_interval|rotate_size|synchronized|type_column|write_expire))/,constant:{pattern:/(\bconst[ \t]+)\w+/i,lookbehind:!0},keyword:/\b(?:add|addr|alarm|any|bool|break|const|continue|count|delete|double|else|enum|event|export|file|for|function|global|hook|if|in|int|interval|local|module|next|of|opaque|pattern|port|print|record|return|schedule|set|string|subnet|table|time|timeout|using|vector|when)\b/,operator:/--?|\+\+?|!=?=?|<=?|>=?|==?=?|&&|\|\|?|\?|\*|\/|~|\^|%/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,punctuation:/[{}[\];(),.:]/}}return Qb}var Jb,nI;function _pe(){if(nI)return Jb;nI=1,Jb=e,e.displayName="bsl",e.aliases=[];function e(t){t.languages.bsl={comment:/\/\/.*/,string:[{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},{pattern:/'(?:[^'\r\n\\]|\\.)*'/}],keyword:[{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:пока|для|новый|прервать|попытка|исключение|вызватьисключение|иначе|конецпопытки|неопределено|функция|перем|возврат|конецфункции|если|иначеесли|процедура|конецпроцедуры|тогда|знач|экспорт|конецесли|из|каждого|истина|ложь|по|цикл|конеццикла|выполнить)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:break|do|each|else|elseif|enddo|endfunction|endif|endprocedure|endtry|except|execute|export|false|for|function|if|in|new|null|procedure|raise|return|then|to|true|try|undefined|val|var|while)\b/i}],number:{pattern:/(^(?=\d)|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:\d+(?:\.\d*)?|\.\d+)(?:E[+-]?\d+)?/i,lookbehind:!0},operator:[/[<>+\-*/]=?|[%=]/,{pattern:/(^|[^\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])(?:и|или|не)(?![\w\u0400-\u0484\u0487-\u052f\u1d2b\u1d78\u2de0-\u2dff\ua640-\ua69f\ufe2e\ufe2f])/i,lookbehind:!0},{pattern:/\b(?:and|not|or)\b/i}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/,directive:[{pattern:/^([ \t]*)&.*/m,lookbehind:!0,greedy:!0,alias:"important"},{pattern:/^([ \t]*)#.*/gm,lookbehind:!0,greedy:!0,alias:"important"}]},t.languages.oscript=t.languages.bsl}return Jb}var ey,rI;function Rpe(){if(rI)return ey;rI=1,ey=e,e.displayName="cfscript",e.aliases=[];function e(t){t.languages.cfscript=t.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,inside:{annotation:{pattern:/(?:^|[^.])@[\w\.]+/,alias:"punctuation"}}},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],keyword:/\b(?:abstract|break|catch|component|continue|default|do|else|extends|final|finally|for|function|if|in|include|package|private|property|public|remote|required|rethrow|return|static|switch|throw|try|var|while|xml)\b(?!\s*=)/,operator:[/\+\+|--|&&|\|\||::|=>|[!=]==|<=?|>=?|[-+*/%&|^!=<>]=?|\?(?:\.|:)?|[?:]/,/\b(?:and|contains|eq|equal|eqv|gt|gte|imp|is|lt|lte|mod|not|or|xor)\b/],scope:{pattern:/\b(?:application|arguments|cgi|client|cookie|local|session|super|this|variables)\b/,alias:"global"},type:{pattern:/\b(?:any|array|binary|boolean|date|guid|numeric|query|string|struct|uuid|void|xml)\b/,alias:"builtin"}}),t.languages.insertBefore("cfscript","keyword",{"function-variable":{pattern:/[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*[=:]\s*(?:\bfunction\b|(?:\((?:[^()]|\([^()]*\))*\)|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/,alias:"function"}}),delete t.languages.cfscript["class-name"],t.languages.cfc=t.languages.cfscript}return ey}var ty,aI;function Cpe(){if(aI)return ty;aI=1;var e=uA();ty=t,t.displayName="chaiscript",t.aliases=[];function t(n){n.register(e),n.languages.chaiscript=n.languages.extend("clike",{string:{pattern:/(^|[^\\])'(?:[^'\\]|\\[\s\S])*'/,lookbehind:!0,greedy:!0},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},{pattern:/(\b(?:attr|def)\s+)\w+(?=\s*::)/,lookbehind:!0}],keyword:/\b(?:attr|auto|break|case|catch|class|continue|def|default|else|finally|for|fun|global|if|return|switch|this|try|var|while)\b/,number:[n.languages.cpp.number,/\b(?:Infinity|NaN)\b/],operator:/>>=?|<<=?|\|\||&&|:[:=]?|--|\+\+|[=!<>+\-*/%|&^]=?|[?~]|`[^`\r\n]{1,4}`/}),n.languages.insertBefore("chaiscript","operator",{"parameter-type":{pattern:/([,(]\s*)\w+(?=\s+\w)/,lookbehind:!0,alias:"class-name"}}),n.languages.insertBefore("chaiscript","string",{"string-interpolation":{pattern:/(^|[^\\])"(?:[^"$\\]|\\[\s\S]|\$(?!\{)|\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\}/,lookbehind:!0,inside:{"interpolation-expression":{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:n.languages.chaiscript},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"}}},string:/[\s\S]+/}}})}return ty}var ny,oI;function Npe(){if(oI)return ny;oI=1,ny=e,e.displayName="cil",e.aliases=[];function e(t){t.languages.cil={comment:/\/\/.*/,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},directive:{pattern:/(^|\W)\.[a-z]+(?=\s)/,lookbehind:!0,alias:"class-name"},variable:/\[[\w\.]+\]/,keyword:/\b(?:abstract|ansi|assembly|auto|autochar|beforefieldinit|bool|bstr|byvalstr|catch|char|cil|class|currency|date|decimal|default|enum|error|explicit|extends|extern|famandassem|family|famorassem|final(?:ly)?|float32|float64|hidebysig|u?int(?:8|16|32|64)?|iant|idispatch|implements|import|initonly|instance|interface|iunknown|literal|lpstr|lpstruct|lptstr|lpwstr|managed|method|native(?:Type)?|nested|newslot|object(?:ref)?|pinvokeimpl|private|privatescope|public|reqsecobj|rtspecialname|runtime|sealed|sequential|serializable|specialname|static|string|struct|syschar|tbstr|unicode|unmanagedexp|unsigned|value(?:type)?|variant|virtual|void)\b/,function:/\b(?:(?:constrained|no|readonly|tail|unaligned|volatile)\.)?(?:conv\.(?:[iu][1248]?|ovf\.[iu][1248]?(?:\.un)?|r\.un|r4|r8)|ldc\.(?:i4(?:\.\d+|\.[mM]1|\.s)?|i8|r4|r8)|ldelem(?:\.[iu][1248]?|\.r[48]|\.ref|a)?|ldind\.(?:[iu][1248]?|r[48]|ref)|stelem\.?(?:i[1248]?|r[48]|ref)?|stind\.(?:i[1248]?|r[48]|ref)?|end(?:fault|filter|finally)|ldarg(?:\.[0-3s]|a(?:\.s)?)?|ldloc(?:\.\d+|\.s)?|sub(?:\.ovf(?:\.un)?)?|mul(?:\.ovf(?:\.un)?)?|add(?:\.ovf(?:\.un)?)?|stloc(?:\.[0-3s])?|refany(?:type|val)|blt(?:\.un)?(?:\.s)?|ble(?:\.un)?(?:\.s)?|bgt(?:\.un)?(?:\.s)?|bge(?:\.un)?(?:\.s)?|unbox(?:\.any)?|init(?:blk|obj)|call(?:i|virt)?|brfalse(?:\.s)?|bne\.un(?:\.s)?|ldloca(?:\.s)?|brzero(?:\.s)?|brtrue(?:\.s)?|brnull(?:\.s)?|brinst(?:\.s)?|starg(?:\.s)?|leave(?:\.s)?|shr(?:\.un)?|rem(?:\.un)?|div(?:\.un)?|clt(?:\.un)?|alignment|castclass|ldvirtftn|beq(?:\.s)?|ckfinite|ldsflda|ldtoken|localloc|mkrefany|rethrow|cgt\.un|arglist|switch|stsfld|sizeof|newobj|newarr|ldsfld|ldnull|ldflda|isinst|throw|stobj|stfld|ldstr|ldobj|ldlen|ldftn|ldfld|cpobj|cpblk|break|br\.s|xor|shl|ret|pop|not|nop|neg|jmp|dup|cgt|ceq|box|and|or|br)\b/,boolean:/\b(?:false|true)\b/,number:/\b-?(?:0x[0-9a-f]+|\d+)(?:\.[0-9a-f]+)?\b/i,punctuation:/[{}[\];(),:=]|IL_[0-9A-Za-z]+/}}return ny}var ry,iI;function Ope(){if(iI)return ry;iI=1,ry=e,e.displayName="clojure",e.aliases=[];function e(t){t.languages.clojure={comment:{pattern:/;.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},char:/\\\w+/,symbol:{pattern:/(^|[\s()\[\]{},])::?[\w*+!?'<>=/.-]+/,lookbehind:!0},keyword:{pattern:/(\()(?:-|->|->>|\.|\.\.|\*|\/|\+|<|<=|=|==|>|>=|accessor|agent|agent-errors|aget|alength|all-ns|alter|and|append-child|apply|array-map|aset|aset-boolean|aset-byte|aset-char|aset-double|aset-float|aset-int|aset-long|aset-short|assert|assoc|await|await-for|bean|binding|bit-and|bit-not|bit-or|bit-shift-left|bit-shift-right|bit-xor|boolean|branch\?|butlast|byte|cast|char|children|class|clear-agent-errors|comment|commute|comp|comparator|complement|concat|cond|conj|cons|constantly|construct-proxy|contains\?|count|create-ns|create-struct|cycle|dec|declare|def|def-|definline|definterface|defmacro|defmethod|defmulti|defn|defn-|defonce|defproject|defprotocol|defrecord|defstruct|deftype|deref|difference|disj|dissoc|distinct|do|doall|doc|dorun|doseq|dosync|dotimes|doto|double|down|drop|drop-while|edit|end\?|ensure|eval|every\?|false\?|ffirst|file-seq|filter|find|find-doc|find-ns|find-var|first|float|flush|fn|fnseq|for|frest|gensym|get|get-proxy-class|hash-map|hash-set|identical\?|identity|if|if-let|if-not|import|in-ns|inc|index|insert-child|insert-left|insert-right|inspect-table|inspect-tree|instance\?|int|interleave|intersection|into|into-array|iterate|join|key|keys|keyword|keyword\?|last|lazy-cat|lazy-cons|left|lefts|let|line-seq|list|list\*|load|load-file|locking|long|loop|macroexpand|macroexpand-1|make-array|make-node|map|map-invert|map\?|mapcat|max|max-key|memfn|merge|merge-with|meta|min|min-key|monitor-enter|name|namespace|neg\?|new|newline|next|nil\?|node|not|not-any\?|not-every\?|not=|ns|ns-imports|ns-interns|ns-map|ns-name|ns-publics|ns-refers|ns-resolve|ns-unmap|nth|nthrest|or|parse|partial|path|peek|pop|pos\?|pr|pr-str|print|print-str|println|println-str|prn|prn-str|project|proxy|proxy-mappings|quot|quote|rand|rand-int|range|re-find|re-groups|re-matcher|re-matches|re-pattern|re-seq|read|read-line|recur|reduce|ref|ref-set|refer|rem|remove|remove-method|remove-ns|rename|rename-keys|repeat|replace|replicate|resolve|rest|resultset-seq|reverse|rfirst|right|rights|root|rrest|rseq|second|select|select-keys|send|send-off|seq|seq-zip|seq\?|set|set!|short|slurp|some|sort|sort-by|sorted-map|sorted-map-by|sorted-set|special-symbol\?|split-at|split-with|str|string\?|struct|struct-map|subs|subvec|symbol|symbol\?|sync|take|take-nth|take-while|test|throw|time|to-array|to-array-2d|tree-seq|true\?|try|union|up|update-proxy|val|vals|var|var-get|var-set|var\?|vector|vector-zip|vector\?|when|when-first|when-let|when-not|with-local-vars|with-meta|with-open|with-out-str|xml-seq|xml-zip|zero\?|zipmap|zipper)(?=[\s)]|$)/,lookbehind:!0},boolean:/\b(?:false|nil|true)\b/,number:{pattern:/(^|[^\w$@])(?:\d+(?:[/.]\d+)?(?:e[+-]?\d+)?|0x[a-f0-9]+|[1-9]\d?r[a-z0-9]+)[lmn]?(?![\w$@])/i,lookbehind:!0},function:{pattern:/((?:^|[^'])\()[\w*+!?'<>=/.-]+(?=[\s)]|$)/,lookbehind:!0},operator:/[#@^`~]/,punctuation:/[{}\[\](),]/}}return ry}var ay,lI;function Dpe(){if(lI)return ay;lI=1,ay=e,e.displayName="cmake",e.aliases=[];function e(t){t.languages.cmake={comment:/#.*/,string:{pattern:/"(?:[^\\"]|\\.)*"/,greedy:!0,inside:{interpolation:{pattern:/\$\{(?:[^{}$]|\$\{[^{}$]*\})*\}/,inside:{punctuation:/\$\{|\}/,variable:/\w+/}}}},variable:/\b(?:CMAKE_\w+|\w+_(?:(?:BINARY|SOURCE)_DIR|DESCRIPTION|HOMEPAGE_URL|ROOT|VERSION(?:_MAJOR|_MINOR|_PATCH|_TWEAK)?)|(?:ANDROID|APPLE|BORLAND|BUILD_SHARED_LIBS|CACHE|CPACK_(?:ABSOLUTE_DESTINATION_FILES|COMPONENT_INCLUDE_TOPLEVEL_DIRECTORY|ERROR_ON_ABSOLUTE_INSTALL_DESTINATION|INCLUDE_TOPLEVEL_DIRECTORY|INSTALL_DEFAULT_DIRECTORY_PERMISSIONS|INSTALL_SCRIPT|PACKAGING_INSTALL_PREFIX|SET_DESTDIR|WARN_ON_ABSOLUTE_INSTALL_DESTINATION)|CTEST_(?:BINARY_DIRECTORY|BUILD_COMMAND|BUILD_NAME|BZR_COMMAND|BZR_UPDATE_OPTIONS|CHANGE_ID|CHECKOUT_COMMAND|CONFIGURATION_TYPE|CONFIGURE_COMMAND|COVERAGE_COMMAND|COVERAGE_EXTRA_FLAGS|CURL_OPTIONS|CUSTOM_(?:COVERAGE_EXCLUDE|ERROR_EXCEPTION|ERROR_MATCH|ERROR_POST_CONTEXT|ERROR_PRE_CONTEXT|MAXIMUM_FAILED_TEST_OUTPUT_SIZE|MAXIMUM_NUMBER_OF_(?:ERRORS|WARNINGS)|MAXIMUM_PASSED_TEST_OUTPUT_SIZE|MEMCHECK_IGNORE|POST_MEMCHECK|POST_TEST|PRE_MEMCHECK|PRE_TEST|TESTS_IGNORE|WARNING_EXCEPTION|WARNING_MATCH)|CVS_CHECKOUT|CVS_COMMAND|CVS_UPDATE_OPTIONS|DROP_LOCATION|DROP_METHOD|DROP_SITE|DROP_SITE_CDASH|DROP_SITE_PASSWORD|DROP_SITE_USER|EXTRA_COVERAGE_GLOB|GIT_COMMAND|GIT_INIT_SUBMODULES|GIT_UPDATE_CUSTOM|GIT_UPDATE_OPTIONS|HG_COMMAND|HG_UPDATE_OPTIONS|LABELS_FOR_SUBPROJECTS|MEMORYCHECK_(?:COMMAND|COMMAND_OPTIONS|SANITIZER_OPTIONS|SUPPRESSIONS_FILE|TYPE)|NIGHTLY_START_TIME|P4_CLIENT|P4_COMMAND|P4_OPTIONS|P4_UPDATE_OPTIONS|RUN_CURRENT_SCRIPT|SCP_COMMAND|SITE|SOURCE_DIRECTORY|SUBMIT_URL|SVN_COMMAND|SVN_OPTIONS|SVN_UPDATE_OPTIONS|TEST_LOAD|TEST_TIMEOUT|TRIGGER_SITE|UPDATE_COMMAND|UPDATE_OPTIONS|UPDATE_VERSION_ONLY|USE_LAUNCHERS)|CYGWIN|ENV|EXECUTABLE_OUTPUT_PATH|GHS-MULTI|IOS|LIBRARY_OUTPUT_PATH|MINGW|MSVC(?:10|11|12|14|60|70|71|80|90|_IDE|_TOOLSET_VERSION|_VERSION)?|MSYS|PROJECT_(?:BINARY_DIR|DESCRIPTION|HOMEPAGE_URL|NAME|SOURCE_DIR|VERSION|VERSION_(?:MAJOR|MINOR|PATCH|TWEAK))|UNIX|WIN32|WINCE|WINDOWS_PHONE|WINDOWS_STORE|XCODE|XCODE_VERSION))\b/,property:/\b(?:cxx_\w+|(?:ARCHIVE_OUTPUT_(?:DIRECTORY|NAME)|COMPILE_DEFINITIONS|COMPILE_PDB_NAME|COMPILE_PDB_OUTPUT_DIRECTORY|EXCLUDE_FROM_DEFAULT_BUILD|IMPORTED_(?:IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_LANGUAGES|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|NO_SONAME|OBJECTS|SONAME)|INTERPROCEDURAL_OPTIMIZATION|LIBRARY_OUTPUT_DIRECTORY|LIBRARY_OUTPUT_NAME|LINK_FLAGS|LINK_INTERFACE_LIBRARIES|LINK_INTERFACE_MULTIPLICITY|LOCATION|MAP_IMPORTED_CONFIG|OSX_ARCHITECTURES|OUTPUT_NAME|PDB_NAME|PDB_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_DIRECTORY|RUNTIME_OUTPUT_NAME|STATIC_LIBRARY_FLAGS|VS_CSHARP|VS_DOTNET_REFERENCEPROP|VS_DOTNET_REFERENCE|VS_GLOBAL_SECTION_POST|VS_GLOBAL_SECTION_PRE|VS_GLOBAL|XCODE_ATTRIBUTE)_\w+|\w+_(?:CLANG_TIDY|COMPILER_LAUNCHER|CPPCHECK|CPPLINT|INCLUDE_WHAT_YOU_USE|OUTPUT_NAME|POSTFIX|VISIBILITY_PRESET)|ABSTRACT|ADDITIONAL_MAKE_CLEAN_FILES|ADVANCED|ALIASED_TARGET|ALLOW_DUPLICATE_CUSTOM_TARGETS|ANDROID_(?:ANT_ADDITIONAL_OPTIONS|API|API_MIN|ARCH|ASSETS_DIRECTORIES|GUI|JAR_DEPENDENCIES|NATIVE_LIB_DEPENDENCIES|NATIVE_LIB_DIRECTORIES|PROCESS_MAX|PROGUARD|PROGUARD_CONFIG_PATH|SECURE_PROPS_PATH|SKIP_ANT_STEP|STL_TYPE)|ARCHIVE_OUTPUT_DIRECTORY|ATTACHED_FILES|ATTACHED_FILES_ON_FAIL|AUTOGEN_(?:BUILD_DIR|ORIGIN_DEPENDS|PARALLEL|SOURCE_GROUP|TARGETS_FOLDER|TARGET_DEPENDS)|AUTOMOC|AUTOMOC_(?:COMPILER_PREDEFINES|DEPEND_FILTERS|EXECUTABLE|MACRO_NAMES|MOC_OPTIONS|SOURCE_GROUP|TARGETS_FOLDER)|AUTORCC|AUTORCC_EXECUTABLE|AUTORCC_OPTIONS|AUTORCC_SOURCE_GROUP|AUTOUIC|AUTOUIC_EXECUTABLE|AUTOUIC_OPTIONS|AUTOUIC_SEARCH_PATHS|BINARY_DIR|BUILDSYSTEM_TARGETS|BUILD_RPATH|BUILD_RPATH_USE_ORIGIN|BUILD_WITH_INSTALL_NAME_DIR|BUILD_WITH_INSTALL_RPATH|BUNDLE|BUNDLE_EXTENSION|CACHE_VARIABLES|CLEAN_NO_CUSTOM|COMMON_LANGUAGE_RUNTIME|COMPATIBLE_INTERFACE_(?:BOOL|NUMBER_MAX|NUMBER_MIN|STRING)|COMPILE_(?:DEFINITIONS|FEATURES|FLAGS|OPTIONS|PDB_NAME|PDB_OUTPUT_DIRECTORY)|COST|CPACK_DESKTOP_SHORTCUTS|CPACK_NEVER_OVERWRITE|CPACK_PERMANENT|CPACK_STARTUP_SHORTCUTS|CPACK_START_MENU_SHORTCUTS|CPACK_WIX_ACL|CROSSCOMPILING_EMULATOR|CUDA_EXTENSIONS|CUDA_PTX_COMPILATION|CUDA_RESOLVE_DEVICE_SYMBOLS|CUDA_SEPARABLE_COMPILATION|CUDA_STANDARD|CUDA_STANDARD_REQUIRED|CXX_EXTENSIONS|CXX_STANDARD|CXX_STANDARD_REQUIRED|C_EXTENSIONS|C_STANDARD|C_STANDARD_REQUIRED|DEBUG_CONFIGURATIONS|DEFINE_SYMBOL|DEFINITIONS|DEPENDS|DEPLOYMENT_ADDITIONAL_FILES|DEPLOYMENT_REMOTE_DIRECTORY|DISABLED|DISABLED_FEATURES|ECLIPSE_EXTRA_CPROJECT_CONTENTS|ECLIPSE_EXTRA_NATURES|ENABLED_FEATURES|ENABLED_LANGUAGES|ENABLE_EXPORTS|ENVIRONMENT|EXCLUDE_FROM_ALL|EXCLUDE_FROM_DEFAULT_BUILD|EXPORT_NAME|EXPORT_PROPERTIES|EXTERNAL_OBJECT|EchoString|FAIL_REGULAR_EXPRESSION|FIND_LIBRARY_USE_LIB32_PATHS|FIND_LIBRARY_USE_LIB64_PATHS|FIND_LIBRARY_USE_LIBX32_PATHS|FIND_LIBRARY_USE_OPENBSD_VERSIONING|FIXTURES_CLEANUP|FIXTURES_REQUIRED|FIXTURES_SETUP|FOLDER|FRAMEWORK|Fortran_FORMAT|Fortran_MODULE_DIRECTORY|GENERATED|GENERATOR_FILE_NAME|GENERATOR_IS_MULTI_CONFIG|GHS_INTEGRITY_APP|GHS_NO_SOURCE_GROUP_FILE|GLOBAL_DEPENDS_DEBUG_MODE|GLOBAL_DEPENDS_NO_CYCLES|GNUtoMS|HAS_CXX|HEADER_FILE_ONLY|HELPSTRING|IMPLICIT_DEPENDS_INCLUDE_TRANSFORM|IMPORTED|IMPORTED_(?:COMMON_LANGUAGE_RUNTIME|CONFIGURATIONS|GLOBAL|IMPLIB|LIBNAME|LINK_DEPENDENT_LIBRARIES|LINK_INTERFACE_(?:LANGUAGES|LIBRARIES|MULTIPLICITY)|LOCATION|NO_SONAME|OBJECTS|SONAME)|IMPORT_PREFIX|IMPORT_SUFFIX|INCLUDE_DIRECTORIES|INCLUDE_REGULAR_EXPRESSION|INSTALL_NAME_DIR|INSTALL_RPATH|INSTALL_RPATH_USE_LINK_PATH|INTERFACE_(?:AUTOUIC_OPTIONS|COMPILE_DEFINITIONS|COMPILE_FEATURES|COMPILE_OPTIONS|INCLUDE_DIRECTORIES|LINK_DEPENDS|LINK_DIRECTORIES|LINK_LIBRARIES|LINK_OPTIONS|POSITION_INDEPENDENT_CODE|SOURCES|SYSTEM_INCLUDE_DIRECTORIES)|INTERPROCEDURAL_OPTIMIZATION|IN_TRY_COMPILE|IOS_INSTALL_COMBINED|JOB_POOLS|JOB_POOL_COMPILE|JOB_POOL_LINK|KEEP_EXTENSION|LABELS|LANGUAGE|LIBRARY_OUTPUT_DIRECTORY|LINKER_LANGUAGE|LINK_(?:DEPENDS|DEPENDS_NO_SHARED|DIRECTORIES|FLAGS|INTERFACE_LIBRARIES|INTERFACE_MULTIPLICITY|LIBRARIES|OPTIONS|SEARCH_END_STATIC|SEARCH_START_STATIC|WHAT_YOU_USE)|LISTFILE_STACK|LOCATION|MACOSX_BUNDLE|MACOSX_BUNDLE_INFO_PLIST|MACOSX_FRAMEWORK_INFO_PLIST|MACOSX_PACKAGE_LOCATION|MACOSX_RPATH|MACROS|MANUALLY_ADDED_DEPENDENCIES|MEASUREMENT|MODIFIED|NAME|NO_SONAME|NO_SYSTEM_FROM_IMPORTED|OBJECT_DEPENDS|OBJECT_OUTPUTS|OSX_ARCHITECTURES|OUTPUT_NAME|PACKAGES_FOUND|PACKAGES_NOT_FOUND|PARENT_DIRECTORY|PASS_REGULAR_EXPRESSION|PDB_NAME|PDB_OUTPUT_DIRECTORY|POSITION_INDEPENDENT_CODE|POST_INSTALL_SCRIPT|PREDEFINED_TARGETS_FOLDER|PREFIX|PRE_INSTALL_SCRIPT|PRIVATE_HEADER|PROCESSORS|PROCESSOR_AFFINITY|PROJECT_LABEL|PUBLIC_HEADER|REPORT_UNDEFINED_PROPERTIES|REQUIRED_FILES|RESOURCE|RESOURCE_LOCK|RULE_LAUNCH_COMPILE|RULE_LAUNCH_CUSTOM|RULE_LAUNCH_LINK|RULE_MESSAGES|RUNTIME_OUTPUT_DIRECTORY|RUN_SERIAL|SKIP_AUTOGEN|SKIP_AUTOMOC|SKIP_AUTORCC|SKIP_AUTOUIC|SKIP_BUILD_RPATH|SKIP_RETURN_CODE|SOURCES|SOURCE_DIR|SOVERSION|STATIC_LIBRARY_FLAGS|STATIC_LIBRARY_OPTIONS|STRINGS|SUBDIRECTORIES|SUFFIX|SYMBOLIC|TARGET_ARCHIVES_MAY_BE_SHARED_LIBS|TARGET_MESSAGES|TARGET_SUPPORTS_SHARED_LIBS|TESTS|TEST_INCLUDE_FILE|TEST_INCLUDE_FILES|TIMEOUT|TIMEOUT_AFTER_MATCH|TYPE|USE_FOLDERS|VALUE|VARIABLES|VERSION|VISIBILITY_INLINES_HIDDEN|VS_(?:CONFIGURATION_TYPE|COPY_TO_OUT_DIR|DEBUGGER_(?:COMMAND|COMMAND_ARGUMENTS|ENVIRONMENT|WORKING_DIRECTORY)|DEPLOYMENT_CONTENT|DEPLOYMENT_LOCATION|DOTNET_REFERENCES|DOTNET_REFERENCES_COPY_LOCAL|GLOBAL_KEYWORD|GLOBAL_PROJECT_TYPES|GLOBAL_ROOTNAMESPACE|INCLUDE_IN_VSIX|IOT_STARTUP_TASK|KEYWORD|RESOURCE_GENERATOR|SCC_AUXPATH|SCC_LOCALPATH|SCC_PROJECTNAME|SCC_PROVIDER|SDK_REFERENCES|SHADER_(?:DISABLE_OPTIMIZATIONS|ENABLE_DEBUG|ENTRYPOINT|FLAGS|MODEL|OBJECT_FILE_NAME|OUTPUT_HEADER_FILE|TYPE|VARIABLE_NAME)|STARTUP_PROJECT|TOOL_OVERRIDE|USER_PROPS|WINRT_COMPONENT|WINRT_EXTENSIONS|WINRT_REFERENCES|XAML_TYPE)|WILL_FAIL|WIN32_EXECUTABLE|WINDOWS_EXPORT_ALL_SYMBOLS|WORKING_DIRECTORY|WRAP_EXCLUDE|XCODE_(?:EMIT_EFFECTIVE_PLATFORM_NAME|EXPLICIT_FILE_TYPE|FILE_ATTRIBUTES|LAST_KNOWN_FILE_TYPE|PRODUCT_TYPE|SCHEME_(?:ADDRESS_SANITIZER|ADDRESS_SANITIZER_USE_AFTER_RETURN|ARGUMENTS|DISABLE_MAIN_THREAD_CHECKER|DYNAMIC_LIBRARY_LOADS|DYNAMIC_LINKER_API_USAGE|ENVIRONMENT|EXECUTABLE|GUARD_MALLOC|MAIN_THREAD_CHECKER_STOP|MALLOC_GUARD_EDGES|MALLOC_SCRIBBLE|MALLOC_STACK|THREAD_SANITIZER(?:_STOP)?|UNDEFINED_BEHAVIOUR_SANITIZER(?:_STOP)?|ZOMBIE_OBJECTS))|XCTEST)\b/,keyword:/\b(?:add_compile_definitions|add_compile_options|add_custom_command|add_custom_target|add_definitions|add_dependencies|add_executable|add_library|add_link_options|add_subdirectory|add_test|aux_source_directory|break|build_command|build_name|cmake_host_system_information|cmake_minimum_required|cmake_parse_arguments|cmake_policy|configure_file|continue|create_test_sourcelist|ctest_build|ctest_configure|ctest_coverage|ctest_empty_binary_directory|ctest_memcheck|ctest_read_custom_files|ctest_run_script|ctest_sleep|ctest_start|ctest_submit|ctest_test|ctest_update|ctest_upload|define_property|else|elseif|enable_language|enable_testing|endforeach|endfunction|endif|endmacro|endwhile|exec_program|execute_process|export|export_library_dependencies|file|find_file|find_library|find_package|find_path|find_program|fltk_wrap_ui|foreach|function|get_cmake_property|get_directory_property|get_filename_component|get_property|get_source_file_property|get_target_property|get_test_property|if|include|include_directories|include_external_msproject|include_guard|include_regular_expression|install|install_files|install_programs|install_targets|link_directories|link_libraries|list|load_cache|load_command|macro|make_directory|mark_as_advanced|math|message|option|output_required_files|project|qt_wrap_cpp|qt_wrap_ui|remove|remove_definitions|return|separate_arguments|set|set_directory_properties|set_property|set_source_files_properties|set_target_properties|set_tests_properties|site_name|source_group|string|subdir_depends|subdirs|target_compile_definitions|target_compile_features|target_compile_options|target_include_directories|target_link_directories|target_link_libraries|target_link_options|target_sources|try_compile|try_run|unset|use_mangled_mesa|utility_source|variable_requires|variable_watch|while|write_file)(?=\s*\()\b/,boolean:/\b(?:FALSE|OFF|ON|TRUE)\b/,namespace:/\b(?:INTERFACE|PRIVATE|PROPERTIES|PUBLIC|SHARED|STATIC|TARGET_OBJECTS)\b/,operator:/\b(?:AND|DEFINED|EQUAL|GREATER|LESS|MATCHES|NOT|OR|STREQUAL|STRGREATER|STRLESS|VERSION_EQUAL|VERSION_GREATER|VERSION_LESS)\b/,inserted:{pattern:/\b\w+::\w+\b/,alias:"class-name"},number:/\b\d+(?:\.\d+)*\b/,function:/\b[a-z_]\w*(?=\s*\()\b/i,punctuation:/[()>}]|\$[<{]/}}return ay}var oy,sI;function Ipe(){if(sI)return oy;sI=1,oy=e,e.displayName="cobol",e.aliases=[];function e(t){t.languages.cobol={comment:{pattern:/\*>.*|(^[ \t]*)\*.*/m,lookbehind:!0,greedy:!0},string:{pattern:/[xzgn]?(?:"(?:[^\r\n"]|"")*"(?!")|'(?:[^\r\n']|'')*'(?!'))/i,greedy:!0},level:{pattern:/(^[ \t]*)\d+\b/m,lookbehind:!0,greedy:!0,alias:"number"},"class-name":{pattern:/(\bpic(?:ture)?\s+)(?:(?:[-\w$/,:*+<>]|\.(?!\s|$))(?:\(\d+\))?)+/i,lookbehind:!0,inside:{number:{pattern:/(\()\d+/,lookbehind:!0},punctuation:/[()]/}},keyword:{pattern:/(^|[^\w-])(?:ABORT|ACCEPT|ACCESS|ADD|ADDRESS|ADVANCING|AFTER|ALIGNED|ALL|ALPHABET|ALPHABETIC|ALPHABETIC-LOWER|ALPHABETIC-UPPER|ALPHANUMERIC|ALPHANUMERIC-EDITED|ALSO|ALTER|ALTERNATE|ANY|ARE|AREA|AREAS|AS|ASCENDING|ASCII|ASSIGN|ASSOCIATED-DATA|ASSOCIATED-DATA-LENGTH|AT|ATTRIBUTE|AUTHOR|AUTO|AUTO-SKIP|BACKGROUND-COLOR|BACKGROUND-COLOUR|BASIS|BEEP|BEFORE|BEGINNING|BELL|BINARY|BIT|BLANK|BLINK|BLOCK|BOTTOM|BOUNDS|BY|BYFUNCTION|BYTITLE|CALL|CANCEL|CAPABLE|CCSVERSION|CD|CF|CH|CHAINING|CHANGED|CHANNEL|CHARACTER|CHARACTERS|CLASS|CLASS-ID|CLOCK-UNITS|CLOSE|CLOSE-DISPOSITION|COBOL|CODE|CODE-SET|COL|COLLATING|COLUMN|COM-REG|COMMA|COMMITMENT|COMMON|COMMUNICATION|COMP|COMP-1|COMP-2|COMP-3|COMP-4|COMP-5|COMPUTATIONAL|COMPUTATIONAL-1|COMPUTATIONAL-2|COMPUTATIONAL-3|COMPUTATIONAL-4|COMPUTATIONAL-5|COMPUTE|CONFIGURATION|CONTAINS|CONTENT|CONTINUE|CONTROL|CONTROL-POINT|CONTROLS|CONVENTION|CONVERTING|COPY|CORR|CORRESPONDING|COUNT|CRUNCH|CURRENCY|CURSOR|DATA|DATA-BASE|DATE|DATE-COMPILED|DATE-WRITTEN|DAY|DAY-OF-WEEK|DBCS|DE|DEBUG-CONTENTS|DEBUG-ITEM|DEBUG-LINE|DEBUG-NAME|DEBUG-SUB-1|DEBUG-SUB-2|DEBUG-SUB-3|DEBUGGING|DECIMAL-POINT|DECLARATIVES|DEFAULT|DEFAULT-DISPLAY|DEFINITION|DELETE|DELIMITED|DELIMITER|DEPENDING|DESCENDING|DESTINATION|DETAIL|DFHRESP|DFHVALUE|DISABLE|DISK|DISPLAY|DISPLAY-1|DIVIDE|DIVISION|DONTCARE|DOUBLE|DOWN|DUPLICATES|DYNAMIC|EBCDIC|EGCS|EGI|ELSE|EMI|EMPTY-CHECK|ENABLE|END|END-ACCEPT|END-ADD|END-CALL|END-COMPUTE|END-DELETE|END-DIVIDE|END-EVALUATE|END-IF|END-MULTIPLY|END-OF-PAGE|END-PERFORM|END-READ|END-RECEIVE|END-RETURN|END-REWRITE|END-SEARCH|END-START|END-STRING|END-SUBTRACT|END-UNSTRING|END-WRITE|ENDING|ENTER|ENTRY|ENTRY-PROCEDURE|ENVIRONMENT|EOL|EOP|EOS|ERASE|ERROR|ESCAPE|ESI|EVALUATE|EVENT|EVERY|EXCEPTION|EXCLUSIVE|EXHIBIT|EXIT|EXPORT|EXTEND|EXTENDED|EXTERNAL|FD|FILE|FILE-CONTROL|FILLER|FINAL|FIRST|FOOTING|FOR|FOREGROUND-COLOR|FOREGROUND-COLOUR|FROM|FULL|FUNCTION|FUNCTION-POINTER|FUNCTIONNAME|GENERATE|GIVING|GLOBAL|GO|GOBACK|GRID|GROUP|HEADING|HIGH-VALUE|HIGH-VALUES|HIGHLIGHT|I-O|I-O-CONTROL|ID|IDENTIFICATION|IF|IMPLICIT|IMPORT|IN|INDEX|INDEXED|INDICATE|INITIAL|INITIALIZE|INITIATE|INPUT|INPUT-OUTPUT|INSPECT|INSTALLATION|INTEGER|INTO|INVALID|INVOKE|IS|JUST|JUSTIFIED|KANJI|KEPT|KEY|KEYBOARD|LABEL|LANGUAGE|LAST|LB|LD|LEADING|LEFT|LEFTLINE|LENGTH|LENGTH-CHECK|LIBACCESS|LIBPARAMETER|LIBRARY|LIMIT|LIMITS|LINAGE|LINAGE-COUNTER|LINE|LINE-COUNTER|LINES|LINKAGE|LIST|LOCAL|LOCAL-STORAGE|LOCK|LONG-DATE|LONG-TIME|LOW-VALUE|LOW-VALUES|LOWER|LOWLIGHT|MEMORY|MERGE|MESSAGE|MMDDYYYY|MODE|MODULES|MORE-LABELS|MOVE|MULTIPLE|MULTIPLY|NAMED|NATIONAL|NATIONAL-EDITED|NATIVE|NEGATIVE|NETWORK|NEXT|NO|NO-ECHO|NULL|NULLS|NUMBER|NUMERIC|NUMERIC-DATE|NUMERIC-EDITED|NUMERIC-TIME|OBJECT-COMPUTER|OCCURS|ODT|OF|OFF|OMITTED|ON|OPEN|OPTIONAL|ORDER|ORDERLY|ORGANIZATION|OTHER|OUTPUT|OVERFLOW|OVERLINE|OWN|PACKED-DECIMAL|PADDING|PAGE|PAGE-COUNTER|PASSWORD|PERFORM|PF|PH|PIC|PICTURE|PLUS|POINTER|PORT|POSITION|POSITIVE|PRINTER|PRINTING|PRIVATE|PROCEDURE|PROCEDURE-POINTER|PROCEDURES|PROCEED|PROCESS|PROGRAM|PROGRAM-ID|PROGRAM-LIBRARY|PROMPT|PURGE|QUEUE|QUOTE|QUOTES|RANDOM|RD|READ|READER|REAL|RECEIVE|RECEIVED|RECORD|RECORDING|RECORDS|RECURSIVE|REDEFINES|REEL|REF|REFERENCE|REFERENCES|RELATIVE|RELEASE|REMAINDER|REMARKS|REMOTE|REMOVAL|REMOVE|RENAMES|REPLACE|REPLACING|REPORT|REPORTING|REPORTS|REQUIRED|RERUN|RESERVE|RESET|RETURN|RETURN-CODE|RETURNING|REVERSE-VIDEO|REVERSED|REWIND|REWRITE|RF|RH|RIGHT|ROUNDED|RUN|SAME|SAVE|SCREEN|SD|SEARCH|SECTION|SECURE|SECURITY|SEGMENT|SEGMENT-LIMIT|SELECT|SEND|SENTENCE|SEPARATE|SEQUENCE|SEQUENTIAL|SET|SHARED|SHAREDBYALL|SHAREDBYRUNUNIT|SHARING|SHIFT-IN|SHIFT-OUT|SHORT-DATE|SIGN|SIZE|SORT|SORT-CONTROL|SORT-CORE-SIZE|SORT-FILE-SIZE|SORT-MERGE|SORT-MESSAGE|SORT-MODE-SIZE|SORT-RETURN|SOURCE|SOURCE-COMPUTER|SPACE|SPACES|SPECIAL-NAMES|STANDARD|STANDARD-1|STANDARD-2|START|STATUS|STOP|STRING|SUB-QUEUE-1|SUB-QUEUE-2|SUB-QUEUE-3|SUBTRACT|SUM|SUPPRESS|SYMBOL|SYMBOLIC|SYNC|SYNCHRONIZED|TABLE|TALLY|TALLYING|TAPE|TASK|TERMINAL|TERMINATE|TEST|TEXT|THEN|THREAD|THREAD-LOCAL|THROUGH|THRU|TIME|TIMER|TIMES|TITLE|TO|TODAYS-DATE|TODAYS-NAME|TOP|TRAILING|TRUNCATED|TYPE|TYPEDEF|UNDERLINE|UNIT|UNSTRING|UNTIL|UP|UPON|USAGE|USE|USING|VALUE|VALUES|VARYING|VIRTUAL|WAIT|WHEN|WHEN-COMPILED|WITH|WORDS|WORKING-STORAGE|WRITE|YEAR|YYYYDDD|YYYYMMDD|ZERO-FILL|ZEROES|ZEROS)(?![\w-])/i,lookbehind:!0},boolean:{pattern:/(^|[^\w-])(?:false|true)(?![\w-])/i,lookbehind:!0},number:{pattern:/(^|[^\w-])(?:[+-]?(?:(?:\d+(?:[.,]\d+)?|[.,]\d+)(?:e[+-]?\d+)?|zero))(?![\w-])/i,lookbehind:!0},operator:[/<>|[<>]=?|[=+*/&]/,{pattern:/(^|[^\w-])(?:-|and|equal|greater|less|not|or|than)(?![\w-])/i,lookbehind:!0}],punctuation:/[.:,()]/}}return oy}var iy,uI;function Lpe(){if(uI)return iy;uI=1,iy=e,e.displayName="coffeescript",e.aliases=["coffee"];function e(t){(function(n){var r=/#(?!\{).+/,a={pattern:/#\{[^}]+\}/,alias:"variable"};n.languages.coffeescript=n.languages.extend("javascript",{comment:r,string:[{pattern:/'(?:\\[\s\S]|[^\\'])*'/,greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0,inside:{interpolation:a}}],keyword:/\b(?:and|break|by|catch|class|continue|debugger|delete|do|each|else|extend|extends|false|finally|for|if|in|instanceof|is|isnt|let|loop|namespace|new|no|not|null|of|off|on|or|own|return|super|switch|then|this|throw|true|try|typeof|undefined|unless|until|when|while|window|with|yes|yield)\b/,"class-member":{pattern:/@(?!\d)\w+/,alias:"variable"}}),n.languages.insertBefore("coffeescript","comment",{"multiline-comment":{pattern:/###[\s\S]+?###/,alias:"comment"},"block-regex":{pattern:/\/{3}[\s\S]*?\/{3}/,alias:"regex",inside:{comment:r,interpolation:a}}}),n.languages.insertBefore("coffeescript","string",{"inline-javascript":{pattern:/`(?:\\[\s\S]|[^\\`])*`/,inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"},script:{pattern:/[\s\S]+/,alias:"language-javascript",inside:n.languages.javascript}}},"multiline-string":[{pattern:/'''[\s\S]*?'''/,greedy:!0,alias:"string"},{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string",inside:{interpolation:a}}]}),n.languages.insertBefore("coffeescript","keyword",{property:/(?!\d)\w+(?=\s*:(?!:))/}),delete n.languages.coffeescript["template-string"],n.languages.coffee=n.languages.coffeescript})(t)}return iy}var ly,cI;function Mpe(){if(cI)return ly;cI=1,ly=e,e.displayName="concurnas",e.aliases=["conc"];function e(t){t.languages.concurnas={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*)/,lookbehind:!0,greedy:!0},langext:{pattern:/\b\w+\s*\|\|[\s\S]+?\|\|/,greedy:!0,inside:{"class-name":/^\w+/,string:{pattern:/(^\s*\|\|)[\s\S]+(?=\|\|$)/,lookbehind:!0},punctuation:/\|\|/}},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/,lookbehind:!0},keyword:/\b(?:abstract|actor|also|annotation|assert|async|await|bool|boolean|break|byte|case|catch|changed|char|class|closed|constant|continue|def|default|del|double|elif|else|enum|every|extends|false|finally|float|for|from|global|gpudef|gpukernel|if|import|in|init|inject|int|lambda|local|long|loop|match|new|nodefault|null|of|onchange|open|out|override|package|parfor|parforsync|post|pre|private|protected|provide|provider|public|return|shared|short|single|size_t|sizeof|super|sync|this|throw|trait|trans|transient|true|try|typedef|unchecked|using|val|var|void|while|with)\b/,boolean:/\b(?:false|true)\b/,number:/\b0b[01][01_]*L?\b|\b0x(?:[\da-f_]*\.)?[\da-f_p+-]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfls]?/i,punctuation:/[{}[\];(),.:]/,operator:/<==|>==|=>|->|<-|<>|&==|&<>|\?:?|\.\?|\+\+|--|[-+*/=<>]=?|[!^~]|\b(?:and|as|band|bor|bxor|comp|is|isnot|mod|or)\b=?/,annotation:{pattern:/@(?:\w+:)?(?:\w+|\[[^\]]+\])?/,alias:"builtin"}},t.languages.insertBefore("concurnas","langext",{"regex-literal":{pattern:/\br("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:t.languages.concurnas},regex:/[\s\S]+/}},"string-literal":{pattern:/(?:\B|\bs)("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\{(?:[^{}]|\{(?:[^{}]|\{[^}]*\})*\})+\}/,lookbehind:!0,inside:t.languages.concurnas},string:/[\s\S]+/}}}),t.languages.conc=t.languages.concurnas}return ly}var sy,dI;function Fpe(){if(dI)return sy;dI=1,sy=e,e.displayName="coq",e.aliases=[];function e(t){(function(n){for(var r=/\(\*(?:[^(*]|\((?!\*)|\*(?!\))|<self>)*\*\)/.source,a=0;a<2;a++)r=r.replace(/<self>/g,function(){return r});r=r.replace(/<self>/g,"[]"),n.languages.coq={comment:RegExp(r),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},attribute:[{pattern:RegExp(/#\[(?:[^\[\]("]|"(?:[^"]|"")*"(?!")|\((?!\*)|<comment>)*\]/.source.replace(/<comment>/g,function(){return r})),greedy:!0,alias:"attr-name",inside:{comment:RegExp(r),string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},operator:/=/,punctuation:/^#\[|\]$|[,()]/}},{pattern:/\b(?:Cumulative|Global|Local|Monomorphic|NonCumulative|Polymorphic|Private|Program)\b/,alias:"attr-name"}],keyword:/\b(?:Abort|About|Add|Admit|Admitted|All|Arguments|As|Assumptions|Axiom|Axioms|Back|BackTo|Backtrace|BinOp|BinOpSpec|BinRel|Bind|Blacklist|Canonical|Case|Cd|Check|Class|Classes|Close|CoFixpoint|CoInductive|Coercion|Coercions|Collection|Combined|Compute|Conjecture|Conjectures|Constant|Constants|Constraint|Constructors|Context|Corollary|Create|CstOp|Custom|Cut|Debug|Declare|Defined|Definition|Delimit|Dependencies|Dependent|Derive|Diffs|Drop|Elimination|End|Entry|Equality|Eval|Example|Existential|Existentials|Existing|Export|Extern|Extraction|Fact|Fail|Field|File|Firstorder|Fixpoint|Flags|Focus|From|Funclass|Function|Functional|GC|Generalizable|Goal|Grab|Grammar|Graph|Guarded|Haskell|Heap|Hide|Hint|HintDb|Hints|Hypotheses|Hypothesis|IF|Identity|Immediate|Implicit|Implicits|Import|Include|Induction|Inductive|Infix|Info|Initial|InjTyp|Inline|Inspect|Instance|Instances|Intro|Intros|Inversion|Inversion_clear|JSON|Language|Left|Lemma|Let|Lia|Libraries|Library|Load|LoadPath|Locate|Ltac|Ltac2|ML|Match|Method|Minimality|Module|Modules|Morphism|Next|NoInline|Notation|Number|OCaml|Obligation|Obligations|Opaque|Open|Optimize|Parameter|Parameters|Parametric|Path|Paths|Prenex|Preterm|Primitive|Print|Profile|Projections|Proof|Prop|PropBinOp|PropOp|PropUOp|Property|Proposition|Pwd|Qed|Quit|Rec|Record|Recursive|Redirect|Reduction|Register|Relation|Remark|Remove|Require|Reserved|Reset|Resolve|Restart|Rewrite|Right|Ring|Rings|SProp|Saturate|Save|Scheme|Scope|Scopes|Search|SearchHead|SearchPattern|SearchRewrite|Section|Separate|Set|Setoid|Show|Signatures|Solve|Solver|Sort|Sortclass|Sorted|Spec|Step|Strategies|Strategy|String|Structure|SubClass|Subgraph|SuchThat|Tactic|Term|TestCompile|Theorem|Time|Timeout|To|Transparent|Type|Typeclasses|Types|Typing|UnOp|UnOpSpec|Undelimit|Undo|Unfocus|Unfocused|Unfold|Universe|Universes|Unshelve|Variable|Variables|Variant|Verbose|View|Visibility|Zify|_|apply|as|at|by|cofix|else|end|exists|exists2|fix|for|forall|fun|if|in|let|match|measure|move|removed|return|struct|then|using|wf|where|with)\b/,number:/\b(?:0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]+)?(?:p[+-]?\d[\d_]*)?|\d[\d_]*(?:\.[\d_]+)?(?:e[+-]?\d[\d_]*)?)\b/i,punct:{pattern:/@\{|\{\||\[=|:>/,alias:"punctuation"},operator:/\/\\|\\\/|\.{2,3}|:{1,2}=|\*\*|[-=]>|<(?:->?|[+:=>]|<:)|>(?:=|->)|\|[-|]?|[-!%&*+/<=>?@^~']/,punctuation:/\.\(|`\(|@\{|`\{|\{\||\[=|:>|[:.,;(){}\[\]]/}})(t)}return sy}var uy,fI;function Wf(){if(fI)return uy;fI=1,uy=e,e.displayName="ruby",e.aliases=["rb"];function e(t){(function(n){n.languages.ruby=n.languages.extend("clike",{comment:{pattern:/#.*|^=begin\s[\s\S]*?^=end/m,greedy:!0},"class-name":{pattern:/(\b(?:class|module)\s+|\bcatch\s+\()[\w.\\]+|\b[A-Z_]\w*(?=\s*\.\s*new\b)/,lookbehind:!0,inside:{punctuation:/[.\\]/}},keyword:/\b(?:BEGIN|END|alias|and|begin|break|case|class|def|define_method|defined|do|each|else|elsif|end|ensure|extend|for|if|in|include|module|new|next|nil|not|or|prepend|private|protected|public|raise|redo|require|rescue|retry|return|self|super|then|throw|undef|unless|until|when|while|yield)\b/,operator:/\.{2,3}|&\.|===|<?=>|[!=]?~|(?:&&|\|\||<<|>>|\*\*|[+\-*/%<>!^&|=])=?|[?:]/,punctuation:/[(){}[\].,;]/}),n.languages.insertBefore("ruby","operator",{"double-colon":{pattern:/::/,alias:"punctuation"}});var r={pattern:/((?:^|[^\\])(?:\\{2})*)#\{(?:[^{}]|\{[^{}]*\})*\}/,lookbehind:!0,inside:{content:{pattern:/^(#\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:n.languages.ruby},delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"}}};delete n.languages.ruby.function;var a="(?:"+[/([^a-zA-Z0-9\s{(\[<=])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/\((?:[^()\\]|\\[\s\S]|\((?:[^()\\]|\\[\s\S])*\))*\)/.source,/\{(?:[^{}\\]|\\[\s\S]|\{(?:[^{}\\]|\\[\s\S])*\})*\}/.source,/\[(?:[^\[\]\\]|\\[\s\S]|\[(?:[^\[\]\\]|\\[\s\S])*\])*\]/.source,/<(?:[^<>\\]|\\[\s\S]|<(?:[^<>\\]|\\[\s\S])*>)*>/.source].join("|")+")",i=/(?:"(?:\\.|[^"\\\r\n])*"|(?:\b[a-zA-Z_]\w*|[^\s\0-\x7F]+)[?!]?|\$.)/.source;n.languages.insertBefore("ruby","keyword",{"regex-literal":[{pattern:RegExp(/%r/.source+a+/[egimnosux]{0,6}/.source),greedy:!0,inside:{interpolation:r,regex:/[\s\S]+/}},{pattern:/(^|[^/])\/(?!\/)(?:\[[^\r\n\]]+\]|\\.|[^[/\\\r\n])+\/[egimnosux]{0,6}(?=\s*(?:$|[\r\n,.;})#]))/,lookbehind:!0,greedy:!0,inside:{interpolation:r,regex:/[\s\S]+/}}],variable:/[@$]+[a-zA-Z_]\w*(?:[?!]|\b)/,symbol:[{pattern:RegExp(/(^|[^:]):/.source+i),lookbehind:!0,greedy:!0},{pattern:RegExp(/([\r\n{(,][ \t]*)/.source+i+/(?=:(?!:))/.source),lookbehind:!0,greedy:!0}],"method-definition":{pattern:/(\bdef\s+)\w+(?:\s*\.\s*\w+)?/,lookbehind:!0,inside:{function:/\b\w+$/,keyword:/^self\b/,"class-name":/^\w+/,punctuation:/\./}}}),n.languages.insertBefore("ruby","string",{"string-literal":[{pattern:RegExp(/%[qQiIwWs]?/.source+a),greedy:!0,inside:{interpolation:r,string:/[\s\S]+/}},{pattern:/("|')(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|(?!\1)[^\\#\r\n])*\1/,greedy:!0,inside:{interpolation:r,string:/[\s\S]+/}},{pattern:/<<[-~]?([a-z_]\w*)[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?[a-z_]\w*|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?/}},interpolation:r,string:/[\s\S]+/}},{pattern:/<<[-~]?'([a-z_]\w*)'[\r\n](?:.*[\r\n])*?[\t ]*\1/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<[-~]?'[a-z_]\w*'|\b[a-z_]\w*$/i,inside:{symbol:/\b\w+/,punctuation:/^<<[-~]?'|'$/}},string:/[\s\S]+/}}],"command-literal":[{pattern:RegExp(/%x/.source+a),greedy:!0,inside:{interpolation:r,command:{pattern:/[\s\S]+/,alias:"string"}}},{pattern:/`(?:#\{[^}]+\}|#(?!\{)|\\(?:\r\n|[\s\S])|[^\\`#\r\n])*`/,greedy:!0,inside:{interpolation:r,command:{pattern:/[\s\S]+/,alias:"string"}}}]}),delete n.languages.ruby.string,n.languages.insertBefore("ruby","number",{builtin:/\b(?:Array|Bignum|Binding|Class|Continuation|Dir|Exception|FalseClass|File|Fixnum|Float|Hash|IO|Integer|MatchData|Method|Module|NilClass|Numeric|Object|Proc|Range|Regexp|Stat|String|Struct|Symbol|TMS|Thread|ThreadGroup|Time|TrueClass)\b/,constant:/\b[A-Z][A-Z0-9_]*(?:[?!]|\b)/}),n.languages.rb=n.languages.ruby})(t)}return uy}var cy,pI;function zpe(){if(pI)return cy;pI=1;var e=Wf();cy=t,t.displayName="crystal",t.aliases=[];function t(n){n.register(e),function(r){r.languages.crystal=r.languages.extend("ruby",{keyword:[/\b(?:__DIR__|__END_LINE__|__FILE__|__LINE__|abstract|alias|annotation|as|asm|begin|break|case|class|def|do|else|elsif|end|ensure|enum|extend|for|fun|if|ifdef|include|instance_sizeof|lib|macro|module|next|of|out|pointerof|private|protected|ptr|require|rescue|return|select|self|sizeof|struct|super|then|type|typeof|undef|uninitialized|union|unless|until|when|while|with|yield)\b/,{pattern:/(\.\s*)(?:is_a|responds_to)\?/,lookbehind:!0}],number:/\b(?:0b[01_]*[01]|0o[0-7_]*[0-7]|0x[\da-fA-F_]*[\da-fA-F]|(?:\d(?:[\d_]*\d)?)(?:\.[\d_]*\d)?(?:[eE][+-]?[\d_]*\d)?)(?:_(?:[uif](?:8|16|32|64))?)?\b/,operator:[/->/,r.languages.ruby.operator],punctuation:/[(){}[\].,;\\]/}),r.languages.insertBefore("crystal","string-literal",{attribute:{pattern:/@\[.*?\]/,inside:{delimiter:{pattern:/^@\[|\]$/,alias:"punctuation"},attribute:{pattern:/^(\s*)\w+/,lookbehind:!0,alias:"class-name"},args:{pattern:/\S(?:[\s\S]*\S)?/,inside:r.languages.crystal}}},expansion:{pattern:/\{(?:\{.*?\}|%.*?%)\}/,inside:{content:{pattern:/^(\{.)[\s\S]+(?=.\}$)/,lookbehind:!0,inside:r.languages.crystal},delimiter:{pattern:/^\{[\{%]|[\}%]\}$/,alias:"operator"}}},char:{pattern:/'(?:[^\\\r\n]{1,2}|\\(?:.|u(?:[A-Fa-f0-9]{1,4}|\{[A-Fa-f0-9]{1,6}\})))'/,greedy:!0}})}(n)}return cy}var dy,gI;function Ppe(){if(gI)return dy;gI=1;var e=Vf();dy=t,t.displayName="cshtml",t.aliases=["razor"];function t(n){n.register(e),function(r){var a=/\/(?![/*])|\/\/.*[\r\n]|\/\*[^*]*(?:\*(?!\/)[^*]*)*\*\//.source,i=/@(?!")|"(?:[^\r\n\\"]|\\.)*"|@"(?:[^\\"]|""|\\[\s\S])*"(?!")/.source+"|"+/'(?:(?:[^\r\n'\\]|\\.|\\[Uux][\da-fA-F]{1,8})'|(?=[^\\](?!')))/.source;function l(A,R){for(var x=0;x<R;x++)A=A.replace(/<self>/g,function(){return"(?:"+A+")"});return A.replace(/<self>/g,"[^\\s\\S]").replace(/<str>/g,"(?:"+i+")").replace(/<comment>/g,"(?:"+a+")")}var u=l(/\((?:[^()'"@/]|<str>|<comment>|<self>)*\)/.source,2),c=l(/\[(?:[^\[\]'"@/]|<str>|<comment>|<self>)*\]/.source,2),f=l(/\{(?:[^{}'"@/]|<str>|<comment>|<self>)*\}/.source,2),p=l(/<(?:[^<>'"@/]|<str>|<comment>|<self>)*>/.source,2),g=/(?:\s(?:\s*[^\s>\/=]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+(?=[\s>]))|(?=[\s/>])))+)?/.source,b=/(?!\d)[^\s>\/=$<%]+/.source+g+/\s*\/?>/.source,m=/\B@?/.source+"(?:"+/<([a-zA-Z][\w:]*)/.source+g+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+b+"|"+l(/<\1/.source+g+/\s*>/.source+"(?:"+(/[^<]/.source+"|"+/<\/?(?!\1\b)/.source+b+"|<self>")+")*"+/<\/\1\s*>/.source,2))+")*"+/<\/\1\s*>/.source+"|"+/</.source+b+")";r.languages.cshtml=r.languages.extend("markup",{});var S=r.languages.insertBefore("csharp","string",{html:{pattern:RegExp(m),greedy:!0,inside:r.languages.cshtml}},{csharp:r.languages.extend("csharp",{})}),v={pattern:/\S[\s\S]*/,alias:"language-csharp",inside:S};r.languages.insertBefore("cshtml","prolog",{"razor-comment":{pattern:/@\*[\s\S]*?\*@/,greedy:!0,alias:"comment"},block:{pattern:RegExp(/(^|[^@])@/.source+"(?:"+[f,/(?:code|functions)\s*/.source+f,/(?:for|foreach|lock|switch|using|while)\s*/.source+u+/\s*/.source+f,/do\s*/.source+f+/\s*while\s*/.source+u+/(?:\s*;)?/.source,/try\s*/.source+f+/\s*catch\s*/.source+u+/\s*/.source+f+/\s*finally\s*/.source+f,/if\s*/.source+u+/\s*/.source+f+"(?:"+/\s*else/.source+"(?:"+/\s+if\s*/.source+u+")?"+/\s*/.source+f+")*"].join("|")+")"),lookbehind:!0,greedy:!0,inside:{keyword:/^@\w*/,csharp:v}},directive:{pattern:/^([ \t]*)@(?:addTagHelper|attribute|implements|inherits|inject|layout|model|namespace|page|preservewhitespace|removeTagHelper|section|tagHelperPrefix|using)(?=\s).*/m,lookbehind:!0,greedy:!0,inside:{keyword:/^@\w+/,csharp:v}},value:{pattern:RegExp(/(^|[^@])@/.source+/(?:await\b\s*)?/.source+"(?:"+/\w+\b/.source+"|"+u+")(?:"+/[?!]?\.\w+\b/.source+"|"+u+"|"+c+"|"+p+u+")*"),lookbehind:!0,greedy:!0,alias:"variable",inside:{keyword:/^@/,csharp:v}},"delegate-operator":{pattern:/(^|[^@])@(?=<)/,lookbehind:!0,alias:"operator"}}),r.languages.razor=r.languages.cshtml}(n)}return dy}var fy,hI;function Bpe(){if(hI)return fy;hI=1,fy=e,e.displayName="csp",e.aliases=[];function e(t){(function(n){function r(a){return RegExp(/([ \t])/.source+"(?:"+a+")"+/(?=[\s;]|$)/.source,"i")}n.languages.csp={directive:{pattern:/(^|[\s;])(?:base-uri|block-all-mixed-content|(?:child|connect|default|font|frame|img|manifest|media|object|prefetch|script|style|worker)-src|disown-opener|form-action|frame-(?:ancestors|options)|input-protection(?:-(?:clip|selectors))?|navigate-to|plugin-types|policy-uri|referrer|reflected-xss|report-(?:to|uri)|require-sri-for|sandbox|(?:script|style)-src-(?:attr|elem)|upgrade-insecure-requests)(?=[\s;]|$)/i,lookbehind:!0,alias:"property"},scheme:{pattern:r(/[a-z][a-z0-9.+-]*:/.source),lookbehind:!0},none:{pattern:r(/'none'/.source),lookbehind:!0,alias:"keyword"},nonce:{pattern:r(/'nonce-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},hash:{pattern:r(/'sha(?:256|384|512)-[-+/\w=]+'/.source),lookbehind:!0,alias:"number"},host:{pattern:r(/[a-z][a-z0-9.+-]*:\/\/[^\s;,']*/.source+"|"+/\*[^\s;,']*/.source+"|"+/[a-z0-9-]+(?:\.[a-z0-9-]+)+(?::[\d*]+)?(?:\/[^\s;,']*)?/.source),lookbehind:!0,alias:"url",inside:{important:/\*/}},keyword:[{pattern:r(/'unsafe-[a-z-]+'/.source),lookbehind:!0,alias:"unsafe"},{pattern:r(/'[a-z-]+'/.source),lookbehind:!0,alias:"safe"}],punctuation:/;/}})(t)}return fy}var py,mI;function Upe(){if(mI)return py;mI=1,py=e,e.displayName="cssExtras",e.aliases=[];function e(t){(function(n){var r=/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,a;n.languages.css.selector={pattern:n.languages.css.selector.pattern,lookbehind:!0,inside:a={"pseudo-element":/:(?:after|before|first-letter|first-line|selection)|::[-\w]+/,"pseudo-class":/:[-\w]+/,class:/\.[-\w]+/,id:/#[-\w]+/,attribute:{pattern:RegExp(`\\[(?:[^[\\]"']|`+r.source+")*\\]"),greedy:!0,inside:{punctuation:/^\[|\]$/,"case-sensitivity":{pattern:/(\s)[si]$/i,lookbehind:!0,alias:"keyword"},namespace:{pattern:/^(\s*)(?:(?!\s)[-*\w\xA0-\uFFFF])*\|(?!=)/,lookbehind:!0,inside:{punctuation:/\|$/}},"attr-name":{pattern:/^(\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+/,lookbehind:!0},"attr-value":[r,{pattern:/(=\s*)(?:(?!\s)[-\w\xA0-\uFFFF])+(?=\s*$)/,lookbehind:!0}],operator:/[|~*^$]?=/}},"n-th":[{pattern:/(\(\s*)[+-]?\d*[\dn](?:\s*[+-]\s*\d+)?(?=\s*\))/,lookbehind:!0,inside:{number:/[\dn]+/,operator:/[+-]/}},{pattern:/(\(\s*)(?:even|odd)(?=\s*\))/i,lookbehind:!0}],combinator:/>|\+|~|\|\|/,punctuation:/[(),]/}},n.languages.css.atrule.inside["selector-function-argument"].inside=a,n.languages.insertBefore("css","property",{variable:{pattern:/(^|[^-\w\xA0-\uFFFF])--(?!\s)[-_a-z\xA0-\uFFFF](?:(?!\s)[-\w\xA0-\uFFFF])*/i,lookbehind:!0}});var i={pattern:/(\b\d+)(?:%|[a-z]+(?![\w-]))/,lookbehind:!0},l={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0};n.languages.insertBefore("css","function",{operator:{pattern:/(\s)[+\-*\/](?=\s)/,lookbehind:!0},hexcode:{pattern:/\B#[\da-f]{3,8}\b/i,alias:"color"},color:[{pattern:/(^|[^\w-])(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)(?![\w-])/i,lookbehind:!0},{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:i,number:l,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:i,number:l})})(t)}return py}var gy,bI;function jpe(){if(bI)return gy;bI=1,gy=e,e.displayName="csv",e.aliases=[];function e(t){t.languages.csv={value:/[^\r\n,"]+|"(?:[^"]|"")*"(?!")/,punctuation:/,/}}return gy}var hy,yI;function Gpe(){if(yI)return hy;yI=1,hy=e,e.displayName="cypher",e.aliases=[];function e(t){t.languages.cypher={comment:/\/\/.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/,greedy:!0},"class-name":{pattern:/(:\s*)(?:\w+|`(?:[^`\\\r\n])*`)(?=\s*[{):])/,lookbehind:!0,greedy:!0},relationship:{pattern:/(-\[\s*(?:\w+\s*|`(?:[^`\\\r\n])*`\s*)?:\s*|\|\s*:\s*)(?:\w+|`(?:[^`\\\r\n])*`)/,lookbehind:!0,greedy:!0,alias:"property"},identifier:{pattern:/`(?:[^`\\\r\n])*`/,greedy:!0},variable:/\$\w+/,keyword:/\b(?:ADD|ALL|AND|AS|ASC|ASCENDING|ASSERT|BY|CALL|CASE|COMMIT|CONSTRAINT|CONTAINS|CREATE|CSV|DELETE|DESC|DESCENDING|DETACH|DISTINCT|DO|DROP|ELSE|END|ENDS|EXISTS|FOR|FOREACH|IN|INDEX|IS|JOIN|KEY|LIMIT|LOAD|MANDATORY|MATCH|MERGE|NODE|NOT|OF|ON|OPTIONAL|OR|ORDER(?=\s+BY)|PERIODIC|REMOVE|REQUIRE|RETURN|SCALAR|SCAN|SET|SKIP|START|STARTS|THEN|UNION|UNIQUE|UNWIND|USING|WHEN|WHERE|WITH|XOR|YIELD)\b/i,function:/\b\w+\b(?=\s*\()/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:[eE][+-]?\d+)?)\b/,operator:/:|<--?|--?>?|<>|=~?|[<>]=?|[+*/%^|]|\.\.\.?/,punctuation:/[()[\]{},;.]/}}return hy}var my,vI;function Hpe(){if(vI)return my;vI=1,my=e,e.displayName="d",e.aliases=[];function e(t){t.languages.d=t.languages.extend("clike",{comment:[{pattern:/^\s*#!.+/,greedy:!0},{pattern:RegExp(/(^|[^\\])/.source+"(?:"+[/\/\+(?:\/\+(?:[^+]|\+(?!\/))*\+\/|(?!\/\+)[\s\S])*?\+\//.source,/\/\/.*/.source,/\/\*[\s\S]*?\*\//.source].join("|")+")"),lookbehind:!0,greedy:!0}],string:[{pattern:RegExp([/\b[rx]"(?:\\[\s\S]|[^\\"])*"[cwd]?/.source,/\bq"(?:\[[\s\S]*?\]|\([\s\S]*?\)|<[\s\S]*?>|\{[\s\S]*?\})"/.source,/\bq"((?!\d)\w+)$[\s\S]*?^\1"/.source,/\bq"(.)[\s\S]*?\2"/.source,/(["`])(?:\\[\s\S]|(?!\3)[^\\])*\3[cwd]?/.source].join("|"),"m"),greedy:!0},{pattern:/\bq\{(?:\{[^{}]*\}|[^{}])*\}/,greedy:!0,alias:"token-string"}],keyword:/\$|\b(?:__(?:(?:DATE|EOF|FILE|FUNCTION|LINE|MODULE|PRETTY_FUNCTION|TIMESTAMP|TIME|VENDOR|VERSION)__|gshared|parameters|traits|vector)|abstract|alias|align|asm|assert|auto|body|bool|break|byte|case|cast|catch|cdouble|cent|cfloat|char|class|const|continue|creal|dchar|debug|default|delegate|delete|deprecated|do|double|dstring|else|enum|export|extern|false|final|finally|float|for|foreach|foreach_reverse|function|goto|idouble|if|ifloat|immutable|import|inout|int|interface|invariant|ireal|lazy|long|macro|mixin|module|new|nothrow|null|out|override|package|pragma|private|protected|ptrdiff_t|public|pure|real|ref|return|scope|shared|short|size_t|static|string|struct|super|switch|synchronized|template|this|throw|true|try|typedef|typeid|typeof|ubyte|ucent|uint|ulong|union|unittest|ushort|version|void|volatile|wchar|while|with|wstring)\b/,number:[/\b0x\.?[a-f\d_]+(?:(?!\.\.)\.[a-f\d_]*)?(?:p[+-]?[a-f\d_]+)?[ulfi]{0,4}/i,{pattern:/((?:\.\.)?)(?:\b0b\.?|\b|\.)\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:e[+-]?\d[\d_]*)?[ulfi]{0,4}/i,lookbehind:!0}],operator:/\|[|=]?|&[&=]?|\+[+=]?|-[-=]?|\.?\.\.|=[>=]?|!(?:i[ns]\b|<>?=?|>=?|=)?|\bi[ns]\b|(?:<[<>]?|>>?>?|\^\^|[*\/%^~])=?/}),t.languages.insertBefore("d","string",{char:/'(?:\\(?:\W|\w+)|[^\\])'/}),t.languages.insertBefore("d","keyword",{property:/\B@\w*/}),t.languages.insertBefore("d","function",{register:{pattern:/\b(?:[ABCD][LHX]|E?(?:BP|DI|SI|SP)|[BS]PL|[ECSDGF]S|CR[0234]|[DS]IL|DR[012367]|E[ABCD]X|X?MM[0-7]|R(?:1[0-5]|[89])[BWD]?|R[ABCD]X|R[BS]P|R[DS]I|TR[3-7]|XMM(?:1[0-5]|[89])|YMM(?:1[0-5]|\d))\b|\bST(?:\([0-7]\)|\b)/,alias:"variable"}})}return my}var by,SI;function $pe(){if(SI)return by;SI=1,by=e,e.displayName="dart",e.aliases=[];function e(t){(function(n){var r=[/\b(?:async|sync|yield)\*/,/\b(?:abstract|assert|async|await|break|case|catch|class|const|continue|covariant|default|deferred|do|dynamic|else|enum|export|extends|extension|external|factory|final|finally|for|get|hide|if|implements|import|in|interface|library|mixin|new|null|on|operator|part|rethrow|return|set|show|static|super|switch|sync|this|throw|try|typedef|var|void|while|with|yield)\b/],a=/(^|[^\w.])(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,i={pattern:RegExp(a+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}}}};n.languages.dart=n.languages.extend("clike",{"class-name":[i,{pattern:RegExp(a+/[A-Z]\w*(?=\s+\w+\s*[;,=()])/.source),lookbehind:!0,inside:i.inside}],keyword:r,operator:/\bis!|\b(?:as|is)\b|\+\+|--|&&|\|\||<<=?|>>=?|~(?:\/=?)?|[+\-*\/%&^|=!<>]=?|\?/}),n.languages.insertBefore("dart","string",{"string-literal":{pattern:/r?(?:("""|''')[\s\S]*?\1|(["'])(?:\\.|(?!\2)[^\\\r\n])*\2(?!\2))/,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,lookbehind:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.dart}}},string:/[\s\S]+/}},string:void 0}),n.languages.insertBefore("dart","class-name",{metadata:{pattern:/@\w+/,alias:"function"}}),n.languages.insertBefore("dart","class-name",{generics:{pattern:/<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<(?:[\w\s,.&?]|<[\w\s,.&?]*>)*>)*>)*>/,inside:{"class-name":i,keyword:r,punctuation:/[<>(),.:]/,operator:/[?&|]/}}})})(t)}return by}var yy,EI;function qpe(){if(EI)return yy;EI=1,yy=e,e.displayName="dataweave",e.aliases=[];function e(t){(function(n){n.languages.dataweave={url:/\b[A-Za-z]+:\/\/[\w/:.?=&-]+|\burn:[\w:.?=&-]+/,property:{pattern:/(?:\b\w+#)?(?:"(?:\\.|[^\\"\r\n])*"|\b\w+)(?=\s*[:@])/,greedy:!0},string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},"mime-type":/\b(?:application|audio|image|multipart|text|video)\/[\w+-]+/,date:{pattern:/\|[\w:+-]+\|/,greedy:!0},comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],regex:{pattern:/\/(?:[^\\\/\r\n]|\\[^\r\n])+\//,greedy:!0},keyword:/\b(?:and|as|at|case|do|else|fun|if|input|is|match|not|ns|null|or|output|type|unless|update|using|var)\b/,function:/\b[A-Z_]\w*(?=\s*\()/i,number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\];(),.:@]/,operator:/<<|>>|->|[<>~=]=?|!=|--?-?|\+\+?|!|\?/,boolean:/\b(?:false|true)\b/}})(t)}return yy}var vy,wI;function Vpe(){if(wI)return vy;wI=1,vy=e,e.displayName="dax",e.aliases=[];function e(t){t.languages.dax={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/).*)/,lookbehind:!0},"data-field":{pattern:/'(?:[^']|'')*'(?!')(?:\[[ \w\xA0-\uFFFF]+\])?|\w+\[[ \w\xA0-\uFFFF]+\]/,alias:"symbol"},measure:{pattern:/\[[ \w\xA0-\uFFFF]+\]/,alias:"constant"},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},function:/\b(?:ABS|ACOS|ACOSH|ACOT|ACOTH|ADDCOLUMNS|ADDMISSINGITEMS|ALL|ALLCROSSFILTERED|ALLEXCEPT|ALLNOBLANKROW|ALLSELECTED|AND|APPROXIMATEDISTINCTCOUNT|ASIN|ASINH|ATAN|ATANH|AVERAGE|AVERAGEA|AVERAGEX|BETA\.DIST|BETA\.INV|BLANK|CALCULATE|CALCULATETABLE|CALENDAR|CALENDARAUTO|CEILING|CHISQ\.DIST|CHISQ\.DIST\.RT|CHISQ\.INV|CHISQ\.INV\.RT|CLOSINGBALANCEMONTH|CLOSINGBALANCEQUARTER|CLOSINGBALANCEYEAR|COALESCE|COMBIN|COMBINA|COMBINEVALUES|CONCATENATE|CONCATENATEX|CONFIDENCE\.NORM|CONFIDENCE\.T|CONTAINS|CONTAINSROW|CONTAINSSTRING|CONTAINSSTRINGEXACT|CONVERT|COS|COSH|COT|COTH|COUNT|COUNTA|COUNTAX|COUNTBLANK|COUNTROWS|COUNTX|CROSSFILTER|CROSSJOIN|CURRENCY|CURRENTGROUP|CUSTOMDATA|DATATABLE|DATE|DATEADD|DATEDIFF|DATESBETWEEN|DATESINPERIOD|DATESMTD|DATESQTD|DATESYTD|DATEVALUE|DAY|DEGREES|DETAILROWS|DISTINCT|DISTINCTCOUNT|DISTINCTCOUNTNOBLANK|DIVIDE|EARLIER|EARLIEST|EDATE|ENDOFMONTH|ENDOFQUARTER|ENDOFYEAR|EOMONTH|ERROR|EVEN|EXACT|EXCEPT|EXP|EXPON\.DIST|FACT|FALSE|FILTER|FILTERS|FIND|FIRSTDATE|FIRSTNONBLANK|FIRSTNONBLANKVALUE|FIXED|FLOOR|FORMAT|GCD|GENERATE|GENERATEALL|GENERATESERIES|GEOMEAN|GEOMEANX|GROUPBY|HASONEFILTER|HASONEVALUE|HOUR|IF|IF\.EAGER|IFERROR|IGNORE|INT|INTERSECT|ISBLANK|ISCROSSFILTERED|ISEMPTY|ISERROR|ISEVEN|ISFILTERED|ISINSCOPE|ISLOGICAL|ISNONTEXT|ISNUMBER|ISO\.CEILING|ISODD|ISONORAFTER|ISSELECTEDMEASURE|ISSUBTOTAL|ISTEXT|KEEPFILTERS|KEYWORDMATCH|LASTDATE|LASTNONBLANK|LASTNONBLANKVALUE|LCM|LEFT|LEN|LN|LOG|LOG10|LOOKUPVALUE|LOWER|MAX|MAXA|MAXX|MEDIAN|MEDIANX|MID|MIN|MINA|MINUTE|MINX|MOD|MONTH|MROUND|NATURALINNERJOIN|NATURALLEFTOUTERJOIN|NEXTDAY|NEXTMONTH|NEXTQUARTER|NEXTYEAR|NONVISUAL|NORM\.DIST|NORM\.INV|NORM\.S\.DIST|NORM\.S\.INV|NOT|NOW|ODD|OPENINGBALANCEMONTH|OPENINGBALANCEQUARTER|OPENINGBALANCEYEAR|OR|PARALLELPERIOD|PATH|PATHCONTAINS|PATHITEM|PATHITEMREVERSE|PATHLENGTH|PERCENTILE\.EXC|PERCENTILE\.INC|PERCENTILEX\.EXC|PERCENTILEX\.INC|PERMUT|PI|POISSON\.DIST|POWER|PREVIOUSDAY|PREVIOUSMONTH|PREVIOUSQUARTER|PREVIOUSYEAR|PRODUCT|PRODUCTX|QUARTER|QUOTIENT|RADIANS|RAND|RANDBETWEEN|RANK\.EQ|RANKX|RELATED|RELATEDTABLE|REMOVEFILTERS|REPLACE|REPT|RIGHT|ROLLUP|ROLLUPADDISSUBTOTAL|ROLLUPGROUP|ROLLUPISSUBTOTAL|ROUND|ROUNDDOWN|ROUNDUP|ROW|SAMEPERIODLASTYEAR|SAMPLE|SEARCH|SECOND|SELECTCOLUMNS|SELECTEDMEASURE|SELECTEDMEASUREFORMATSTRING|SELECTEDMEASURENAME|SELECTEDVALUE|SIGN|SIN|SINH|SQRT|SQRTPI|STARTOFMONTH|STARTOFQUARTER|STARTOFYEAR|STDEV\.P|STDEV\.S|STDEVX\.P|STDEVX\.S|SUBSTITUTE|SUBSTITUTEWITHINDEX|SUM|SUMMARIZE|SUMMARIZECOLUMNS|SUMX|SWITCH|T\.DIST|T\.DIST\.2T|T\.DIST\.RT|T\.INV|T\.INV\.2T|TAN|TANH|TIME|TIMEVALUE|TODAY|TOPN|TOPNPERLEVEL|TOPNSKIP|TOTALMTD|TOTALQTD|TOTALYTD|TREATAS|TRIM|TRUE|TRUNC|UNICHAR|UNICODE|UNION|UPPER|USERELATIONSHIP|USERNAME|USEROBJECTID|USERPRINCIPALNAME|UTCNOW|UTCTODAY|VALUE|VALUES|VAR\.P|VAR\.S|VARX\.P|VARX\.S|WEEKDAY|WEEKNUM|XIRR|XNPV|YEAR|YEARFRAC)(?=\s*\()/i,keyword:/\b(?:DEFINE|EVALUATE|MEASURE|ORDER\s+BY|RETURN|VAR|START\s+AT|ASC|DESC)\b/i,boolean:{pattern:/\b(?:FALSE|NULL|TRUE)\b/i,alias:"constant"},number:/\b\d+(?:\.\d*)?|\B\.\d+\b/,operator:/:=|[-+*\/=^]|&&?|\|\||<(?:=>?|<|>)?|>[>=]?|\b(?:IN|NOT)\b/i,punctuation:/[;\[\](){}`,.]/}}return vy}var Sy,xI;function Wpe(){if(xI)return Sy;xI=1,Sy=e,e.displayName="dhall",e.aliases=[];function e(t){t.languages.dhall={comment:/--.*|\{-(?:[^-{]|-(?!\})|\{(?!-)|\{-(?:[^-{]|-(?!\})|\{(?!-))*-\})*-\}/,string:{pattern:/"(?:[^"\\]|\\.)*"|''(?:[^']|'(?!')|'''|''\$\{)*''(?!'|\$)/,greedy:!0,inside:{interpolation:{pattern:/\$\{[^{}]*\}/,inside:{expression:{pattern:/(^\$\{)[\s\S]+(?=\}$)/,lookbehind:!0,alias:"language-dhall",inside:null},punctuation:/\$\{|\}/}}}},label:{pattern:/`[^`]*`/,greedy:!0},url:{pattern:/\bhttps?:\/\/[\w.:%!$&'*+;=@~-]+(?:\/[\w.:%!$&'*+;=@~-]*)*(?:\?[/?\w.:%!$&'*+;=@~-]*)?/,greedy:!0},env:{pattern:/\benv:(?:(?!\d)\w+|"(?:[^"\\=]|\\.)*")/,greedy:!0,inside:{function:/^env/,operator:/^:/,variable:/[\s\S]+/}},hash:{pattern:/\bsha256:[\da-fA-F]{64}\b/,inside:{function:/sha256/,operator:/:/,number:/[\da-fA-F]{64}/}},keyword:/\b(?:as|assert|else|forall|if|in|let|merge|missing|then|toMap|using|with)\b|\u2200/,builtin:/\b(?:None|Some)\b/,boolean:/\b(?:False|True)\b/,number:/\bNaN\b|-?\bInfinity\b|[+-]?\b(?:0x[\da-fA-F]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/,operator:/\/\\|\/\/\\\\|&&|\|\||===|[!=]=|\/\/|->|\+\+|::|[+*#@=:?<>|\\\u2227\u2a53\u2261\u2afd\u03bb\u2192]/,punctuation:/\.\.|[{}\[\](),./]/,"class-name":/\b[A-Z]\w*\b/},t.languages.dhall.string.inside.interpolation.inside.expression.inside=t.languages.dhall}return Sy}var Ey,kI;function Ype(){if(kI)return Ey;kI=1,Ey=e,e.displayName="diff",e.aliases=[];function e(t){(function(n){n.languages.diff={coord:[/^(?:\*{3}|-{3}|\+{3}).*$/m,/^@@.*@@$/m,/^\d.*$/m]};var r={"deleted-sign":"-","deleted-arrow":"<","inserted-sign":"+","inserted-arrow":">",unchanged:" ",diff:"!"};Object.keys(r).forEach(function(a){var i=r[a],l=[];/^\w+$/.test(a)||l.push(/\w+/.exec(a)[0]),a==="diff"&&l.push("bold"),n.languages.diff[a]={pattern:RegExp("^(?:["+i+`].*(?:\r
?|
|(?![\\s\\S])))+`,"m"),alias:l,inside:{line:{pattern:/(.)(?=[\s\S]).*(?:\r\n?|\n)?/,lookbehind:!0},prefix:{pattern:/[\s\S]/,alias:/\w+/.exec(a)[0]}}}}),Object.defineProperty(n.languages.diff,"PREFIXES",{value:r})})(t)}return Ey}var wy,AI;function Gn(){if(AI)return wy;AI=1,wy=e,e.displayName="markupTemplating",e.aliases=[];function e(t){(function(n){function r(a,i){return"___"+a.toUpperCase()+i+"___"}Object.defineProperties(n.languages["markup-templating"]={},{buildPlaceholders:{value:function(a,i,l,u){if(a.language===i){var c=a.tokenStack=[];a.code=a.code.replace(l,function(f){if(typeof u=="function"&&!u(f))return f;for(var p=c.length,g;a.code.indexOf(g=r(i,p))!==-1;)++p;return c[p]=f,g}),a.grammar=n.languages.markup}}},tokenizePlaceholders:{value:function(a,i){if(a.language!==i||!a.tokenStack)return;a.grammar=n.languages[i];var l=0,u=Object.keys(a.tokenStack);function c(f){for(var p=0;p<f.length&&!(l>=u.length);p++){var g=f[p];if(typeof g=="string"||g.content&&typeof g.content=="string"){var b=u[l],m=a.tokenStack[b],S=typeof g=="string"?g:g.content,v=r(i,b),A=S.indexOf(v);if(A>-1){++l;var R=S.substring(0,A),x=new n.Token(i,n.tokenize(m,a.grammar),"language-"+i,m),T=S.substring(A+v.length),C=[];R&&C.push.apply(C,c([R])),C.push(x),T&&C.push.apply(C,c([T])),typeof g=="string"?f.splice.apply(f,[p,1].concat(C)):g.content=C}}else g.content&&c(g.content)}return f}c(a.tokens)}}})})(t)}return wy}var xy,TI;function Kpe(){if(TI)return xy;TI=1;var e=Gn();xy=t,t.displayName="django",t.aliases=["jinja2"];function t(n){n.register(e),function(r){r.languages.django={comment:/^\{#[\s\S]*?#\}$/,tag:{pattern:/(^\{%[+-]?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%][+-]?|[+-]?[}%]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},filter:{pattern:/(\|)\w+/,lookbehind:!0,alias:"function"},test:{pattern:/(\bis\s+(?:not\s+)?)(?!not\b)\w+/,lookbehind:!0,alias:"function"},function:/\b[a-z_]\w+(?=\s*\()/i,keyword:/\b(?:and|as|by|else|for|if|import|in|is|loop|not|or|recursive|with|without)\b/,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,number:/\b\d+(?:\.\d+)?\b/,boolean:/[Ff]alse|[Nn]one|[Tt]rue/,variable:/\b\w+\b/,punctuation:/[{}[\](),.:;]/};var a=/\{\{[\s\S]*?\}\}|\{%[\s\S]*?%\}|\{#[\s\S]*?#\}/g,i=r.languages["markup-templating"];r.hooks.add("before-tokenize",function(l){i.buildPlaceholders(l,"django",a)}),r.hooks.add("after-tokenize",function(l){i.tokenizePlaceholders(l,"django")}),r.languages.jinja2=r.languages.django,r.hooks.add("before-tokenize",function(l){i.buildPlaceholders(l,"jinja2",a)}),r.hooks.add("after-tokenize",function(l){i.tokenizePlaceholders(l,"jinja2")})}(n)}return xy}var ky,_I;function Xpe(){if(_I)return ky;_I=1,ky=e,e.displayName="dnsZoneFile",e.aliases=[];function e(t){t.languages["dns-zone-file"]={comment:/;.*/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},variable:[{pattern:/(^\$ORIGIN[ \t]+)\S+/m,lookbehind:!0},{pattern:/(^|\s)@(?=\s|$)/,lookbehind:!0}],keyword:/^\$(?:INCLUDE|ORIGIN|TTL)(?=\s|$)/m,class:{pattern:/(^|\s)(?:CH|CS|HS|IN)(?=\s|$)/,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|\s)(?:A|A6|AAAA|AFSDB|APL|ATMA|CAA|CDNSKEY|CDS|CERT|CNAME|DHCID|DLV|DNAME|DNSKEY|DS|EID|GID|GPOS|HINFO|HIP|IPSECKEY|ISDN|KEY|KX|LOC|MAILA|MAILB|MB|MD|MF|MG|MINFO|MR|MX|NAPTR|NB|NBSTAT|NIMLOC|NINFO|NS|NSAP|NSAP-PTR|NSEC|NSEC3|NSEC3PARAM|NULL|NXT|OPENPGPKEY|PTR|PX|RKEY|RP|RRSIG|RT|SIG|SINK|SMIMEA|SOA|SPF|SRV|SSHFP|TA|TKEY|TLSA|TSIG|TXT|UID|UINFO|UNSPEC|URI|WKS|X25)(?=\s|$)/,lookbehind:!0,alias:"keyword"},punctuation:/[()]/},t.languages["dns-zone"]=t.languages["dns-zone-file"]}return ky}var Ay,RI;function Zpe(){if(RI)return Ay;RI=1,Ay=e,e.displayName="docker",e.aliases=["dockerfile"];function e(t){(function(n){var r=/\\[\r\n](?:\s|\\[\r\n]|#.*(?!.))*(?![\s#]|\\[\r\n])/.source,a=/(?:[ \t]+(?![ \t])(?:<SP_BS>)?|<SP_BS>)/.source.replace(/<SP_BS>/g,function(){return r}),i=/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"|'(?:[^'\\\r\n]|\\(?:\r\n|[\s\S]))*'/.source,l=/--[\w-]+=(?:<STR>|(?!["'])(?:[^\s\\]|\\.)+)/.source.replace(/<STR>/g,function(){return i}),u={pattern:RegExp(i),greedy:!0},c={pattern:/(^[ \t]*)#.*/m,lookbehind:!0,greedy:!0};function f(p,g){return p=p.replace(/<OPT>/g,function(){return l}).replace(/<SP>/g,function(){return a}),RegExp(p,g)}n.languages.docker={instruction:{pattern:/(^[ \t]*)(?:ADD|ARG|CMD|COPY|ENTRYPOINT|ENV|EXPOSE|FROM|HEALTHCHECK|LABEL|MAINTAINER|ONBUILD|RUN|SHELL|STOPSIGNAL|USER|VOLUME|WORKDIR)(?=\s)(?:\\.|[^\r\n\\])*(?:\\$(?:\s|#.*$)*(?![\s#])(?:\\.|[^\r\n\\])*)*/im,lookbehind:!0,greedy:!0,inside:{options:{pattern:f(/(^(?:ONBUILD<SP>)?\w+<SP>)<OPT>(?:<SP><OPT>)*/.source,"i"),lookbehind:!0,greedy:!0,inside:{property:{pattern:/(^|\s)--[\w-]+/,lookbehind:!0},string:[u,{pattern:/(=)(?!["'])(?:[^\s\\]|\\.)+/,lookbehind:!0}],operator:/\\$/m,punctuation:/=/}},keyword:[{pattern:f(/(^(?:ONBUILD<SP>)?HEALTHCHECK<SP>(?:<OPT><SP>)*)(?:CMD|NONE)\b/.source,"i"),lookbehind:!0,greedy:!0},{pattern:f(/(^(?:ONBUILD<SP>)?FROM<SP>(?:<OPT><SP>)*(?!--)[^ \t\\]+<SP>)AS/.source,"i"),lookbehind:!0,greedy:!0},{pattern:f(/(^ONBUILD<SP>)\w+/.source,"i"),lookbehind:!0,greedy:!0},{pattern:/^\w+/,greedy:!0}],comment:c,string:u,variable:/\$(?:\w+|\{[^{}"'\\]*\})/,operator:/\\$/m}},comment:c},n.languages.dockerfile=n.languages.docker})(t)}return Ay}var Ty,CI;function Qpe(){if(CI)return Ty;CI=1,Ty=e,e.displayName="dot",e.aliases=["gv"];function e(t){(function(n){var r="(?:"+[/[a-zA-Z_\x80-\uFFFF][\w\x80-\uFFFF]*/.source,/-?(?:\.\d+|\d+(?:\.\d*)?)/.source,/"[^"\\]*(?:\\[\s\S][^"\\]*)*"/.source,/<(?:[^<>]|(?!<!--)<(?:[^<>"']|"[^"]*"|'[^']*')+>|<!--(?:[^-]|-(?!->))*-->)*>/.source].join("|")+")",a={markup:{pattern:/(^<)[\s\S]+(?=>$)/,lookbehind:!0,alias:["language-markup","language-html","language-xml"],inside:n.languages.markup}};function i(l,u){return RegExp(l.replace(/<ID>/g,function(){return r}),u)}n.languages.dot={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\/|^#.*/m,greedy:!0},"graph-name":{pattern:i(/(\b(?:digraph|graph|subgraph)[ \t\r\n]+)<ID>/.source,"i"),lookbehind:!0,greedy:!0,alias:"class-name",inside:a},"attr-value":{pattern:i(/(=[ \t\r\n]*)<ID>/.source),lookbehind:!0,greedy:!0,inside:a},"attr-name":{pattern:i(/([\[;, \t\r\n])<ID>(?=[ \t\r\n]*=)/.source),lookbehind:!0,greedy:!0,inside:a},keyword:/\b(?:digraph|edge|graph|node|strict|subgraph)\b/i,"compass-point":{pattern:/(:[ \t\r\n]*)(?:[ewc_]|[ns][ew]?)(?![\w\x80-\uFFFF])/,lookbehind:!0,alias:"builtin"},node:{pattern:i(/(^|[^-.\w\x80-\uFFFF\\])<ID>/.source),lookbehind:!0,greedy:!0,inside:a},operator:/[=:]|-[->]/,punctuation:/[\[\]{};,]/},n.languages.gv=n.languages.dot})(t)}return Ty}var _y,NI;function Jpe(){if(NI)return _y;NI=1,_y=e,e.displayName="ebnf",e.aliases=[];function e(t){t.languages.ebnf={comment:/\(\*[\s\S]*?\*\)/,string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},special:{pattern:/\?[^?\r\n]*\?/,greedy:!0,alias:"class-name"},definition:{pattern:/^([\t ]*)[a-z]\w*(?:[ \t]+[a-z]\w*)*(?=\s*=)/im,lookbehind:!0,alias:["rule","keyword"]},rule:/\b[a-z]\w*(?:[ \t]+[a-z]\w*)*\b/i,punctuation:/\([:/]|[:/]\)|[.,;()[\]{}]/,operator:/[-=|*/!]/}}return _y}var Ry,OI;function ege(){if(OI)return Ry;OI=1,Ry=e,e.displayName="editorconfig",e.aliases=[];function e(t){t.languages.editorconfig={comment:/[;#].*/,section:{pattern:/(^[ \t]*)\[.+\]/m,lookbehind:!0,alias:"selector",inside:{regex:/\\\\[\[\]{},!?.*]/,operator:/[!?]|\.\.|\*{1,2}/,punctuation:/[\[\]{},]/}},key:{pattern:/(^[ \t]*)[^\s=]+(?=[ \t]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/=.*/,alias:"attr-value",inside:{punctuation:/^=/}}}}return Ry}var Cy,DI;function tge(){if(DI)return Cy;DI=1,Cy=e,e.displayName="eiffel",e.aliases=[];function e(t){t.languages.eiffel={comment:/--.*/,string:[{pattern:/"([^[]*)\[[\s\S]*?\]\1"/,greedy:!0},{pattern:/"([^{]*)\{[\s\S]*?\}\1"/,greedy:!0},{pattern:/"(?:%(?:(?!\n)\s)*\n\s*%|%\S|[^%"\r\n])*"/,greedy:!0}],char:/'(?:%.|[^%'\r\n])+'/,keyword:/\b(?:across|agent|alias|all|and|as|assign|attached|attribute|check|class|convert|create|Current|debug|deferred|detachable|do|else|elseif|end|ensure|expanded|export|external|feature|from|frozen|if|implies|inherit|inspect|invariant|like|local|loop|not|note|obsolete|old|once|or|Precursor|redefine|rename|require|rescue|Result|retry|select|separate|some|then|undefine|until|variant|Void|when|xor)\b/i,boolean:/\b(?:False|True)\b/i,"class-name":/\b[A-Z][\dA-Z_]*\b/,number:[/\b0[xcb][\da-f](?:_*[\da-f])*\b/i,/(?:\b\d(?:_*\d)*)?\.(?:(?:\d(?:_*\d)*)?e[+-]?)?\d(?:_*\d)*\b|\b\d(?:_*\d)*\b\.?/i],punctuation:/:=|<<|>>|\(\||\|\)|->|\.(?=\w)|[{}[\];(),:?]/,operator:/\\\\|\|\.\.\||\.\.|\/[~\/=]?|[><]=?|[-+*^=~]/}}return Cy}var Ny,II;function nge(){if(II)return Ny;II=1;var e=Gn();Ny=t,t.displayName="ejs",t.aliases=["eta"];function t(n){n.register(e),function(r){r.languages.ejs={delimiter:{pattern:/^<%[-_=]?|[-_]?%>$/,alias:"punctuation"},comment:/^#[\s\S]*/,"language-javascript":{pattern:/[\s\S]+/,inside:r.languages.javascript}},r.hooks.add("before-tokenize",function(a){var i=/<%(?!%)[\s\S]+?%>/g;r.languages["markup-templating"].buildPlaceholders(a,"ejs",i)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"ejs")}),r.languages.eta=r.languages.ejs}(n)}return Ny}var Oy,LI;function rge(){if(LI)return Oy;LI=1,Oy=e,e.displayName="elixir",e.aliases=[];function e(t){t.languages.elixir={doc:{pattern:/@(?:doc|moduledoc)\s+(?:("""|''')[\s\S]*?\1|("|')(?:\\(?:\r\n|[\s\S])|(?!\2)[^\\\r\n])*\2)/,inside:{attribute:/^@\w+/,string:/['"][\s\S]+/}},comment:{pattern:/#.*/,greedy:!0},regex:{pattern:/~[rR](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|[^\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[uismxfr]*/,greedy:!0},string:[{pattern:/~[cCsSwW](?:("""|''')(?:\\[\s\S]|(?!\1)[^\\])+\1|([\/|"'])(?:\\.|(?!\2)[^\\\r\n])+\2|\((?:\\.|[^\\)\r\n])+\)|\[(?:\\.|[^\\\]\r\n])+\]|\{(?:\\.|#\{[^}]+\}|#(?!\{)|[^#\\}\r\n])+\}|<(?:\\.|[^\\>\r\n])+>)[csa]?/,greedy:!0,inside:{}},{pattern:/("""|''')[\s\S]*?\1/,greedy:!0,inside:{}},{pattern:/("|')(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0,inside:{}}],atom:{pattern:/(^|[^:]):\w+/,lookbehind:!0,alias:"symbol"},module:{pattern:/\b[A-Z]\w*\b/,alias:"class-name"},"attr-name":/\b\w+\??:(?!:)/,argument:{pattern:/(^|[^&])&\d+/,lookbehind:!0,alias:"variable"},attribute:{pattern:/@\w+/,alias:"variable"},function:/\b[_a-zA-Z]\w*[?!]?(?:(?=\s*(?:\.\s*)?\()|(?=\/\d))/,number:/\b(?:0[box][a-f\d_]+|\d[\d_]*)(?:\.[\d_]+)?(?:e[+-]?[\d_]+)?\b/i,keyword:/\b(?:after|alias|and|case|catch|cond|def(?:callback|delegate|exception|impl|macro|module|n|np|p|protocol|struct)?|do|else|end|fn|for|if|import|not|or|quote|raise|require|rescue|try|unless|unquote|use|when)\b/,boolean:/\b(?:false|nil|true)\b/,operator:[/\bin\b|&&?|\|[|>]?|\\\\|::|\.\.\.?|\+\+?|-[->]?|<[-=>]|>=|!==?|\B!|=(?:==?|[>~])?|[*\/^]/,{pattern:/([^<])<(?!<)/,lookbehind:!0},{pattern:/([^>])>(?!>)/,lookbehind:!0}],punctuation:/<<|>>|[.,%\[\]{}()]/},t.languages.elixir.string.forEach(function(n){n.inside={interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},rest:t.languages.elixir}}}})}return Oy}var Dy,MI;function age(){if(MI)return Dy;MI=1,Dy=e,e.displayName="elm",e.aliases=[];function e(t){t.languages.elm={comment:/--.*|\{-[\s\S]*?-\}/,char:{pattern:/'(?:[^\\'\r\n]|\\(?:[abfnrtv\\']|\d+|x[0-9a-fA-F]+|u\{[0-9a-fA-F]+\}))'/,greedy:!0},string:[{pattern:/"""[\s\S]*?"""/,greedy:!0},{pattern:/"(?:[^\\"\r\n]|\\.)*"/,greedy:!0}],"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z]\w*(?:\.[A-Z]\w*)*(?:\s+as\s+(?:[A-Z]\w*)(?:\.[A-Z]\w*)*)?(?:\s+exposing\s+)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|exposing|import)\b/}},keyword:/\b(?:alias|as|case|else|exposing|if|in|infixl|infixr|let|module|of|then|type)\b/,builtin:/\b(?:abs|acos|always|asin|atan|atan2|ceiling|clamp|compare|cos|curry|degrees|e|flip|floor|fromPolar|identity|isInfinite|isNaN|logBase|max|min|negate|never|not|pi|radians|rem|round|sin|sqrt|tan|toFloat|toPolar|toString|truncate|turns|uncurry|xor)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0x[0-9a-f]+)\b/i,operator:/\s\.\s|[+\-/*=.$<>:&|^?%#@~!]{2,}|[+\-/*=$<>:&|^?%#@~!]/,hvariable:/\b(?:[A-Z]\w*\.)*[a-z]\w*\b/,constant:/\b(?:[A-Z]\w*\.)*[A-Z]\w*\b/,punctuation:/[{}[\]|(),.:]/}}return Dy}var Iy,FI;function oge(){if(FI)return Iy;FI=1;var e=Wf(),t=Gn();Iy=n,n.displayName="erb",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.erb={delimiter:{pattern:/^(\s*)<%=?|%>(?=\s*$)/,lookbehind:!0,alias:"punctuation"},ruby:{pattern:/\s*\S[\s\S]*/,alias:"language-ruby",inside:a.languages.ruby}},a.hooks.add("before-tokenize",function(i){var l=/<%=?(?:[^\r\n]|[\r\n](?!=begin)|[\r\n]=begin\s(?:[^\r\n]|[\r\n](?!=end))*[\r\n]=end)+?%>/g;a.languages["markup-templating"].buildPlaceholders(i,"erb",l)}),a.hooks.add("after-tokenize",function(i){a.languages["markup-templating"].tokenizePlaceholders(i,"erb")})}(r)}return Iy}var Ly,zI;function ige(){if(zI)return Ly;zI=1,Ly=e,e.displayName="erlang",e.aliases=[];function e(t){t.languages.erlang={comment:/%.+/,string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},"quoted-function":{pattern:/'(?:\\.|[^\\'\r\n])+'(?=\()/,alias:"function"},"quoted-atom":{pattern:/'(?:\\.|[^\\'\r\n])+'/,alias:"atom"},boolean:/\b(?:false|true)\b/,keyword:/\b(?:after|case|catch|end|fun|if|of|receive|try|when)\b/,number:[/\$\\?./,/\b\d+#[a-z0-9]+/i,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i],function:/\b[a-z][\w@]*(?=\()/,variable:{pattern:/(^|[^@])(?:\b|\?)[A-Z_][\w@]*/,lookbehind:!0},operator:[/[=\/<>:]=|=[:\/]=|\+\+?|--?|[=*\/!]|\b(?:and|andalso|band|bnot|bor|bsl|bsr|bxor|div|not|or|orelse|rem|xor)\b/,{pattern:/(^|[^<])<(?!<)/,lookbehind:!0},{pattern:/(^|[^>])>(?!>)/,lookbehind:!0}],atom:/\b[a-z][\w@]*/,punctuation:/[()[\]{}:;,.#|]|<<|>>/}}return Ly}var My,PI;function Y5(){if(PI)return My;PI=1,My=e,e.displayName="lua",e.aliases=[];function e(t){t.languages.lua={comment:/^#!.+|--(?:\[(=*)\[[\s\S]*?\]\1\]|.*)/m,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n]|\\z(?:\r\n|\s)|\\(?:\r\n|[^z]))*\1|\[(=*)\[[\s\S]*?\]\2\]/,greedy:!0},number:/\b0x[a-f\d]+(?:\.[a-f\d]*)?(?:p[+-]?\d+)?\b|\b\d+(?:\.\B|(?:\.\d*)?(?:e[+-]?\d+)?\b)|\B\.\d+(?:e[+-]?\d+)?\b/i,keyword:/\b(?:and|break|do|else|elseif|end|false|for|function|goto|if|in|local|nil|not|or|repeat|return|then|true|until|while)\b/,function:/(?!\d)\w+(?=\s*(?:[({]))/,operator:[/[-+*%^&|#]|\/\/?|<[<=]?|>[>=]?|[=~]=?/,{pattern:/(^|[^.])\.\.(?!\.)/,lookbehind:!0}],punctuation:/[\[\](){},;]|\.+|:+/}}return My}var Fy,BI;function lge(){if(BI)return Fy;BI=1;var e=Y5(),t=Gn();Fy=n,n.displayName="etlua",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.etlua={delimiter:{pattern:/^<%[-=]?|-?%>$/,alias:"punctuation"},"language-lua":{pattern:/[\s\S]+/,inside:a.languages.lua}},a.hooks.add("before-tokenize",function(i){var l=/<%[\s\S]+?%>/g;a.languages["markup-templating"].buildPlaceholders(i,"etlua",l)}),a.hooks.add("after-tokenize",function(i){a.languages["markup-templating"].tokenizePlaceholders(i,"etlua")})}(r)}return Fy}var zy,UI;function sge(){if(UI)return zy;UI=1,zy=e,e.displayName="excelFormula",e.aliases=[];function e(t){t.languages["excel-formula"]={comment:{pattern:/(\bN\(\s*)"(?:[^"]|"")*"(?=\s*\))/i,lookbehind:!0,greedy:!0},string:{pattern:/"(?:[^"]|"")*"(?!")/,greedy:!0},reference:{pattern:/(?:'[^']*'|(?:[^\s()[\]{}<>*?"';,$&]*\[[^^\s()[\]{}<>*?"']+\])?\w+)!/,greedy:!0,alias:"string",inside:{operator:/!$/,punctuation:/'/,sheet:{pattern:/[^[\]]+$/,alias:"function"},file:{pattern:/\[[^[\]]+\]$/,inside:{punctuation:/[[\]]/}},path:/[\s\S]+/}},"function-name":{pattern:/\b[A-Z]\w*(?=\()/i,alias:"keyword"},range:{pattern:/\$?\b(?:[A-Z]+\$?\d+:\$?[A-Z]+\$?\d+|[A-Z]+:\$?[A-Z]+|\d+:\$?\d+)\b/i,alias:"property",inside:{operator:/:/,cell:/\$?[A-Z]+\$?\d+/i,column:/\$?[A-Z]+/i,row:/\$?\d+/}},cell:{pattern:/\b[A-Z]+\d+\b|\$[A-Za-z]+\$?\d+\b|\b[A-Za-z]+\$\d+\b/,alias:"property"},number:/(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?\b/i,boolean:/\b(?:FALSE|TRUE)\b/i,operator:/[-+*/^%=&,]|<[=>]?|>=?/,punctuation:/[[\]();{}|]/},t.languages.xlsx=t.languages.xls=t.languages["excel-formula"]}return zy}var Py,jI;function uge(){if(jI)return Py;jI=1,Py=e,e.displayName="factor",e.aliases=[];function e(t){(function(n){var r={function:/\b(?:BUGS?|FIX(?:MES?)?|NOTES?|TODOS?|XX+|HACKS?|WARN(?:ING)?|\?{2,}|!{2,})\b/},a={number:/\\[^\s']|%\w/},i={comment:[{pattern:/(^|\s)(?:! .*|!$)/,lookbehind:!0,inside:r},{pattern:/(^|\s)\/\*\s[\s\S]*?\*\/(?=\s|$)/,lookbehind:!0,greedy:!0,inside:r},{pattern:/(^|\s)!\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,inside:r}],number:[{pattern:/(^|\s)[+-]?\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b[01]+|o[0-7]+|d\d+|x[\dA-F]+)(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)[+-]?\d+\/\d+\.?(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)\+?\d+\+\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)-\d+-\d+\/\d+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?(?:\d*\.\d+|\d+\.\d*|\d+)(?:e[+-]?\d+)?(?=\s|$)/i,lookbehind:!0},{pattern:/(^|\s)NAN:\s+[\da-fA-F]+(?=\s|$)/,lookbehind:!0},{pattern:/(^|\s)[+-]?0(?:b1\.[01]*|o1\.[0-7]*|d1\.\d*|x1\.[\dA-F]*)p\d+(?=\s|$)/i,lookbehind:!0}],regexp:{pattern:/(^|\s)R\/\s(?:\\\S|[^\\/])*\/(?:[idmsr]*|[idmsr]+-[idmsr]+)(?=\s|$)/,lookbehind:!0,alias:"number",inside:{variable:/\\\S/,keyword:/[+?*\[\]^$(){}.|]/,operator:{pattern:/(\/)[idmsr]+(?:-[idmsr]+)?/,lookbehind:!0}}},boolean:{pattern:/(^|\s)[tf](?=\s|$)/,lookbehind:!0},"custom-string":{pattern:/(^|\s)[A-Z0-9\-]+"\s(?:\\\S|[^"\\])*"/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:/\\\S|%\w|\//}},"multiline-string":[{pattern:/(^|\s)STRING:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*;(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:{number:a.number,"semicolon-or-setlocal":{pattern:/([\r\n][ \t]*);(?=\s|$)/,lookbehind:!0,alias:"function"}}},{pattern:/(^|\s)HEREDOC:\s+\S+(?:\n|\r\n).*(?:\n|\r\n)\s*\S+(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:a},{pattern:/(^|\s)\[(={0,6})\[\s[\s\S]*?\]\2\](?=\s|$)/,lookbehind:!0,greedy:!0,alias:"string",inside:a}],"special-using":{pattern:/(^|\s)USING:(?:\s\S+)*(?=\s+;(?:\s|$))/,lookbehind:!0,alias:"function",inside:{string:{pattern:/(\s)[^:\s]+/,lookbehind:!0}}},"stack-effect-delimiter":[{pattern:/(^|\s)(?:call|eval|execute)?\((?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)--(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\)(?=\s|$)/,lookbehind:!0,alias:"operator"}],combinators:{pattern:null,lookbehind:!0,alias:"keyword"},"kernel-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"sequences-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"math-builtin":{pattern:null,lookbehind:!0,alias:"variable"},"constructor-word":{pattern:/(^|\s)<(?!=+>|-+>)\S+>(?=\s|$)/,lookbehind:!0,alias:"keyword"},"other-builtin-syntax":{pattern:null,lookbehind:!0,alias:"operator"},"conventionally-named-word":{pattern:/(^|\s)(?!")(?:(?:change|new|set|with)-\S+|\$\S+|>[^>\s]+|[^:>\s]+>|[^>\s]+>[^>\s]+|\+[^+\s]+\+|[^?\s]+\?|\?[^?\s]+|[^>\s]+>>|>>[^>\s]+|[^<\s]+<<|\([^()\s]+\)|[^!\s]+!|[^*\s]\S*\*|[^.\s]\S*\.)(?=\s|$)/,lookbehind:!0,alias:"keyword"},"colon-syntax":{pattern:/(^|\s)(?:[A-Z0-9\-]+#?)?:{1,2}\s+(?:;\S+|(?!;)\S+)(?=\s|$)/,lookbehind:!0,greedy:!0,alias:"function"},"semicolon-or-setlocal":{pattern:/(\s)(?:;|:>)(?=\s|$)/,lookbehind:!0,alias:"function"},"curly-brace-literal-delimiter":[{pattern:/(^|\s)[a-z]*\{(?=\s)/i,lookbehind:!0,alias:"operator"},{pattern:/(\s)\}(?=\s|$)/,lookbehind:!0,alias:"operator"}],"quotation-delimiter":[{pattern:/(^|\s)\[(?=\s)/,lookbehind:!0,alias:"operator"},{pattern:/(\s)\](?=\s|$)/,lookbehind:!0,alias:"operator"}],"normal-word":{pattern:/(^|\s)[^"\s]\S*(?=\s|$)/,lookbehind:!0},string:{pattern:/"(?:\\\S|[^"\\])*"/,greedy:!0,inside:a}},l=function(p){return(p+"").replace(/([.?*+\^$\[\]\\(){}|\-])/g,"\\$1")},u=function(p){return new RegExp("(^|\\s)(?:"+p.map(l).join("|")+")(?=\\s|$)")},c={"kernel-builtin":["or","2nipd","4drop","tuck","wrapper","nip","wrapper?","callstack>array","die","dupd","callstack","callstack?","3dup","hashcode","pick","4nip","build",">boolean","nipd","clone","5nip","eq?","?","=","swapd","2over","clear","2dup","get-retainstack","not","tuple?","dup","3nipd","call","-rotd","object","drop","assert=","assert?","-rot","execute","boa","get-callstack","curried?","3drop","pickd","overd","over","roll","3nip","swap","and","2nip","rotd","throw","(clone)","hashcode*","spin","reach","4dup","equal?","get-datastack","assert","2drop","<wrapper>","boolean?","identity-hashcode","identity-tuple?","null","composed?","new","5drop","rot","-roll","xor","identity-tuple","boolean"],"other-builtin-syntax":["=======","recursive","flushable",">>","<<<<<<","M\\","B","PRIVATE>","\\","======","final","inline","delimiter","deprecated","<PRIVATE",">>>>>>","<<<<<<<","parse-complex","malformed-complex","read-only",">>>>>>>","call-next-method","<<","foldable","$","$[","${"],"sequences-builtin":["member-eq?","mismatch","append","assert-sequence=","longer","repetition","clone-like","3sequence","assert-sequence?","last-index-from","reversed","index-from","cut*","pad-tail","join-as","remove-eq!","concat-as","but-last","snip","nths","nth","sequence","longest","slice?","<slice>","remove-nth","tail-slice","empty?","tail*","member?","virtual-sequence?","set-length","drop-prefix","iota","unclip","bounds-error?","unclip-last-slice","non-negative-integer-expected","non-negative-integer-expected?","midpoint@","longer?","?set-nth","?first","rest-slice","prepend-as","prepend","fourth","sift","subseq-start","new-sequence","?last","like","first4","1sequence","reverse","slice","virtual@","repetition?","set-last","index","4sequence","max-length","set-second","immutable-sequence","first2","first3","supremum","unclip-slice","suffix!","insert-nth","tail","3append","short","suffix","concat","flip","immutable?","reverse!","2sequence","sum","delete-all","indices","snip-slice","<iota>","check-slice","sequence?","head","append-as","halves","sequence=","collapse-slice","?second","slice-error?","product","bounds-check?","bounds-check","immutable","virtual-exemplar","harvest","remove","pad-head","last","set-fourth","cartesian-product","remove-eq","shorten","shorter","reversed?","shorter?","shortest","head-slice","pop*","tail-slice*","but-last-slice","iota?","append!","cut-slice","new-resizable","head-slice*","sequence-hashcode","pop","set-nth","?nth","second","join","immutable-sequence?","<reversed>","3append-as","virtual-sequence","subseq?","remove-nth!","length","last-index","lengthen","assert-sequence","copy","move","third","first","tail?","set-first","prefix","bounds-error","<repetition>","exchange","surround","cut","min-length","set-third","push-all","head?","subseq-start-from","delete-slice","rest","sum-lengths","head*","infimum","remove!","glue","slice-error","subseq","push","replace-slice","subseq-as","unclip-last"],"math-builtin":["number=","next-power-of-2","?1+","fp-special?","imaginary-part","float>bits","number?","fp-infinity?","bignum?","fp-snan?","denominator","gcd","*","+","fp-bitwise=","-","u>=","/",">=","bitand","power-of-2?","log2-expects-positive","neg?","<","log2",">","integer?","number","bits>double","2/","zero?","bits>float","float?","shift","ratio?","rect>","even?","ratio","fp-sign","bitnot",">fixnum","complex?","/i","integer>fixnum","/f","sgn",">bignum","next-float","u<","u>","mod","recip","rational",">float","2^","integer","fixnum?","neg","fixnum","sq","bignum",">rect","bit?","fp-qnan?","simple-gcd","complex","<fp-nan>","real",">fraction","double>bits","bitor","rem","fp-nan-payload","real-part","log2-expects-positive?","prev-float","align","unordered?","float","fp-nan?","abs","bitxor","integer>fixnum-strict","u<=","odd?","<=","/mod",">integer","real?","rational?","numerator"]};Object.keys(c).forEach(function(p){i[p].pattern=u(c[p])});var f=["2bi","while","2tri","bi*","4dip","both?","same?","tri@","curry","prepose","3bi","?if","tri*","2keep","3keep","curried","2keepd","when","2bi*","2tri*","4keep","bi@","keepdd","do","unless*","tri-curry","if*","loop","bi-curry*","when*","2bi@","2tri@","with","2with","either?","bi","until","3dip","3curry","tri-curry*","tri-curry@","bi-curry","keepd","compose","2dip","if","3tri","unless","tuple","keep","2curry","tri","most","while*","dip","composed","bi-curry@","find-last-from","trim-head-slice","map-as","each-from","none?","trim-tail","partition","if-empty","accumulate*","reject!","find-from","accumulate-as","collector-for-as","reject","map","map-sum","accumulate!","2each-from","follow","supremum-by","map!","unless-empty","collector","padding","reduce-index","replicate-as","infimum-by","trim-tail-slice","count","find-index","filter","accumulate*!","reject-as","map-integers","map-find","reduce","selector","interleave","2map","filter-as","binary-reduce","map-index-as","find","produce","filter!","replicate","cartesian-map","cartesian-each","find-index-from","map-find-last","3map-as","3map","find-last","selector-as","2map-as","2map-reduce","accumulate","each","each-index","accumulate*-as","when-empty","all?","collector-as","push-either","new-like","collector-for","2selector","push-if","2all?","map-reduce","3each","any?","trim-slice","2reduce","change-nth","produce-as","2each","trim","trim-head","cartesian-find","map-index","if-zero","each-integer","unless-zero","(find-integer)","when-zero","find-last-integer","(all-integers?)","times","(each-integer)","find-integer","all-integers?","unless-negative","if-positive","when-positive","when-negative","unless-positive","if-negative","case","2cleave","cond>quot","case>quot","3cleave","wrong-values","to-fixed-point","alist>quot","cond","cleave","call-effect","recursive-hashcode","spread","deep-spread>quot","2||","0||","n||","0&&","2&&","3||","1||","1&&","n&&","3&&","smart-unless*","keep-inputs","reduce-outputs","smart-when*","cleave>array","smart-with","smart-apply","smart-if","inputs/outputs","output>sequence-n","map-outputs","map-reduce-outputs","dropping","output>array","smart-map-reduce","smart-2map-reduce","output>array-n","nullary","input<sequence","append-outputs","drop-inputs","inputs","smart-2reduce","drop-outputs","smart-reduce","preserving","smart-when","outputs","append-outputs-as","smart-unless","smart-if*","sum-outputs","input<sequence-unsafe","output>sequence"];i.combinators.pattern=u(f),n.languages.factor=i})(t)}return Py}var By,GI;function cge(){if(GI)return By;GI=1,By=e,e.displayName="$false",e.aliases=[];function e(t){(function(n){n.languages.false={comment:{pattern:/\{[^}]*\}/},string:{pattern:/"[^"]*"/,greedy:!0},"character-code":{pattern:/'(?:[^\r]|\r\n?)/,alias:"number"},"assembler-code":{pattern:/\d+`/,alias:"important"},number:/\d+/,operator:/[-!#$%&'*+,./:;=>?@\\^_`|~ßø]/,punctuation:/\[|\]/,variable:/[a-z]/,"non-standard":{pattern:/[()<BDO®]/,alias:"bold"}}})(t)}return By}var Uy,HI;function dge(){if(HI)return Uy;HI=1,Uy=e,e.displayName="firestoreSecurityRules",e.aliases=[];function e(t){t.languages["firestore-security-rules"]=t.languages.extend("clike",{comment:/\/\/.*/,keyword:/\b(?:allow|function|if|match|null|return|rules_version|service)\b/,operator:/&&|\|\||[<>!=]=?|[-+*/%]|\b(?:in|is)\b/}),delete t.languages["firestore-security-rules"]["class-name"],t.languages.insertBefore("firestore-security-rules","keyword",{path:{pattern:/(^|[\s(),])(?:\/(?:[\w\xA0-\uFFFF]+|\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)))+/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/\{[\w\xA0-\uFFFF]+(?:=\*\*)?\}|\$\([\w\xA0-\uFFFF.]+\)/,inside:{operator:/=/,keyword:/\*\*/,punctuation:/[.$(){}]/}},punctuation:/\//}},method:{pattern:/(\ballow\s+)[a-z]+(?:\s*,\s*[a-z]+)*(?=\s*[:;])/,lookbehind:!0,alias:"builtin",inside:{punctuation:/,/}}})}return Uy}var jy,$I;function fge(){if($I)return jy;$I=1,jy=e,e.displayName="flow",e.aliases=[];function e(t){(function(n){n.languages.flow=n.languages.extend("javascript",{}),n.languages.insertBefore("flow","keyword",{type:[{pattern:/\b(?:[Bb]oolean|Function|[Nn]umber|[Ss]tring|any|mixed|null|void)\b/,alias:"tag"}]}),n.languages.flow["function-variable"].pattern=/(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*=\s*(?:function\b|(?:\([^()]*\)(?:\s*:\s*\w+)?|(?!\s)[_$a-z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)\s*=>))/i,delete n.languages.flow.parameter,n.languages.insertBefore("flow","operator",{"flow-punctuation":{pattern:/\{\||\|\}/,alias:"punctuation"}}),Array.isArray(n.languages.flow.keyword)||(n.languages.flow.keyword=[n.languages.flow.keyword]),n.languages.flow.keyword.unshift({pattern:/(^|[^$]\b)(?:Class|declare|opaque|type)\b(?!\$)/,lookbehind:!0},{pattern:/(^|[^$]\B)\$(?:Diff|Enum|Exact|Keys|ObjMap|PropertyType|Record|Shape|Subtype|Supertype|await)\b(?!\$)/,lookbehind:!0})})(t)}return jy}var Gy,qI;function pge(){if(qI)return Gy;qI=1,Gy=e,e.displayName="fortran",e.aliases=[];function e(t){t.languages.fortran={"quoted-number":{pattern:/[BOZ](['"])[A-F0-9]+\1/i,alias:"number"},string:{pattern:/(?:\b\w+_)?(['"])(?:\1\1|&(?:\r\n?|\n)(?:[ \t]*!.*(?:\r\n?|\n)|(?![ \t]*!))|(?!\1).)*(?:\1|&)/,inside:{comment:{pattern:/(&(?:\r\n?|\n)\s*)!.*/,lookbehind:!0}}},comment:{pattern:/!.*/,greedy:!0},boolean:/\.(?:FALSE|TRUE)\.(?:_\w+)?/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[ED][+-]?\d+)?(?:_\w+)?/i,keyword:[/\b(?:CHARACTER|COMPLEX|DOUBLE ?PRECISION|INTEGER|LOGICAL|REAL)\b/i,/\b(?:END ?)?(?:BLOCK ?DATA|DO|FILE|FORALL|FUNCTION|IF|INTERFACE|MODULE(?! PROCEDURE)|PROGRAM|SELECT|SUBROUTINE|TYPE|WHERE)\b/i,/\b(?:ALLOCATABLE|ALLOCATE|BACKSPACE|CALL|CASE|CLOSE|COMMON|CONTAINS|CONTINUE|CYCLE|DATA|DEALLOCATE|DIMENSION|DO|END|EQUIVALENCE|EXIT|EXTERNAL|FORMAT|GO ?TO|IMPLICIT(?: NONE)?|INQUIRE|INTENT|INTRINSIC|MODULE PROCEDURE|NAMELIST|NULLIFY|OPEN|OPTIONAL|PARAMETER|POINTER|PRINT|PRIVATE|PUBLIC|READ|RETURN|REWIND|SAVE|SELECT|STOP|TARGET|WHILE|WRITE)\b/i,/\b(?:ASSIGNMENT|DEFAULT|ELEMENTAL|ELSE|ELSEIF|ELSEWHERE|ENTRY|IN|INCLUDE|INOUT|KIND|NULL|ONLY|OPERATOR|OUT|PURE|RECURSIVE|RESULT|SEQUENCE|STAT|THEN|USE)\b/i],operator:[/\*\*|\/\/|=>|[=\/]=|[<>]=?|::|[+\-*=%]|\.[A-Z]+\./i,{pattern:/(^|(?!\().)\/(?!\))/,lookbehind:!0}],punctuation:/\(\/|\/\)|[(),;:&]/}}return Gy}var Hy,VI;function gge(){if(VI)return Hy;VI=1,Hy=e,e.displayName="fsharp",e.aliases=[];function e(t){t.languages.fsharp=t.languages.extend("clike",{comment:[{pattern:/(^|[^\\])\(\*(?!\))[\s\S]*?\*\)/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(?:"""[\s\S]*?"""|@"(?:""|[^"])*"|"(?:\\[\s\S]|[^\\"])*")B?/,greedy:!0},"class-name":{pattern:/(\b(?:exception|inherit|interface|new|of|type)\s+|\w\s*:\s*|\s:\??>\s*)[.\w]+\b(?:\s*(?:->|\*)\s*[.\w]+\b)*(?!\s*[:.])/,lookbehind:!0,inside:{operator:/->|\*/,punctuation:/\./}},keyword:/\b(?:let|return|use|yield)(?:!\B|\b)|\b(?:abstract|and|as|asr|assert|atomic|base|begin|break|checked|class|component|const|constraint|constructor|continue|default|delegate|do|done|downcast|downto|eager|elif|else|end|event|exception|extern|external|false|finally|fixed|for|fun|function|functor|global|if|in|include|inherit|inline|interface|internal|land|lazy|lor|lsl|lsr|lxor|match|member|method|mixin|mod|module|mutable|namespace|new|not|null|object|of|open|or|override|parallel|private|process|protected|public|pure|rec|sealed|select|sig|static|struct|tailcall|then|to|trait|true|try|type|upcast|val|virtual|void|volatile|when|while|with)\b/,number:[/\b0x[\da-fA-F]+(?:LF|lf|un)?\b/,/\b0b[01]+(?:uy|y)?\b/,/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[fm]|e[+-]?\d+)?\b/i,/\b\d+(?:[IlLsy]|UL|u[lsy]?)?\b/],operator:/([<>~&^])\1\1|([*.:<>&])\2|<-|->|[!=:]=|<?\|{1,3}>?|\??(?:<=|>=|<>|[-+*/%=<>])\??|[!?^&]|~[+~-]|:>|:\?>?/}),t.languages.insertBefore("fsharp","keyword",{preprocessor:{pattern:/(^[\t ]*)#.*/m,lookbehind:!0,alias:"property",inside:{directive:{pattern:/(^#)\b(?:else|endif|if|light|line|nowarn)\b/,lookbehind:!0,alias:"keyword"}}}}),t.languages.insertBefore("fsharp","punctuation",{"computation-expression":{pattern:/\b[_a-z]\w*(?=\s*\{)/i,alias:"keyword"}}),t.languages.insertBefore("fsharp","string",{annotation:{pattern:/\[<.+?>\]/,greedy:!0,inside:{punctuation:/^\[<|>\]$/,"class-name":{pattern:/^\w+$|(^|;\s*)[A-Z]\w*(?=\()/,lookbehind:!0},"annotation-content":{pattern:/[\s\S]+/,inside:t.languages.fsharp}}},char:{pattern:/'(?:[^\\']|\\(?:.|\d{3}|x[a-fA-F\d]{2}|u[a-fA-F\d]{4}|U[a-fA-F\d]{8}))'B?/,greedy:!0}})}return Hy}var $y,WI;function hge(){if(WI)return $y;WI=1;var e=Gn();$y=t,t.displayName="ftl",t.aliases=[];function t(n){n.register(e),function(r){for(var a=/[^<()"']|\((?:<expr>)*\)|<(?!#--)|<#--(?:[^-]|-(?!->))*-->|"(?:[^\\"]|\\.)*"|'(?:[^\\']|\\.)*'/.source,i=0;i<2;i++)a=a.replace(/<expr>/g,function(){return a});a=a.replace(/<expr>/g,/[^\s\S]/.source);var l={comment:/<#--[\s\S]*?-->/,string:[{pattern:/\br("|')(?:(?!\1)[^\\]|\\.)*\1/,greedy:!0},{pattern:RegExp(/("|')(?:(?!\1|\$\{)[^\\]|\\.|\$\{(?:(?!\})(?:<expr>))*\})*\1/.source.replace(/<expr>/g,function(){return a})),greedy:!0,inside:{interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\\\)*)\$\{(?:(?!\})(?:<expr>))*\}/.source.replace(/<expr>/g,function(){return a})),lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},rest:null}}}}],keyword:/\b(?:as)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/((?:^|[^?])\?\s*)\w+/,lookbehind:!0,alias:"function"},function:/\b\w+(?=\s*\()/,number:/\b\d+(?:\.\d+)?\b/,operator:/\.\.[<*!]?|->|--|\+\+|&&|\|\||\?{1,2}|[-+*/%!=<>]=?|\b(?:gt|gte|lt|lte)\b/,punctuation:/[,;.:()[\]{}]/};l.string[1].inside.interpolation.inside.rest=l,r.languages.ftl={"ftl-comment":{pattern:/^<#--[\s\S]*/,alias:"comment"},"ftl-directive":{pattern:/^<[\s\S]+>$/,inside:{directive:{pattern:/(^<\/?)[#@][a-z]\w*/i,lookbehind:!0,alias:"keyword"},punctuation:/^<\/?|\/?>$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:l}}},"ftl-interpolation":{pattern:/^\$\{[\s\S]*\}$/,inside:{punctuation:/^\$\{|\}$/,content:{pattern:/\s*\S[\s\S]*/,alias:"ftl",inside:l}}}},r.hooks.add("before-tokenize",function(u){var c=RegExp(/<#--[\s\S]*?-->|<\/?[#@][a-zA-Z](?:<expr>)*?>|\$\{(?:<expr>)*?\}/.source.replace(/<expr>/g,function(){return a}),"gi");r.languages["markup-templating"].buildPlaceholders(u,"ftl",c)}),r.hooks.add("after-tokenize",function(u){r.languages["markup-templating"].tokenizePlaceholders(u,"ftl")})}(n)}return $y}var qy,YI;function mge(){if(YI)return qy;YI=1,qy=e,e.displayName="gap",e.aliases=[];function e(t){t.languages.gap={shell:{pattern:/^gap>[\s\S]*?(?=^gap>|$(?![\s\S]))/m,greedy:!0,inside:{gap:{pattern:/^(gap>).+(?:(?:\r(?:\n|(?!\n))|\n)>.*)*/,lookbehind:!0,inside:null},punctuation:/^gap>/}},comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(^|[^\\'"])(?:'(?:[^\r\n\\']|\\.){1,10}'|"(?:[^\r\n\\"]|\\.)*"(?!")|"""[\s\S]*?""")/,lookbehind:!0,greedy:!0,inside:{continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"}}},keyword:/\b(?:Assert|Info|IsBound|QUIT|TryNextMethod|Unbind|and|atomic|break|continue|do|elif|else|end|fi|for|function|if|in|local|mod|not|od|or|quit|readonly|readwrite|rec|repeat|return|then|until|while)\b/,boolean:/\b(?:false|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},continuation:{pattern:/([\r\n])>/,lookbehind:!0,alias:"punctuation"},operator:/->|[-+*/^~=!]|<>|[<>]=?|:=|\.\./,punctuation:/[()[\]{},;.:]/},t.languages.gap.shell.inside.gap.inside=t.languages.gap}return qy}var Vy,KI;function bge(){if(KI)return Vy;KI=1,Vy=e,e.displayName="gcode",e.aliases=[];function e(t){t.languages.gcode={comment:/;.*|\B\(.*?\)\B/,string:{pattern:/"(?:""|[^"])*"/,greedy:!0},keyword:/\b[GM]\d+(?:\.\d+)?\b/,property:/\b[A-Z]/,checksum:{pattern:/(\*)\d+/,lookbehind:!0,alias:"number"},punctuation:/[:*]/}}return Vy}var Wy,XI;function yge(){if(XI)return Wy;XI=1,Wy=e,e.displayName="gdscript",e.aliases=[];function e(t){t.languages.gdscript={comment:/#.*/,string:{pattern:/@?(?:("|')(?:(?!\1)[^\n\\]|\\[\s\S])*\1(?!"|')|"""(?:[^\\]|\\[\s\S])*?""")/,greedy:!0},"class-name":{pattern:/(^(?:class|class_name|extends)[ \t]+|^export\([ \t]*|\bas[ \t]+|(?:\b(?:const|var)[ \t]|[,(])[ \t]*\w+[ \t]*:[ \t]*|->[ \t]*)[a-zA-Z_]\w*/m,lookbehind:!0},keyword:/\b(?:and|as|assert|break|breakpoint|class|class_name|const|continue|elif|else|enum|export|extends|for|func|if|in|is|master|mastersync|match|not|null|onready|or|pass|preload|puppet|puppetsync|remote|remotesync|return|self|setget|signal|static|tool|var|while|yield)\b/,function:/\b[a-z_]\w*(?=[ \t]*\()/i,variable:/\$\w+/,number:[/\b0b[01_]+\b|\b0x[\da-fA-F_]+\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.[\d_]+)(?:e[+-]?[\d_]+)?\b/,/\b(?:INF|NAN|PI|TAU)\b/],constant:/\b[A-Z][A-Z_\d]*\b/,boolean:/\b(?:false|true)\b/,operator:/->|:=|&&|\|\||<<|>>|[-+*/%&|!<>=]=?|[~^]/,punctuation:/[.:,;()[\]{}]/}}return Wy}var Yy,ZI;function vge(){if(ZI)return Yy;ZI=1,Yy=e,e.displayName="gedcom",e.aliases=[];function e(t){t.languages.gedcom={"line-value":{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?\w+ ).+/m,lookbehind:!0,inside:{pointer:{pattern:/^@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@$/,alias:"variable"}}},tag:{pattern:/(^[\t ]*\d+ +(?:@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@ +)?)\w+/m,lookbehind:!0,alias:"string"},level:{pattern:/(^[\t ]*)\d+/m,lookbehind:!0,alias:"number"},pointer:{pattern:/@\w[\w!"$%&'()*+,\-./:;<=>?[\\\]^`{|}~\x80-\xfe #]*@/,alias:"variable"}}}return Yy}var Ky,QI;function Sge(){if(QI)return Ky;QI=1,Ky=e,e.displayName="gherkin",e.aliases=[];function e(t){(function(n){var r=/(?:\r?\n|\r)[ \t]*\|.+\|(?:(?!\|).)*/.source;n.languages.gherkin={pystring:{pattern:/("""|''')[\s\S]+?\1/,alias:"string"},comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},tag:{pattern:/(^[ \t]*)@\S*/m,lookbehind:!0},feature:{pattern:/((?:^|\r?\n|\r)[ \t]*)(?:Ability|Ahoy matey!|Arwedd|Aspekt|Besigheid Behoefte|Business Need|Caracteristica|Característica|Egenskab|Egenskap|Eiginleiki|Feature|Fīča|Fitur|Fonctionnalité|Fonksyonalite|Funcionalidade|Funcionalitat|Functionalitate|Funcţionalitate|Funcționalitate|Functionaliteit|Fungsi|Funkcia|Funkcija|Funkcionalitāte|Funkcionalnost|Funkcja|Funksie|Funktionalität|Funktionalitéit|Funzionalità|Hwaet|Hwæt|Jellemző|Karakteristik|Lastnost|Mak|Mogucnost|laH|Mogućnost|Moznosti|Možnosti|OH HAI|Omadus|Ominaisuus|Osobina|Özellik|Potrzeba biznesowa|perbogh|poQbogh malja'|Požadavek|Požiadavka|Pretty much|Qap|Qu'meH 'ut|Savybė|Tính năng|Trajto|Vermoë|Vlastnosť|Właściwość|Značilnost|Δυνατότητα|Λειτουργία|Могућност|Мөмкинлек|Особина|Свойство|Үзенчәлеклелек|Функционал|Функционалност|Функция|Функціонал|תכונה|خاصية|خصوصیت|صلاحیت|کاروبار کی ضرورت|وِیژگی|रूप लेख|ਖਾਸੀਅਤ|ਨਕਸ਼ ਨੁਹਾਰ|ਮੁਹਾਂਦਰਾ|గుణము|ಹೆಚ್ಚಳ|ความต้องการทางธุรกิจ|ความสามารถ|โครงหลัก|기능|フィーチャ|功能|機能):(?:[^:\r\n]+(?:\r?\n|\r|$))*/,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]+/,lookbehind:!0},keyword:/[^:\r\n]+:/}},scenario:{pattern:/(^[ \t]*)(?:Abstract Scenario|Abstrakt Scenario|Achtergrond|Aer|Ær|Agtergrond|All y'all|Antecedentes|Antecedents|Atburðarás|Atburðarásir|Awww, look mate|B4|Background|Baggrund|Bakgrund|Bakgrunn|Bakgrunnur|Beispiele|Beispiller|Bối cảnh|Cefndir|Cenario|Cenário|Cenario de Fundo|Cenário de Fundo|Cenarios|Cenários|Contesto|Context|Contexte|Contexto|Conto|Contoh|Contone|Dæmi|Dasar|Dead men tell no tales|Delineacao do Cenario|Delineação do Cenário|Dis is what went down|Dữ liệu|Dyagram Senaryo|Dyagram senaryo|Egzanp|Ejemplos|Eksempler|Ekzemploj|Enghreifftiau|Esbozo do escenario|Escenari|Escenario|Esempi|Esquema de l'escenari|Esquema del escenario|Esquema do Cenario|Esquema do Cenário|EXAMPLZ|Examples|Exempel|Exemple|Exemples|Exemplos|First off|Fono|Forgatókönyv|Forgatókönyv vázlat|Fundo|Geçmiş|Grundlage|Hannergrond|ghantoH|Háttér|Heave to|Istorik|Juhtumid|Keadaan|Khung kịch bản|Khung tình huống|Kịch bản|Koncept|Konsep skenario|Kontèks|Kontekst|Kontekstas|Konteksts|Kontext|Konturo de la scenaro|Latar Belakang|lut chovnatlh|lut|lutmey|Lýsing Atburðarásar|Lýsing Dæma|MISHUN SRSLY|MISHUN|Menggariskan Senario|mo'|Náčrt Scenára|Náčrt Scénáře|Náčrt Scenáru|Oris scenarija|Örnekler|Osnova|Osnova Scenára|Osnova scénáře|Osnutek|Ozadje|Paraugs|Pavyzdžiai|Példák|Piemēri|Plan du scénario|Plan du Scénario|Plan Senaryo|Plan senaryo|Plang vum Szenario|Pozadí|Pozadie|Pozadina|Príklady|Příklady|Primer|Primeri|Primjeri|Przykłady|Raamstsenaarium|Reckon it's like|Rerefons|Scenár|Scénář|Scenarie|Scenarij|Scenarijai|Scenarijaus šablonas|Scenariji|Scenārijs|Scenārijs pēc parauga|Scenarijus|Scenario|Scénario|Scenario Amlinellol|Scenario Outline|Scenario Template|Scenariomal|Scenariomall|Scenarios|Scenariu|Scenariusz|Scenaro|Schema dello scenario|Se ðe|Se the|Se þe|Senario|Senaryo Deskripsyon|Senaryo deskripsyon|Senaryo|Senaryo taslağı|Shiver me timbers|Situācija|Situai|Situasie Uiteensetting|Situasie|Skenario konsep|Skenario|Skica|Structura scenariu|Structură scenariu|Struktura scenarija|Stsenaarium|Swa hwaer swa|Swa|Swa hwær swa|Szablon scenariusza|Szenario|Szenariogrundriss|Tapaukset|Tapaus|Tapausaihio|Taust|Tausta|Template Keadaan|Template Senario|Template Situai|The thing of it is|Tình huống|Variantai|Voorbeelde|Voorbeelden|Wharrimean is|Yo-ho-ho|You'll wanna|Założenia|Παραδείγματα|Περιγραφή Σεναρίου|Σενάρια|Σενάριο|Υπόβαθρο|Кереш|Контекст|Концепт|Мисаллар|Мисоллар|Основа|Передумова|Позадина|Предистория|Предыстория|Приклади|Пример|Примери|Примеры|Рамка на сценарий|Скица|Структура сценарија|Структура сценария|Структура сценарію|Сценарий|Сценарий структураси|Сценарийның төзелеше|Сценарији|Сценарио|Сценарій|Тарих|Үрнәкләр|דוגמאות|רקע|תבנית תרחיש|תרחיש|الخلفية|الگوی سناریو|امثلة|پس منظر|زمینه|سناریو|سيناريو|سيناريو مخطط|مثالیں|منظر نامے کا خاکہ|منظرنامہ|نمونه ها|उदाहरण|परिदृश्य|परिदृश्य रूपरेखा|पृष्ठभूमि|ਉਦਾਹਰਨਾਂ|ਪਟਕਥਾ|ਪਟਕਥਾ ਢਾਂਚਾ|ਪਟਕਥਾ ਰੂਪ ਰੇਖਾ|ਪਿਛੋਕੜ|ఉదాహరణలు|కథనం|నేపథ్యం|సన్నివేశం|ಉದಾಹರಣೆಗಳು|ಕಥಾಸಾರಾಂಶ|ವಿವರಣೆ|ಹಿನ್ನೆಲೆ|โครงสร้างของเหตุการณ์|ชุดของตัวอย่าง|ชุดของเหตุการณ์|แนวคิด|สรุปเหตุการณ์|เหตุการณ์|배경|시나리오|시나리오 개요|예|サンプル|シナリオ|シナリオアウトライン|シナリオテンプレ|シナリオテンプレート|テンプレ|例|例子|剧本|剧本大纲|劇本|劇本大綱|场景|场景大纲|場景|場景大綱|背景):[^:\r\n]*/m,lookbehind:!0,inside:{important:{pattern:/(:)[^\r\n]*/,lookbehind:!0},keyword:/[^:\r\n]+:/}},"table-body":{pattern:RegExp("("+r+")(?:"+r+")+"),lookbehind:!0,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"},td:{pattern:/\s*[^\s|][^|]*/,alias:"string"},punctuation:/\|/}},"table-head":{pattern:RegExp(r),inside:{th:{pattern:/\s*[^\s|][^|]*/,alias:"variable"},punctuation:/\|/}},atrule:{pattern:/(^[ \t]+)(?:'a|'ach|'ej|7|a|A také|A taktiež|A tiež|A zároveň|Aber|Ac|Adott|Akkor|Ak|Aleshores|Ale|Ali|Allora|Alors|Als|Ama|Amennyiben|Amikor|Ampak|an|AN|Ananging|And y'all|And|Angenommen|Anrhegedig a|An|Apabila|Atès|Atesa|Atunci|Avast!|Aye|A|awer|Bagi|Banjur|Bet|Biết|Blimey!|Buh|But at the end of the day I reckon|But y'all|But|BUT|Cal|Când|Cand|Cando|Ce|Cuando|Če|Ða ðe|Ða|Dadas|Dada|Dados|Dado|DaH ghu' bejlu'|dann|Dann|Dano|Dan|Dar|Dat fiind|Data|Date fiind|Date|Dati fiind|Dati|Daţi fiind|Dați fiind|DEN|Dato|De|Den youse gotta|Dengan|Diberi|Diyelim ki|Donada|Donat|Donitaĵo|Do|Dun|Duota|Ðurh|Eeldades|Ef|Eğer ki|Entao|Então|Entón|E|En|Entonces|Epi|És|Etant donnée|Etant donné|Et|Étant données|Étant donnée|Étant donné|Etant données|Etant donnés|Étant donnés|Fakat|Gangway!|Gdy|Gegeben seien|Gegeben sei|Gegeven|Gegewe|ghu' noblu'|Gitt|Given y'all|Given|Givet|Givun|Ha|Cho|I CAN HAZ|In|Ir|It's just unbelievable|I|Ja|Jeśli|Jeżeli|Kad|Kada|Kadar|Kai|Kaj|Když|Keď|Kemudian|Ketika|Khi|Kiedy|Ko|Kuid|Kui|Kun|Lan|latlh|Le sa a|Let go and haul|Le|Lè sa a|Lè|Logo|Lorsqu'<|Lorsque|mä|Maar|Mais|Mając|Ma|Majd|Maka|Manawa|Mas|Men|Menawa|Mutta|Nalika|Nalikaning|Nanging|Når|När|Nato|Nhưng|Niin|Njuk|O zaman|Och|Og|Oletetaan|Ond|Onda|Oraz|Pak|Pero|Però|Podano|Pokiaľ|Pokud|Potem|Potom|Privzeto|Pryd|Quan|Quand|Quando|qaSDI'|Så|Sed|Se|Siis|Sipoze ke|Sipoze Ke|Sipoze|Si|Şi|Și|Soit|Stel|Tada|Tad|Takrat|Tak|Tapi|Ter|Tetapi|Tha the|Tha|Then y'all|Then|Thì|Thurh|Toda|Too right|Un|Und|ugeholl|Và|vaj|Vendar|Ve|wann|Wanneer|WEN|Wenn|When y'all|When|Wtedy|Wun|Y'know|Yeah nah|Yna|Youse know like when|Youse know when youse got|Y|Za predpokladu|Za předpokladu|Zadan|Zadani|Zadano|Zadate|Zadato|Zakładając|Zaradi|Zatati|Þa þe|Þa|Þá|Þegar|Þurh|Αλλά|Δεδομένου|Και|Όταν|Τότε|А також|Агар|Але|Али|Аммо|А|Әгәр|Әйтик|Әмма|Бирок|Ва|Вә|Дадено|Дано|Допустим|Если|Задате|Задати|Задато|И|І|К тому же|Када|Кад|Когато|Когда|Коли|Ләкин|Лекин|Нәтиҗәдә|Нехай|Но|Онда|Припустимо, що|Припустимо|Пусть|Также|Та|Тогда|Тоді|То|Унда|Һәм|Якщо|אבל|אזי|אז|בהינתן|וגם|כאשר|آنگاه|اذاً|اگر|اما|اور|با فرض|بالفرض|بفرض|پھر|تب|ثم|جب|عندما|فرض کیا|لكن|لیکن|متى|هنگامی|و|अगर|और|कदा|किन्तु|चूंकि|जब|तथा|तदा|तब|परन्तु|पर|यदि|ਅਤੇ|ਜਦੋਂ|ਜਿਵੇਂ ਕਿ|ਜੇਕਰ|ਤਦ|ਪਰ|అప్పుడు|ఈ పరిస్థితిలో|కాని|చెప్పబడినది|మరియు|ಆದರೆ|ನಂತರ|ನೀಡಿದ|ಮತ್ತು|ಸ್ಥಿತಿಯನ್ನು|กำหนดให้|ดังนั้น|แต่|เมื่อ|และ|그러면<|그리고<|단<|만약<|만일<|먼저<|조건<|하지만<|かつ<|しかし<|ただし<|ならば<|もし<|並且<|但し<|但是<|假如<|假定<|假設<|假设<|前提<|同时<|同時<|并且<|当<|當<|而且<|那么<|那麼<)(?=[ \t])/m,lookbehind:!0},string:{pattern:/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,inside:{outline:{pattern:/<[^>]+>/,alias:"variable"}}},outline:{pattern:/<[^>]+>/,alias:"variable"}}})(t)}return Ky}var Xy,JI;function Ege(){if(JI)return Xy;JI=1,Xy=e,e.displayName="git",e.aliases=[];function e(t){t.languages.git={comment:/^#.*/m,deleted:/^[-–].*/m,inserted:/^\+.*/m,string:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,command:{pattern:/^.*\$ git .*$/m,inside:{parameter:/\s--?\w+/}},coord:/^@@.*@@$/m,"commit-sha1":/^commit \w{40}$/m}}return Xy}var Zy,eL;function wge(){if(eL)return Zy;eL=1;var e=fi();Zy=t,t.displayName="glsl",t.aliases=[];function t(n){n.register(e),n.languages.glsl=n.languages.extend("c",{keyword:/\b(?:active|asm|atomic_uint|attribute|[ibdu]?vec[234]|bool|break|buffer|case|cast|centroid|class|coherent|common|const|continue|d?mat[234](?:x[234])?|default|discard|do|double|else|enum|extern|external|false|filter|fixed|flat|float|for|fvec[234]|goto|half|highp|hvec[234]|[iu]?sampler2DMS(?:Array)?|[iu]?sampler2DRect|[iu]?samplerBuffer|[iu]?samplerCube|[iu]?samplerCubeArray|[iu]?sampler[123]D|[iu]?sampler[12]DArray|[iu]?image2DMS(?:Array)?|[iu]?image2DRect|[iu]?imageBuffer|[iu]?imageCube|[iu]?imageCubeArray|[iu]?image[123]D|[iu]?image[12]DArray|if|in|inline|inout|input|int|interface|invariant|layout|long|lowp|mediump|namespace|noinline|noperspective|out|output|partition|patch|precise|precision|public|readonly|resource|restrict|return|sample|sampler[12]DArrayShadow|sampler[12]DShadow|sampler2DRectShadow|sampler3DRect|samplerCubeArrayShadow|samplerCubeShadow|shared|short|sizeof|smooth|static|struct|subroutine|superp|switch|template|this|true|typedef|uint|uniform|union|unsigned|using|varying|void|volatile|while|writeonly)\b/})}return Zy}var Qy,tL;function xge(){if(tL)return Qy;tL=1,Qy=e,e.displayName="gml",e.aliases=[];function e(t){t.languages.gamemakerlanguage=t.languages.gml=t.languages.extend("clike",{keyword:/\b(?:break|case|continue|default|do|else|enum|exit|for|globalvar|if|repeat|return|switch|until|var|while)\b/,number:/(?:\b0x[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[ulf]{0,4}/i,operator:/--|\+\+|[-+%/=]=?|!=|\*\*?=?|<[<=>]?|>[=>]?|&&?|\^\^?|\|\|?|~|\b(?:and|at|not|or|with|xor)\b/,constant:/\b(?:GM_build_date|GM_version|action_(?:continue|restart|reverse|stop)|all|gamespeed_(?:fps|microseconds)|global|local|noone|other|pi|pointer_(?:invalid|null)|self|timezone_(?:local|utc)|undefined|ev_(?:create|destroy|step|alarm|keyboard|mouse|collision|other|draw|draw_(?:begin|end|post|pre)|keypress|keyrelease|trigger|(?:left|middle|no|right)_button|(?:left|middle|right)_press|(?:left|middle|right)_release|mouse_(?:enter|leave|wheel_down|wheel_up)|global_(?:left|middle|right)_button|global_(?:left|middle|right)_press|global_(?:left|middle|right)_release|joystick(?:1|2)_(?:button1|button2|button3|button4|button5|button6|button7|button8|down|left|right|up)|outside|boundary|game_start|game_end|room_start|room_end|no_more_lives|animation_end|end_of_path|no_more_health|user\d|gui|gui_begin|gui_end|step_(?:begin|end|normal))|vk_(?:alt|anykey|backspace|control|delete|down|end|enter|escape|home|insert|left|nokey|pagedown|pageup|pause|printscreen|return|right|shift|space|tab|up|f\d|numpad\d|add|decimal|divide|lalt|lcontrol|lshift|multiply|ralt|rcontrol|rshift|subtract)|achievement_(?:filter_(?:all_players|favorites_only|friends_only)|friends_info|info|leaderboard_info|our_info|pic_loaded|show_(?:achievement|bank|friend_picker|leaderboard|profile|purchase_prompt|ui)|type_challenge|type_score_challenge)|asset_(?:font|object|path|room|script|shader|sound|sprite|tiles|timeline|unknown)|audio_(?:3d|falloff_(?:exponent_distance|exponent_distance_clamped|inverse_distance|inverse_distance_clamped|linear_distance|linear_distance_clamped|none)|mono|new_system|old_system|stereo)|bm_(?:add|complex|dest_alpha|dest_color|dest_colour|inv_dest_alpha|inv_dest_color|inv_dest_colour|inv_src_alpha|inv_src_color|inv_src_colour|max|normal|one|src_alpha|src_alpha_sat|src_color|src_colour|subtract|zero)|browser_(?:chrome|firefox|ie|ie_mobile|not_a_browser|opera|safari|safari_mobile|tizen|unknown|windows_store)|buffer_(?:bool|f16|f32|f64|fast|fixed|generalerror|grow|invalidtype|network|outofbounds|outofspace|s16|s32|s8|seek_end|seek_relative|seek_start|string|text|u16|u32|u64|u8|vbuffer|wrap)|c_(?:aqua|black|blue|dkgray|fuchsia|gray|green|lime|ltgray|maroon|navy|olive|orange|purple|red|silver|teal|white|yellow)|cmpfunc_(?:always|equal|greater|greaterequal|less|lessequal|never|notequal)|cr_(?:appstart|arrow|beam|cross|default|drag|handpoint|hourglass|none|size_all|size_nesw|size_ns|size_nwse|size_we|uparrow)|cull_(?:clockwise|counterclockwise|noculling)|device_(?:emulator|tablet)|device_ios_(?:ipad|ipad_retina|iphone|iphone5|iphone6|iphone6plus|iphone_retina|unknown)|display_(?:landscape|landscape_flipped|portrait|portrait_flipped)|dll_(?:cdecl|cdel|stdcall)|ds_type_(?:grid|list|map|priority|queue|stack)|ef_(?:cloud|ellipse|explosion|firework|flare|rain|ring|smoke|smokeup|snow|spark|star)|fa_(?:archive|bottom|center|directory|hidden|left|middle|readonly|right|sysfile|top|volumeid)|fb_login_(?:default|fallback_to_webview|forcing_safari|forcing_webview|no_fallback_to_webview|use_system_account)|iap_(?:available|canceled|ev_consume|ev_product|ev_purchase|ev_restore|ev_storeload|failed|purchased|refunded|status_available|status_loading|status_processing|status_restoring|status_unavailable|status_uninitialised|storeload_failed|storeload_ok|unavailable)|leaderboard_type_(?:number|time_mins_secs)|lighttype_(?:dir|point)|matrix_(?:projection|view|world)|mb_(?:any|left|middle|none|right)|network_(?:config_(?:connect_timeout|disable_reliable_udp|enable_reliable_udp|use_non_blocking_socket)|socket_(?:bluetooth|tcp|udp)|type_(?:connect|data|disconnect|non_blocking_connect))|of_challenge_(?:lose|tie|win)|os_(?:android|ios|linux|macosx|ps3|ps4|psvita|unknown|uwp|win32|win8native|windows|winphone|xboxone)|phy_debug_render_(?:aabb|collision_pairs|coms|core_shapes|joints|obb|shapes)|phy_joint_(?:anchor_1_x|anchor_1_y|anchor_2_x|anchor_2_y|angle|angle_limits|damping_ratio|frequency|length_1|length_2|lower_angle_limit|max_force|max_length|max_motor_force|max_motor_torque|max_torque|motor_force|motor_speed|motor_torque|reaction_force_x|reaction_force_y|reaction_torque|speed|translation|upper_angle_limit)|phy_particle_data_flag_(?:category|color|colour|position|typeflags|velocity)|phy_particle_flag_(?:colormixing|colourmixing|elastic|powder|spring|tensile|viscous|wall|water|zombie)|phy_particle_group_flag_(?:rigid|solid)|pr_(?:linelist|linestrip|pointlist|trianglefan|trianglelist|trianglestrip)|ps_(?:distr|shape)_(?:diamond|ellipse|gaussian|invgaussian|line|linear|rectangle)|pt_shape_(?:circle|cloud|disk|explosion|flare|line|pixel|ring|smoke|snow|spark|sphere|square|star)|ty_(?:real|string)|gp_(?:face\d|axislh|axislv|axisrh|axisrv|padd|padl|padr|padu|select|shoulderl|shoulderlb|shoulderr|shoulderrb|start|stickl|stickr)|lb_disp_(?:none|numeric|time_ms|time_sec)|lb_sort_(?:ascending|descending|none)|ov_(?:achievements|community|friends|gamegroup|players|settings)|ugc_(?:filetype_(?:community|microtrans)|list_(?:Favorited|Followed|Published|Subscribed|UsedOrPlayed|VotedDown|VotedOn|VotedUp|WillVoteLater)|match_(?:AllGuides|Artwork|Collections|ControllerBindings|IntegratedGuides|Items|Items_Mtx|Items_ReadyToUse|Screenshots|UsableInGame|Videos|WebGuides)|query_(?:AcceptedForGameRankedByAcceptanceDate|CreatedByFriendsRankedByPublicationDate|FavoritedByFriendsRankedByPublicationDate|NotYetRated)|query_RankedBy(?:NumTimesReported|PublicationDate|TextSearch|TotalVotesAsc|Trend|Vote|VotesUp)|result_success|sortorder_CreationOrder(?:Asc|Desc)|sortorder_(?:ForModeration|LastUpdatedDesc|SubscriptionDateDesc|TitleAsc|VoteScoreDesc)|visibility_(?:friends_only|private|public))|vertex_usage_(?:binormal|blendindices|blendweight|color|colour|depth|fog|normal|position|psize|sample|tangent|texcoord|textcoord)|vertex_type_(?:float\d|color|colour|ubyte4)|input_type|layerelementtype_(?:background|instance|oldtilemap|particlesystem|sprite|tile|tilemap|undefined)|se_(?:chorus|compressor|echo|equalizer|flanger|gargle|none|reverb)|text_type|tile_(?:flip|index_mask|mirror|rotate)|(?:obj|rm|scr|spr)\w+)\b/,variable:/\b(?:alarm|application_surface|async_load|background_(?:alpha|blend|color|colour|foreground|height|hspeed|htiled|index|showcolor|showcolour|visible|vspeed|vtiled|width|x|xscale|y|yscale)|bbox_(?:bottom|left|right|top)|browser_(?:height|width)|caption_(?:health|lives|score)|current_(?:day|hour|minute|month|second|time|weekday|year)|cursor_sprite|debug_mode|delta_time|direction|display_aa|error_(?:last|occurred)|event_(?:action|number|object|type)|fps|fps_real|friction|game_(?:display|project|save)_(?:id|name)|gamemaker_(?:pro|registered|version)|gravity|gravity_direction|(?:h|v)speed|health|iap_data|id|image_(?:alpha|angle|blend|depth|index|number|speed|xscale|yscale)|instance_(?:count|id)|keyboard_(?:key|lastchar|lastkey|string)|layer|lives|mask_index|mouse_(?:button|lastbutton|x|y)|object_index|os_(?:browser|device|type|version)|path_(?:endaction|index|orientation|position|positionprevious|scale|speed)|persistent|phy_(?:rotation|(?:col_normal|collision|com|linear_velocity|position|speed)_(?:x|y)|angular_(?:damping|velocity)|position_(?:x|y)previous|speed|linear_damping|bullet|fixed_rotation|active|mass|inertia|dynamic|kinematic|sleeping|collision_points)|pointer_(?:invalid|null)|room|room_(?:caption|first|height|last|persistent|speed|width)|score|secure_mode|show_(?:health|lives|score)|solid|speed|sprite_(?:height|index|width|xoffset|yoffset)|temp_directory|timeline_(?:index|loop|position|running|speed)|transition_(?:color|kind|steps)|undefined|view_(?:angle|current|enabled|(?:h|v)(?:border|speed)|(?:h|w|x|y)port|(?:h|w|x|y)view|object|surface_id|visible)|visible|webgl_enabled|working_directory|(?:x|y)(?:previous|start)|x|y|argument(?:_relitive|_count|\d)|argument|global|local|other|self)\b/})}return Qy}var Jy,nL;function kge(){if(nL)return Jy;nL=1,Jy=e,e.displayName="gn",e.aliases=["gni"];function e(t){t.languages.gn={comment:{pattern:/#.*/,greedy:!0},"string-literal":{pattern:/(^|[^\\"])"(?:[^\r\n"\\]|\\.)*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[\s\S]*?\}|[a-zA-Z_]\w*|0x[a-fA-F0-9]{2})/,lookbehind:!0,inside:{number:/^\$0x[\s\S]{2}$/,variable:/^\$\w+$/,"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},string:/[\s\S]+/}},keyword:/\b(?:else|if)\b/,boolean:/\b(?:false|true)\b/,"builtin-function":{pattern:/\b(?:assert|defined|foreach|import|pool|print|template|tool|toolchain)(?=\s*\()/i,alias:"keyword"},function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:current_cpu|current_os|current_toolchain|default_toolchain|host_cpu|host_os|root_build_dir|root_gen_dir|root_out_dir|target_cpu|target_gen_dir|target_os|target_out_dir)\b/,number:/-?\b\d+\b/,operator:/[-+!=<>]=?|&&|\|\|/,punctuation:/[(){}[\],.]/},t.languages.gn["string-literal"].inside.interpolation.inside.expression.inside=t.languages.gn,t.languages.gni=t.languages.gn}return Jy}var ev,rL;function Age(){if(rL)return ev;rL=1,ev=e,e.displayName="goModule",e.aliases=[];function e(t){t.languages["go-mod"]=t.languages["go-module"]={comment:{pattern:/\/\/.*/,greedy:!0},version:{pattern:/(^|[\s()[\],])v\d+\.\d+\.\d+(?:[+-][-+.\w]*)?(?![^\s()[\],])/,lookbehind:!0,alias:"number"},"go-version":{pattern:/((?:^|\s)go\s+)\d+(?:\.\d+){1,2}/,lookbehind:!0,alias:"number"},keyword:{pattern:/^([ \t]*)(?:exclude|go|module|replace|require|retract)\b/m,lookbehind:!0},operator:/=>/,punctuation:/[()[\],]/}}return ev}var tv,aL;function Tge(){if(aL)return tv;aL=1,tv=e,e.displayName="go",e.aliases=[];function e(t){t.languages.go=t.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:break|case|chan|const|continue|default|defer|else|fallthrough|for|func|go(?:to)?|if|import|interface|map|package|range|return|select|struct|switch|type|var)\b/,boolean:/\b(?:_|false|iota|nil|true)\b/,number:[/\b0(?:b[01_]+|o[0-7_]+)i?\b/i,/\b0x(?:[a-f\d_]+(?:\.[a-f\d_]*)?|\.[a-f\d_]+)(?:p[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,/(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?[\d_]+)?i?(?!\w)/i],operator:/[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\./,builtin:/\b(?:append|bool|byte|cap|close|complex|complex(?:64|128)|copy|delete|error|float(?:32|64)|u?int(?:8|16|32|64)?|imag|len|make|new|panic|print(?:ln)?|real|recover|rune|string|uintptr)\b/}),t.languages.insertBefore("go","string",{char:{pattern:/'(?:\\.|[^'\\\r\n]){0,10}'/,greedy:!0}}),delete t.languages.go["class-name"]}return tv}var nv,oL;function _ge(){if(oL)return nv;oL=1,nv=e,e.displayName="graphql",e.aliases=[];function e(t){t.languages.graphql={comment:/#.*/,description:{pattern:/(?:"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*")(?=\s*[a-z_])/i,greedy:!0,alias:"string",inside:{"language-markdown":{pattern:/(^"(?:"")?)(?!\1)[\s\S]+(?=\1$)/,lookbehind:!0,inside:t.languages.markdown}}},string:{pattern:/"""(?:[^"]|(?!""")")*"""|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},number:/(?:\B-|\b)\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,boolean:/\b(?:false|true)\b/,variable:/\$[a-z_]\w*/i,directive:{pattern:/@[a-z_]\w*/i,alias:"function"},"attr-name":{pattern:/\b[a-z_]\w*(?=\s*(?:\((?:[^()"]|"(?:\\.|[^\\"\r\n])*")*\))?:)/i,greedy:!0},"atom-input":{pattern:/\b[A-Z]\w*Input\b/,alias:"class-name"},scalar:/\b(?:Boolean|Float|ID|Int|String)\b/,constant:/\b[A-Z][A-Z_\d]*\b/,"class-name":{pattern:/(\b(?:enum|implements|interface|on|scalar|type|union)\s+|&\s*|:\s*|\[)[A-Z_]\w*/,lookbehind:!0},fragment:{pattern:/(\bfragment\s+|\.{3}\s*(?!on\b))[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-mutation":{pattern:/(\bmutation\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},"definition-query":{pattern:/(\bquery\s+)[a-zA-Z_]\w*/,lookbehind:!0,alias:"function"},keyword:/\b(?:directive|enum|extend|fragment|implements|input|interface|mutation|on|query|repeatable|scalar|schema|subscription|type|union)\b/,operator:/[!=|&]|\.{3}/,"property-query":/\w+(?=\s*\()/,object:/\w+(?=\s*\{)/,punctuation:/[!(){}\[\]:=,]/,property:/\w+/},t.hooks.add("after-tokenize",function(r){if(r.language!=="graphql")return;var a=r.tokens.filter(function(R){return typeof R!="string"&&R.type!=="comment"&&R.type!=="scalar"}),i=0;function l(R){return a[i+R]}function u(R,x){x=x||0;for(var T=0;T<R.length;T++){var C=l(T+x);if(!C||C.type!==R[T])return!1}return!0}function c(R,x){for(var T=1,C=i;C<a.length;C++){var N=a[C],_=N.content;if(N.type==="punctuation"&&typeof _=="string"){if(R.test(_))T++;else if(x.test(_)&&(T--,T===0))return C}}return-1}function f(R,x){var T=R.alias;T?Array.isArray(T)||(R.alias=T=[T]):R.alias=T=[],T.push(x)}for(;i<a.length;){var p=a[i++];if(p.type==="keyword"&&p.content==="mutation"){var g=[];if(u(["definition-mutation","punctuation"])&&l(1).content==="("){i+=2;var b=c(/^\($/,/^\)$/);if(b===-1)continue;for(;i<b;i++){var m=l(0);m.type==="variable"&&(f(m,"variable-input"),g.push(m.content))}i=b+1}if(u(["punctuation","property-query"])&&l(0).content==="{"&&(i++,f(l(0),"property-mutation"),g.length>0)){var S=c(/^\{$/,/^\}$/);if(S===-1)continue;for(var v=i;v<S;v++){var A=a[v];A.type==="variable"&&g.indexOf(A.content)>=0&&f(A,"variable-input")}}}}})}return nv}var rv,iL;function Rge(){if(iL)return rv;iL=1,rv=e,e.displayName="groovy",e.aliases=[];function e(t){t.languages.groovy=t.languages.extend("clike",{string:[{pattern:/("""|''')(?:[^\\]|\\[\s\S])*?\1|\$\/(?:[^/$]|\$(?:[/$]|(?![/$]))|\/(?!\$))*\/\$/,greedy:!0},{pattern:/(["'/])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0}],keyword:/\b(?:abstract|as|assert|boolean|break|byte|case|catch|char|class|const|continue|def|default|do|double|else|enum|extends|final|finally|float|for|goto|if|implements|import|in|instanceof|int|interface|long|native|new|package|private|protected|public|return|short|static|strictfp|super|switch|synchronized|this|throw|throws|trait|transient|try|void|volatile|while)\b/,number:/\b(?:0b[01_]+|0x[\da-f_]+(?:\.[\da-f_p\-]+)?|[\d_]+(?:\.[\d_]+)?(?:e[+-]?\d+)?)[glidf]?\b/i,operator:{pattern:/(^|[^.])(?:~|==?~?|\?[.:]?|\*(?:[.=]|\*=?)?|\.[@&]|\.\.<|\.\.(?!\.)|-[-=>]?|\+[+=]?|!=?|<(?:<=?|=>?)?|>(?:>>?=?|=)?|&[&=]?|\|[|=]?|\/=?|\^=?|%=?)/,lookbehind:!0},punctuation:/\.+|[{}[\];(),:$]/}),t.languages.insertBefore("groovy","string",{shebang:{pattern:/#!.+/,alias:"comment"}}),t.languages.insertBefore("groovy","punctuation",{"spock-block":/\b(?:and|cleanup|expect|given|setup|then|when|where):/}),t.languages.insertBefore("groovy","function",{annotation:{pattern:/(^|[^.])@\w+/,lookbehind:!0,alias:"punctuation"}}),t.hooks.add("wrap",function(n){if(n.language==="groovy"&&n.type==="string"){var r=n.content.value[0];if(r!="'"){var a=/([^\\])(?:\$(?:\{.*?\}|[\w.]+))/;r==="$"&&(a=/([^\$])(?:\$(?:\{.*?\}|[\w.]+))/),n.content.value=n.content.value.replace(/&lt;/g,"<").replace(/&amp;/g,"&"),n.content=t.highlight(n.content.value,{expression:{pattern:a,lookbehind:!0,inside:t.languages.groovy}}),n.classes.push(r==="/"?"regex":"gstring")}}})}return rv}var av,lL;function Cge(){if(lL)return av;lL=1;var e=Wf();av=t,t.displayName="haml",t.aliases=[];function t(n){n.register(e),function(r){r.languages.haml={"multiline-comment":{pattern:/((?:^|\r?\n|\r)([\t ]*))(?:\/|-#).*(?:(?:\r?\n|\r)\2[\t ].+)*/,lookbehind:!0,alias:"comment"},"multiline-code":[{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*,[\t ]*(?:(?:\r?\n|\r)\2[\t ].*,[\t ]*)*(?:(?:\r?\n|\r)\2[\t ].+)/,lookbehind:!0,inside:r.languages.ruby},{pattern:/((?:^|\r?\n|\r)([\t ]*)(?:[~-]|[&!]?=)).*\|[\t ]*(?:(?:\r?\n|\r)\2[\t ].*\|[\t ]*)*/,lookbehind:!0,inside:r.languages.ruby}],filter:{pattern:/((?:^|\r?\n|\r)([\t ]*)):[\w-]+(?:(?:\r?\n|\r)(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"}}},markup:{pattern:/((?:^|\r?\n|\r)[\t ]*)<.+/,lookbehind:!0,inside:r.languages.markup},doctype:{pattern:/((?:^|\r?\n|\r)[\t ]*)!!!(?: .+)?/,lookbehind:!0},tag:{pattern:/((?:^|\r?\n|\r)[\t ]*)[%.#][\w\-#.]*[\w\-](?:\([^)]+\)|\{(?:\{[^}]+\}|[^{}])+\}|\[[^\]]+\])*[\/<>]*/,lookbehind:!0,inside:{attributes:[{pattern:/(^|[^#])\{(?:\{[^}]+\}|[^{}])+\}/,lookbehind:!0,inside:r.languages.ruby},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*)(?:"(?:\\.|[^\\"\r\n])*"|[^)\s]+)/,lookbehind:!0},"attr-name":/[\w:-]+(?=\s*!?=|\s*[,)])/,punctuation:/[=(),]/}},{pattern:/\[[^\]]+\]/,inside:r.languages.ruby}],punctuation:/[<>]/}},code:{pattern:/((?:^|\r?\n|\r)[\t ]*(?:[~-]|[&!]?=)).+/,lookbehind:!0,inside:r.languages.ruby},interpolation:{pattern:/#\{[^}]+\}/,inside:{delimiter:{pattern:/^#\{|\}$/,alias:"punctuation"},ruby:{pattern:/[\s\S]+/,inside:r.languages.ruby}}},punctuation:{pattern:/((?:^|\r?\n|\r)[\t ]*)[~=\-&!]+/,lookbehind:!0}};for(var a="((?:^|\\r?\\n|\\r)([\\t ]*)):{{filter_name}}(?:(?:\\r?\\n|\\r)(?:\\2[\\t ].+|\\s*?(?=\\r?\\n|\\r)))+",i=["css",{filter:"coffee",language:"coffeescript"},"erb","javascript","less","markdown","ruby","scss","textile"],l={},u=0,c=i.length;u<c;u++){var f=i[u];f=typeof f=="string"?{filter:f,language:f}:f,r.languages[f.language]&&(l["filter-"+f.filter]={pattern:RegExp(a.replace("{{filter_name}}",function(){return f.filter})),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"symbol"},text:{pattern:/[\s\S]+/,alias:[f.language,"language-"+f.language],inside:r.languages[f.language]}}})}r.languages.insertBefore("haml","filter",l)}(n)}return av}var ov,sL;function Nge(){if(sL)return ov;sL=1;var e=Gn();ov=t,t.displayName="handlebars",t.aliases=["hbs"];function t(n){n.register(e),function(r){r.languages.handlebars={comment:/\{\{![\s\S]*?\}\}/,delimiter:{pattern:/^\{\{\{?|\}\}\}?$/,alias:"punctuation"},string:/(["'])(?:\\.|(?!\1)[^\\\r\n])*\1/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][+-]?\d+)?/,boolean:/\b(?:false|true)\b/,block:{pattern:/^(\s*(?:~\s*)?)[#\/]\S+?(?=\s*(?:~\s*)?$|\s)/,lookbehind:!0,alias:"keyword"},brackets:{pattern:/\[[^\]]+\]/,inside:{punctuation:/\[|\]/,variable:/[\s\S]+/}},punctuation:/[!"#%&':()*+,.\/;<=>@\[\\\]^`{|}~]/,variable:/[^!"#%&'()*+,\/;<=>@\[\\\]^`{|}~\s]+/},r.hooks.add("before-tokenize",function(a){var i=/\{\{\{[\s\S]+?\}\}\}|\{\{[\s\S]+?\}\}/g;r.languages["markup-templating"].buildPlaceholders(a,"handlebars",i)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"handlebars")}),r.languages.hbs=r.languages.handlebars}(n)}return ov}var iv,uL;function cA(){if(uL)return iv;uL=1,iv=e,e.displayName="haskell",e.aliases=["hs"];function e(t){t.languages.haskell={comment:{pattern:/(^|[^-!#$%*+=?&@|~.:<>^\\\/])(?:--(?:(?=.)[^-!#$%*+=?&@|~.:<>^\\\/].*|$)|\{-[\s\S]*?-\})/m,lookbehind:!0},char:{pattern:/'(?:[^\\']|\\(?:[abfnrtv\\"'&]|\^[A-Z@[\]^_]|ACK|BEL|BS|CAN|CR|DC1|DC2|DC3|DC4|DEL|DLE|EM|ENQ|EOT|ESC|ETB|ETX|FF|FS|GS|HT|LF|NAK|NUL|RS|SI|SO|SOH|SP|STX|SUB|SYN|US|VT|\d+|o[0-7]+|x[0-9a-fA-F]+))'/,alias:"string"},string:{pattern:/"(?:[^\\"]|\\(?:\S|\s+\\))*"/,greedy:!0},keyword:/\b(?:case|class|data|deriving|do|else|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b/,"import-statement":{pattern:/(^[\t ]*)import\s+(?:qualified\s+)?(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*(?:\s+as\s+(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import|qualified)\b/,punctuation:/\./}},builtin:/\b(?:abs|acos|acosh|all|and|any|appendFile|approxRational|asTypeOf|asin|asinh|atan|atan2|atanh|basicIORun|break|catch|ceiling|chr|compare|concat|concatMap|const|cos|cosh|curry|cycle|decodeFloat|denominator|digitToInt|div|divMod|drop|dropWhile|either|elem|encodeFloat|enumFrom|enumFromThen|enumFromThenTo|enumFromTo|error|even|exp|exponent|fail|filter|flip|floatDigits|floatRadix|floatRange|floor|fmap|foldl|foldl1|foldr|foldr1|fromDouble|fromEnum|fromInt|fromInteger|fromIntegral|fromRational|fst|gcd|getChar|getContents|getLine|group|head|id|inRange|index|init|intToDigit|interact|ioError|isAlpha|isAlphaNum|isAscii|isControl|isDenormalized|isDigit|isHexDigit|isIEEE|isInfinite|isLower|isNaN|isNegativeZero|isOctDigit|isPrint|isSpace|isUpper|iterate|last|lcm|length|lex|lexDigits|lexLitChar|lines|log|logBase|lookup|map|mapM|mapM_|max|maxBound|maximum|maybe|min|minBound|minimum|mod|negate|not|notElem|null|numerator|odd|or|ord|otherwise|pack|pi|pred|primExitWith|print|product|properFraction|putChar|putStr|putStrLn|quot|quotRem|range|rangeSize|read|readDec|readFile|readFloat|readHex|readIO|readInt|readList|readLitChar|readLn|readOct|readParen|readSigned|reads|readsPrec|realToFrac|recip|rem|repeat|replicate|return|reverse|round|scaleFloat|scanl|scanl1|scanr|scanr1|seq|sequence|sequence_|show|showChar|showInt|showList|showLitChar|showParen|showSigned|showString|shows|showsPrec|significand|signum|sin|sinh|snd|sort|span|splitAt|sqrt|subtract|succ|sum|tail|take|takeWhile|tan|tanh|threadToIOResult|toEnum|toInt|toInteger|toLower|toRational|toUpper|truncate|uncurry|undefined|unlines|until|unwords|unzip|unzip3|userError|words|writeFile|zip|zip3|zipWith|zipWith3)\b/,number:/\b(?:\d+(?:\.\d+)?(?:e[+-]?\d+)?|0o[0-7]+|0x[0-9a-f]+)\b/i,operator:[{pattern:/`(?:[A-Z][\w']*\.)*[_a-z][\w']*`/,greedy:!0},{pattern:/(\s)\.(?=\s)/,lookbehind:!0},/[-!#$%*+=?&@|~:<>^\\\/][-!#$%*+=?&@|~.:<>^\\\/]*|\.[-!#$%*+=?&@|~.:<>^\\\/]+/],hvariable:{pattern:/\b(?:[A-Z][\w']*\.)*[_a-z][\w']*/,inside:{punctuation:/\./}},constant:{pattern:/\b(?:[A-Z][\w']*\.)*[A-Z][\w']*/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:]/},t.languages.hs=t.languages.haskell}return iv}var lv,cL;function Oge(){if(cL)return lv;cL=1,lv=e,e.displayName="haxe",e.aliases=[];function e(t){t.languages.haxe=t.languages.extend("clike",{string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},"class-name":[{pattern:/(\b(?:abstract|class|enum|extends|implements|interface|new|typedef)\s+)[A-Z_]\w*/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\bthis\b|\b(?:abstract|as|break|case|cast|catch|class|continue|default|do|dynamic|else|enum|extends|extern|final|for|from|function|if|implements|import|in|inline|interface|macro|new|null|operator|overload|override|package|private|public|return|static|super|switch|throw|to|try|typedef|untyped|using|var|while)(?!\.)\b/,function:{pattern:/\b[a-z_]\w*(?=\s*(?:<[^<>]*>\s*)?\()/i,greedy:!0},operator:/\.{3}|\+\+|--|&&|\|\||->|=>|(?:<<?|>{1,3}|[-+*/%!=&|^])=?|[?:~]/}),t.languages.insertBefore("haxe","string",{"string-interpolation":{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,inside:{interpolation:{pattern:/(^|[^\\])\$(?:\w+|\{[^{}]+\})/,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:t.languages.haxe}}},string:/[\s\S]+/}}}),t.languages.insertBefore("haxe","class-name",{regex:{pattern:/~\/(?:[^\/\\\r\n]|\\.)+\/[a-z]*/,greedy:!0,inside:{"regex-flags":/\b[a-z]+$/,"regex-source":{pattern:/^(~\/)[\s\S]+(?=\/$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^~\/|\/$/}}}),t.languages.insertBefore("haxe","keyword",{preprocessor:{pattern:/#(?:else|elseif|end|if)\b.*/,alias:"property"},metadata:{pattern:/@:?[\w.]+/,alias:"symbol"},reification:{pattern:/\$(?:\w+|(?=\{))/,alias:"important"}})}return lv}var sv,dL;function Dge(){if(dL)return sv;dL=1,sv=e,e.displayName="hcl",e.aliases=[];function e(t){t.languages.hcl={comment:/(?:\/\/|#).*|\/\*[\s\S]*?(?:\*\/|$)/,heredoc:{pattern:/<<-?(\w+\b)[\s\S]*?^[ \t]*\1/m,greedy:!0,alias:"string"},keyword:[{pattern:/(?:data|resource)\s+(?:"(?:\\[\s\S]|[^\\"])*")(?=\s+"[\w-]+"\s+\{)/i,inside:{type:{pattern:/(resource|data|\s+)(?:"(?:\\[\s\S]|[^\\"])*")/i,lookbehind:!0,alias:"variable"}}},{pattern:/(?:backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+(?=\{)/i,inside:{type:{pattern:/(backend|module|output|provider|provisioner|variable)\s+(?:[\w-]+|"(?:\\[\s\S]|[^\\"])*")\s+/i,lookbehind:!0,alias:"variable"}}},/[\w-]+(?=\s+\{)/],property:[/[-\w\.]+(?=\s*=(?!=))/,/"(?:\\[\s\S]|[^\\"])+"(?=\s*[:=])/],string:{pattern:/"(?:[^\\$"]|\\[\s\S]|\$(?:(?=")|\$+(?!\$)|[^"${])|\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\})*"/,greedy:!0,inside:{interpolation:{pattern:/(^|[^$])\$\{(?:[^{}"]|"(?:[^\\"]|\\[\s\S])*")*\}/,lookbehind:!0,inside:{type:{pattern:/(\b(?:count|data|local|module|path|self|terraform|var)\b\.)[\w\*]+/i,lookbehind:!0,alias:"variable"},keyword:/\b(?:count|data|local|module|path|self|terraform|var)\b/i,function:/\w+(?=\()/,string:{pattern:/"(?:\\[\s\S]|[^\\"])*"/,greedy:!0},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[!\$#%&'()*+,.\/;<=>@\[\\\]^`{|}~?:]/}}}},number:/\b0x[\da-f]+\b|\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,boolean:/\b(?:false|true)\b/i,punctuation:/[=\[\]{}]/}}return sv}var uv,fL;function Ige(){if(fL)return uv;fL=1;var e=fi();uv=t,t.displayName="hlsl",t.aliases=[];function t(n){n.register(e),n.languages.hlsl=n.languages.extend("c",{"class-name":[n.languages.c["class-name"],/\b(?:AppendStructuredBuffer|BlendState|Buffer|ByteAddressBuffer|CompileShader|ComputeShader|ConsumeStructuredBuffer|DepthStencilState|DepthStencilView|DomainShader|GeometryShader|Hullshader|InputPatch|LineStream|OutputPatch|PixelShader|PointStream|RWBuffer|RWByteAddressBuffer|RWStructuredBuffer|RWTexture(?:1D|1DArray|2D|2DArray|3D)|RasterizerState|RenderTargetView|SamplerComparisonState|SamplerState|StructuredBuffer|Texture(?:1D|1DArray|2D|2DArray|2DMS|2DMSArray|3D|Cube|CubeArray)|TriangleStream|VertexShader)\b/],keyword:[/\b(?:asm|asm_fragment|auto|break|case|catch|cbuffer|centroid|char|class|column_major|compile|compile_fragment|const|const_cast|continue|default|delete|discard|do|dynamic_cast|else|enum|explicit|export|extern|for|friend|fxgroup|goto|groupshared|if|in|inline|inout|interface|line|lineadj|linear|long|matrix|mutable|namespace|new|nointerpolation|noperspective|operator|out|packoffset|pass|pixelfragment|point|precise|private|protected|public|register|reinterpret_cast|return|row_major|sample|sampler|shared|short|signed|sizeof|snorm|stateblock|stateblock_state|static|static_cast|string|struct|switch|tbuffer|technique|technique10|technique11|template|texture|this|throw|triangle|triangleadj|try|typedef|typename|uniform|union|unorm|unsigned|using|vector|vertexfragment|virtual|void|volatile|while)\b/,/\b(?:bool|double|dword|float|half|int|min(?:10float|12int|16(?:float|int|uint))|uint)(?:[1-4](?:x[1-4])?)?\b/],number:/(?:(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?|\b0x[\da-fA-F]+)[fFhHlLuU]?\b/,boolean:/\b(?:false|true)\b/})}return uv}var cv,pL;function Lge(){if(pL)return cv;pL=1,cv=e,e.displayName="hoon",e.aliases=[];function e(t){t.languages.hoon={comment:{pattern:/::.*/,greedy:!0},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},constant:/%(?:\.[ny]|[\w-]+)/,"class-name":/@(?:[a-z0-9-]*[a-z0-9])?|\*/i,function:/(?:\+[-+] {2})?(?:[a-z](?:[a-z0-9-]*[a-z0-9])?)/,keyword:/\.[\^\+\*=\?]|![><:\.=\?!]|=[>|:,\.\-\^<+;/~\*\?]|\?[>|:\.\-\^<\+&~=@!]|\|[\$_%:\.\-\^~\*=@\?]|\+[|\$\+\*]|:[_\-\^\+~\*]|%[_:\.\-\^\+~\*=]|\^[|:\.\-\+&~\*=\?]|\$[|_%:<>\-\^&~@=\?]|;[:<\+;\/~\*=]|~[>|\$_%<\+\/&=\?!]|--|==/}}return cv}var dv,gL;function Mge(){if(gL)return dv;gL=1,dv=e,e.displayName="hpkp",e.aliases=[];function e(t){t.languages.hpkp={directive:{pattern:/\b(?:includeSubDomains|max-age|pin-sha256|preload|report-to|report-uri|strict)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}return dv}var fv,hL;function Fge(){if(hL)return fv;hL=1,fv=e,e.displayName="hsts",e.aliases=[];function e(t){t.languages.hsts={directive:{pattern:/\b(?:includeSubDomains|max-age|preload)(?=[\s;=]|$)/i,alias:"property"},operator:/=/,punctuation:/;/}}return fv}var pv,mL;function zge(){if(mL)return pv;mL=1,pv=e,e.displayName="http",e.aliases=[];function e(t){(function(n){function r(g){return RegExp("(^(?:"+g+"):[ 	]*(?![ 	]))[^]+","i")}n.languages.http={"request-line":{pattern:/^(?:CONNECT|DELETE|GET|HEAD|OPTIONS|PATCH|POST|PRI|PUT|SEARCH|TRACE)\s(?:https?:\/\/|\/)\S*\sHTTP\/[\d.]+/m,inside:{method:{pattern:/^[A-Z]+\b/,alias:"property"},"request-target":{pattern:/^(\s)(?:https?:\/\/|\/)\S*(?=\s)/,lookbehind:!0,alias:"url",inside:n.languages.uri},"http-version":{pattern:/^(\s)HTTP\/[\d.]+/,lookbehind:!0,alias:"property"}}},"response-status":{pattern:/^HTTP\/[\d.]+ \d+ .+/m,inside:{"http-version":{pattern:/^HTTP\/[\d.]+/,alias:"property"},"status-code":{pattern:/^(\s)\d+(?=\s)/,lookbehind:!0,alias:"number"},"reason-phrase":{pattern:/^(\s).+/,lookbehind:!0,alias:"string"}}},header:{pattern:/^[\w-]+:.+(?:(?:\r\n?|\n)[ \t].+)*/m,inside:{"header-value":[{pattern:r(/Content-Security-Policy/.source),lookbehind:!0,alias:["csp","languages-csp"],inside:n.languages.csp},{pattern:r(/Public-Key-Pins(?:-Report-Only)?/.source),lookbehind:!0,alias:["hpkp","languages-hpkp"],inside:n.languages.hpkp},{pattern:r(/Strict-Transport-Security/.source),lookbehind:!0,alias:["hsts","languages-hsts"],inside:n.languages.hsts},{pattern:r(/[^:]+/.source),lookbehind:!0}],"header-name":{pattern:/^[^:]+/,alias:"keyword"},punctuation:/^:/}}};var a=n.languages,i={"application/javascript":a.javascript,"application/json":a.json||a.javascript,"application/xml":a.xml,"text/xml":a.xml,"text/html":a.html,"text/css":a.css,"text/plain":a.plain},l={"application/json":!0,"application/xml":!0};function u(g){var b=g.replace(/^[a-z]+\//,""),m="\\w+/(?:[\\w.-]+\\+)+"+b+"(?![+\\w.-])";return"(?:"+g+"|"+m+")"}var c;for(var f in i)if(i[f]){c=c||{};var p=l[f]?u(f):f;c[f.replace(/\//g,"-")]={pattern:RegExp("("+/content-type:\s*/.source+p+/(?:(?:\r\n?|\n)[\w-].*)*(?:\r(?:\n|(?!\n))|\n)/.source+")"+/[^ \t\w-][\s\S]*/.source,"i"),lookbehind:!0,inside:i[f]}}c&&n.languages.insertBefore("http","header",c)})(t)}return pv}var gv,bL;function Pge(){if(bL)return gv;bL=1,gv=e,e.displayName="ichigojam",e.aliases=[];function e(t){t.languages.ichigojam={comment:/(?:\B'|REM)(?:[^\n\r]*)/i,string:{pattern:/"(?:""|[!#$%&'()*,\/:;<=>?^\w +\-.])*"/,greedy:!0},number:/\B#[0-9A-F]+|\B`[01]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,keyword:/\b(?:BEEP|BPS|CASE|CLEAR|CLK|CLO|CLP|CLS|CLT|CLV|CONT|COPY|ELSE|END|FILE|FILES|FOR|GOSUB|GOTO|GSB|IF|INPUT|KBD|LED|LET|LIST|LOAD|LOCATE|LRUN|NEW|NEXT|OUT|PLAY|POKE|PRINT|PWM|REM|RENUM|RESET|RETURN|RIGHT|RTN|RUN|SAVE|SCROLL|SLEEP|SRND|STEP|STOP|SUB|TEMPO|THEN|TO|UART|VIDEO|WAIT)(?:\$|\b)/i,function:/\b(?:ABS|ANA|ASC|BIN|BTN|DEC|END|FREE|HELP|HEX|I2CR|I2CW|IN|INKEY|LEN|LINE|PEEK|RND|SCR|SOUND|STR|TICK|USR|VER|VPEEK|ZER)(?:\$|\b)/i,label:/(?:\B@\S+)/,operator:/<[=>]?|>=?|\|\||&&|[+\-*\/=|&^~!]|\b(?:AND|NOT|OR)\b/i,punctuation:/[\[,;:()\]]/}}return gv}var hv,yL;function Bge(){if(yL)return hv;yL=1,hv=e,e.displayName="icon",e.aliases=[];function e(t){t.languages.icon={comment:/#.*/,string:{pattern:/(["'])(?:(?!\1)[^\\\r\n_]|\\.|_(?!\1)(?:\r\n|[\s\S]))*\1/,greedy:!0},number:/\b(?:\d+r[a-z\d]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b|\.\d+\b/i,"builtin-keyword":{pattern:/&(?:allocated|ascii|clock|collections|cset|current|date|dateline|digits|dump|e|error(?:number|text|value)?|errout|fail|features|file|host|input|lcase|letters|level|line|main|null|output|phi|pi|pos|progname|random|regions|source|storage|subject|time|trace|ucase|version)\b/,alias:"variable"},directive:{pattern:/\$\w+/,alias:"builtin"},keyword:/\b(?:break|by|case|create|default|do|else|end|every|fail|global|if|initial|invocable|link|local|next|not|of|procedure|record|repeat|return|static|suspend|then|to|until|while)\b/,function:/\b(?!\d)\w+(?=\s*[({]|\s*!\s*\[)/,operator:/[+-]:(?!=)|(?:[\/?@^%&]|\+\+?|--?|==?=?|~==?=?|\*\*?|\|\|\|?|<(?:->?|<?=?)|>>?=?)(?::=)?|:(?:=:?)?|[!.\\|~]/,punctuation:/[\[\](){},;]/}}return hv}var mv,vL;function Uge(){if(vL)return mv;vL=1,mv=e,e.displayName="icuMessageFormat",e.aliases=[];function e(t){(function(n){function r(f,p){return p<=0?/[]/.source:f.replace(/<SELF>/g,function(){return r(f,p-1)})}var a=/'[{}:=,](?:[^']|'')*'(?!')/,i={pattern:/''/,greedy:!0,alias:"operator"},l={pattern:a,greedy:!0,inside:{escape:i}},u=r(/\{(?:[^{}']|'(?![{},'])|''|<STR>|<SELF>)*\}/.source.replace(/<STR>/g,function(){return a.source}),8),c={pattern:RegExp(u),inside:{message:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:null},"message-delimiter":{pattern:/./,alias:"punctuation"}}};n.languages["icu-message-format"]={argument:{pattern:RegExp(u),greedy:!0,inside:{content:{pattern:/^(\{)[\s\S]+(?=\}$)/,lookbehind:!0,inside:{"argument-name":{pattern:/^(\s*)[^{}:=,\s]+/,lookbehind:!0},"choice-style":{pattern:/^(\s*,\s*choice\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{punctuation:/\|/,range:{pattern:/^(\s*)[+-]?(?:\d+(?:\.\d*)?|\u221e)\s*[<#\u2264]/,lookbehind:!0,inside:{operator:/[<#\u2264]/,number:/\S+/}},rest:null}},"plural-style":{pattern:/^(\s*,\s*(?:plural|selectordinal)\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{offset:/^offset:\s*\d+/,"nested-message":c,selector:{pattern:/=\d+|[^{}:=,\s]+/,inside:{keyword:/^(?:few|many|one|other|two|zero)$/}}}},"select-style":{pattern:/^(\s*,\s*select\s*,\s*)\S(?:[\s\S]*\S)?/,lookbehind:!0,inside:{"nested-message":c,selector:{pattern:/[^{}:=,\s]+/,inside:{keyword:/^other$/}}}},keyword:/\b(?:choice|plural|select|selectordinal)\b/,"arg-type":{pattern:/\b(?:date|duration|number|ordinal|spellout|time)\b/,alias:"keyword"},"arg-skeleton":{pattern:/(,\s*)::[^{}:=,\s]+/,lookbehind:!0},"arg-style":{pattern:/(,\s*)(?:currency|full|integer|long|medium|percent|short)(?=\s*$)/,lookbehind:!0},"arg-style-text":{pattern:RegExp(/(^\s*,\s*(?=\S))/.source+r(/(?:[^{}']|'[^']*'|\{(?:<SELF>)?\})+/.source,8)+"$"),lookbehind:!0,alias:"string"},punctuation:/,/}},"argument-delimiter":{pattern:/./,alias:"operator"}}},escape:i,string:l},c.inside.message.inside=n.languages["icu-message-format"],n.languages["icu-message-format"].argument.inside.content.inside["choice-style"].inside.rest=n.languages["icu-message-format"]})(t)}return mv}var bv,SL;function jge(){if(SL)return bv;SL=1;var e=cA();bv=t,t.displayName="idris",t.aliases=["idr"];function t(n){n.register(e),n.languages.idris=n.languages.extend("haskell",{comment:{pattern:/(?:(?:--|\|\|\|).*$|\{-[\s\S]*?-\})/m},keyword:/\b(?:Type|case|class|codata|constructor|corecord|data|do|dsl|else|export|if|implementation|implicit|import|impossible|in|infix|infixl|infixr|instance|interface|let|module|mutual|namespace|of|parameters|partial|postulate|private|proof|public|quoteGoal|record|rewrite|syntax|then|total|using|where|with)\b/,builtin:void 0}),n.languages.insertBefore("idris","keyword",{"import-statement":{pattern:/(^\s*import\s+)(?:[A-Z][\w']*)(?:\.[A-Z][\w']*)*/m,lookbehind:!0,inside:{punctuation:/\./}}}),n.languages.idr=n.languages.idris}return bv}var yv,EL;function Gge(){if(EL)return yv;EL=1,yv=e,e.displayName="iecst",e.aliases=[];function e(t){t.languages.iecst={comment:[{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\(\*[\s\S]*?(?:\*\)|$)|\{[\s\S]*?(?:\}|$))/,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:[/\b(?:END_)?(?:PROGRAM|CONFIGURATION|INTERFACE|FUNCTION_BLOCK|FUNCTION|ACTION|TRANSITION|TYPE|STRUCT|(?:INITIAL_)?STEP|NAMESPACE|LIBRARY|CHANNEL|FOLDER|RESOURCE|VAR_(?:ACCESS|CONFIG|EXTERNAL|GLOBAL|INPUT|IN_OUT|OUTPUT|TEMP)|VAR|METHOD|PROPERTY)\b/i,/\b(?:AT|BY|(?:END_)?(?:CASE|FOR|IF|REPEAT|WHILE)|CONSTANT|CONTINUE|DO|ELSE|ELSIF|EXIT|EXTENDS|FROM|GET|GOTO|IMPLEMENTS|JMP|NON_RETAIN|OF|PRIVATE|PROTECTED|PUBLIC|RETAIN|RETURN|SET|TASK|THEN|TO|UNTIL|USING|WITH|__CATCH|__ENDTRY|__FINALLY|__TRY)\b/],"class-name":/\b(?:ANY|ARRAY|BOOL|BYTE|U?(?:D|L|S)?INT|(?:D|L)?WORD|DATE(?:_AND_TIME)?|DT|L?REAL|POINTER|STRING|TIME(?:_OF_DAY)?|TOD)\b/,address:{pattern:/%[IQM][XBWDL][\d.]*|%[IQ][\d.]*/,alias:"symbol"},number:/\b(?:16#[\da-f]+|2#[01_]+|0x[\da-f]+)\b|\b(?:D|DT|T|TOD)#[\d_shmd:]*|\b[A-Z]*#[\d.,_]*|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,boolean:/\b(?:FALSE|NULL|TRUE)\b/,operator:/S?R?:?=>?|&&?|\*\*?|<[=>]?|>=?|[-:^/+#]|\b(?:AND|EQ|EXPT|GE|GT|LE|LT|MOD|NE|NOT|OR|XOR)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,punctuation:/[()[\].,;]/}}return yv}var vv,wL;function Hge(){if(wL)return vv;wL=1,vv=e,e.displayName="ignore",e.aliases=["gitignore","hgignore","npmignore"];function e(t){(function(n){n.languages.ignore={comment:/^#.*/m,entry:{pattern:/\S(?:.*(?:(?:\\ )|\S))?/,alias:"string",inside:{operator:/^!|\*\*?|\?/,regex:{pattern:/(^|[^\\])\[[^\[\]]*\]/,lookbehind:!0},punctuation:/\//}}},n.languages.gitignore=n.languages.ignore,n.languages.hgignore=n.languages.ignore,n.languages.npmignore=n.languages.ignore})(t)}return vv}var Sv,xL;function $ge(){if(xL)return Sv;xL=1,Sv=e,e.displayName="inform7",e.aliases=[];function e(t){t.languages.inform7={string:{pattern:/"[^"]*"/,inside:{substitution:{pattern:/\[[^\[\]]+\]/,inside:{delimiter:{pattern:/\[|\]/,alias:"punctuation"}}}}},comment:{pattern:/\[[^\[\]]+\]/,greedy:!0},title:{pattern:/^[ \t]*(?:book|chapter|part(?! of)|section|table|volume)\b.+/im,alias:"important"},number:{pattern:/(^|[^-])(?:\b\d+(?:\.\d+)?(?:\^\d+)?(?:(?!\d)\w+)?|\b(?:eight|eleven|five|four|nine|one|seven|six|ten|three|twelve|two))\b(?!-)/i,lookbehind:!0},verb:{pattern:/(^|[^-])\b(?:answering|applying to|are|asking|attacking|be(?:ing)?|burning|buying|called|carries|carry(?! out)|carrying|climbing|closing|conceal(?:ing|s)?|consulting|contain(?:ing|s)?|cutting|drinking|dropping|eating|enclos(?:es?|ing)|entering|examining|exiting|getting|giving|going|ha(?:s|ve|ving)|hold(?:ing|s)?|impl(?:ies|y)|incorporat(?:es?|ing)|inserting|is|jumping|kissing|listening|locking|looking|mean(?:ing|s)?|opening|provid(?:es?|ing)|pulling|pushing|putting|relat(?:es?|ing)|removing|searching|see(?:ing|s)?|setting|showing|singing|sleeping|smelling|squeezing|support(?:ing|s)?|swearing|switching|taking|tasting|telling|thinking|throwing|touching|turning|tying|unlock(?:ing|s)?|var(?:ies|y|ying)|waiting|waking|waving|wear(?:ing|s)?)\b(?!-)/i,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^-])\b(?:after|before|carry out|check|continue the action|definition(?= *:)|do nothing|else|end (?:if|the story|unless)|every turn|if|include|instead(?: of)?|let|move|no|now|otherwise|repeat|report|resume the story|rule for|running through|say(?:ing)?|stop the action|test|try(?:ing)?|understand|unless|use|when|while|yes)\b(?!-)/i,lookbehind:!0},property:{pattern:/(^|[^-])\b(?:adjacent(?! to)|carried|closed|concealed|contained|dark|described|edible|empty|enclosed|enterable|even|female|fixed in place|full|handled|held|improper-named|incorporated|inedible|invisible|lighted|lit|lock(?:able|ed)|male|marked for listing|mentioned|negative|neuter|non-(?:empty|full|recurring)|odd|opaque|open(?:able)?|plural-named|portable|positive|privately-named|proper-named|provided|publically-named|pushable between rooms|recurring|related|rubbing|scenery|seen|singular-named|supported|swinging|switch(?:able|ed(?: off| on)?)|touch(?:able|ed)|transparent|unconcealed|undescribed|unlit|unlocked|unmarked for listing|unmentioned|unopenable|untouchable|unvisited|variable|visible|visited|wearable|worn)\b(?!-)/i,lookbehind:!0,alias:"symbol"},position:{pattern:/(^|[^-])\b(?:above|adjacent to|back side of|below|between|down|east|everywhere|front side|here|in|inside(?: from)?|north(?:east|west)?|nowhere|on(?: top of)?|other side|outside(?: from)?|parts? of|regionally in|south(?:east|west)?|through|up|west|within)\b(?!-)/i,lookbehind:!0,alias:"keyword"},type:{pattern:/(^|[^-])\b(?:actions?|activit(?:ies|y)|actors?|animals?|backdrops?|containers?|devices?|directions?|doors?|holders?|kinds?|lists?|m[ae]n|nobody|nothing|nouns?|numbers?|objects?|people|persons?|player(?:'s holdall)?|regions?|relations?|rooms?|rule(?:book)?s?|scenes?|someone|something|supporters?|tables?|texts?|things?|time|vehicles?|wom[ae]n)\b(?!-)/i,lookbehind:!0,alias:"variable"},punctuation:/[.,:;(){}]/},t.languages.inform7.string.inside.substitution.inside.rest=t.languages.inform7,t.languages.inform7.string.inside.substitution.inside.rest.text={pattern:/\S(?:\s*\S)*/,alias:"comment"}}return Sv}var Ev,kL;function qge(){if(kL)return Ev;kL=1,Ev=e,e.displayName="ini",e.aliases=[];function e(t){t.languages.ini={comment:{pattern:/(^[ \f\t\v]*)[#;][^\n\r]*/m,lookbehind:!0},section:{pattern:/(^[ \f\t\v]*)\[[^\n\r\]]*\]?/m,lookbehind:!0,inside:{"section-name":{pattern:/(^\[[ \f\t\v]*)[^ \f\t\v\]]+(?:[ \f\t\v]+[^ \f\t\v\]]+)*/,lookbehind:!0,alias:"selector"},punctuation:/\[|\]/}},key:{pattern:/(^[ \f\t\v]*)[^ \f\n\r\t\v=]+(?:[ \f\t\v]+[^ \f\n\r\t\v=]+)*(?=[ \f\t\v]*=)/m,lookbehind:!0,alias:"attr-name"},value:{pattern:/(=[ \f\t\v]*)[^ \f\n\r\t\v]+(?:[ \f\t\v]+[^ \f\n\r\t\v]+)*/,lookbehind:!0,alias:"attr-value",inside:{"inner-value":{pattern:/^("|').+(?=\1$)/,lookbehind:!0}}},punctuation:/=/}}return Ev}var wv,AL;function Vge(){if(AL)return wv;AL=1,wv=e,e.displayName="io",e.aliases=[];function e(t){t.languages.io={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?(?:\*\/|$)|\/\/.*|#.*)/,lookbehind:!0,greedy:!0},"triple-quoted-string":{pattern:/"""(?:\\[\s\S]|(?!""")[^\\])*"""/,greedy:!0,alias:"string"},string:{pattern:/"(?:\\.|[^\\\r\n"])*"/,greedy:!0},keyword:/\b(?:activate|activeCoroCount|asString|block|break|call|catch|clone|collectGarbage|compileString|continue|do|doFile|doMessage|doString|else|elseif|exit|for|foreach|forward|getEnvironmentVariable|getSlot|hasSlot|if|ifFalse|ifNil|ifNilEval|ifTrue|isActive|isNil|isResumable|list|message|method|parent|pass|pause|perform|performWithArgList|print|println|proto|raise|raiseResumable|removeSlot|resend|resume|schedulerSleepSeconds|self|sender|setSchedulerSleepSeconds|setSlot|shallowCopy|slotNames|super|system|then|thisBlock|thisContext|try|type|uniqueId|updateSlot|wait|while|write|yield)\b/,builtin:/\b(?:Array|AudioDevice|AudioMixer|BigNum|Block|Box|Buffer|CFunction|CGI|Color|Curses|DBM|DNSResolver|DOConnection|DOProxy|DOServer|Date|Directory|Duration|DynLib|Error|Exception|FFT|File|Fnmatch|Font|Future|GL|GLE|GLScissor|GLU|GLUCylinder|GLUQuadric|GLUSphere|GLUT|Host|Image|Importer|LinkList|List|Lobby|Locals|MD5|MP3Decoder|MP3Encoder|Map|Message|Movie|Notification|Number|Object|OpenGL|Point|Protos|Random|Regex|SGML|SGMLElement|SGMLParser|SQLite|Sequence|Server|ShowMessage|SleepyCat|SleepyCatCursor|Socket|SocketManager|Sound|Soup|Store|String|Tree|UDPSender|UPDReceiver|URL|User|Warning|WeakLink)\b/,boolean:/\b(?:false|nil|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e-?\d+)?/i,operator:/[=!*/%+\-^&|]=|>>?=?|<<?=?|:?:?=|\+\+?|--?|\*\*?|\/\/?|%|\|\|?|&&?|\b(?:and|not|or|return)\b|@@?|\?\??|\.\./,punctuation:/[{}[\];(),.:]/}}return wv}var xv,TL;function Wge(){if(TL)return xv;TL=1,xv=e,e.displayName="j",e.aliases=[];function e(t){t.languages.j={comment:{pattern:/\bNB\..*/,greedy:!0},string:{pattern:/'(?:''|[^'\r\n])*'/,greedy:!0},keyword:/\b(?:(?:CR|LF|adverb|conjunction|def|define|dyad|monad|noun|verb)\b|(?:assert|break|case|catch[dt]?|continue|do|else|elseif|end|fcase|for|for_\w+|goto_\w+|if|label_\w+|return|select|throw|try|while|whilst)\.)/,verb:{pattern:/(?!\^:|;\.|[=!][.:])(?:\{(?:\.|::?)?|p(?:\.\.?|:)|[=!\]]|[<>+*\-%$|,#][.:]?|[?^]\.?|[;\[]:?|[~}"i][.:]|[ACeEIjLor]\.|(?:[_\/\\qsux]|_?\d):)/,alias:"keyword"},number:/\b_?(?:(?!\d:)\d+(?:\.\d+)?(?:(?:ad|ar|[ejpx])_?\d+(?:\.\d+)?)*(?:b_?[\da-z]+(?:\.[\da-z]+)?)?|_\b(?!\.))/,adverb:{pattern:/[~}]|[\/\\]\.?|[bfM]\.|t[.:]/,alias:"builtin"},operator:/[=a][.:]|_\./,conjunction:{pattern:/&(?:\.:?|:)?|[.:@][.:]?|[!D][.:]|[;dHT]\.|`:?|[\^LS]:|"/,alias:"variable"},punctuation:/[()]/}}return xv}var kv,_L;function dA(){if(_L)return kv;_L=1,kv=e,e.displayName="java",e.aliases=[];function e(t){(function(n){var r=/\b(?:abstract|assert|boolean|break|byte|case|catch|char|class|const|continue|default|do|double|else|enum|exports|extends|final|finally|float|for|goto|if|implements|import|instanceof|int|interface|long|module|native|new|non-sealed|null|open|opens|package|permits|private|protected|provides|public|record|requires|return|sealed|short|static|strictfp|super|switch|synchronized|this|throw|throws|to|transient|transitive|try|uses|var|void|volatile|while|with|yield)\b/,a=/(^|[^\w.])(?:[a-z]\w*\s*\.\s*)*(?:[A-Z]\w*\s*\.\s*)*/.source,i={pattern:RegExp(a+/[A-Z](?:[\d_A-Z]*[a-z]\w*)?\b/.source),lookbehind:!0,inside:{namespace:{pattern:/^[a-z]\w*(?:\s*\.\s*[a-z]\w*)*(?:\s*\.)?/,inside:{punctuation:/\./}},punctuation:/\./}};n.languages.java=n.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\.|[^"\\\r\n])*"/,lookbehind:!0,greedy:!0},"class-name":[i,{pattern:RegExp(a+/[A-Z]\w*(?=\s+\w+\s*[;,=()])/.source),lookbehind:!0,inside:i.inside}],keyword:r,function:[n.languages.clike.function,{pattern:/(::\s*)[a-z_]\w*/,lookbehind:!0}],number:/\b0b[01][01_]*L?\b|\b0x(?:\.[\da-f_p+-]+|[\da-f_]+(?:\.[\da-f_p+-]+)?)\b|(?:\b\d[\d_]*(?:\.[\d_]*)?|\B\.\d[\d_]*)(?:e[+-]?\d[\d_]*)?[dfl]?/i,operator:{pattern:/(^|[^.])(?:<<=?|>>>?=?|->|--|\+\+|&&|\|\||::|[?:~]|[-+*/%&|^!=<>]=?)/m,lookbehind:!0}}),n.languages.insertBefore("java","string",{"triple-quoted-string":{pattern:/"""[ \t]*[\r\n](?:(?:"|"")?(?:\\.|[^"\\]))*"""/,greedy:!0,alias:"string"},char:{pattern:/'(?:\\.|[^'\\\r\n]){1,6}'/,greedy:!0}}),n.languages.insertBefore("java","class-name",{annotation:{pattern:/(^|[^.])@\w+(?:\s*\.\s*\w+)*/,lookbehind:!0,alias:"punctuation"},generics:{pattern:/<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&)|<(?:[\w\s,.?]|&(?!&))*>)*>)*>)*>/,inside:{"class-name":i,keyword:r,punctuation:/[<>(),.:]/,operator:/[?&|]/}},namespace:{pattern:RegExp(/(\b(?:exports|import(?:\s+static)?|module|open|opens|package|provides|requires|to|transitive|uses|with)\s+)(?!<keyword>)[a-z]\w*(?:\.[a-z]\w*)*\.?/.source.replace(/<keyword>/g,function(){return r.source})),lookbehind:!0,inside:{punctuation:/\./}}})})(t)}return kv}var Av,RL;function Yf(){if(RL)return Av;RL=1,Av=e,e.displayName="javadoclike",e.aliases=[];function e(t){(function(n){var r=n.languages.javadoclike={parameter:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*@(?:arg|arguments|param)\s+)\w+/m,lookbehind:!0},keyword:{pattern:/(^[\t ]*(?:\/{3}|\*|\/\*\*)\s*|\{)@[a-z][a-zA-Z-]+\b/m,lookbehind:!0},punctuation:/[{}]/};function a(l,u){var c="doc-comment",f=n.languages[l];if(f){var p=f[c];if(!p){var g={};g[c]={pattern:/(^|[^\\])\/\*\*[^/][\s\S]*?(?:\*\/|$)/,lookbehind:!0,alias:"comment"},f=n.languages.insertBefore(l,"comment",g),p=f[c]}if(p instanceof RegExp&&(p=f[c]={pattern:p}),Array.isArray(p))for(var b=0,m=p.length;b<m;b++)p[b]instanceof RegExp&&(p[b]={pattern:p[b]}),u(p[b]);else u(p)}}function i(l,u){typeof l=="string"&&(l=[l]),l.forEach(function(c){a(c,function(f){f.inside||(f.inside={}),f.inside.rest=u})})}Object.defineProperty(r,"addSupport",{value:i}),r.addSupport(["java","javascript","php"],r)})(t)}return Av}var Tv,CL;function Yge(){if(CL)return Tv;CL=1;var e=dA(),t=Yf();Tv=n,n.displayName="javadoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var i=/(^(?:[\t ]*(?:\*\s*)*))[^*\s].*$/m,l=/#\s*\w+(?:\s*\([^()]*\))?/.source,u=/(?:\b[a-zA-Z]\w+\s*\.\s*)*\b[A-Z]\w*(?:\s*<mem>)?|<mem>/.source.replace(/<mem>/g,function(){return l});a.languages.javadoc=a.languages.extend("javadoclike",{}),a.languages.insertBefore("javadoc","keyword",{reference:{pattern:RegExp(/(@(?:exception|link|linkplain|see|throws|value)\s+(?:\*\s*)?)/.source+"(?:"+u+")"),lookbehind:!0,inside:{function:{pattern:/(#\s*)\w+(?=\s*\()/,lookbehind:!0},field:{pattern:/(#\s*)\w+/,lookbehind:!0},namespace:{pattern:/\b(?:[a-z]\w*\s*\.\s*)+/,inside:{punctuation:/\./}},"class-name":/\b[A-Z]\w*/,keyword:a.languages.java.keyword,punctuation:/[#()[\],.]/}},"class-name":{pattern:/(@param\s+)<[A-Z]\w*>/,lookbehind:!0,inside:{punctuation:/[.<>]/}},"code-section":[{pattern:/(\{@code\s+(?!\s))(?:[^\s{}]|\s+(?![\s}])|\{(?:[^{}]|\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})*\})*\})+(?=\s*\})/,lookbehind:!0,inside:{code:{pattern:i,lookbehind:!0,inside:a.languages.java,alias:"language-java"}}},{pattern:/(<(code|pre|tt)>(?!<code>)\s*)\S(?:\S|\s+\S)*?(?=\s*<\/\2>)/,lookbehind:!0,inside:{line:{pattern:i,lookbehind:!0,inside:{tag:a.languages.markup.tag,entity:a.languages.markup.entity,code:{pattern:/.+/,inside:a.languages.java,alias:"language-java"}}}}}],tag:a.languages.markup.tag,entity:a.languages.markup.entity}),a.languages.javadoclike.addSupport("java",a.languages.javadoc)}(r)}return Tv}var _v,NL;function Kge(){if(NL)return _v;NL=1,_v=e,e.displayName="javastacktrace",e.aliases=[];function e(t){t.languages.javastacktrace={summary:{pattern:/^([\t ]*)(?:(?:Caused by:|Suppressed:|Exception in thread "[^"]*")[\t ]+)?[\w$.]+(?::.*)?$/m,lookbehind:!0,inside:{keyword:{pattern:/^([\t ]*)(?:(?:Caused by|Suppressed)(?=:)|Exception in thread)/m,lookbehind:!0},string:{pattern:/^(\s*)"[^"]*"/,lookbehind:!0},exceptions:{pattern:/^(:?\s*)[\w$.]+(?=:|$)/,lookbehind:!0,inside:{"class-name":/[\w$]+$/,namespace:/\b[a-z]\w*\b/,punctuation:/\./}},message:{pattern:/(:\s*)\S.*/,lookbehind:!0,alias:"string"},punctuation:/:/}},"stack-frame":{pattern:/^([\t ]*)at (?:[\w$./]|@[\w$.+-]*\/)+(?:<init>)?\([^()]*\)/m,lookbehind:!0,inside:{keyword:{pattern:/^(\s*)at(?= )/,lookbehind:!0},source:[{pattern:/(\()\w+\.\w+:\d+(?=\))/,lookbehind:!0,inside:{file:/^\w+\.\w+/,punctuation:/:/,"line-number":{pattern:/\b\d+\b/,alias:"number"}}},{pattern:/(\()[^()]*(?=\))/,lookbehind:!0,inside:{keyword:/^(?:Native Method|Unknown Source)$/}}],"class-name":/[\w$]+(?=\.(?:<init>|[\w$]+)\()/,function:/(?:<init>|[\w$]+)(?=\()/,"class-loader":{pattern:/(\s)[a-z]\w*(?:\.[a-z]\w*)*(?=\/[\w@$.]*\/)/,lookbehind:!0,alias:"namespace",inside:{punctuation:/\./}},module:{pattern:/([\s/])[a-z]\w*(?:\.[a-z]\w*)*(?:@[\w$.+-]*)?(?=\/)/,lookbehind:!0,inside:{version:{pattern:/(@)[\s\S]+/,lookbehind:!0,alias:"number"},punctuation:/[@.]/}},namespace:{pattern:/(?:\b[a-z]\w*\.)+/,inside:{punctuation:/\./}},punctuation:/[()/.]/}},more:{pattern:/^([\t ]*)\.{3} \d+ [a-z]+(?: [a-z]+)*/m,lookbehind:!0,inside:{punctuation:/\.{3}/,number:/\d+/,keyword:/\b[a-z]+(?: [a-z]+)*\b/}}}}return _v}var Rv,OL;function Xge(){if(OL)return Rv;OL=1,Rv=e,e.displayName="jexl",e.aliases=[];function e(t){t.languages.jexl={string:/(["'])(?:\\[\s\S]|(?!\1)[^\\])*\1/,transform:{pattern:/(\|\s*)[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*/,alias:"function",lookbehind:!0},function:/[a-zA-Zа-яА-Я_\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$][\wа-яА-Я\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u00FF$]*\s*(?=\()/,number:/\b\d+(?:\.\d+)?\b|\B\.\d+\b/,operator:/[<>!]=?|-|\+|&&|==|\|\|?|\/\/?|[?:*^%]/,boolean:/\b(?:false|true)\b/,keyword:/\bin\b/,punctuation:/[{}[\](),.]/}}return Rv}var Cv,DL;function Zge(){if(DL)return Cv;DL=1,Cv=e,e.displayName="jolie",e.aliases=[];function e(t){t.languages.jolie=t.languages.extend("clike",{string:{pattern:/(^|[^\\])"(?:\\[\s\S]|[^"\\])*"/,lookbehind:!0,greedy:!0},"class-name":{pattern:/((?:\b(?:as|courier|embed|in|inputPort|outputPort|service)\b|@)[ \t]*)\w+/,lookbehind:!0},keyword:/\b(?:as|cH|comp|concurrent|constants|courier|cset|csets|default|define|else|embed|embedded|execution|exit|extender|for|foreach|forward|from|global|if|import|in|include|init|inputPort|install|instanceof|interface|is_defined|linkIn|linkOut|main|new|nullProcess|outputPort|over|private|provide|public|scope|sequential|service|single|spawn|synchronized|this|throw|throws|type|undef|until|while|with)\b/,function:/\b[a-z_]\w*(?=[ \t]*[@(])/i,number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?l?/i,operator:/-[-=>]?|\+[+=]?|<[<=]?|[>=*!]=?|&&|\|\||[?\/%^@|]/,punctuation:/[()[\]{},;.:]/,builtin:/\b(?:Byte|any|bool|char|double|enum|float|int|length|long|ranges|regex|string|undefined|void)\b/}),t.languages.insertBefore("jolie","keyword",{aggregates:{pattern:/(\bAggregates\s*:\s*)(?:\w+(?:\s+with\s+\w+)?\s*,\s*)*\w+(?:\s+with\s+\w+)?/,lookbehind:!0,inside:{keyword:/\bwith\b/,"class-name":/\w+/,punctuation:/,/}},redirects:{pattern:/(\bRedirects\s*:\s*)(?:\w+\s*=>\s*\w+\s*,\s*)*(?:\w+\s*=>\s*\w+)/,lookbehind:!0,inside:{punctuation:/,/,"class-name":/\w+/,operator:/=>/}},property:{pattern:/\b(?:Aggregates|[Ii]nterfaces|Java|Javascript|Jolie|[Ll]ocation|OneWay|[Pp]rotocol|Redirects|RequestResponse)\b(?=[ \t]*:)/}})}return Cv}var Nv,IL;function Qge(){if(IL)return Nv;IL=1,Nv=e,e.displayName="jq",e.aliases=[];function e(t){(function(n){var r=/\\\((?:[^()]|\([^()]*\))*\)/.source,a=RegExp(/(^|[^\\])"(?:[^"\r\n\\]|\\[^\r\n(]|__)*"/.source.replace(/__/g,function(){return r})),i={interpolation:{pattern:RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+r),lookbehind:!0,inside:{content:{pattern:/^(\\\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:null},punctuation:/^\\\(|\)$/}}},l=n.languages.jq={comment:/#.*/,property:{pattern:RegExp(a.source+/(?=\s*:(?!:))/.source),lookbehind:!0,greedy:!0,inside:i},string:{pattern:a,lookbehind:!0,greedy:!0,inside:i},function:{pattern:/(\bdef\s+)[a-z_]\w+/i,lookbehind:!0},variable:/\B\$\w+/,"property-literal":{pattern:/\b[a-z_]\w*(?=\s*:(?!:))/i,alias:"property"},keyword:/\b(?:as|break|catch|def|elif|else|end|foreach|if|import|include|label|module|modulemeta|null|reduce|then|try|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b\d+\.|\B\.)?\b\d+(?:[eE][+-]?\d+)?\b/,operator:[{pattern:/\|=?/,alias:"pipe"},/\.\.|[!=<>]?=|\?\/\/|\/\/=?|[-+*/%]=?|[<>?]|\b(?:and|not|or)\b/],"c-style-function":{pattern:/\b[a-z_]\w*(?=\s*\()/i,alias:"function"},punctuation:/::|[()\[\]{},:;]|\.(?=\s*[\[\w$])/,dot:{pattern:/\./,alias:"important"}};i.interpolation.inside.content.inside=l})(t)}return Nv}var Ov,LL;function Jge(){if(LL)return Ov;LL=1,Ov=e,e.displayName="jsExtras",e.aliases=[];function e(t){(function(n){n.languages.insertBefore("javascript","function-variable",{"method-variable":{pattern:RegExp("(\\.\\s*)"+n.languages.javascript["function-variable"].pattern.source),lookbehind:!0,alias:["function-variable","method","function","property-access"]}}),n.languages.insertBefore("javascript","function",{method:{pattern:RegExp("(\\.\\s*)"+n.languages.javascript.function.source),lookbehind:!0,alias:["function","property-access"]}}),n.languages.insertBefore("javascript","constant",{"known-class-name":[{pattern:/\b(?:(?:Float(?:32|64)|(?:Int|Uint)(?:8|16|32)|Uint8Clamped)?Array|ArrayBuffer|BigInt|Boolean|DataView|Date|Error|Function|Intl|JSON|(?:Weak)?(?:Map|Set)|Math|Number|Object|Promise|Proxy|Reflect|RegExp|String|Symbol|WebAssembly)\b/,alias:"class-name"},{pattern:/\b(?:[A-Z]\w*)Error\b/,alias:"class-name"}]});function r(f,p){return RegExp(f.replace(/<ID>/g,function(){return/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/.source}),p)}n.languages.insertBefore("javascript","keyword",{imports:{pattern:r(/(\bimport\b\s*)(?:<ID>(?:\s*,\s*(?:\*\s*as\s+<ID>|\{[^{}]*\}))?|\*\s*as\s+<ID>|\{[^{}]*\})(?=\s*\bfrom\b)/.source),lookbehind:!0,inside:n.languages.javascript},exports:{pattern:r(/(\bexport\b\s*)(?:\*(?:\s*as\s+<ID>)?(?=\s*\bfrom\b)|\{[^{}]*\})/.source),lookbehind:!0,inside:n.languages.javascript}}),n.languages.javascript.keyword.unshift({pattern:/\b(?:as|default|export|from|import)\b/,alias:"module"},{pattern:/\b(?:await|break|catch|continue|do|else|finally|for|if|return|switch|throw|try|while|yield)\b/,alias:"control-flow"},{pattern:/\bnull\b/,alias:["null","nil"]},{pattern:/\bundefined\b/,alias:"nil"}),n.languages.insertBefore("javascript","operator",{spread:{pattern:/\.{3}/,alias:"operator"},arrow:{pattern:/=>/,alias:"operator"}}),n.languages.insertBefore("javascript","punctuation",{"property-access":{pattern:r(/(\.\s*)#?<ID>/.source),lookbehind:!0},"maybe-class-name":{pattern:/(^|[^$\w\xA0-\uFFFF])[A-Z][$\w\xA0-\uFFFF]+/,lookbehind:!0},dom:{pattern:/\b(?:document|(?:local|session)Storage|location|navigator|performance|window)\b/,alias:"variable"},console:{pattern:/\bconsole(?=\s*\.)/,alias:"class-name"}});for(var a=["function","function-variable","method","method-variable","property-access"],i=0;i<a.length;i++){var l=a[i],u=n.languages.javascript[l];n.util.type(u)==="RegExp"&&(u=n.languages.javascript[l]={pattern:u});var c=u.inside||{};u.inside=c,c["maybe-class-name"]=/^[A-Z][\s\S]*/}})(t)}return Ov}var Dv,ML;function ehe(){if(ML)return Dv;ML=1,Dv=e,e.displayName="jsTemplates",e.aliases=[];function e(t){(function(n){var r=n.languages.javascript["template-string"],a=r.pattern.source,i=r.inside.interpolation,l=i.inside["interpolation-punctuation"],u=i.pattern.source;function c(v,A){if(n.languages[v])return{pattern:RegExp("((?:"+A+")\\s*)"+a),lookbehind:!0,greedy:!0,inside:{"template-punctuation":{pattern:/^`|`$/,alias:"string"},"embedded-code":{pattern:/[\s\S]+/,alias:v}}}}n.languages.javascript["template-string"]=[c("css",/\b(?:styled(?:\([^)]*\))?(?:\s*\.\s*\w+(?:\([^)]*\))*)*|css(?:\s*\.\s*(?:global|resolve))?|createGlobalStyle|keyframes)/.source),c("html",/\bhtml|\.\s*(?:inner|outer)HTML\s*\+?=/.source),c("svg",/\bsvg/.source),c("markdown",/\b(?:markdown|md)/.source),c("graphql",/\b(?:gql|graphql(?:\s*\.\s*experimental)?)/.source),c("sql",/\bsql/.source),r].filter(Boolean);function f(v,A){return"___"+A.toUpperCase()+"_"+v+"___"}function p(v,A,R){var x={code:v,grammar:A,language:R};return n.hooks.run("before-tokenize",x),x.tokens=n.tokenize(x.code,x.grammar),n.hooks.run("after-tokenize",x),x.tokens}function g(v){var A={};A["interpolation-punctuation"]=l;var R=n.tokenize(v,A);if(R.length===3){var x=[1,1];x.push.apply(x,p(R[1],n.languages.javascript,"javascript")),R.splice.apply(R,x)}return new n.Token("interpolation",R,i.alias,v)}function b(v,A,R){var x=n.tokenize(v,{interpolation:{pattern:RegExp(u),lookbehind:!0}}),T=0,C={},N=x.map(function(I){if(typeof I=="string")return I;for(var M=I.content,H;v.indexOf(H=f(T++,R))!==-1;);return C[H]=M,H}).join(""),_=p(N,A,R),O=Object.keys(C);T=0;function z(I){for(var M=0;M<I.length;M++){if(T>=O.length)return;var H=I[M];if(typeof H=="string"||typeof H.content=="string"){var q=O[T],P=typeof H=="string"?H:H.content,W=P.indexOf(q);if(W!==-1){++T;var Z=P.substring(0,W),j=g(C[q]),G=P.substring(W+q.length),B=[];if(Z&&B.push(Z),B.push(j),G){var X=[G];z(X),B.push.apply(B,X)}typeof H=="string"?(I.splice.apply(I,[M,1].concat(B)),M+=B.length-1):H.content=B}}else{var D=H.content;Array.isArray(D)?z(D):z([D])}}}return z(_),new n.Token(R,_,"language-"+R,v)}var m={javascript:!0,js:!0,typescript:!0,ts:!0,jsx:!0,tsx:!0};n.hooks.add("after-tokenize",function(v){if(!(v.language in m))return;function A(R){for(var x=0,T=R.length;x<T;x++){var C=R[x];if(typeof C!="string"){var N=C.content;if(!Array.isArray(N)){typeof N!="string"&&A([N]);continue}if(C.type==="template-string"){var _=N[1];if(N.length===3&&typeof _!="string"&&_.type==="embedded-code"){var O=S(_),z=_.alias,I=Array.isArray(z)?z[0]:z,M=n.languages[I];if(!M)continue;N[1]=b(O,M,I)}}else A(N)}}}A(v.tokens)});function S(v){return typeof v=="string"?v:Array.isArray(v)?v.map(S).join(""):S(v.content)}})(t)}return Dv}var Iv,FL;function fA(){if(FL)return Iv;FL=1,Iv=e,e.displayName="typescript",e.aliases=["ts"];function e(t){(function(n){n.languages.typescript=n.languages.extend("javascript",{"class-name":{pattern:/(\b(?:class|extends|implements|instanceof|interface|new|type)\s+)(?!keyof\b)(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?:\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>)?/,lookbehind:!0,greedy:!0,inside:null},builtin:/\b(?:Array|Function|Promise|any|boolean|console|never|number|string|symbol|unknown)\b/}),n.languages.typescript.keyword.push(/\b(?:abstract|declare|is|keyof|readonly|require)\b/,/\b(?:asserts|infer|interface|module|namespace|type)\b(?=\s*(?:[{_$a-zA-Z\xA0-\uFFFF]|$))/,/\btype\b(?=\s*(?:[\{*]|$))/),delete n.languages.typescript.parameter,delete n.languages.typescript["literal-property"];var r=n.languages.extend("typescript",{});delete r["class-name"],n.languages.typescript["class-name"].inside=r,n.languages.insertBefore("typescript","function",{decorator:{pattern:/@[$\w\xA0-\uFFFF]+/,inside:{at:{pattern:/^@/,alias:"operator"},function:/^[\s\S]+/}},"generic-function":{pattern:/#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*<(?:[^<>]|<(?:[^<>]|<[^<>]*>)*>)*>(?=\s*\()/,greedy:!0,inside:{function:/^#?(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*/,generic:{pattern:/<[\s\S]+/,alias:"class-name",inside:r}}}}),n.languages.ts=n.languages.typescript})(t)}return Iv}var Lv,zL;function the(){if(zL)return Lv;zL=1;var e=Yf(),t=fA();Lv=n,n.displayName="jsdoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var i=a.languages.javascript,l=/\{(?:[^{}]|\{(?:[^{}]|\{[^{}]*\})*\})+\}/.source,u="(@(?:arg|argument|param|property)\\s+(?:"+l+"\\s+)?)";a.languages.jsdoc=a.languages.extend("javadoclike",{parameter:{pattern:RegExp(u+/(?:(?!\s)[$\w\xA0-\uFFFF.])+(?=\s|$)/.source),lookbehind:!0,inside:{punctuation:/\./}}}),a.languages.insertBefore("jsdoc","keyword",{"optional-parameter":{pattern:RegExp(u+/\[(?:(?!\s)[$\w\xA0-\uFFFF.])+(?:=[^[\]]+)?\](?=\s|$)/.source),lookbehind:!0,inside:{parameter:{pattern:/(^\[)[$\w\xA0-\uFFFF\.]+/,lookbehind:!0,inside:{punctuation:/\./}},code:{pattern:/(=)[\s\S]*(?=\]$)/,lookbehind:!0,inside:i,alias:"language-javascript"},punctuation:/[=[\]]/}},"class-name":[{pattern:RegExp(/(@(?:augments|class|extends|interface|memberof!?|template|this|typedef)\s+(?:<TYPE>\s+)?)[A-Z]\w*(?:\.[A-Z]\w*)*/.source.replace(/<TYPE>/g,function(){return l})),lookbehind:!0,inside:{punctuation:/\./}},{pattern:RegExp("(@[a-z]+\\s+)"+l),lookbehind:!0,inside:{string:i.string,number:i.number,boolean:i.boolean,keyword:a.languages.typescript.keyword,operator:/=>|\.\.\.|[&|?:*]/,punctuation:/[.,;=<>{}()[\]]/}}],example:{pattern:/(@example\s+(?!\s))(?:[^@\s]|\s+(?!\s))+?(?=\s*(?:\*\s*)?(?:@\w|\*\/))/,lookbehind:!0,inside:{code:{pattern:/^([\t ]*(?:\*\s*)?)\S.*$/m,lookbehind:!0,inside:i,alias:"language-javascript"}}}}),a.languages.javadoclike.addSupport("javascript",a.languages.jsdoc)}(r)}return Lv}var Mv,PL;function pA(){if(PL)return Mv;PL=1,Mv=e,e.displayName="json",e.aliases=["webmanifest"];function e(t){t.languages.json={property:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?=\s*:)/,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"(?!\s*:)/,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,greedy:!0},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,punctuation:/[{}[\],]/,operator:/:/,boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"}},t.languages.webmanifest=t.languages.json}return Mv}var Fv,BL;function nhe(){if(BL)return Fv;BL=1;var e=pA();Fv=t,t.displayName="json5",t.aliases=[];function t(n){n.register(e),function(r){var a=/("|')(?:\\(?:\r\n?|\n|.)|(?!\1)[^\\\r\n])*\1/;r.languages.json5=r.languages.extend("json",{property:[{pattern:RegExp(a.source+"(?=\\s*:)"),greedy:!0},{pattern:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*:)/,alias:"unquoted"}],string:{pattern:a,greedy:!0},number:/[+-]?\b(?:NaN|Infinity|0x[a-fA-F\d]+)\b|[+-]?(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+\b)?/})}(n)}return Fv}var zv,UL;function rhe(){if(UL)return zv;UL=1;var e=pA();zv=t,t.displayName="jsonp",t.aliases=[];function t(n){n.register(e),n.languages.jsonp=n.languages.extend("json",{punctuation:/[{}[\]();,.]/}),n.languages.insertBefore("jsonp","punctuation",{function:/(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*(?=\s*\()/})}return zv}var Pv,jL;function ahe(){if(jL)return Pv;jL=1,Pv=e,e.displayName="jsstacktrace",e.aliases=[];function e(t){t.languages.jsstacktrace={"error-message":{pattern:/^\S.*/m,alias:"string"},"stack-frame":{pattern:/(^[ \t]+)at[ \t].*/m,lookbehind:!0,inside:{"not-my-code":{pattern:/^at[ \t]+(?!\s)(?:node\.js|<unknown>|.*(?:node_modules|\(<anonymous>\)|\(<unknown>|<anonymous>$|\(internal\/|\(node\.js)).*/m,alias:"comment"},filename:{pattern:/(\bat\s+(?!\s)|\()(?:[a-zA-Z]:)?[^():]+(?=:)/,lookbehind:!0,alias:"url"},function:{pattern:/(\bat\s+(?:new\s+)?)(?!\s)[_$a-zA-Z\xA0-\uFFFF<][.$\w\xA0-\uFFFF<>]*/,lookbehind:!0,inside:{punctuation:/\./}},punctuation:/[()]/,keyword:/\b(?:at|new)\b/,alias:{pattern:/\[(?:as\s+)?(?!\s)[_$a-zA-Z\xA0-\uFFFF][$\w\xA0-\uFFFF]*\]/,alias:"variable"},"line-number":{pattern:/:\d+(?::\d+)?\b/,alias:"number",inside:{punctuation:/:/}}}}}}return Pv}var Bv,GL;function K5(){if(GL)return Bv;GL=1,Bv=e,e.displayName="jsx",e.aliases=[];function e(t){(function(n){var r=n.util.clone(n.languages.javascript),a=/(?:\s|\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))\*\/)/.source,i=/(?:\{(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])*\})/.source,l=/(?:\{<S>*\.{3}(?:[^{}]|<BRACES>)*\})/.source;function u(p,g){return p=p.replace(/<S>/g,function(){return a}).replace(/<BRACES>/g,function(){return i}).replace(/<SPREAD>/g,function(){return l}),RegExp(p,g)}l=u(l).source,n.languages.jsx=n.languages.extend("markup",r),n.languages.jsx.tag.pattern=u(/<\/?(?:[\w.:-]+(?:<S>+(?:[\w.:$-]+(?:=(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s{'"/>=]+|<BRACES>))?|<SPREAD>))*<S>*\/?)?>/.source),n.languages.jsx.tag.inside.tag.pattern=/^<\/?[^\s>\/]*/,n.languages.jsx.tag.inside["attr-value"].pattern=/=(?!\{)(?:"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*'|[^\s'">]+)/,n.languages.jsx.tag.inside.tag.inside["class-name"]=/^[A-Z]\w*(?:\.[A-Z]\w*)*$/,n.languages.jsx.tag.inside.comment=r.comment,n.languages.insertBefore("inside","attr-name",{spread:{pattern:u(/<SPREAD>/.source),inside:n.languages.jsx}},n.languages.jsx.tag),n.languages.insertBefore("inside","special-attr",{script:{pattern:u(/=<BRACES>/.source),alias:"language-javascript",inside:{"script-punctuation":{pattern:/^=(?=\{)/,alias:"punctuation"},rest:n.languages.jsx}}},n.languages.jsx.tag);var c=function(p){return p?typeof p=="string"?p:typeof p.content=="string"?p.content:p.content.map(c).join(""):""},f=function(p){for(var g=[],b=0;b<p.length;b++){var m=p[b],S=!1;if(typeof m!="string"&&(m.type==="tag"&&m.content[0]&&m.content[0].type==="tag"?m.content[0].content[0].content==="</"?g.length>0&&g[g.length-1].tagName===c(m.content[0].content[1])&&g.pop():m.content[m.content.length-1].content==="/>"||g.push({tagName:c(m.content[0].content[1]),openedBraces:0}):g.length>0&&m.type==="punctuation"&&m.content==="{"?g[g.length-1].openedBraces++:g.length>0&&g[g.length-1].openedBraces>0&&m.type==="punctuation"&&m.content==="}"?g[g.length-1].openedBraces--:S=!0),(S||typeof m=="string")&&g.length>0&&g[g.length-1].openedBraces===0){var v=c(m);b<p.length-1&&(typeof p[b+1]=="string"||p[b+1].type==="plain-text")&&(v+=c(p[b+1]),p.splice(b+1,1)),b>0&&(typeof p[b-1]=="string"||p[b-1].type==="plain-text")&&(v=c(p[b-1])+v,p.splice(b-1,1),b--),p[b]=new n.Token("plain-text",v,null,v)}m.content&&typeof m.content!="string"&&f(m.content)}};n.hooks.add("after-tokenize",function(p){p.language!=="jsx"&&p.language!=="tsx"||f(p.tokens)})})(t)}return Bv}var Uv,HL;function ohe(){if(HL)return Uv;HL=1,Uv=e,e.displayName="julia",e.aliases=[];function e(t){t.languages.julia={comment:{pattern:/(^|[^\\])(?:#=(?:[^#=]|=(?!#)|#(?!=)|#=(?:[^#=]|=(?!#)|#(?!=))*=#)*=#|#.*)/,lookbehind:!0},regex:{pattern:/r"(?:\\.|[^"\\\r\n])*"[imsx]{0,4}/,greedy:!0},string:{pattern:/"""[\s\S]+?"""|(?:\b\w+)?"(?:\\.|[^"\\\r\n])*"|`(?:[^\\`\r\n]|\\.)*`/,greedy:!0},char:{pattern:/(^|[^\w'])'(?:\\[^\r\n][^'\r\n]*|[^\\\r\n])'/,lookbehind:!0,greedy:!0},keyword:/\b(?:abstract|baremodule|begin|bitstype|break|catch|ccall|const|continue|do|else|elseif|end|export|finally|for|function|global|if|immutable|import|importall|in|let|local|macro|module|print|println|quote|return|struct|try|type|typealias|using|while)\b/,boolean:/\b(?:false|true)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[box])?(?:[\da-f]+(?:_[\da-f]+)*(?:\.(?:\d+(?:_\d+)*)?)?|\.\d+(?:_\d+)*)(?:[efp][+-]?\d+(?:_\d+)*)?j?/i,operator:/&&|\|\||[-+*^%÷⊻&$\\]=?|\/[\/=]?|!=?=?|\|[=>]?|<(?:<=?|[=:|])?|>(?:=|>>?=?)?|==?=?|[~≠≤≥'√∛]/,punctuation:/::?|[{}[\]();,.?]/,constant:/\b(?:(?:Inf|NaN)(?:16|32|64)?|im|pi)\b|[πℯ]/}}return Uv}var jv,$L;function ihe(){if($L)return jv;$L=1,jv=e,e.displayName="keepalived",e.aliases=[];function e(t){t.languages.keepalived={comment:{pattern:/[#!].*/,greedy:!0},string:{pattern:/(^|[^\\])(?:"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"|'(?:\\(?:\r\n|[\s\S])|[^'\\\r\n])*')/,lookbehind:!0,greedy:!0},ip:{pattern:RegExp(/\b(?:(?:(?:[\da-f]{1,4}:){7}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}:[\da-f]{1,4}|(?:[\da-f]{1,4}:){5}:(?:[\da-f]{1,4}:)?[\da-f]{1,4}|(?:[\da-f]{1,4}:){4}:(?:[\da-f]{1,4}:){0,2}[\da-f]{1,4}|(?:[\da-f]{1,4}:){3}:(?:[\da-f]{1,4}:){0,3}[\da-f]{1,4}|(?:[\da-f]{1,4}:){2}:(?:[\da-f]{1,4}:){0,4}[\da-f]{1,4}|(?:[\da-f]{1,4}:){6}<ipv4>|(?:[\da-f]{1,4}:){0,5}:<ipv4>|::(?:[\da-f]{1,4}:){0,5}<ipv4>|[\da-f]{1,4}::(?:[\da-f]{1,4}:){0,5}[\da-f]{1,4}|::(?:[\da-f]{1,4}:){0,6}[\da-f]{1,4}|(?:[\da-f]{1,4}:){1,7}:)(?:\/\d{1,3})?|<ipv4>(?:\/\d{1,2})?)\b/.source.replace(/<ipv4>/g,function(){return/(?:(?:(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d)\.){3}(?:25[0-5]|2[0-4]\d|1\d\d|[1-9]\d|\d))/.source}),"i"),alias:"number"},path:{pattern:/(\s)\/(?:[^\/\s]+\/)*[^\/\s]*|\b[a-zA-Z]:\\(?:[^\\\s]+\\)*[^\\\s]*/,lookbehind:!0,alias:"string"},variable:/\$\{?\w+\}?/,email:{pattern:/[\w-]+@[\w-]+(?:\.[\w-]{2,3}){1,2}/,alias:"string"},"conditional-configuration":{pattern:/@\^?[\w-]+/,alias:"variable"},operator:/=/,property:/\b(?:BFD_CHECK|DNS_CHECK|FILE_CHECK|HTTP_GET|MISC_CHECK|NAME|PING_CHECK|SCRIPTS|SMTP_CHECK|SSL|SSL_GET|TCP_CHECK|UDP_CHECK|accept|advert_int|alpha|auth_pass|auth_type|authentication|bfd_cpu_affinity|bfd_instance|bfd_no_swap|bfd_priority|bfd_process_name|bfd_rlimit_rttime|bfd_rt_priority|bind_if|bind_port|bindto|ca|certificate|check_unicast_src|checker|checker_cpu_affinity|checker_log_all_failures|checker_no_swap|checker_priority|checker_rlimit_rttime|checker_rt_priority|child_wait_time|connect_ip|connect_port|connect_timeout|dbus_service_name|debug|default_interface|delay|delay_before_retry|delay_loop|digest|dont_track_primary|dynamic|dynamic_interfaces|enable_(?:dbus|script_security|sni|snmp_checker|snmp_rfc|snmp_rfcv2|snmp_rfcv3|snmp_vrrp|traps)|end|fall|fast_recovery|file|flag-[123]|fork_delay|full_command|fwmark|garp_group|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|global_defs|global_tracking|gna_interval|group|ha_suspend|hashed|helo_name|higher_prio_send_advert|hoplimit|http_protocol|hysteresis|idle_tx|include|inhibit_on_failure|init_fail|init_file|instance|interface|interfaces|interval|ip_family|ipvs_process_name|keepalived.conf|kernel_rx_buf_size|key|linkbeat_interfaces|linkbeat_use_polling|log_all_failures|log_unknown_vrids|lower_prio_no_advert|lthreshold|lvs_flush|lvs_flush_onstop|lvs_method|lvs_netlink_cmd_rcv_bufs|lvs_netlink_cmd_rcv_bufs_force|lvs_netlink_monitor_rcv_bufs|lvs_netlink_monitor_rcv_bufs_force|lvs_notify_fifo|lvs_notify_fifo_script|lvs_sched|lvs_sync_daemon|max_auto_priority|max_hops|mcast_src_ip|mh-fallback|mh-port|min_auto_priority_delay|min_rx|min_tx|misc_dynamic|misc_path|misc_timeout|multiplier|name|namespace_with_ipsets|native_ipv6|neighbor_ip|net_namespace|net_namespace_ipvs|nftables|nftables_counters|nftables_ifindex|nftables_priority|no_accept|no_checker_emails|no_email_faults|nopreempt|notification_email|notification_email_from|notify|notify_backup|notify_deleted|notify_down|notify_fault|notify_fifo|notify_fifo_script|notify_master|notify_master_rx_lower_pri|notify_priority_changes|notify_stop|notify_up|old_unicast_checksum|omega|ops|param_match|passive|password|path|persistence_engine|persistence_granularity|persistence_timeout|preempt|preempt_delay|priority|process|process_monitor_rcv_bufs|process_monitor_rcv_bufs_force|process_name|process_names|promote_secondaries|protocol|proxy_arp|proxy_arp_pvlan|quorum|quorum_down|quorum_max|quorum_up|random_seed|real_server|regex|regex_max_offset|regex_min_offset|regex_no_match|regex_options|regex_stack|reload_repeat|reload_time_file|require_reply|retry|rise|router_id|rs_init_notifies|script|script_user|sh-fallback|sh-port|shutdown_script|shutdown_script_timeout|skip_check_adv_addr|smtp_alert|smtp_alert_checker|smtp_alert_vrrp|smtp_connect_timeout|smtp_helo_name|smtp_server|snmp_socket|sorry_server|sorry_server_inhibit|sorry_server_lvs_method|source_ip|start|startup_script|startup_script_timeout|state|static_ipaddress|static_routes|static_rules|status_code|step|strict_mode|sync_group_tracking_weight|terminate_delay|timeout|track_bfd|track_file|track_group|track_interface|track_process|track_script|track_src_ip|ttl|type|umask|unicast_peer|unicast_src_ip|unicast_ttl|url|use_ipvlan|use_pid_dir|use_vmac|user|uthreshold|val[123]|version|virtual_ipaddress|virtual_ipaddress_excluded|virtual_router_id|virtual_routes|virtual_rules|virtual_server|virtual_server_group|virtualhost|vmac_xmit_base|vrrp|vrrp_(?:check_unicast_src|cpu_affinity|garp_interval|garp_lower_prio_delay|garp_lower_prio_repeat|garp_master_delay|garp_master_refresh|garp_master_refresh_repeat|garp_master_repeat|gna_interval|higher_prio_send_advert|instance|ipsets|iptables|lower_prio_no_advert|mcast_group4|mcast_group6|min_garp|netlink_cmd_rcv_bufs|netlink_cmd_rcv_bufs_force|netlink_monitor_rcv_bufs|netlink_monitor_rcv_bufs_force|no_swap|notify_fifo|notify_fifo_script|notify_priority_changes|priority|process_name|rlimit_rttime|rt_priority|rx_bufs_multiplier|rx_bufs_policy|script|skip_check_adv_addr|startup_delay|strict|sync_group|track_process|version)|warmup|weight)\b/,constant:/\b(?:A|AAAA|AH|BACKUP|CNAME|DR|MASTER|MX|NAT|NS|PASS|SCTP|SOA|TCP|TUN|TXT|UDP|dh|fo|lblc|lblcr|lc|mh|nq|ovf|rr|sed|sh|wlc|wrr)\b/,number:{pattern:/(^|[^\w.-])-?\d+(?:\.\d+)?/,lookbehind:!0},boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\{\}]/}}return jv}var Gv,qL;function lhe(){if(qL)return Gv;qL=1,Gv=e,e.displayName="keyman",e.aliases=[];function e(t){t.languages.keyman={comment:{pattern:/\bc .*/i,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0},"virtual-key":{pattern:/\[\s*(?:(?:ALT|CAPS|CTRL|LALT|LCTRL|NCAPS|RALT|RCTRL|SHIFT)\s+)*(?:[TKU]_[\w?]+|[A-E]\d\d?|"[^"\r\n]*"|'[^'\r\n]*')\s*\]/i,greedy:!0,alias:"function"},"header-keyword":{pattern:/&\w+/,alias:"bold"},"header-statement":{pattern:/\b(?:bitmap|bitmaps|caps always off|caps on only|copyright|hotkey|language|layout|message|name|shift frees caps|version)\b/i,alias:"bold"},"rule-keyword":{pattern:/\b(?:any|baselayout|beep|call|context|deadkey|dk|if|index|layer|notany|nul|outs|platform|reset|return|save|set|store|use)\b/i,alias:"keyword"},"structural-keyword":{pattern:/\b(?:ansi|begin|group|match|nomatch|unicode|using keys)\b/i,alias:"keyword"},"compile-target":{pattern:/\$(?:keyman|keymanonly|keymanweb|kmfl|weaver):/i,alias:"property"},number:/\b(?:U\+[\dA-F]+|d\d+|x[\da-f]+|\d+)\b/i,operator:/[+>\\$]|\.\./,punctuation:/[()=,]/}}return Gv}var Hv,VL;function she(){if(VL)return Hv;VL=1,Hv=e,e.displayName="kotlin",e.aliases=["kt","kts"];function e(t){(function(n){n.languages.kotlin=n.languages.extend("clike",{keyword:{pattern:/(^|[^.])\b(?:abstract|actual|annotation|as|break|by|catch|class|companion|const|constructor|continue|crossinline|data|do|dynamic|else|enum|expect|external|final|finally|for|fun|get|if|import|in|infix|init|inline|inner|interface|internal|is|lateinit|noinline|null|object|open|operator|out|override|package|private|protected|public|reified|return|sealed|set|super|suspend|tailrec|this|throw|to|try|typealias|val|var|vararg|when|where|while)\b/,lookbehind:!0},function:[{pattern:/(?:`[^\r\n`]+`|\b\w+)(?=\s*\()/,greedy:!0},{pattern:/(\.)(?:`[^\r\n`]+`|\w+)(?=\s*\{)/,lookbehind:!0,greedy:!0}],number:/\b(?:0[xX][\da-fA-F]+(?:_[\da-fA-F]+)*|0[bB][01]+(?:_[01]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?[fFL]?)\b/,operator:/\+[+=]?|-[-=>]?|==?=?|!(?:!|==?)?|[\/*%<>]=?|[?:]:?|\.\.|&&|\|\||\b(?:and|inv|or|shl|shr|ushr|xor)\b/}),delete n.languages.kotlin["class-name"];var r={"interpolation-punctuation":{pattern:/^\$\{?|\}$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:n.languages.kotlin}};n.languages.insertBefore("kotlin","string",{"string-literal":[{pattern:/"""(?:[^$]|\$(?:(?!\{)|\{[^{}]*\}))*?"""/,alias:"multiline",inside:{interpolation:{pattern:/\$(?:[a-z_]\w*|\{[^{}]*\})/i,inside:r},string:/[\s\S]+/}},{pattern:/"(?:[^"\\\r\n$]|\\.|\$(?:(?!\{)|\{[^{}]*\}))*"/,alias:"singleline",inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:[a-z_]\w*|\{[^{}]*\})/i,lookbehind:!0,inside:r},string:/[\s\S]+/}}],char:{pattern:/'(?:[^'\\\r\n]|\\(?:.|u[a-fA-F0-9]{0,4}))'/,greedy:!0}}),delete n.languages.kotlin.string,n.languages.insertBefore("kotlin","keyword",{annotation:{pattern:/\B@(?:\w+:)?(?:[A-Z]\w*|\[[^\]]+\])/,alias:"builtin"}}),n.languages.insertBefore("kotlin","function",{label:{pattern:/\b\w+@|@\w+\b/,alias:"symbol"}}),n.languages.kt=n.languages.kotlin,n.languages.kts=n.languages.kotlin})(t)}return Hv}var $v,WL;function uhe(){if(WL)return $v;WL=1,$v=e,e.displayName="kumir",e.aliases=["kum"];function e(t){(function(n){var r=/\s\x00-\x1f\x22-\x2f\x3a-\x3f\x5b-\x5e\x60\x7b-\x7e/.source;function a(i,l){return RegExp(i.replace(/<nonId>/g,r),l)}n.languages.kumir={comment:{pattern:/\|.*/},prolog:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^\n\r"]*"|'[^\n\r']*'/,greedy:!0},boolean:{pattern:a(/(^|[<nonId>])(?:да|нет)(?=[<nonId>]|$)/.source),lookbehind:!0},"operator-word":{pattern:a(/(^|[<nonId>])(?:и|или|не)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},"system-variable":{pattern:a(/(^|[<nonId>])знач(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"keyword"},type:[{pattern:a(/(^|[<nonId>])(?:вещ|лит|лог|сим|цел)(?:\x20*таб)?(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"builtin"},{pattern:a(/(^|[<nonId>])(?:компл|сканкод|файл|цвет)(?=[<nonId>]|$)/.source),lookbehind:!0,alias:"important"}],keyword:{pattern:a(/(^|[<nonId>])(?:алг|арг(?:\x20*рез)?|ввод|ВКЛЮЧИТЬ|вс[её]|выбор|вывод|выход|дано|для|до|дс|если|иначе|исп|использовать|кон(?:(?:\x20+|_)исп)?|кц(?:(?:\x20+|_)при)?|надо|нач|нс|нц|от|пауза|пока|при|раза?|рез|стоп|таб|то|утв|шаг)(?=[<nonId>]|$)/.source),lookbehind:!0},name:{pattern:a(/(^|[<nonId>])[^\d<nonId>][^<nonId>]*(?:\x20+[^<nonId>]+)*(?=[<nonId>]|$)/.source),lookbehind:!0},number:{pattern:a(/(^|[<nonId>])(?:\B\$[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?=[<nonId>]|$)/.source,"i"),lookbehind:!0},punctuation:/:=|[(),:;\[\]]/,"operator-char":{pattern:/\*\*?|<[=>]?|>=?|[-+/=]/,alias:"operator"}},n.languages.kum=n.languages.kumir})(t)}return $v}var qv,YL;function che(){if(YL)return qv;YL=1,qv=e,e.displayName="kusto",e.aliases=[];function e(t){t.languages.kusto={comment:{pattern:/\/\/.*/,greedy:!0},string:{pattern:/```[\s\S]*?```|[hH]?(?:"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\.)*'|@(?:"[^\r\n"]*"|'[^\r\n']*'))/,greedy:!0},verb:{pattern:/(\|\s*)[a-z][\w-]*/i,lookbehind:!0,alias:"keyword"},command:{pattern:/\.[a-z][a-z\d-]*\b/,alias:"keyword"},"class-name":/\b(?:bool|datetime|decimal|dynamic|guid|int|long|real|string|timespan)\b/,keyword:/\b(?:access|alias|and|anti|as|asc|auto|between|by|(?:contains|(?:ends|starts)with|has(?:perfix|suffix)?)(?:_cs)?|database|declare|desc|external|from|fullouter|has_all|in|ingestion|inline|inner|innerunique|into|(?:left|right)(?:anti(?:semi)?|inner|outer|semi)?|let|like|local|not|of|on|or|pattern|print|query_parameters|range|restrict|schema|set|step|table|tables|to|view|where|with|matches\s+regex|nulls\s+(?:first|last))(?![\w-])/,boolean:/\b(?:false|null|true)\b/,function:/\b[a-z_]\w*(?=\s*\()/,datetime:[{pattern:/\b(?:(?:Fri|Friday|Mon|Monday|Sat|Saturday|Sun|Sunday|Thu|Thursday|Tue|Tuesday|Wed|Wednesday)\s*,\s*)?\d{1,2}(?:\s+|-)(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)(?:\s+|-)\d{2}\s+\d{2}:\d{2}(?::\d{2})?(?:\s*(?:\b(?:[A-Z]|(?:[ECMT][DS]|GM|U)T)|[+-]\d{4}))?\b/,alias:"number"},{pattern:/[+-]?\b(?:\d{4}-\d{2}-\d{2}(?:[ T]\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)?|\d{2}:\d{2}(?::\d{2}(?:\.\d+)?)?)Z?/,alias:"number"}],number:/\b(?:0x[0-9A-Fa-f]+|\d+(?:\.\d+)?(?:[Ee][+-]?\d+)?)(?:(?:min|sec|[mnµ]s|[dhms]|microsecond|tick)\b)?|[+-]?\binf\b/,operator:/=>|[!=]~|[!=<>]=?|[-+*/%|]|\.\./,punctuation:/[()\[\]{},;.:]/}}return qv}var Vv,KL;function dhe(){if(KL)return Vv;KL=1,Vv=e,e.displayName="latex",e.aliases=["tex","context"];function e(t){(function(n){var r=/\\(?:[^a-z()[\]]|[a-z*]+)/i,a={"equation-command":{pattern:r,alias:"regex"}};n.languages.latex={comment:/%.*/,cdata:{pattern:/(\\begin\{((?:lstlisting|verbatim)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0},equation:[{pattern:/\$\$(?:\\[\s\S]|[^\\$])+\$\$|\$(?:\\[\s\S]|[^\\$])+\$|\\\([\s\S]*?\\\)|\\\[[\s\S]*?\\\]/,inside:a,alias:"string"},{pattern:/(\\begin\{((?:align|eqnarray|equation|gather|math|multline)\*?)\})[\s\S]*?(?=\\end\{\2\})/,lookbehind:!0,inside:a,alias:"string"}],keyword:{pattern:/(\\(?:begin|cite|documentclass|end|label|ref|usepackage)(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0},url:{pattern:/(\\url\{)[^}]+(?=\})/,lookbehind:!0},headline:{pattern:/(\\(?:chapter|frametitle|paragraph|part|section|subparagraph|subsection|subsubparagraph|subsubsection|subsubsubparagraph)\*?(?:\[[^\]]+\])?\{)[^}]+(?=\})/,lookbehind:!0,alias:"class-name"},function:{pattern:r,alias:"selector"},punctuation:/[[\]{}&]/},n.languages.tex=n.languages.latex,n.languages.context=n.languages.latex})(t)}return Vv}var Wv,XL;function Kf(){if(XL)return Wv;XL=1;var e=Gn();Wv=t,t.displayName="php",t.aliases=[];function t(n){n.register(e),function(r){var a=/\/\*[\s\S]*?\*\/|\/\/.*|#(?!\[).*/,i=[{pattern:/\b(?:false|true)\b/i,alias:"boolean"},{pattern:/(::\s*)\b[a-z_]\w*\b(?!\s*\()/i,greedy:!0,lookbehind:!0},{pattern:/(\b(?:case|const)\s+)\b[a-z_]\w*(?=\s*[;=])/i,greedy:!0,lookbehind:!0},/\b(?:null)\b/i,/\b[A-Z_][A-Z0-9_]*\b(?!\s*\()/],l=/\b0b[01]+(?:_[01]+)*\b|\b0o[0-7]+(?:_[0-7]+)*\b|\b0x[\da-f]+(?:_[\da-f]+)*\b|(?:\b\d+(?:_\d+)*\.?(?:\d+(?:_\d+)*)?|\B\.\d+)(?:e[+-]?\d+)?/i,u=/<?=>|\?\?=?|\.{3}|\??->|[!=]=?=?|::|\*\*=?|--|\+\+|&&|\|\||<<|>>|[?~]|[/^|%*&<>.+-]=?/,c=/[{}\[\](),:;]/;r.languages.php={delimiter:{pattern:/\?>$|^<\?(?:php(?=\s)|=)?/i,alias:"important"},comment:a,variable:/\$+(?:\w+\b|(?=\{))/,package:{pattern:/(namespace\s+|use\s+(?:function\s+)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,lookbehind:!0,inside:{punctuation:/\\/}},"class-name-definition":{pattern:/(\b(?:class|enum|interface|trait)\s+)\b[a-z_]\w*(?!\\)\b/i,lookbehind:!0,alias:"class-name"},"function-definition":{pattern:/(\bfunction\s+)[a-z_]\w*(?=\s*\()/i,lookbehind:!0,alias:"function"},keyword:[{pattern:/(\(\s*)\b(?:array|bool|boolean|float|int|integer|object|string)\b(?=\s*\))/i,alias:"type-casting",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string)\b(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b(?:array(?!\s*\()|bool|callable|(?:false|null)(?=\s*\|)|float|int|iterable|mixed|object|self|static|string|void)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/\b(?:array(?!\s*\()|bool|float|int|iterable|mixed|object|string|void)\b/i,alias:"type-declaration",greedy:!0},{pattern:/(\|\s*)(?:false|null)\b|\b(?:false|null)(?=\s*\|)/i,alias:"type-declaration",greedy:!0,lookbehind:!0},{pattern:/\b(?:parent|self|static)(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(\byield\s+)from\b/i,lookbehind:!0},/\bclass\b/i,{pattern:/((?:^|[^\s>:]|(?:^|[^-])>|(?:^|[^:]):)\s*)\b(?:abstract|and|array|as|break|callable|case|catch|clone|const|continue|declare|default|die|do|echo|else|elseif|empty|enddeclare|endfor|endforeach|endif|endswitch|endwhile|enum|eval|exit|extends|final|finally|fn|for|foreach|function|global|goto|if|implements|include|include_once|instanceof|insteadof|interface|isset|list|match|namespace|new|or|parent|print|private|protected|public|require|require_once|return|self|static|switch|throw|trait|try|unset|use|var|while|xor|yield|__halt_compiler)\b/i,lookbehind:!0}],"argument-name":{pattern:/([(,]\s+)\b[a-z_]\w*(?=\s*:(?!:))/i,lookbehind:!0},"class-name":[{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self|\s+static))\s+|\bcatch\s*\()\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/(\|\s*)\b[a-z_]\w*(?!\\)\b/i,greedy:!0,lookbehind:!0},{pattern:/\b[a-z_]\w*(?!\\)\b(?=\s*\|)/i,greedy:!0},{pattern:/(\|\s*)(?:\\?\b[a-z_]\w*)+\b/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(?:\\?\b[a-z_]\w*)+\b(?=\s*\|)/i,alias:"class-name-fully-qualified",greedy:!0,inside:{punctuation:/\\/}},{pattern:/(\b(?:extends|implements|instanceof|new(?!\s+self\b|\s+static\b))\s+|\bcatch\s*\()(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:"class-name-fully-qualified",greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*\$)/i,alias:"type-declaration",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-declaration"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/\b[a-z_]\w*(?=\s*::)/i,alias:"static-context",greedy:!0},{pattern:/(?:\\?\b[a-z_]\w*)+(?=\s*::)/i,alias:["class-name-fully-qualified","static-context"],greedy:!0,inside:{punctuation:/\\/}},{pattern:/([(,?]\s*)[a-z_]\w*(?=\s*\$)/i,alias:"type-hint",greedy:!0,lookbehind:!0},{pattern:/([(,?]\s*)(?:\\?\b[a-z_]\w*)+(?=\s*\$)/i,alias:["class-name-fully-qualified","type-hint"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}},{pattern:/(\)\s*:\s*(?:\?\s*)?)\b[a-z_]\w*(?!\\)\b/i,alias:"return-type",greedy:!0,lookbehind:!0},{pattern:/(\)\s*:\s*(?:\?\s*)?)(?:\\?\b[a-z_]\w*)+\b(?!\\)/i,alias:["class-name-fully-qualified","return-type"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:i,function:{pattern:/(^|[^\\\w])\\?[a-z_](?:[\w\\]*\w)?(?=\s*\()/i,lookbehind:!0,inside:{punctuation:/\\/}},property:{pattern:/(->\s*)\w+/,lookbehind:!0},number:l,operator:u,punctuation:c};var f={pattern:/\{\$(?:\{(?:\{[^{}]+\}|[^{}]+)\}|[^{}])+\}|(^|[^\\{])\$+(?:\w+(?:\[[^\r\n\[\]]+\]|->\w+)?)/,lookbehind:!0,inside:r.languages.php},p=[{pattern:/<<<'([^']+)'[\r\n](?:.*[\r\n])*?\1;/,alias:"nowdoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<'[^']+'|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<'?|[';]$/}}}},{pattern:/<<<(?:"([^"]+)"[\r\n](?:.*[\r\n])*?\1;|([a-z_]\w*)[\r\n](?:.*[\r\n])*?\2;)/i,alias:"heredoc-string",greedy:!0,inside:{delimiter:{pattern:/^<<<(?:"[^"]+"|[a-z_]\w*)|[a-z_]\w*;$/i,alias:"symbol",inside:{punctuation:/^<<<"?|[";]$/}},interpolation:f}},{pattern:/`(?:\\[\s\S]|[^\\`])*`/,alias:"backtick-quoted-string",greedy:!0},{pattern:/'(?:\\[\s\S]|[^\\'])*'/,alias:"single-quoted-string",greedy:!0},{pattern:/"(?:\\[\s\S]|[^\\"])*"/,alias:"double-quoted-string",greedy:!0,inside:{interpolation:f}}];r.languages.insertBefore("php","variable",{string:p,attribute:{pattern:/#\[(?:[^"'\/#]|\/(?![*/])|\/\/.*$|#(?!\[).*$|\/\*(?:[^*]|\*(?!\/))*\*\/|"(?:\\[\s\S]|[^\\"])*"|'(?:\\[\s\S]|[^\\'])*')+\](?=\s*[a-z$#])/im,greedy:!0,inside:{"attribute-content":{pattern:/^(#\[)[\s\S]+(?=\]$)/,lookbehind:!0,inside:{comment:a,string:p,"attribute-class-name":[{pattern:/([^:]|^)\b[a-z_]\w*(?!\\)\b/i,alias:"class-name",greedy:!0,lookbehind:!0},{pattern:/([^:]|^)(?:\\?\b[a-z_]\w*)+/i,alias:["class-name","class-name-fully-qualified"],greedy:!0,lookbehind:!0,inside:{punctuation:/\\/}}],constant:i,number:l,operator:u,punctuation:c}},delimiter:{pattern:/^#\[|\]$/,alias:"punctuation"}}}}),r.hooks.add("before-tokenize",function(g){if(/<\?/.test(g.code)){var b=/<\?(?:[^"'/#]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|(?:\/\/|#(?!\[))(?:[^?\n\r]|\?(?!>))*(?=$|\?>|[\r\n])|#\[|\/\*(?:[^*]|\*(?!\/))*(?:\*\/|$))*?(?:\?>|$)/g;r.languages["markup-templating"].buildPlaceholders(g,"php",b)}}),r.hooks.add("after-tokenize",function(g){r.languages["markup-templating"].tokenizePlaceholders(g,"php")})}(n)}return Wv}var Yv,ZL;function fhe(){if(ZL)return Yv;ZL=1;var e=Gn(),t=Kf();Yv=n,n.displayName="latte",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){a.languages.latte={comment:/^\{\*[\s\S]*/,"latte-tag":{pattern:/(^\{(?:\/(?=[a-z]))?)(?:[=_]|[a-z]\w*\b(?!\())/i,lookbehind:!0,alias:"important"},delimiter:{pattern:/^\{\/?|\}$/,alias:"punctuation"},php:{pattern:/\S(?:[\s\S]*\S)?/,alias:"language-php",inside:a.languages.php}};var i=a.languages.extend("markup",{});a.languages.insertBefore("inside","attr-value",{"n-attr":{pattern:/n:[\w-]+(?:\s*=\s*(?:"[^"]*"|'[^']*'|[^\s'">=]+))?/,inside:{"attr-name":{pattern:/^[^\s=]+/,alias:"important"},"attr-value":{pattern:/=[\s\S]+/,inside:{punctuation:[/^=/,{pattern:/^(\s*)["']|["']$/,lookbehind:!0}],php:{pattern:/\S(?:[\s\S]*\S)?/,inside:a.languages.php}}}}}},i.tag),a.hooks.add("before-tokenize",function(l){if(l.language==="latte"){var u=/\{\*[\s\S]*?\*\}|\{[^'"\s{}*](?:[^"'/{}]|\/(?![*/])|("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|\/\*(?:[^*]|\*(?!\/))*\*\/)*\}/g;a.languages["markup-templating"].buildPlaceholders(l,"latte",u),l.grammar=i}}),a.hooks.add("after-tokenize",function(l){a.languages["markup-templating"].tokenizePlaceholders(l,"latte")})}(r)}return Yv}var Kv,QL;function phe(){if(QL)return Kv;QL=1,Kv=e,e.displayName="less",e.aliases=[];function e(t){t.languages.less=t.languages.extend("css",{comment:[/\/\*[\s\S]*?\*\//,{pattern:/(^|[^\\])\/\/.*/,lookbehind:!0}],atrule:{pattern:/@[\w-](?:\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{punctuation:/[:()]/}},selector:{pattern:/(?:@\{[\w-]+\}|[^{};\s@])(?:@\{[\w-]+\}|\((?:[^(){}]|\([^(){}]*\))*\)|[^(){};@\s]|\s+(?!\s))*?(?=\s*\{)/,inside:{variable:/@+[\w-]+/}},property:/(?:@\{[\w-]+\}|[\w-])+(?:\+_?)?(?=\s*:)/,operator:/[+\-*\/]/}),t.languages.insertBefore("less","property",{variable:[{pattern:/@[\w-]+\s*:/,inside:{punctuation:/:/}},/@@?[\w-]+/],"mixin-usage":{pattern:/([{;]\s*)[.#](?!\d)[\w-].*?(?=[(;])/,lookbehind:!0,alias:"function"}})}return Kv}var Xv,JL;function gA(){if(JL)return Xv;JL=1,Xv=e,e.displayName="scheme",e.aliases=[];function e(t){(function(n){n.languages.scheme={comment:/;.*|#;\s*(?:\((?:[^()]|\([^()]*\))*\)|\[(?:[^\[\]]|\[[^\[\]]*\])*\])|#\|(?:[^#|]|#(?!\|)|\|(?!#)|#\|(?:[^#|]|#(?!\|)|\|(?!#))*\|#)*\|#/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},symbol:{pattern:/'[^()\[\]#'\s]+/,greedy:!0},char:{pattern:/#\\(?:[ux][a-fA-F\d]+\b|[-a-zA-Z]+\b|[\uD800-\uDBFF][\uDC00-\uDFFF]|\S)/,greedy:!0},"lambda-parameter":[{pattern:/((?:^|[^'`#])[(\[]lambda\s+)(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)/,lookbehind:!0},{pattern:/((?:^|[^'`#])[(\[]lambda\s+[(\[])[^()\[\]']+/,lookbehind:!0}],keyword:{pattern:/((?:^|[^'`#])[(\[])(?:begin|case(?:-lambda)?|cond(?:-expand)?|define(?:-library|-macro|-record-type|-syntax|-values)?|defmacro|delay(?:-force)?|do|else|except|export|guard|if|import|include(?:-ci|-library-declarations)?|lambda|let(?:rec)?(?:-syntax|-values|\*)?|let\*-values|only|parameterize|prefix|(?:quasi-?)?quote|rename|set!|syntax-(?:case|rules)|unless|unquote(?:-splicing)?|when)(?=[()\[\]\s]|$)/,lookbehind:!0},builtin:{pattern:/((?:^|[^'`#])[(\[])(?:abs|and|append|apply|assoc|ass[qv]|binary-port\?|boolean=?\?|bytevector(?:-append|-copy|-copy!|-length|-u8-ref|-u8-set!|\?)?|caar|cadr|call-with-(?:current-continuation|port|values)|call\/cc|car|cdar|cddr|cdr|ceiling|char(?:->integer|-ready\?|\?|<\?|<=\?|=\?|>\?|>=\?)|close-(?:input-port|output-port|port)|complex\?|cons|current-(?:error|input|output)-port|denominator|dynamic-wind|eof-object\??|eq\?|equal\?|eqv\?|error|error-object(?:-irritants|-message|\?)|eval|even\?|exact(?:-integer-sqrt|-integer\?|\?)?|expt|features|file-error\?|floor(?:-quotient|-remainder|\/)?|flush-output-port|for-each|gcd|get-output-(?:bytevector|string)|inexact\??|input-port(?:-open\?|\?)|integer(?:->char|\?)|lcm|length|list(?:->string|->vector|-copy|-ref|-set!|-tail|\?)?|make-(?:bytevector|list|parameter|string|vector)|map|max|member|memq|memv|min|modulo|negative\?|newline|not|null\?|number(?:->string|\?)|numerator|odd\?|open-(?:input|output)-(?:bytevector|string)|or|output-port(?:-open\?|\?)|pair\?|peek-char|peek-u8|port\?|positive\?|procedure\?|quotient|raise|raise-continuable|rational\?|rationalize|read-(?:bytevector|bytevector!|char|error\?|line|string|u8)|real\?|remainder|reverse|round|set-c[ad]r!|square|string(?:->list|->number|->symbol|->utf8|->vector|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?|<\?|<=\?|=\?|>\?|>=\?)?|substring|symbol(?:->string|\?|=\?)|syntax-error|textual-port\?|truncate(?:-quotient|-remainder|\/)?|u8-ready\?|utf8->string|values|vector(?:->list|->string|-append|-copy|-copy!|-fill!|-for-each|-length|-map|-ref|-set!|\?)?|with-exception-handler|write-(?:bytevector|char|string|u8)|zero\?)(?=[()\[\]\s]|$)/,lookbehind:!0},operator:{pattern:/((?:^|[^'`#])[(\[])(?:[-+*%/]|[<>]=?|=>?)(?=[()\[\]\s]|$)/,lookbehind:!0},number:{pattern:RegExp(r({"<ureal dec>":/\d+(?:\/\d+)|(?:\d+(?:\.\d*)?|\.\d+)(?:[esfdl][+-]?\d+)?/.source,"<real dec>":/[+-]?<ureal dec>|[+-](?:inf|nan)\.0/.source,"<imaginary dec>":/[+-](?:<ureal dec>|(?:inf|nan)\.0)?i/.source,"<complex dec>":/<real dec>(?:@<real dec>|<imaginary dec>)?|<imaginary dec>/.source,"<num dec>":/(?:#d(?:#[ei])?|#[ei](?:#d)?)?<complex dec>/.source,"<ureal box>":/[0-9a-f]+(?:\/[0-9a-f]+)?/.source,"<real box>":/[+-]?<ureal box>|[+-](?:inf|nan)\.0/.source,"<imaginary box>":/[+-](?:<ureal box>|(?:inf|nan)\.0)?i/.source,"<complex box>":/<real box>(?:@<real box>|<imaginary box>)?|<imaginary box>/.source,"<num box>":/#[box](?:#[ei])?|(?:#[ei])?#[box]<complex box>/.source,"<number>":/(^|[()\[\]\s])(?:<num dec>|<num box>)(?=[()\[\]\s]|$)/.source}),"i"),lookbehind:!0},boolean:{pattern:/(^|[()\[\]\s])#(?:[ft]|false|true)(?=[()\[\]\s]|$)/,lookbehind:!0},function:{pattern:/((?:^|[^'`#])[(\[])(?:[^|()\[\]'\s]+|\|(?:[^\\|]|\\.)*\|)(?=[()\[\]\s]|$)/,lookbehind:!0},identifier:{pattern:/(^|[()\[\]\s])\|(?:[^\\|]|\\.)*\|(?=[()\[\]\s]|$)/,lookbehind:!0,greedy:!0},punctuation:/[()\[\]']/};function r(a){for(var i in a)a[i]=a[i].replace(/<[\w\s]+>/g,function(l){return"(?:"+a[l].trim()+")"});return a[i]}})(t)}return Xv}var Zv,e2;function ghe(){if(e2)return Zv;e2=1;var e=gA();Zv=t,t.displayName="lilypond",t.aliases=[];function t(n){n.register(e),function(r){for(var a=/\((?:[^();"#\\]|\\[\s\S]|;.*(?!.)|"(?:[^"\\]|\\.)*"|#(?:\{(?:(?!#\})[\s\S])*#\}|[^{])|<expr>)*\)/.source,i=5,l=0;l<i;l++)a=a.replace(/<expr>/g,function(){return a});a=a.replace(/<expr>/g,/[^\s\S]/.source);var u=r.languages.lilypond={comment:/%(?:(?!\{).*|\{[\s\S]*?%\})/,"embedded-scheme":{pattern:RegExp(/(^|[=\s])#(?:"(?:[^"\\]|\\.)*"|[^\s()"]*(?:[^\s()]|<expr>))/.source.replace(/<expr>/g,function(){return a}),"m"),lookbehind:!0,greedy:!0,inside:{scheme:{pattern:/^(#)[\s\S]+$/,lookbehind:!0,alias:"language-scheme",inside:{"embedded-lilypond":{pattern:/#\{[\s\S]*?#\}/,greedy:!0,inside:{punctuation:/^#\{|#\}$/,lilypond:{pattern:/[\s\S]+/,alias:"language-lilypond",inside:null}}},rest:r.languages.scheme}},punctuation:/#/}},string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":{pattern:/(\\new\s+)[\w-]+/,lookbehind:!0},keyword:{pattern:/\\[a-z][-\w]*/i,inside:{punctuation:/^\\/}},operator:/[=|]|<<|>>/,punctuation:{pattern:/(^|[a-z\d])(?:'+|,+|[_^]?-[_^]?(?:[-+^!>._]|(?=\d))|[_^]\.?|[.!])|[{}()[\]<>^~]|\\[()[\]<>\\!]|--|__/,lookbehind:!0},number:/\b\d+(?:\/\d+)?\b/};u["embedded-scheme"].inside.scheme.inside["embedded-lilypond"].inside.lilypond.inside=u,r.languages.ly=u}(n)}return Zv}var Qv,t2;function hhe(){if(t2)return Qv;t2=1;var e=Gn();Qv=t,t.displayName="liquid",t.aliases=[];function t(n){n.register(e),n.languages.liquid={comment:{pattern:/(^\{%\s*comment\s*%\})[\s\S]+(?=\{%\s*endcomment\s*%\}$)/,lookbehind:!0},delimiter:{pattern:/^\{(?:\{\{|[%\{])-?|-?(?:\}\}|[%\}])\}$/,alias:"punctuation"},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},keyword:/\b(?:as|assign|break|(?:end)?(?:capture|case|comment|for|form|if|paginate|raw|style|tablerow|unless)|continue|cycle|decrement|echo|else|elsif|in|include|increment|limit|liquid|offset|range|render|reversed|section|when|with)\b/,object:/\b(?:address|all_country_option_tags|article|block|blog|cart|checkout|collection|color|country|country_option_tags|currency|current_page|current_tags|customer|customer_address|date|discount_allocation|discount_application|external_video|filter|filter_value|font|forloop|fulfillment|generic_file|gift_card|group|handle|image|line_item|link|linklist|localization|location|measurement|media|metafield|model|model_source|order|page|page_description|page_image|page_title|part|policy|product|product_option|recommendations|request|robots|routes|rule|script|search|selling_plan|selling_plan_allocation|selling_plan_group|shipping_method|shop|shop_locale|sitemap|store_availability|tax_line|template|theme|transaction|unit_price_measurement|user_agent|variant|video|video_source)\b/,function:[{pattern:/(\|\s*)\w+/,lookbehind:!0,alias:"filter"},{pattern:/(\.\s*)(?:first|last|size)/,lookbehind:!0}],boolean:/\b(?:false|nil|true)\b/,range:{pattern:/\.\./,alias:"operator"},number:/\b\d+(?:\.\d+)?\b/,operator:/[!=]=|<>|[<>]=?|[|?:=-]|\b(?:and|contains(?=\s)|or)\b/,punctuation:/[.,\[\]()]/,empty:{pattern:/\bempty\b/,alias:"keyword"}},n.hooks.add("before-tokenize",function(r){var a=/\{%\s*comment\s*%\}[\s\S]*?\{%\s*endcomment\s*%\}|\{(?:%[\s\S]*?%|\{\{[\s\S]*?\}\}|\{[\s\S]*?\})\}/g,i=!1;n.languages["markup-templating"].buildPlaceholders(r,"liquid",a,function(l){var u=/^\{%-?\s*(\w+)/.exec(l);if(u){var c=u[1];if(c==="raw"&&!i)return i=!0,!0;if(c==="endraw")return i=!1,!0}return!i})}),n.hooks.add("after-tokenize",function(r){n.languages["markup-templating"].tokenizePlaceholders(r,"liquid")})}return Qv}var Jv,n2;function mhe(){if(n2)return Jv;n2=1,Jv=e,e.displayName="lisp",e.aliases=[];function e(t){(function(n){function r(v){return RegExp(/(\()/.source+"(?:"+v+")"+/(?=[\s\)])/.source)}function a(v){return RegExp(/([\s([])/.source+"(?:"+v+")"+/(?=[\s)])/.source)}var i=/(?!\d)[-+*/~!@$%^=<>{}\w]+/.source,l="&"+i,u="(\\()",c="(?=\\))",f="(?=\\s)",p=/(?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\))*\))*\))*/.source,g={heading:{pattern:/;;;.*/,alias:["comment","title"]},comment:/;.*/,string:{pattern:/"(?:[^"\\]|\\.)*"/,greedy:!0,inside:{argument:/[-A-Z]+(?=[.,\s])/,symbol:RegExp("`"+i+"'")}},"quoted-symbol":{pattern:RegExp("#?'"+i),alias:["variable","symbol"]},"lisp-property":{pattern:RegExp(":"+i),alias:"property"},splice:{pattern:RegExp(",@?"+i),alias:["symbol","variable"]},keyword:[{pattern:RegExp(u+"(?:and|(?:cl-)?letf|cl-loop|cond|cons|error|if|(?:lexical-)?let\\*?|message|not|null|or|provide|require|setq|unless|use-package|when|while)"+f),lookbehind:!0},{pattern:RegExp(u+"(?:append|by|collect|concat|do|finally|for|in|return)"+f),lookbehind:!0}],declare:{pattern:r(/declare/.source),lookbehind:!0,alias:"keyword"},interactive:{pattern:r(/interactive/.source),lookbehind:!0,alias:"keyword"},boolean:{pattern:a(/nil|t/.source),lookbehind:!0},number:{pattern:a(/[-+]?\d+(?:\.\d*)?/.source),lookbehind:!0},defvar:{pattern:RegExp(u+"def(?:const|custom|group|var)\\s+"+i),lookbehind:!0,inside:{keyword:/^def[a-z]+/,variable:RegExp(i)}},defun:{pattern:RegExp(u+/(?:cl-)?(?:defmacro|defun\*?)\s+/.source+i+/\s+\(/.source+p+/\)/.source),lookbehind:!0,greedy:!0,inside:{keyword:/^(?:cl-)?def\S+/,arguments:null,function:{pattern:RegExp("(^\\s)"+i),lookbehind:!0},punctuation:/[()]/}},lambda:{pattern:RegExp(u+"lambda\\s+\\(\\s*(?:&?"+i+"(?:\\s+&?"+i+")*\\s*)?\\)"),lookbehind:!0,greedy:!0,inside:{keyword:/^lambda/,arguments:null,punctuation:/[()]/}},car:{pattern:RegExp(u+i),lookbehind:!0},punctuation:[/(?:['`,]?\(|[)\[\]])/,{pattern:/(\s)\.(?=\s)/,lookbehind:!0}]},b={"lisp-marker":RegExp(l),varform:{pattern:RegExp(/\(/.source+i+/\s+(?=\S)/.source+p+/\)/.source),inside:g},argument:{pattern:RegExp(/(^|[\s(])/.source+i),lookbehind:!0,alias:"variable"},rest:g},m="\\S+(?:\\s+\\S+)*",S={pattern:RegExp(u+p+c),lookbehind:!0,inside:{"rest-vars":{pattern:RegExp("&(?:body|rest)\\s+"+m),inside:b},"other-marker-vars":{pattern:RegExp("&(?:aux|optional)\\s+"+m),inside:b},keys:{pattern:RegExp("&key\\s+"+m+"(?:\\s+&allow-other-keys)?"),inside:b},argument:{pattern:RegExp(i),alias:"variable"},punctuation:/[()]/}};g.lambda.inside.arguments=S,g.defun.inside.arguments=n.util.clone(S),g.defun.inside.arguments.inside.sublist=S,n.languages.lisp=g,n.languages.elisp=g,n.languages.emacs=g,n.languages["emacs-lisp"]=g})(t)}return Jv}var eS,r2;function bhe(){if(r2)return eS;r2=1,eS=e,e.displayName="livescript",e.aliases=[];function e(t){t.languages.livescript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\])#.*/,lookbehind:!0}],"interpolated-string":{pattern:/(^|[^"])("""|")(?:\\[\s\S]|(?!\2)[^\\])*\2(?!")/,lookbehind:!0,greedy:!0,inside:{variable:{pattern:/(^|[^\\])#[a-z_](?:-?[a-z]|[\d_])*/m,lookbehind:!0},interpolation:{pattern:/(^|[^\\])#\{[^}]+\}/m,lookbehind:!0,inside:{"interpolation-punctuation":{pattern:/^#\{|\}$/,alias:"variable"}}},string:/[\s\S]+/}},string:[{pattern:/('''|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},{pattern:/<\[[\s\S]*?\]>/,greedy:!0},/\\[^\s,;\])}]+/],regex:[{pattern:/\/\/(?:\[[^\r\n\]]*\]|\\.|(?!\/\/)[^\\\[])+\/\/[gimyu]{0,5}/,greedy:!0,inside:{comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0}}},{pattern:/\/(?:\[[^\r\n\]]*\]|\\.|[^/\\\r\n\[])+\/[gimyu]{0,5}/,greedy:!0}],keyword:{pattern:/(^|(?!-).)\b(?:break|case|catch|class|const|continue|default|do|else|extends|fallthrough|finally|for(?: ever)?|function|if|implements|it|let|loop|new|null|otherwise|own|return|super|switch|that|then|this|throw|try|unless|until|var|void|when|while|yield)(?!-)\b/m,lookbehind:!0},"keyword-operator":{pattern:/(^|[^-])\b(?:(?:delete|require|typeof)!|(?:and|by|delete|export|from|import(?: all)?|in|instanceof|is(?: not|nt)?|not|of|or|til|to|typeof|with|xor)(?!-)\b)/m,lookbehind:!0,alias:"operator"},boolean:{pattern:/(^|[^-])\b(?:false|no|off|on|true|yes)(?!-)\b/m,lookbehind:!0},argument:{pattern:/(^|(?!\.&\.)[^&])&(?!&)\d*/m,lookbehind:!0,alias:"variable"},number:/\b(?:\d+~[\da-z]+|\d[\d_]*(?:\.\d[\d_]*)?(?:[a-z]\w*)?)/i,identifier:/[a-z_](?:-?[a-z]|[\d_])*/i,operator:[{pattern:/( )\.(?= )/,lookbehind:!0},/\.(?:[=~]|\.\.?)|\.(?:[&|^]|<<|>>>?)\.|:(?:=|:=?)|&&|\|[|>]|<(?:<<?<?|--?!?|~~?!?|[|=?])?|>[>=?]?|-(?:->?|>)?|\+\+?|@@?|%%?|\*\*?|!(?:~?=|--?>|~?~>)?|~(?:~?>|=)?|==?|\^\^?|[\/?]/],punctuation:/[(){}\[\]|.,:;`]/},t.languages.livescript["interpolated-string"].inside.interpolation.inside.rest=t.languages.livescript}return eS}var tS,a2;function yhe(){if(a2)return tS;a2=1,tS=e,e.displayName="llvm",e.aliases=[];function e(t){(function(n){n.languages.llvm={comment:/;.*/,string:{pattern:/"[^"]*"/,greedy:!0},boolean:/\b(?:false|true)\b/,variable:/[%@!#](?:(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+|\d+)/i,label:/(?!\d)(?:[-$.\w]|\\[a-f\d]{2})+:/i,type:{pattern:/\b(?:double|float|fp128|half|i[1-9]\d*|label|metadata|ppc_fp128|token|void|x86_fp80|x86_mmx)\b/,alias:"class-name"},keyword:/\b[a-z_][a-z_0-9]*\b/,number:/[+-]?\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-Fa-f]+\b|\b0xK[\dA-Fa-f]{20}\b|\b0x[ML][\dA-Fa-f]{32}\b|\b0xH[\dA-Fa-f]{4}\b/,punctuation:/[{}[\];(),.!*=<>]/}})(t)}return tS}var nS,o2;function vhe(){if(o2)return nS;o2=1,nS=e,e.displayName="log",e.aliases=[];function e(t){t.languages.log={string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?![st] | \w)(?:[^'\\\r\n]|\\.)*'/,greedy:!0},exception:{pattern:/(^|[^\w.])[a-z][\w.]*(?:Error|Exception):.*(?:(?:\r\n?|\n)[ \t]*(?:at[ \t].+|\.{3}.*|Caused by:.*))+(?:(?:\r\n?|\n)[ \t]*\.\.\. .*)?/,lookbehind:!0,greedy:!0,alias:["javastacktrace","language-javastacktrace"],inside:t.languages.javastacktrace||{keyword:/\bat\b/,function:/[a-z_][\w$]*(?=\()/,punctuation:/[.:()]/}},level:[{pattern:/\b(?:ALERT|CRIT|CRITICAL|EMERG|EMERGENCY|ERR|ERROR|FAILURE|FATAL|SEVERE)\b/,alias:["error","important"]},{pattern:/\b(?:WARN|WARNING|WRN)\b/,alias:["warning","important"]},{pattern:/\b(?:DISPLAY|INF|INFO|NOTICE|STATUS)\b/,alias:["info","keyword"]},{pattern:/\b(?:DBG|DEBUG|FINE)\b/,alias:["debug","keyword"]},{pattern:/\b(?:FINER|FINEST|TRACE|TRC|VERBOSE|VRB)\b/,alias:["trace","comment"]}],property:{pattern:/((?:^|[\]|])[ \t]*)[a-z_](?:[\w-]|\b\/\b)*(?:[. ]\(?\w(?:[\w-]|\b\/\b)*\)?)*:(?=\s)/im,lookbehind:!0},separator:{pattern:/(^|[^-+])-{3,}|={3,}|\*{3,}|- - /m,lookbehind:!0,alias:"comment"},url:/\b(?:file|ftp|https?):\/\/[^\s|,;'"]*[^\s|,;'">.]/,email:{pattern:/(^|\s)[-\w+.]+@[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)+(?=\s)/,lookbehind:!0,alias:"url"},"ip-address":{pattern:/\b(?:\d{1,3}(?:\.\d{1,3}){3})\b/,alias:"constant"},"mac-address":{pattern:/\b[a-f0-9]{2}(?::[a-f0-9]{2}){5}\b/i,alias:"constant"},domain:{pattern:/(^|\s)[a-z][a-z0-9-]*(?:\.[a-z][a-z0-9-]*)*\.[a-z][a-z0-9-]+(?=\s)/,lookbehind:!0,alias:"constant"},uuid:{pattern:/\b[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}\b/i,alias:"constant"},hash:{pattern:/\b(?:[a-f0-9]{32}){1,2}\b/i,alias:"constant"},"file-path":{pattern:/\b[a-z]:[\\/][^\s|,;:(){}\[\]"']+|(^|[\s:\[\](>|])\.{0,2}\/\w[^\s|,;:(){}\[\]"']*/i,lookbehind:!0,greedy:!0,alias:"string"},date:{pattern:RegExp(/\b\d{4}[-/]\d{2}[-/]\d{2}(?:T(?=\d{1,2}:)|(?=\s\d{1,2}:))/.source+"|"+/\b\d{1,4}[-/ ](?:\d{1,2}|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)[-/ ]\d{2,4}T?\b/.source+"|"+/\b(?:(?:Fri|Mon|Sat|Sun|Thu|Tue|Wed)(?:\s{1,2}(?:Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep))?|Apr|Aug|Dec|Feb|Jan|Jul|Jun|Mar|May|Nov|Oct|Sep)\s{1,2}\d{1,2}\b/.source,"i"),alias:"number"},time:{pattern:/\b\d{1,2}:\d{1,2}:\d{1,2}(?:[.,:]\d+)?(?:\s?[+-]\d{2}:?\d{2}|Z)?\b/,alias:"number"},boolean:/\b(?:false|null|true)\b/i,number:{pattern:/(^|[^.\w])(?:0x[a-f0-9]+|0o[0-7]+|0b[01]+|v?\d[\da-f]*(?:\.\d+)*(?:e[+-]?\d+)?[a-z]{0,3}\b)\b(?!\.\w)/i,lookbehind:!0},operator:/[;:?<=>~/@!$%&+\-|^(){}*#]/,punctuation:/[\[\].,]/}}return nS}var rS,i2;function She(){if(i2)return rS;i2=1,rS=e,e.displayName="lolcode",e.aliases=[];function e(t){t.languages.lolcode={comment:[/\bOBTW\s[\s\S]*?\sTLDR\b/,/\bBTW.+/],string:{pattern:/"(?::.|[^":])*"/,inside:{variable:/:\{[^}]+\}/,symbol:[/:\([a-f\d]+\)/i,/:\[[^\]]+\]/,/:[)>o":]/]},greedy:!0},number:/(?:\B-)?(?:\b\d+(?:\.\d*)?|\B\.\d+)/,symbol:{pattern:/(^|\s)(?:A )?(?:BUKKIT|NOOB|NUMBAR|NUMBR|TROOF|YARN)(?=\s|,|$)/,lookbehind:!0,inside:{keyword:/A(?=\s)/}},label:{pattern:/((?:^|\s)(?:IM IN YR|IM OUTTA YR) )[a-zA-Z]\w*/,lookbehind:!0,alias:"string"},function:{pattern:/((?:^|\s)(?:HOW IZ I|I IZ|IZ) )[a-zA-Z]\w*/,lookbehind:!0},keyword:[{pattern:/(^|\s)(?:AN|FOUND YR|GIMMEH|GTFO|HAI|HAS A|HOW IZ I|I HAS A|I IZ|IF U SAY SO|IM IN YR|IM OUTTA YR|IS NOW(?: A)?|ITZ(?: A)?|IZ|KTHX|KTHXBYE|LIEK(?: A)?|MAEK|MEBBE|MKAY|NERFIN|NO WAI|O HAI IM|O RLY\?|OIC|OMG|OMGWTF|R|SMOOSH|SRS|TIL|UPPIN|VISIBLE|WILE|WTF\?|YA RLY|YR)(?=\s|,|$)/,lookbehind:!0},/'Z(?=\s|,|$)/],boolean:{pattern:/(^|\s)(?:FAIL|WIN)(?=\s|,|$)/,lookbehind:!0},variable:{pattern:/(^|\s)IT(?=\s|,|$)/,lookbehind:!0},operator:{pattern:/(^|\s)(?:NOT|BOTH SAEM|DIFFRINT|(?:ALL|ANY|BIGGR|BOTH|DIFF|EITHER|MOD|PRODUKT|QUOSHUNT|SMALLR|SUM|WON) OF)(?=\s|,|$)/,lookbehind:!0},punctuation:/\.{3}|…|,|!/}}return rS}var aS,l2;function Ehe(){if(l2)return aS;l2=1,aS=e,e.displayName="magma",e.aliases=[];function e(t){t.languages.magma={output:{pattern:/^(>.*(?:\r(?:\n|(?!\n))|\n))(?!>)(?:.+|(?:\r(?:\n|(?!\n))|\n)(?!>).*)(?:(?:\r(?:\n|(?!\n))|\n)(?!>).*)*/m,lookbehind:!0,greedy:!0},comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/(^|[^\\"])"(?:[^\r\n\\"]|\\.)*"/,lookbehind:!0,greedy:!0},keyword:/\b(?:_|adj|and|assert|assert2|assert3|assigned|break|by|case|cat|catch|clear|cmpeq|cmpne|continue|declare|default|delete|diff|div|do|elif|else|end|eq|error|eval|exists|exit|for|forall|forward|fprintf|freeze|function|ge|gt|if|iload|import|in|intrinsic|is|join|le|load|local|lt|meet|mod|ne|not|notadj|notin|notsubset|or|print|printf|procedure|quit|random|read|readi|repeat|require|requirege|requirerange|restore|return|save|sdiff|select|subset|then|time|to|try|until|vprint|vprintf|vtime|when|where|while|xor)\b/,boolean:/\b(?:false|true)\b/,generator:{pattern:/\b[a-z_]\w*(?=\s*<)/i,alias:"class-name"},function:/\b[a-z_]\w*(?=\s*\()/i,number:{pattern:/(^|[^\w.]|\.\.)(?:\d+(?:\.\d*)?|\.\d+)(?:[eE][+-]?\d+)?(?:_[a-z]?)?(?=$|[^\w.]|\.\.)/,lookbehind:!0},operator:/->|[-+*/^~!|#=]|:=|\.\./,punctuation:/[()[\]{}<>,;.:]/}}return aS}var oS,s2;function whe(){if(s2)return oS;s2=1,oS=e,e.displayName="makefile",e.aliases=[];function e(t){t.languages.makefile={comment:{pattern:/(^|[^\\])#(?:\\(?:\r\n|[\s\S])|[^\\\r\n])*/,lookbehind:!0},string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},"builtin-target":{pattern:/\.[A-Z][^:#=\s]+(?=\s*:(?!=))/,alias:"builtin"},target:{pattern:/^(?:[^:=\s]|[ \t]+(?![\s:]))+(?=\s*:(?!=))/m,alias:"symbol",inside:{variable:/\$+(?:(?!\$)[^(){}:#=\s]+|(?=[({]))/}},variable:/\$+(?:(?!\$)[^(){}:#=\s]+|\([@*%<^+?][DF]\)|(?=[({]))/,keyword:/-include\b|\b(?:define|else|endef|endif|export|ifn?def|ifn?eq|include|override|private|sinclude|undefine|unexport|vpath)\b/,function:{pattern:/(\()(?:abspath|addsuffix|and|basename|call|dir|error|eval|file|filter(?:-out)?|findstring|firstword|flavor|foreach|guile|if|info|join|lastword|load|notdir|or|origin|patsubst|realpath|shell|sort|strip|subst|suffix|value|warning|wildcard|word(?:list|s)?)(?=[ \t])/,lookbehind:!0},operator:/(?:::|[?:+!])?=|[|@]/,punctuation:/[:;(){}]/}}return oS}var iS,u2;function xhe(){if(u2)return iS;u2=1,iS=e,e.displayName="markdown",e.aliases=["md"];function e(t){(function(n){var r=/(?:\\.|[^\\\n\r]|(?:\n|\r\n?)(?![\r\n]))/.source;function a(b){return b=b.replace(/<inner>/g,function(){return r}),RegExp(/((?:^|[^\\])(?:\\{2})*)/.source+"(?:"+b+")")}var i=/(?:\\.|``(?:[^`\r\n]|`(?!`))+``|`[^`\r\n]+`|[^\\|\r\n`])+/.source,l=/\|?__(?:\|__)+\|?(?:(?:\n|\r\n?)|(?![\s\S]))/.source.replace(/__/g,function(){return i}),u=/\|?[ \t]*:?-{3,}:?[ \t]*(?:\|[ \t]*:?-{3,}:?[ \t]*)+\|?(?:\n|\r\n?)/.source;n.languages.markdown=n.languages.extend("markup",{}),n.languages.insertBefore("markdown","prolog",{"front-matter-block":{pattern:/(^(?:\s*[\r\n])?)---(?!.)[\s\S]*?[\r\n]---(?!.)/,lookbehind:!0,greedy:!0,inside:{punctuation:/^---|---$/,"front-matter":{pattern:/\S+(?:\s+\S+)*/,alias:["yaml","language-yaml"],inside:n.languages.yaml}}},blockquote:{pattern:/^>(?:[\t ]*>)*/m,alias:"punctuation"},table:{pattern:RegExp("^"+l+u+"(?:"+l+")*","m"),inside:{"table-data-rows":{pattern:RegExp("^("+l+u+")(?:"+l+")*$"),lookbehind:!0,inside:{"table-data":{pattern:RegExp(i),inside:n.languages.markdown},punctuation:/\|/}},"table-line":{pattern:RegExp("^("+l+")"+u+"$"),lookbehind:!0,inside:{punctuation:/\||:?-{3,}:?/}},"table-header-row":{pattern:RegExp("^"+l+"$"),inside:{"table-header":{pattern:RegExp(i),alias:"important",inside:n.languages.markdown},punctuation:/\|/}}}},code:[{pattern:/((?:^|\n)[ \t]*\n|(?:^|\r\n?)[ \t]*\r\n?)(?: {4}|\t).+(?:(?:\n|\r\n?)(?: {4}|\t).+)*/,lookbehind:!0,alias:"keyword"},{pattern:/^```[\s\S]*?^```$/m,greedy:!0,inside:{"code-block":{pattern:/^(```.*(?:\n|\r\n?))[\s\S]+?(?=(?:\n|\r\n?)^```$)/m,lookbehind:!0},"code-language":{pattern:/^(```).+/,lookbehind:!0},punctuation:/```/}}],title:[{pattern:/\S.*(?:\n|\r\n?)(?:==+|--+)(?=[ \t]*$)/m,alias:"important",inside:{punctuation:/==+$|--+$/}},{pattern:/(^\s*)#.+/m,lookbehind:!0,alias:"important",inside:{punctuation:/^#+|#+$/}}],hr:{pattern:/(^\s*)([*-])(?:[\t ]*\2){2,}(?=\s*$)/m,lookbehind:!0,alias:"punctuation"},list:{pattern:/(^\s*)(?:[*+-]|\d+\.)(?=[\t ].)/m,lookbehind:!0,alias:"punctuation"},"url-reference":{pattern:/!?\[[^\]]+\]:[\t ]+(?:\S+|<(?:\\.|[^>\\])+>)(?:[\t ]+(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\)))?/,inside:{variable:{pattern:/^(!?\[)[^\]]+/,lookbehind:!0},string:/(?:"(?:\\.|[^"\\])*"|'(?:\\.|[^'\\])*'|\((?:\\.|[^)\\])*\))$/,punctuation:/^[\[\]!:]|[<>]/},alias:"url"},bold:{pattern:a(/\b__(?:(?!_)<inner>|_(?:(?!_)<inner>)+_)+__\b|\*\*(?:(?!\*)<inner>|\*(?:(?!\*)<inner>)+\*)+\*\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^..)[\s\S]+(?=..$)/,lookbehind:!0,inside:{}},punctuation:/\*\*|__/}},italic:{pattern:a(/\b_(?:(?!_)<inner>|__(?:(?!_)<inner>)+__)+_\b|\*(?:(?!\*)<inner>|\*\*(?:(?!\*)<inner>)+\*\*)+\*/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^.)[\s\S]+(?=.$)/,lookbehind:!0,inside:{}},punctuation:/[*_]/}},strike:{pattern:a(/(~~?)(?:(?!~)<inner>)+\2/.source),lookbehind:!0,greedy:!0,inside:{content:{pattern:/(^~~?)[\s\S]+(?=\1$)/,lookbehind:!0,inside:{}},punctuation:/~~?/}},"code-snippet":{pattern:/(^|[^\\`])(?:``[^`\r\n]+(?:`[^`\r\n]+)*``(?!`)|`[^`\r\n]+`(?!`))/,lookbehind:!0,greedy:!0,alias:["code","keyword"]},url:{pattern:a(/!?\[(?:(?!\])<inner>)+\](?:\([^\s)]+(?:[\t ]+"(?:\\.|[^"\\])*")?\)|[ \t]?\[(?:(?!\])<inner>)+\])/.source),lookbehind:!0,greedy:!0,inside:{operator:/^!/,content:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0,inside:{}},variable:{pattern:/(^\][ \t]?\[)[^\]]+(?=\]$)/,lookbehind:!0},url:{pattern:/(^\]\()[^\s)]+/,lookbehind:!0},string:{pattern:/(^[ \t]+)"(?:\\.|[^"\\])*"(?=\)$)/,lookbehind:!0}}}}),["url","bold","italic","strike"].forEach(function(b){["url","bold","italic","strike","code-snippet"].forEach(function(m){b!==m&&(n.languages.markdown[b].inside.content.inside[m]=n.languages.markdown[m])})}),n.hooks.add("after-tokenize",function(b){if(b.language!=="markdown"&&b.language!=="md")return;function m(S){if(!(!S||typeof S=="string"))for(var v=0,A=S.length;v<A;v++){var R=S[v];if(R.type!=="code"){m(R.content);continue}var x=R.content[1],T=R.content[3];if(x&&T&&x.type==="code-language"&&T.type==="code-block"&&typeof x.content=="string"){var C=x.content.replace(/\b#/g,"sharp").replace(/\b\+\+/g,"pp");C=(/[a-z][\w-]*/i.exec(C)||[""])[0].toLowerCase();var N="language-"+C;T.alias?typeof T.alias=="string"?T.alias=[T.alias,N]:T.alias.push(N):T.alias=[N]}}}m(b.tokens)}),n.hooks.add("wrap",function(b){if(b.type==="code-block"){for(var m="",S=0,v=b.classes.length;S<v;S++){var A=b.classes[S],R=/language-(.+)/.exec(A);if(R){m=R[1];break}}var x=n.languages[m];if(x)b.content=n.highlight(g(b.content.value),x,m);else if(m&&m!=="none"&&n.plugins.autoloader){var T="md-"+new Date().valueOf()+"-"+Math.floor(Math.random()*1e16);b.attributes.id=T,n.plugins.autoloader.loadLanguages(m,function(){var C=document.getElementById(T);C&&(C.innerHTML=n.highlight(C.textContent,n.languages[m],m))})}}});var c=RegExp(n.languages.markup.tag.pattern.source,"gi"),f={amp:"&",lt:"<",gt:">",quot:'"'},p=String.fromCodePoint||String.fromCharCode;function g(b){var m=b.replace(c,"");return m=m.replace(/&(\w{1,8}|#x?[\da-f]{1,8});/gi,function(S,v){if(v=v.toLowerCase(),v[0]==="#"){var A;return v[1]==="x"?A=parseInt(v.slice(2),16):A=Number(v.slice(1)),p(A)}else{var R=f[v];return R||S}}),m}n.languages.md=n.languages.markdown})(t)}return iS}var lS,c2;function khe(){if(c2)return lS;c2=1,lS=e,e.displayName="matlab",e.aliases=[];function e(t){t.languages.matlab={comment:[/%\{[\s\S]*?\}%/,/%.+/],string:{pattern:/\B'(?:''|[^'\r\n])*'/,greedy:!0},number:/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[eE][+-]?\d+)?(?:[ij])?|\b[ij]\b/,keyword:/\b(?:NaN|break|case|catch|continue|else|elseif|end|for|function|if|inf|otherwise|parfor|pause|pi|return|switch|try|while)\b/,function:/\b(?!\d)\w+(?=\s*\()/,operator:/\.?[*^\/\\']|[+\-:@]|[<>=~]=?|&&?|\|\|?/,punctuation:/\.{3}|[.,;\[\](){}!]/}}return lS}var sS,d2;function Ahe(){if(d2)return sS;d2=1,sS=e,e.displayName="maxscript",e.aliases=[];function e(t){(function(n){var r=/\b(?:about|and|animate|as|at|attributes|by|case|catch|collect|continue|coordsys|do|else|exit|fn|for|from|function|global|if|in|local|macroscript|mapped|max|not|of|off|on|or|parameters|persistent|plugin|rcmenu|return|rollout|set|struct|then|throw|to|tool|try|undo|utility|when|where|while|with)\b/i;n.languages.maxscript={comment:{pattern:/\/\*[\s\S]*?(?:\*\/|$)|--.*/,greedy:!0},string:{pattern:/(^|[^"\\@])(?:"(?:[^"\\]|\\[\s\S])*"|@"[^"]*")/,lookbehind:!0,greedy:!0},path:{pattern:/\$(?:[\w/\\.*?]|'[^']*')*/,greedy:!0,alias:"string"},"function-call":{pattern:RegExp("((?:"+(/^/.source+"|"+/[;=<>+\-*/^({\[]/.source+"|"+/\b(?:and|by|case|catch|collect|do|else|if|in|not|or|return|then|to|try|where|while|with)\b/.source)+")[ 	]*)(?!"+r.source+")"+/[a-z_]\w*\b/.source+"(?=[ 	]*(?:"+("(?!"+r.source+")"+/[a-z_]/.source+"|"+/\d|-\.?\d/.source+"|"+/[({'"$@#?]/.source)+"))","im"),lookbehind:!0,greedy:!0,alias:"function"},"function-definition":{pattern:/(\b(?:fn|function)\s+)\w+\b/i,lookbehind:!0,alias:"function"},argument:{pattern:/\b[a-z_]\w*(?=:)/i,alias:"attr-name"},keyword:r,boolean:/\b(?:false|true)\b/,time:{pattern:/(^|[^\w.])(?:(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?[msft])+|\d+:\d+(?:\.\d*)?)(?![\w.:])/,lookbehind:!0,alias:"number"},number:[{pattern:/(^|[^\w.])(?:(?:\d+(?:\.\d*)?|\.\d+)(?:[eEdD][+-]\d+|[LP])?|0x[a-fA-F0-9]+)(?![\w.:])/,lookbehind:!0},/\b(?:e|pi)\b/],constant:/\b(?:dontcollect|ok|silentValue|undefined|unsupplied)\b/,color:{pattern:/\b(?:black|blue|brown|gray|green|orange|red|white|yellow)\b/i,alias:"constant"},operator:/[-+*/<>=!]=?|[&^?]|#(?!\()/,punctuation:/[()\[\]{}.:,;]|#(?=\()|\\$/m}})(t)}return sS}var uS,f2;function The(){if(f2)return uS;f2=1,uS=e,e.displayName="mel",e.aliases=[];function e(t){t.languages.mel={comment:/\/\/.*/,code:{pattern:/`(?:\\.|[^\\`\r\n])*`/,greedy:!0,alias:"italic",inside:{delimiter:{pattern:/^`|`$/,alias:"punctuation"}}},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},variable:/\$\w+/,number:/\b0x[\da-fA-F]+\b|\b\d+(?:\.\d*)?|\B\.\d+/,flag:{pattern:/-[^\d\W]\w*/,alias:"operator"},keyword:/\b(?:break|case|continue|default|do|else|float|for|global|if|in|int|matrix|proc|return|string|switch|vector|while)\b/,function:/\b\w+(?=\()|\b(?:CBG|HfAddAttractorToAS|HfAssignAS|HfBuildEqualMap|HfBuildFurFiles|HfBuildFurImages|HfCancelAFR|HfConnectASToHF|HfCreateAttractor|HfDeleteAS|HfEditAS|HfPerformCreateAS|HfRemoveAttractorFromAS|HfSelectAttached|HfSelectAttractors|HfUnAssignAS|Mayatomr|about|abs|addAttr|addAttributeEditorNodeHelp|addDynamic|addNewShelfTab|addPP|addPanelCategory|addPrefixToName|advanceToNextDrivenKey|affectedNet|affects|aimConstraint|air|alias|aliasAttr|align|alignCtx|alignCurve|alignSurface|allViewFit|ambientLight|angle|angleBetween|animCone|animCurveEditor|animDisplay|animView|annotate|appendStringArray|applicationName|applyAttrPreset|applyTake|arcLenDimContext|arcLengthDimension|arclen|arrayMapper|art3dPaintCtx|artAttrCtx|artAttrPaintVertexCtx|artAttrSkinPaintCtx|artAttrTool|artBuildPaintMenu|artFluidAttrCtx|artPuttyCtx|artSelectCtx|artSetPaintCtx|artUserPaintCtx|assignCommand|assignInputDevice|assignViewportFactories|attachCurve|attachDeviceAttr|attachSurface|attrColorSliderGrp|attrCompatibility|attrControlGrp|attrEnumOptionMenu|attrEnumOptionMenuGrp|attrFieldGrp|attrFieldSliderGrp|attrNavigationControlGrp|attrPresetEditWin|attributeExists|attributeInfo|attributeMenu|attributeQuery|autoKeyframe|autoPlace|bakeClip|bakeFluidShading|bakePartialHistory|bakeResults|bakeSimulation|basename|basenameEx|batchRender|bessel|bevel|bevelPlus|binMembership|bindSkin|blend2|blendShape|blendShapeEditor|blendShapePanel|blendTwoAttr|blindDataType|boneLattice|boundary|boxDollyCtx|boxZoomCtx|bufferCurve|buildBookmarkMenu|buildKeyframeMenu|button|buttonManip|cacheFile|cacheFileCombine|cacheFileMerge|cacheFileTrack|camera|cameraView|canCreateManip|canvas|capitalizeString|catch|catchQuiet|ceil|changeSubdivComponentDisplayLevel|changeSubdivRegion|channelBox|character|characterMap|characterOutlineEditor|characterize|chdir|checkBox|checkBoxGrp|checkDefaultRenderGlobals|choice|circle|circularFillet|clamp|clear|clearCache|clip|clipEditor|clipEditorCurrentTimeCtx|clipSchedule|clipSchedulerOutliner|clipTrimBefore|closeCurve|closeSurface|cluster|cmdFileOutput|cmdScrollFieldExecuter|cmdScrollFieldReporter|cmdShell|coarsenSubdivSelectionList|collision|color|colorAtPoint|colorEditor|colorIndex|colorIndexSliderGrp|colorSliderButtonGrp|colorSliderGrp|columnLayout|commandEcho|commandLine|commandPort|compactHairSystem|componentEditor|compositingInterop|computePolysetVolume|condition|cone|confirmDialog|connectAttr|connectControl|connectDynamic|connectJoint|connectionInfo|constrain|constrainValue|constructionHistory|container|containsMultibyte|contextInfo|control|convertFromOldLayers|convertIffToPsd|convertLightmap|convertSolidTx|convertTessellation|convertUnit|copyArray|copyFlexor|copyKey|copySkinWeights|cos|cpButton|cpCache|cpClothSet|cpCollision|cpConstraint|cpConvClothToMesh|cpForces|cpGetSolverAttr|cpPanel|cpProperty|cpRigidCollisionFilter|cpSeam|cpSetEdit|cpSetSolverAttr|cpSolver|cpSolverTypes|cpTool|cpUpdateClothUVs|createDisplayLayer|createDrawCtx|createEditor|createLayeredPsdFile|createMotionField|createNewShelf|createNode|createRenderLayer|createSubdivRegion|cross|crossProduct|ctxAbort|ctxCompletion|ctxEditMode|ctxTraverse|currentCtx|currentTime|currentTimeCtx|currentUnit|curve|curveAddPtCtx|curveCVCtx|curveEPCtx|curveEditorCtx|curveIntersect|curveMoveEPCtx|curveOnSurface|curveSketchCtx|cutKey|cycleCheck|cylinder|dagPose|date|defaultLightListCheckBox|defaultNavigation|defineDataServer|defineVirtualDevice|deformer|deg_to_rad|delete|deleteAttr|deleteShadingGroupsAndMaterials|deleteShelfTab|deleteUI|deleteUnusedBrushes|delrandstr|detachCurve|detachDeviceAttr|detachSurface|deviceEditor|devicePanel|dgInfo|dgdirty|dgeval|dgtimer|dimWhen|directKeyCtx|directionalLight|dirmap|dirname|disable|disconnectAttr|disconnectJoint|diskCache|displacementToPoly|displayAffected|displayColor|displayCull|displayLevelOfDetail|displayPref|displayRGBColor|displaySmoothness|displayStats|displayString|displaySurface|distanceDimContext|distanceDimension|doBlur|dolly|dollyCtx|dopeSheetEditor|dot|dotProduct|doubleProfileBirailSurface|drag|dragAttrContext|draggerContext|dropoffLocator|duplicate|duplicateCurve|duplicateSurface|dynCache|dynControl|dynExport|dynExpression|dynGlobals|dynPaintEditor|dynParticleCtx|dynPref|dynRelEdPanel|dynRelEditor|dynamicLoad|editAttrLimits|editDisplayLayerGlobals|editDisplayLayerMembers|editRenderLayerAdjustment|editRenderLayerGlobals|editRenderLayerMembers|editor|editorTemplate|effector|emit|emitter|enableDevice|encodeString|endString|endsWith|env|equivalent|equivalentTol|erf|error|eval|evalDeferred|evalEcho|event|exactWorldBoundingBox|exclusiveLightCheckBox|exec|executeForEachObject|exists|exp|expression|expressionEditorListen|extendCurve|extendSurface|extrude|fcheck|fclose|feof|fflush|fgetline|fgetword|file|fileBrowserDialog|fileDialog|fileExtension|fileInfo|filetest|filletCurve|filter|filterCurve|filterExpand|filterStudioImport|findAllIntersections|findAnimCurves|findKeyframe|findMenuItem|findRelatedSkinCluster|finder|firstParentOf|fitBspline|flexor|floatEq|floatField|floatFieldGrp|floatScrollBar|floatSlider|floatSlider2|floatSliderButtonGrp|floatSliderGrp|floor|flow|fluidCacheInfo|fluidEmitter|fluidVoxelInfo|flushUndo|fmod|fontDialog|fopen|formLayout|format|fprint|frameLayout|fread|freeFormFillet|frewind|fromNativePath|fwrite|gamma|gauss|geometryConstraint|getApplicationVersionAsFloat|getAttr|getClassification|getDefaultBrush|getFileList|getFluidAttr|getInputDeviceRange|getMayaPanelTypes|getModifiers|getPanel|getParticleAttr|getPluginResource|getenv|getpid|glRender|glRenderEditor|globalStitch|gmatch|goal|gotoBindPose|grabColor|gradientControl|gradientControlNoAttr|graphDollyCtx|graphSelectContext|graphTrackCtx|gravity|grid|gridLayout|group|groupObjectsByName|hardenPointCurve|hardware|hardwareRenderPanel|headsUpDisplay|headsUpMessage|help|helpLine|hermite|hide|hilite|hitTest|hotBox|hotkey|hotkeyCheck|hsv_to_rgb|hudButton|hudSlider|hudSliderButton|hwReflectionMap|hwRender|hwRenderLoad|hyperGraph|hyperPanel|hyperShade|hypot|iconTextButton|iconTextCheckBox|iconTextRadioButton|iconTextRadioCollection|iconTextScrollList|iconTextStaticLabel|ikHandle|ikHandleCtx|ikHandleDisplayScale|ikSolver|ikSplineHandleCtx|ikSystem|ikSystemInfo|ikfkDisplayMethod|illustratorCurves|image|imfPlugins|inheritTransform|insertJoint|insertJointCtx|insertKeyCtx|insertKnotCurve|insertKnotSurface|instance|instanceable|instancer|intField|intFieldGrp|intScrollBar|intSlider|intSliderGrp|interToUI|internalVar|intersect|iprEngine|isAnimCurve|isConnected|isDirty|isParentOf|isSameObject|isTrue|isValidObjectName|isValidString|isValidUiName|isolateSelect|itemFilter|itemFilterAttr|itemFilterRender|itemFilterType|joint|jointCluster|jointCtx|jointDisplayScale|jointLattice|keyTangent|keyframe|keyframeOutliner|keyframeRegionCurrentTimeCtx|keyframeRegionDirectKeyCtx|keyframeRegionDollyCtx|keyframeRegionInsertKeyCtx|keyframeRegionMoveKeyCtx|keyframeRegionScaleKeyCtx|keyframeRegionSelectKeyCtx|keyframeRegionSetKeyCtx|keyframeRegionTrackCtx|keyframeStats|lassoContext|lattice|latticeDeformKeyCtx|launch|launchImageEditor|layerButton|layeredShaderPort|layeredTexturePort|layout|layoutDialog|lightList|lightListEditor|lightListPanel|lightlink|lineIntersection|linearPrecision|linstep|listAnimatable|listAttr|listCameras|listConnections|listDeviceAttachments|listHistory|listInputDeviceAxes|listInputDeviceButtons|listInputDevices|listMenuAnnotation|listNodeTypes|listPanelCategories|listRelatives|listSets|listTransforms|listUnselected|listerEditor|loadFluid|loadNewShelf|loadPlugin|loadPluginLanguageResources|loadPrefObjects|localizedPanelLabel|lockNode|loft|log|longNameOf|lookThru|ls|lsThroughFilter|lsType|lsUI|mag|makeIdentity|makeLive|makePaintable|makeRoll|makeSingleSurface|makeTubeOn|makebot|manipMoveContext|manipMoveLimitsCtx|manipOptions|manipRotateContext|manipRotateLimitsCtx|manipScaleContext|manipScaleLimitsCtx|marker|match|max|memory|menu|menuBarLayout|menuEditor|menuItem|menuItemToShelf|menuSet|menuSetPref|messageLine|min|minimizeApp|mirrorJoint|modelCurrentTimeCtx|modelEditor|modelPanel|mouse|movIn|movOut|move|moveIKtoFK|moveKeyCtx|moveVertexAlongDirection|multiProfileBirailSurface|mute|nParticle|nameCommand|nameField|namespace|namespaceInfo|newPanelItems|newton|nodeCast|nodeIconButton|nodeOutliner|nodePreset|nodeType|noise|nonLinear|normalConstraint|normalize|nurbsBoolean|nurbsCopyUVSet|nurbsCube|nurbsEditUV|nurbsPlane|nurbsSelect|nurbsSquare|nurbsToPoly|nurbsToPolygonsPref|nurbsToSubdiv|nurbsToSubdivPref|nurbsUVSet|nurbsViewDirectionVector|objExists|objectCenter|objectLayer|objectType|objectTypeUI|obsoleteProc|oceanNurbsPreviewPlane|offsetCurve|offsetCurveOnSurface|offsetSurface|openGLExtension|openMayaPref|optionMenu|optionMenuGrp|optionVar|orbit|orbitCtx|orientConstraint|outlinerEditor|outlinerPanel|overrideModifier|paintEffectsDisplay|pairBlend|palettePort|paneLayout|panel|panelConfiguration|panelHistory|paramDimContext|paramDimension|paramLocator|parent|parentConstraint|particle|particleExists|particleInstancer|particleRenderInfo|partition|pasteKey|pathAnimation|pause|pclose|percent|performanceOptions|pfxstrokes|pickWalk|picture|pixelMove|planarSrf|plane|play|playbackOptions|playblast|plugAttr|plugNode|pluginInfo|pluginResourceUtil|pointConstraint|pointCurveConstraint|pointLight|pointMatrixMult|pointOnCurve|pointOnSurface|pointPosition|poleVectorConstraint|polyAppend|polyAppendFacetCtx|polyAppendVertex|polyAutoProjection|polyAverageNormal|polyAverageVertex|polyBevel|polyBlendColor|polyBlindData|polyBoolOp|polyBridgeEdge|polyCacheMonitor|polyCheck|polyChipOff|polyClipboard|polyCloseBorder|polyCollapseEdge|polyCollapseFacet|polyColorBlindData|polyColorDel|polyColorPerVertex|polyColorSet|polyCompare|polyCone|polyCopyUV|polyCrease|polyCreaseCtx|polyCreateFacet|polyCreateFacetCtx|polyCube|polyCut|polyCutCtx|polyCylinder|polyCylindricalProjection|polyDelEdge|polyDelFacet|polyDelVertex|polyDuplicateAndConnect|polyDuplicateEdge|polyEditUV|polyEditUVShell|polyEvaluate|polyExtrudeEdge|polyExtrudeFacet|polyExtrudeVertex|polyFlipEdge|polyFlipUV|polyForceUV|polyGeoSampler|polyHelix|polyInfo|polyInstallAction|polyLayoutUV|polyListComponentConversion|polyMapCut|polyMapDel|polyMapSew|polyMapSewMove|polyMergeEdge|polyMergeEdgeCtx|polyMergeFacet|polyMergeFacetCtx|polyMergeUV|polyMergeVertex|polyMirrorFace|polyMoveEdge|polyMoveFacet|polyMoveFacetUV|polyMoveUV|polyMoveVertex|polyNormal|polyNormalPerVertex|polyNormalizeUV|polyOptUvs|polyOptions|polyOutput|polyPipe|polyPlanarProjection|polyPlane|polyPlatonicSolid|polyPoke|polyPrimitive|polyPrism|polyProjection|polyPyramid|polyQuad|polyQueryBlindData|polyReduce|polySelect|polySelectConstraint|polySelectConstraintMonitor|polySelectCtx|polySelectEditCtx|polySeparate|polySetToFaceNormal|polySewEdge|polyShortestPathCtx|polySmooth|polySoftEdge|polySphere|polySphericalProjection|polySplit|polySplitCtx|polySplitEdge|polySplitRing|polySplitVertex|polyStraightenUVBorder|polySubdivideEdge|polySubdivideFacet|polyToSubdiv|polyTorus|polyTransfer|polyTriangulate|polyUVSet|polyUnite|polyWedgeFace|popen|popupMenu|pose|pow|preloadRefEd|print|progressBar|progressWindow|projFileViewer|projectCurve|projectTangent|projectionContext|projectionManip|promptDialog|propModCtx|propMove|psdChannelOutliner|psdEditTextureFile|psdExport|psdTextureFile|putenv|pwd|python|querySubdiv|quit|rad_to_deg|radial|radioButton|radioButtonGrp|radioCollection|radioMenuItemCollection|rampColorPort|rand|randomizeFollicles|randstate|rangeControl|readTake|rebuildCurve|rebuildSurface|recordAttr|recordDevice|redo|reference|referenceEdit|referenceQuery|refineSubdivSelectionList|refresh|refreshAE|registerPluginResource|rehash|reloadImage|removeJoint|removeMultiInstance|removePanelCategory|rename|renameAttr|renameSelectionList|renameUI|render|renderGlobalsNode|renderInfo|renderLayerButton|renderLayerParent|renderLayerPostProcess|renderLayerUnparent|renderManip|renderPartition|renderQualityNode|renderSettings|renderThumbnailUpdate|renderWindowEditor|renderWindowSelectContext|renderer|reorder|reorderDeformers|requires|reroot|resampleFluid|resetAE|resetPfxToPolyCamera|resetTool|resolutionNode|retarget|reverseCurve|reverseSurface|revolve|rgb_to_hsv|rigidBody|rigidSolver|roll|rollCtx|rootOf|rot|rotate|rotationInterpolation|roundConstantRadius|rowColumnLayout|rowLayout|runTimeCommand|runup|sampleImage|saveAllShelves|saveAttrPreset|saveFluid|saveImage|saveInitialState|saveMenu|savePrefObjects|savePrefs|saveShelf|saveToolSettings|scale|scaleBrushBrightness|scaleComponents|scaleConstraint|scaleKey|scaleKeyCtx|sceneEditor|sceneUIReplacement|scmh|scriptCtx|scriptEditorInfo|scriptJob|scriptNode|scriptTable|scriptToShelf|scriptedPanel|scriptedPanelType|scrollField|scrollLayout|sculpt|searchPathArray|seed|selLoadSettings|select|selectContext|selectCurveCV|selectKey|selectKeyCtx|selectKeyframeRegionCtx|selectMode|selectPref|selectPriority|selectType|selectedNodes|selectionConnection|separator|setAttr|setAttrEnumResource|setAttrMapping|setAttrNiceNameResource|setConstraintRestPosition|setDefaultShadingGroup|setDrivenKeyframe|setDynamic|setEditCtx|setEditor|setFluidAttr|setFocus|setInfinity|setInputDeviceMapping|setKeyCtx|setKeyPath|setKeyframe|setKeyframeBlendshapeTargetWts|setMenuMode|setNodeNiceNameResource|setNodeTypeFlag|setParent|setParticleAttr|setPfxToPolyCamera|setPluginResource|setProject|setStampDensity|setStartupMessage|setState|setToolTo|setUITemplate|setXformManip|sets|shadingConnection|shadingGeometryRelCtx|shadingLightRelCtx|shadingNetworkCompare|shadingNode|shapeCompare|shelfButton|shelfLayout|shelfTabLayout|shellField|shortNameOf|showHelp|showHidden|showManipCtx|showSelectionInTitle|showShadingGroupAttrEditor|showWindow|sign|simplify|sin|singleProfileBirailSurface|size|sizeBytes|skinCluster|skinPercent|smoothCurve|smoothTangentSurface|smoothstep|snap2to2|snapKey|snapMode|snapTogetherCtx|snapshot|soft|softMod|softModCtx|sort|sound|soundControl|source|spaceLocator|sphere|sphrand|spotLight|spotLightPreviewPort|spreadSheetEditor|spring|sqrt|squareSurface|srtContext|stackTrace|startString|startsWith|stitchAndExplodeShell|stitchSurface|stitchSurfacePoints|strcmp|stringArrayCatenate|stringArrayContains|stringArrayCount|stringArrayInsertAtIndex|stringArrayIntersector|stringArrayRemove|stringArrayRemoveAtIndex|stringArrayRemoveDuplicates|stringArrayRemoveExact|stringArrayToString|stringToStringArray|strip|stripPrefixFromName|stroke|subdAutoProjection|subdCleanTopology|subdCollapse|subdDuplicateAndConnect|subdEditUV|subdListComponentConversion|subdMapCut|subdMapSewMove|subdMatchTopology|subdMirror|subdToBlind|subdToPoly|subdTransferUVsToCache|subdiv|subdivCrease|subdivDisplaySmoothness|substitute|substituteAllString|substituteGeometry|substring|surface|surfaceSampler|surfaceShaderList|swatchDisplayPort|switchTable|symbolButton|symbolCheckBox|sysFile|system|tabLayout|tan|tangentConstraint|texLatticeDeformContext|texManipContext|texMoveContext|texMoveUVShellContext|texRotateContext|texScaleContext|texSelectContext|texSelectShortestPathCtx|texSmudgeUVContext|texWinToolCtx|text|textCurves|textField|textFieldButtonGrp|textFieldGrp|textManip|textScrollList|textToShelf|textureDisplacePlane|textureHairColor|texturePlacementContext|textureWindow|threadCount|threePointArcCtx|timeControl|timePort|timerX|toNativePath|toggle|toggleAxis|toggleWindowVisibility|tokenize|tokenizeList|tolerance|tolower|toolButton|toolCollection|toolDropped|toolHasOptions|toolPropertyWindow|torus|toupper|trace|track|trackCtx|transferAttributes|transformCompare|transformLimits|translator|trim|trunc|truncateFluidCache|truncateHairCache|tumble|tumbleCtx|turbulence|twoPointArcCtx|uiRes|uiTemplate|unassignInputDevice|undo|undoInfo|ungroup|uniform|unit|unloadPlugin|untangleUV|untitledFileName|untrim|upAxis|updateAE|userCtx|uvLink|uvSnapshot|validateShelfName|vectorize|view2dToolCtx|viewCamera|viewClipPlane|viewFit|viewHeadOn|viewLookAt|viewManip|viewPlace|viewSet|visor|volumeAxis|vortex|waitCursor|warning|webBrowser|webBrowserPrefs|whatIs|window|windowPref|wire|wireContext|workspace|wrinkle|wrinkleContext|writeTake|xbmLangPathList|xform)\b/,operator:[/\+[+=]?|-[-=]?|&&|\|\||[<>]=|[*\/!=]=?|[%^]/,{pattern:/(^|[^<])<(?!<)/,lookbehind:!0},{pattern:/(^|[^>])>(?!>)/,lookbehind:!0}],punctuation:/<<|>>|[.,:;?\[\](){}]/},t.languages.mel.code.inside.rest=t.languages.mel}return uS}var cS,p2;function _he(){if(p2)return cS;p2=1,cS=e,e.displayName="mermaid",e.aliases=[];function e(t){t.languages.mermaid={comment:{pattern:/%%.*/,greedy:!0},style:{pattern:/^([ \t]*(?:classDef|linkStyle|style)[ \t]+[\w$-]+[ \t]+)\w.*[^\s;]/m,lookbehind:!0,inside:{property:/\b\w[\w-]*(?=[ \t]*:)/,operator:/:/,punctuation:/,/}},"inter-arrow-label":{pattern:/([^<>ox.=-])(?:-[-.]|==)(?![<>ox.=-])[ \t]*(?:"[^"\r\n]*"|[^\s".=-](?:[^\r\n.=-]*[^\s.=-])?)[ \t]*(?:\.+->?|--+[->]|==+[=>])(?![<>ox.=-])/,lookbehind:!0,greedy:!0,inside:{arrow:{pattern:/(?:\.+->?|--+[->]|==+[=>])$/,alias:"operator"},label:{pattern:/^([\s\S]{2}[ \t]*)\S(?:[\s\S]*\S)?/,lookbehind:!0,alias:"property"},"arrow-head":{pattern:/^\S+/,alias:["arrow","operator"]}}},arrow:[{pattern:/(^|[^{}|o.-])[|}][|o](?:--|\.\.)[|o][|{](?![{}|o.-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>ox.=-])(?:[<ox](?:==+|--+|-\.*-)[>ox]?|(?:==+|--+|-\.*-)[>ox]|===+|---+|-\.+-)(?![<>ox.=-])/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>()x-])(?:--?(?:>>|[x>)])(?![<>()x])|(?:<<|[x<(])--?(?!-))/,lookbehind:!0,alias:"operator"},{pattern:/(^|[^<>|*o.-])(?:[*o]--|--[*o]|<\|?(?:--|\.\.)|(?:--|\.\.)\|?>|--|\.\.)(?![<>|*o.-])/,lookbehind:!0,alias:"operator"}],label:{pattern:/(^|[^|<])\|(?:[^\r\n"|]|"[^"\r\n]*")+\|/,lookbehind:!0,greedy:!0,alias:"property"},text:{pattern:/(?:[(\[{]+|\b>)(?:[^\r\n"()\[\]{}]|"[^"\r\n]*")+(?:[)\]}]+|>)/,alias:"string"},string:{pattern:/"[^"\r\n]*"/,greedy:!0},annotation:{pattern:/<<(?:abstract|choice|enumeration|fork|interface|join|service)>>|\[\[(?:choice|fork|join)\]\]/i,alias:"important"},keyword:[{pattern:/(^[ \t]*)(?:action|callback|class|classDef|classDiagram|click|direction|erDiagram|flowchart|gantt|gitGraph|graph|journey|link|linkStyle|pie|requirementDiagram|sequenceDiagram|stateDiagram|stateDiagram-v2|style|subgraph)(?![\w$-])/m,lookbehind:!0,greedy:!0},{pattern:/(^[ \t]*)(?:activate|alt|and|as|autonumber|deactivate|else|end(?:[ \t]+note)?|loop|opt|par|participant|rect|state|note[ \t]+(?:over|(?:left|right)[ \t]+of))(?![\w$-])/im,lookbehind:!0,greedy:!0}],entity:/#[a-z0-9]+;/,operator:{pattern:/(\w[ \t]*)&(?=[ \t]*\w)|:::|:/,lookbehind:!0},punctuation:/[(){};]/}}return cS}var dS,g2;function Rhe(){if(g2)return dS;g2=1,dS=e,e.displayName="mizar",e.aliases=[];function e(t){t.languages.mizar={comment:/::.+/,keyword:/@proof\b|\b(?:according|aggregate|all|and|antonym|are|as|associativity|assume|asymmetry|attr|be|begin|being|by|canceled|case|cases|clusters?|coherence|commutativity|compatibility|connectedness|consider|consistency|constructors|contradiction|correctness|def|deffunc|define|definitions?|defpred|do|does|end|environ|equals|ex|exactly|existence|for|from|func|given|hence|hereby|holds|idempotence|identity|iff?|implies|involutiveness|irreflexivity|is|it|let|means|mode|non|not|notations?|now|of|or|otherwise|over|per|pred|prefix|projectivity|proof|provided|qua|reconsider|redefine|reduce|reducibility|reflexivity|registrations?|requirements|reserve|sch|schemes?|section|selector|set|sethood|st|struct|such|suppose|symmetry|synonym|take|that|the|then|theorems?|thesis|thus|to|transitivity|uniqueness|vocabular(?:ies|y)|when|where|with|wrt)\b/,parameter:{pattern:/\$(?:10|\d)/,alias:"variable"},variable:/\b\w+(?=:)/,number:/(?:\b|-)\d+\b/,operator:/\.\.\.|->|&|\.?=/,punctuation:/\(#|#\)|[,:;\[\](){}]/}}return dS}var fS,h2;function Che(){if(h2)return fS;h2=1,fS=e,e.displayName="mongodb",e.aliases=[];function e(t){(function(n){var r=["$eq","$gt","$gte","$in","$lt","$lte","$ne","$nin","$and","$not","$nor","$or","$exists","$type","$expr","$jsonSchema","$mod","$regex","$text","$where","$geoIntersects","$geoWithin","$near","$nearSphere","$all","$elemMatch","$size","$bitsAllClear","$bitsAllSet","$bitsAnyClear","$bitsAnySet","$comment","$elemMatch","$meta","$slice","$currentDate","$inc","$min","$max","$mul","$rename","$set","$setOnInsert","$unset","$addToSet","$pop","$pull","$push","$pullAll","$each","$position","$slice","$sort","$bit","$addFields","$bucket","$bucketAuto","$collStats","$count","$currentOp","$facet","$geoNear","$graphLookup","$group","$indexStats","$limit","$listLocalSessions","$listSessions","$lookup","$match","$merge","$out","$planCacheStats","$project","$redact","$replaceRoot","$replaceWith","$sample","$set","$skip","$sort","$sortByCount","$unionWith","$unset","$unwind","$setWindowFields","$abs","$accumulator","$acos","$acosh","$add","$addToSet","$allElementsTrue","$and","$anyElementTrue","$arrayElemAt","$arrayToObject","$asin","$asinh","$atan","$atan2","$atanh","$avg","$binarySize","$bsonSize","$ceil","$cmp","$concat","$concatArrays","$cond","$convert","$cos","$dateFromParts","$dateToParts","$dateFromString","$dateToString","$dayOfMonth","$dayOfWeek","$dayOfYear","$degreesToRadians","$divide","$eq","$exp","$filter","$first","$floor","$function","$gt","$gte","$hour","$ifNull","$in","$indexOfArray","$indexOfBytes","$indexOfCP","$isArray","$isNumber","$isoDayOfWeek","$isoWeek","$isoWeekYear","$last","$last","$let","$literal","$ln","$log","$log10","$lt","$lte","$ltrim","$map","$max","$mergeObjects","$meta","$min","$millisecond","$minute","$mod","$month","$multiply","$ne","$not","$objectToArray","$or","$pow","$push","$radiansToDegrees","$range","$reduce","$regexFind","$regexFindAll","$regexMatch","$replaceOne","$replaceAll","$reverseArray","$round","$rtrim","$second","$setDifference","$setEquals","$setIntersection","$setIsSubset","$setUnion","$size","$sin","$slice","$split","$sqrt","$stdDevPop","$stdDevSamp","$strcasecmp","$strLenBytes","$strLenCP","$substr","$substrBytes","$substrCP","$subtract","$sum","$switch","$tan","$toBool","$toDate","$toDecimal","$toDouble","$toInt","$toLong","$toObjectId","$toString","$toLower","$toUpper","$trim","$trunc","$type","$week","$year","$zip","$count","$dateAdd","$dateDiff","$dateSubtract","$dateTrunc","$getField","$rand","$sampleRate","$setField","$unsetField","$comment","$explain","$hint","$max","$maxTimeMS","$min","$orderby","$query","$returnKey","$showDiskLoc","$natural"],a=["ObjectId","Code","BinData","DBRef","Timestamp","NumberLong","NumberDecimal","MaxKey","MinKey","RegExp","ISODate","UUID"];r=r.map(function(l){return l.replace("$","\\$")});var i="(?:"+r.join("|")+")\\b";n.languages.mongodb=n.languages.extend("javascript",{}),n.languages.insertBefore("mongodb","string",{property:{pattern:/(?:(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1|(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*)(?=\s*:)/,greedy:!0,inside:{keyword:RegExp(`^(['"])?`+i+"(?:\\1)?$")}}}),n.languages.mongodb.string.inside={url:{pattern:/https?:\/\/[-\w@:%.+~#=]{1,256}\.[a-z0-9()]{1,6}\b[-\w()@:%+.~#?&/=]*/i,greedy:!0},entity:{pattern:/\b(?:(?:[01]?\d\d?|2[0-4]\d|25[0-5])\.){3}(?:[01]?\d\d?|2[0-4]\d|25[0-5])\b/,greedy:!0}},n.languages.insertBefore("mongodb","constant",{builtin:{pattern:RegExp("\\b(?:"+a.join("|")+")\\b"),alias:"keyword"}})})(t)}return fS}var pS,m2;function Nhe(){if(m2)return pS;m2=1,pS=e,e.displayName="monkey",e.aliases=[];function e(t){t.languages.monkey={comment:{pattern:/^#Rem\s[\s\S]*?^#End|'.+/im,greedy:!0},string:{pattern:/"[^"\r\n]*"/,greedy:!0},preprocessor:{pattern:/(^[ \t]*)#.+/m,lookbehind:!0,greedy:!0,alias:"property"},function:/\b\w+(?=\()/,"type-char":{pattern:/\b[?%#$]/,alias:"class-name"},number:{pattern:/((?:\.\.)?)(?:(?:\b|\B-\.?|\B\.)\d+(?:(?!\.\.)\.\d*)?|\$[\da-f]+)/i,lookbehind:!0},keyword:/\b(?:Abstract|Array|Bool|Case|Catch|Class|Const|Continue|Default|Eachin|Else|ElseIf|End|EndIf|Exit|Extends|Extern|False|Field|Final|Float|For|Forever|Function|Global|If|Implements|Import|Inline|Int|Interface|Local|Method|Module|New|Next|Null|Object|Private|Property|Public|Repeat|Return|Select|Self|Step|Strict|String|Super|Then|Throw|To|True|Try|Until|Void|Wend|While)\b/i,operator:/\.\.|<[=>]?|>=?|:?=|(?:[+\-*\/&~|]|\b(?:Mod|Shl|Shr)\b)=?|\b(?:And|Not|Or)\b/i,punctuation:/[.,:;()\[\]]/}}return pS}var gS,b2;function Ohe(){if(b2)return gS;b2=1,gS=e,e.displayName="moonscript",e.aliases=["moon"];function e(t){t.languages.moonscript={comment:/--.*/,string:[{pattern:/'[^']*'|\[(=*)\[[\s\S]*?\]\1\]/,greedy:!0},{pattern:/"[^"]*"/,greedy:!0,inside:{interpolation:{pattern:/#\{[^{}]*\}/,inside:{moonscript:{pattern:/(^#\{)[\s\S]+(?=\})/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/#\{|\}/,alias:"punctuation"}}}}}],"class-name":[{pattern:/(\b(?:class|extends)[ \t]+)\w+/,lookbehind:!0},/\b[A-Z]\w*/],keyword:/\b(?:class|continue|do|else|elseif|export|extends|for|from|if|import|in|local|nil|return|self|super|switch|then|unless|using|when|while|with)\b/,variable:/@@?\w*/,property:{pattern:/\b(?!\d)\w+(?=:)|(:)(?!\d)\w+/,lookbehind:!0},function:{pattern:/\b(?:_G|_VERSION|assert|collectgarbage|coroutine\.(?:create|resume|running|status|wrap|yield)|debug\.(?:debug|getfenv|gethook|getinfo|getlocal|getmetatable|getregistry|getupvalue|setfenv|sethook|setlocal|setmetatable|setupvalue|traceback)|dofile|error|getfenv|getmetatable|io\.(?:close|flush|input|lines|open|output|popen|read|stderr|stdin|stdout|tmpfile|type|write)|ipairs|load|loadfile|loadstring|math\.(?:abs|acos|asin|atan|atan2|ceil|cos|cosh|deg|exp|floor|fmod|frexp|ldexp|log|log10|max|min|modf|pi|pow|rad|random|randomseed|sin|sinh|sqrt|tan|tanh)|module|next|os\.(?:clock|date|difftime|execute|exit|getenv|remove|rename|setlocale|time|tmpname)|package\.(?:cpath|loaded|loadlib|path|preload|seeall)|pairs|pcall|print|rawequal|rawget|rawset|require|select|setfenv|setmetatable|string\.(?:byte|char|dump|find|format|gmatch|gsub|len|lower|match|rep|reverse|sub|upper)|table\.(?:concat|insert|maxn|remove|sort)|tonumber|tostring|type|unpack|xpcall)\b/,inside:{punctuation:/\./}},boolean:/\b(?:false|true)\b/,number:/(?:\B\.\d+|\b\d+\.\d+|\b\d+(?=[eE]))(?:[eE][-+]?\d+)?\b|\b(?:0x[a-fA-F\d]+|\d+)(?:U?LL)?\b/,operator:/\.{3}|[-=]>|~=|(?:[-+*/%<>!=]|\.\.)=?|[:#^]|\b(?:and|or)\b=?|\b(?:not)\b/,punctuation:/[.,()[\]{}\\]/},t.languages.moonscript.string[1].inside.interpolation.inside.moonscript.inside=t.languages.moonscript,t.languages.moon=t.languages.moonscript}return gS}var hS,y2;function Dhe(){if(y2)return hS;y2=1,hS=e,e.displayName="n1ql",e.aliases=[];function e(t){t.languages.n1ql={comment:{pattern:/\/\*[\s\S]*?(?:$|\*\/)|--.*/,greedy:!0},string:{pattern:/(["'])(?:\\[\s\S]|(?!\1)[^\\]|\1\1)*\1/,greedy:!0},identifier:{pattern:/`(?:\\[\s\S]|[^\\`]|``)*`/,greedy:!0},parameter:/\$[\w.]+/,keyword:/\b(?:ADVISE|ALL|ALTER|ANALYZE|AS|ASC|AT|BEGIN|BINARY|BOOLEAN|BREAK|BUCKET|BUILD|BY|CALL|CAST|CLUSTER|COLLATE|COLLECTION|COMMIT|COMMITTED|CONNECT|CONTINUE|CORRELATE|CORRELATED|COVER|CREATE|CURRENT|DATABASE|DATASET|DATASTORE|DECLARE|DECREMENT|DELETE|DERIVED|DESC|DESCRIBE|DISTINCT|DO|DROP|EACH|ELEMENT|EXCEPT|EXCLUDE|EXECUTE|EXPLAIN|FETCH|FILTER|FLATTEN|FLUSH|FOLLOWING|FOR|FORCE|FROM|FTS|FUNCTION|GOLANG|GRANT|GROUP|GROUPS|GSI|HASH|HAVING|IF|IGNORE|ILIKE|INCLUDE|INCREMENT|INDEX|INFER|INLINE|INNER|INSERT|INTERSECT|INTO|IS|ISOLATION|JAVASCRIPT|JOIN|KEY|KEYS|KEYSPACE|KNOWN|LANGUAGE|LAST|LEFT|LET|LETTING|LEVEL|LIMIT|LSM|MAP|MAPPING|MATCHED|MATERIALIZED|MERGE|MINUS|MISSING|NAMESPACE|NEST|NL|NO|NTH_VALUE|NULL|NULLS|NUMBER|OBJECT|OFFSET|ON|OPTION|OPTIONS|ORDER|OTHERS|OUTER|OVER|PARSE|PARTITION|PASSWORD|PATH|POOL|PRECEDING|PREPARE|PRIMARY|PRIVATE|PRIVILEGE|PROBE|PROCEDURE|PUBLIC|RANGE|RAW|REALM|REDUCE|RENAME|RESPECT|RETURN|RETURNING|REVOKE|RIGHT|ROLE|ROLLBACK|ROW|ROWS|SATISFIES|SAVEPOINT|SCHEMA|SCOPE|SELECT|SELF|SEMI|SET|SHOW|SOME|START|STATISTICS|STRING|SYSTEM|TIES|TO|TRAN|TRANSACTION|TRIGGER|TRUNCATE|UNBOUNDED|UNDER|UNION|UNIQUE|UNKNOWN|UNNEST|UNSET|UPDATE|UPSERT|USE|USER|USING|VALIDATE|VALUE|VALUES|VIA|VIEW|WHERE|WHILE|WINDOW|WITH|WORK|XOR)\b/i,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:FALSE|TRUE)\b/i,number:/(?:\b\d+\.|\B\.)\d+e[+\-]?\d+\b|\b\d+(?:\.\d*)?|\B\.\d+\b/i,operator:/[-+*\/%]|!=|==?|\|\||<[>=]?|>=?|\b(?:AND|ANY|ARRAY|BETWEEN|CASE|ELSE|END|EVERY|EXISTS|FIRST|IN|LIKE|NOT|OR|THEN|VALUED|WHEN|WITHIN)\b/i,punctuation:/[;[\](),.{}:]/}}return hS}var mS,v2;function Ihe(){if(v2)return mS;v2=1,mS=e,e.displayName="n4js",e.aliases=["n4jsd"];function e(t){t.languages.n4js=t.languages.extend("javascript",{keyword:/\b(?:Array|any|boolean|break|case|catch|class|const|constructor|continue|debugger|declare|default|delete|do|else|enum|export|extends|false|finally|for|from|function|get|if|implements|import|in|instanceof|interface|let|module|new|null|number|package|private|protected|public|return|set|static|string|super|switch|this|throw|true|try|typeof|var|void|while|with|yield)\b/}),t.languages.insertBefore("n4js","constant",{annotation:{pattern:/@+\w+/,alias:"operator"}}),t.languages.n4jsd=t.languages.n4js}return mS}var bS,S2;function Lhe(){if(S2)return bS;S2=1,bS=e,e.displayName="nand2tetrisHdl",e.aliases=[];function e(t){t.languages["nand2tetris-hdl"]={comment:/\/\/.*|\/\*[\s\S]*?(?:\*\/|$)/,keyword:/\b(?:BUILTIN|CHIP|CLOCKED|IN|OUT|PARTS)\b/,boolean:/\b(?:false|true)\b/,function:/\b[A-Za-z][A-Za-z0-9]*(?=\()/,number:/\b\d+\b/,operator:/=|\.\./,punctuation:/[{}[\];(),:]/}}return bS}var yS,E2;function Mhe(){if(E2)return yS;E2=1,yS=e,e.displayName="naniscript",e.aliases=[];function e(t){(function(n){var r=/\{[^\r\n\[\]{}]*\}/,a={"quoted-string":{pattern:/"(?:[^"\\]|\\.)*"/,alias:"operator"},"command-param-id":{pattern:/(\s)\w+:/,lookbehind:!0,alias:"property"},"command-param-value":[{pattern:r,alias:"selector"},{pattern:/([\t ])\S+/,lookbehind:!0,greedy:!0,alias:"operator"},{pattern:/\S(?:.*\S)?/,alias:"operator"}]};n.languages.naniscript={comment:{pattern:/^([\t ]*);.*/m,lookbehind:!0},define:{pattern:/^>.+/m,alias:"tag",inside:{value:{pattern:/(^>\w+[\t ]+)(?!\s)[^{}\r\n]+/,lookbehind:!0,alias:"operator"},key:{pattern:/(^>)\w+/,lookbehind:!0}}},label:{pattern:/^([\t ]*)#[\t ]*\w+[\t ]*$/m,lookbehind:!0,alias:"regex"},command:{pattern:/^([\t ]*)@\w+(?=[\t ]|$).*/m,lookbehind:!0,alias:"function",inside:{"command-name":/^@\w+/,expression:{pattern:r,greedy:!0,alias:"selector"},"command-params":{pattern:/\s*\S[\s\S]*/,inside:a}}},"generic-text":{pattern:/(^[ \t]*)[^#@>;\s].*/m,lookbehind:!0,alias:"punctuation",inside:{"escaped-char":/\\[{}\[\]"]/,expression:{pattern:r,greedy:!0,alias:"selector"},"inline-command":{pattern:/\[[\t ]*\w[^\r\n\[\]]*\]/,greedy:!0,alias:"function",inside:{"command-params":{pattern:/(^\[[\t ]*\w+\b)[\s\S]+(?=\]$)/,lookbehind:!0,inside:a},"command-param-name":{pattern:/^(\[[\t ]*)\w+/,lookbehind:!0,alias:"name"},"start-stop-char":/[\[\]]/}}}}},n.languages.nani=n.languages.naniscript,n.hooks.add("after-tokenize",function(u){var c=u.tokens;c.forEach(function(f){if(typeof f!="string"&&f.type==="generic-text"){var p=l(f);i(p)||(f.type="bad-line",f.content=p)}})});function i(u){for(var c="[]{}",f=[],p=0;p<u.length;p++){var g=u[p],b=c.indexOf(g);if(b!==-1){if(b%2===0)f.push(b+1);else if(f.pop()!==b)return!1}}return f.length===0}function l(u){return typeof u=="string"?u:Array.isArray(u)?u.map(l).join(""):l(u.content)}})(t)}return yS}var vS,w2;function Fhe(){if(w2)return vS;w2=1,vS=e,e.displayName="nasm",e.aliases=[];function e(t){t.languages.nasm={comment:/;.*$/m,string:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,label:{pattern:/(^\s*)[A-Za-z._?$][\w.?$@~#]*:/m,lookbehind:!0,alias:"function"},keyword:[/\[?BITS (?:16|32|64)\]?/,{pattern:/(^\s*)section\s*[a-z.]+:?/im,lookbehind:!0},/(?:extern|global)[^;\r\n]*/i,/(?:CPU|DEFAULT|FLOAT).*$/m],register:{pattern:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s)\b/i,alias:"variable"},number:/(?:\b|(?=\$))(?:0[hx](?:\.[\da-f]+|[\da-f]+(?:\.[\da-f]+)?)(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-\/%<>=&|$!]/}}return vS}var SS,x2;function zhe(){if(x2)return SS;x2=1,SS=e,e.displayName="neon",e.aliases=[];function e(t){t.languages.neon={comment:{pattern:/#.*/,greedy:!0},datetime:{pattern:/(^|[[{(=:,\s])\d\d\d\d-\d\d?-\d\d?(?:(?:[Tt]| +)\d\d?:\d\d:\d\d(?:\.\d*)? *(?:Z|[-+]\d\d?(?::?\d\d)?)?)?(?=$|[\]}),\s])/,lookbehind:!0,alias:"number"},key:{pattern:/(^|[[{(,\s])[^,:=[\]{}()'"\s]+(?=\s*:(?:$|[\]}),\s])|\s*=)/,lookbehind:!0,alias:"atrule"},number:{pattern:/(^|[[{(=:,\s])[+-]?(?:0x[\da-fA-F]+|0o[0-7]+|0b[01]+|(?:\d+(?:\.\d*)?|\.?\d+)(?:[eE][+-]?\d+)?)(?=$|[\]}),:=\s])/,lookbehind:!0},boolean:{pattern:/(^|[[{(=:,\s])(?:false|no|true|yes)(?=$|[\]}),:=\s])/i,lookbehind:!0},null:{pattern:/(^|[[{(=:,\s])(?:null)(?=$|[\]}),:=\s])/i,lookbehind:!0,alias:"keyword"},string:{pattern:/(^|[[{(=:,\s])(?:('''|""")\r?\n(?:(?:[^\r\n]|\r?\n(?![\t ]*\2))*\r?\n)?[\t ]*\2|'[^'\r\n]*'|"(?:\\.|[^\\"\r\n])*")/,lookbehind:!0,greedy:!0},literal:{pattern:/(^|[[{(=:,\s])(?:[^#"',:=[\]{}()\s`-]|[:-][^"',=[\]{}()\s])(?:[^,:=\]})(\s]|:(?![\s,\]})]|$)|[ \t]+[^#,:=\]})(\s])*/,lookbehind:!0,alias:"string"},punctuation:/[,:=[\]{}()-]/}}return SS}var ES,k2;function Phe(){if(k2)return ES;k2=1,ES=e,e.displayName="nevod",e.aliases=[];function e(t){t.languages.nevod={comment:/\/\/.*|(?:\/\*[\s\S]*?(?:\*\/|$))/,string:{pattern:/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))!?\*?/,greedy:!0,inside:{"string-attrs":/!$|!\*$|\*$/}},namespace:{pattern:/(@namespace\s+)[a-zA-Z0-9\-.]+(?=\s*\{)/,lookbehind:!0},pattern:{pattern:/(@pattern\s+)?#?[a-zA-Z0-9\-.]+(?:\s*\(\s*(?:~\s*)?[a-zA-Z0-9\-.]+\s*(?:,\s*(?:~\s*)?[a-zA-Z0-9\-.]*)*\))?(?=\s*=)/,lookbehind:!0,inside:{"pattern-name":{pattern:/^#?[a-zA-Z0-9\-.]+/,alias:"class-name"},fields:{pattern:/\(.*\)/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},punctuation:/[,()]/,operator:{pattern:/~/,alias:"field-hidden-mark"}}}}},search:{pattern:/(@search\s+|#)[a-zA-Z0-9\-.]+(?:\.\*)?(?=\s*;)/,alias:"function",lookbehind:!0},keyword:/@(?:having|inside|namespace|outside|pattern|require|search|where)\b/,"standard-pattern":{pattern:/\b(?:Alpha|AlphaNum|Any|Blank|End|LineBreak|Num|NumAlpha|Punct|Space|Start|Symbol|Word|WordBreak)\b(?:\([a-zA-Z0-9\-.,\s+]*\))?/,inside:{"standard-pattern-name":{pattern:/^[a-zA-Z0-9\-.]+/,alias:"builtin"},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},"standard-pattern-attr":{pattern:/[a-zA-Z0-9\-.]+/,alias:"builtin"},punctuation:/[,()]/}},quantifier:{pattern:/\b\d+(?:\s*\+|\s*-\s*\d+)?(?!\w)/,alias:"number"},operator:[{pattern:/=/,alias:"pattern-def"},{pattern:/&/,alias:"conjunction"},{pattern:/~/,alias:"exception"},{pattern:/\?/,alias:"optionality"},{pattern:/[[\]]/,alias:"repetition"},{pattern:/[{}]/,alias:"variation"},{pattern:/[+_]/,alias:"sequence"},{pattern:/\.{2,3}/,alias:"span"}],"field-capture":[{pattern:/([a-zA-Z0-9\-.]+\s*\()\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+(?:\s*,\s*[a-zA-Z0-9\-.]+\s*:\s*[a-zA-Z0-9\-.]+)*(?=\s*\))/,lookbehind:!0,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}},{pattern:/[a-zA-Z0-9\-.]+\s*:/,inside:{"field-name":{pattern:/[a-zA-Z0-9\-.]+/,alias:"variable"},colon:/:/}}],punctuation:/[:;,()]/,name:/[a-zA-Z0-9\-.]+/}}return ES}var wS,A2;function Bhe(){if(A2)return wS;A2=1,wS=e,e.displayName="nginx",e.aliases=[];function e(t){(function(n){var r=/\$(?:\w[a-z\d]*(?:_[^\x00-\x1F\s"'\\()$]*)?|\{[^}\s"'\\]+\})/i;n.languages.nginx={comment:{pattern:/(^|[\s{};])#.*/,lookbehind:!0,greedy:!0},directive:{pattern:/(^|\s)\w(?:[^;{}"'\\\s]|\\.|"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'|\s+(?:#.*(?!.)|(?![#\s])))*?(?=\s*[;{])/,lookbehind:!0,greedy:!0,inside:{string:{pattern:/((?:^|[^\\])(?:\\\\)*)(?:"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*')/,lookbehind:!0,greedy:!0,inside:{escape:{pattern:/\\["'\\nrt]/,alias:"entity"},variable:r}},comment:{pattern:/(\s)#.*/,lookbehind:!0,greedy:!0},keyword:{pattern:/^\S+/,greedy:!0},boolean:{pattern:/(\s)(?:off|on)(?!\S)/,lookbehind:!0},number:{pattern:/(\s)\d+[a-z]*(?!\S)/i,lookbehind:!0},variable:r}},punctuation:/[{};]/}})(t)}return wS}var xS,T2;function Uhe(){if(T2)return xS;T2=1,xS=e,e.displayName="nim",e.aliases=[];function e(t){t.languages.nim={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/(?:\b(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+)?(?:"""[\s\S]*?"""(?!")|"(?:\\[\s\S]|""|[^"\\])*")/,greedy:!0},char:{pattern:/'(?:\\(?:\d+|x[\da-fA-F]{0,2}|.)|[^'])'/,greedy:!0},function:{pattern:/(?:(?!\d)(?:\w|\\x[89a-fA-F][0-9a-fA-F])+|`[^`\r\n]+`)\*?(?:\[[^\]]+\])?(?=\s*\()/,greedy:!0,inside:{operator:/\*$/}},identifier:{pattern:/`[^`\r\n]+`/,greedy:!0,inside:{punctuation:/`/}},number:/\b(?:0[xXoObB][\da-fA-F_]+|\d[\d_]*(?:(?!\.\.)\.[\d_]*)?(?:[eE][+-]?\d[\d_]*)?)(?:'?[iuf]\d*)?/,keyword:/\b(?:addr|as|asm|atomic|bind|block|break|case|cast|concept|const|continue|converter|defer|discard|distinct|do|elif|else|end|enum|except|export|finally|for|from|func|generic|if|import|include|interface|iterator|let|macro|method|mixin|nil|object|out|proc|ptr|raise|ref|return|static|template|try|tuple|type|using|var|when|while|with|without|yield)\b/,operator:{pattern:/(^|[({\[](?=\.\.)|(?![({\[]\.).)(?:(?:[=+\-*\/<>@$~&%|!?^:\\]|\.\.|\.(?![)}\]]))+|\b(?:and|div|in|is|isnot|mod|not|notin|of|or|shl|shr|xor)\b)/m,lookbehind:!0},punctuation:/[({\[]\.|\.[)}\]]|[`(){}\[\],:]/}}return xS}var kS,_2;function jhe(){if(_2)return kS;_2=1,kS=e,e.displayName="nix",e.aliases=[];function e(t){t.languages.nix={comment:{pattern:/\/\*[\s\S]*?\*\/|#.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"|''(?:(?!'')[\s\S]|''(?:'|\\|\$\{))*''/,greedy:!0,inside:{interpolation:{pattern:/(^|(?:^|(?!'').)[^\\])\$\{(?:[^{}]|\{[^}]*\})*\}/,lookbehind:!0,inside:null}}},url:[/\b(?:[a-z]{3,7}:\/\/)[\w\-+%~\/.:#=?&]+/,{pattern:/([^\/])(?:[\w\-+%~.:#=?&]*(?!\/\/)[\w\-+%~\/.:#=?&])?(?!\/\/)\/[\w\-+%~\/.:#=?&]*/,lookbehind:!0}],antiquotation:{pattern:/\$(?=\{)/,alias:"important"},number:/\b\d+\b/,keyword:/\b(?:assert|builtins|else|if|in|inherit|let|null|or|then|with)\b/,function:/\b(?:abort|add|all|any|attrNames|attrValues|baseNameOf|compareVersions|concatLists|currentSystem|deepSeq|derivation|dirOf|div|elem(?:At)?|fetch(?:Tarball|url)|filter(?:Source)?|fromJSON|genList|getAttr|getEnv|hasAttr|hashString|head|import|intersectAttrs|is(?:Attrs|Bool|Function|Int|List|Null|String)|length|lessThan|listToAttrs|map|mul|parseDrvName|pathExists|read(?:Dir|File)|removeAttrs|replaceStrings|seq|sort|stringLength|sub(?:string)?|tail|throw|to(?:File|JSON|Path|String|XML)|trace|typeOf)\b|\bfoldl'\B/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|\+\+?|\|\||&&|\/\/|->?|[?@]/,punctuation:/[{}()[\].,:;]/},t.languages.nix.string.inside.interpolation.inside=t.languages.nix}return kS}var AS,R2;function Ghe(){if(R2)return AS;R2=1,AS=e,e.displayName="nsis",e.aliases=[];function e(t){t.languages.nsis={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|[#;].*)/,lookbehind:!0,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:{pattern:/(^[\t ]*)(?:Abort|Add(?:BrandingImage|Size)|AdvSplash|Allow(?:RootDirInstall|SkipFiles)|AutoCloseWindow|BG(?:Font|Gradient|Image)|Banner|BrandingText|BringToFront|CRCCheck|Call(?:InstDLL)?|Caption|ChangeUI|CheckBitmap|ClearErrors|CompletedText|ComponentText|CopyFiles|Create(?:Directory|Font|ShortCut)|Delete(?:INISec|INIStr|RegKey|RegValue)?|Detail(?:Print|sButtonText)|Dialer|Dir(?:Text|Var|Verify)|EnableWindow|Enum(?:RegKey|RegValue)|Exch|Exec(?:Shell(?:Wait)?|Wait)?|ExpandEnvStrings|File(?:BufSize|Close|ErrorText|Open|Read|ReadByte|ReadUTF16LE|ReadWord|Seek|Write|WriteByte|WriteUTF16LE|WriteWord)?|Find(?:Close|First|Next|Window)|FlushINI|Get(?:CurInstType|CurrentAddress|DLLVersion(?:Local)?|DlgItem|ErrorLevel|FileTime(?:Local)?|FullPathName|Function(?:Address|End)?|InstDirError|LabelAddress|TempFileName)|Goto|HideWindow|Icon|If(?:Abort|Errors|FileExists|RebootFlag|Silent)|InitPluginsDir|InstProgressFlags|Inst(?:Type(?:GetText|SetText)?)|Install(?:ButtonText|Colors|Dir(?:RegKey)?)|Int(?:64|Ptr)?CmpU?|Int(?:64)?Fmt|Int(?:Ptr)?Op|IsWindow|Lang(?:DLL|String)|License(?:BkColor|Data|ForceSelection|LangString|Text)|LoadLanguageFile|LockWindow|Log(?:Set|Text)|Manifest(?:DPIAware|SupportedOS)|Math|MessageBox|MiscButtonText|NSISdl|Name|Nop|OutFile|PE(?:DllCharacteristics|SubsysVer)|Page(?:Callbacks)?|Pop|Push|Quit|RMDir|Read(?:EnvStr|INIStr|RegDWORD|RegStr)|Reboot|RegDLL|Rename|RequestExecutionLevel|ReserveFile|Return|SearchPath|Section(?:End|GetFlags|GetInstTypes|GetSize|GetText|Group|In|SetFlags|SetInstTypes|SetSize|SetText)?|SendMessage|Set(?:AutoClose|BrandingImage|Compress|Compressor(?:DictSize)?|CtlColors|CurInstType|DatablockOptimize|DateSave|Details(?:Print|View)|ErrorLevel|Errors|FileAttributes|Font|OutPath|Overwrite|PluginUnload|RebootFlag|RegView|ShellVarContext|Silent)|Show(?:InstDetails|UninstDetails|Window)|Silent(?:Install|UnInstall)|Sleep|SpaceTexts|Splash|StartMenu|Str(?:CmpS?|Cpy|Len)|SubCaption|System|UnRegDLL|Unicode|UninstPage|Uninstall(?:ButtonText|Caption|Icon|SubCaption|Text)|UserInfo|VI(?:AddVersionKey|FileVersion|ProductVersion)|VPatch|Var|WindowIcon|Write(?:INIStr|Reg(?:Bin|DWORD|ExpandStr|MultiStr|None|Str)|Uninstaller)|XPStyle|ns(?:Dialogs|Exec))\b/m,lookbehind:!0},property:/\b(?:ARCHIVE|FILE_(?:ATTRIBUTE_ARCHIVE|ATTRIBUTE_NORMAL|ATTRIBUTE_OFFLINE|ATTRIBUTE_READONLY|ATTRIBUTE_SYSTEM|ATTRIBUTE_TEMPORARY)|HK(?:(?:CR|CU|LM)(?:32|64)?|DD|PD|U)|HKEY_(?:CLASSES_ROOT|CURRENT_CONFIG|CURRENT_USER|DYN_DATA|LOCAL_MACHINE|PERFORMANCE_DATA|USERS)|ID(?:ABORT|CANCEL|IGNORE|NO|OK|RETRY|YES)|MB_(?:ABORTRETRYIGNORE|DEFBUTTON1|DEFBUTTON2|DEFBUTTON3|DEFBUTTON4|ICONEXCLAMATION|ICONINFORMATION|ICONQUESTION|ICONSTOP|OK|OKCANCEL|RETRYCANCEL|RIGHT|RTLREADING|SETFOREGROUND|TOPMOST|USERICON|YESNO)|NORMAL|OFFLINE|READONLY|SHCTX|SHELL_CONTEXT|SYSTEM|TEMPORARY|admin|all|auto|both|colored|false|force|hide|highest|lastused|leave|listonly|none|normal|notset|off|on|open|print|show|silent|silentlog|smooth|textonly|true|user)\b/,constant:/\$\{[!\w\.:\^-]+\}|\$\([!\w\.:\^-]+\)/,variable:/\$\w[\w\.]*/,number:/\b0x[\dA-Fa-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee]-?\d+)?/,operator:/--?|\+\+?|<=?|>=?|==?=?|&&?|\|\|?|[?*\/~^%]/,punctuation:/[{}[\];(),.:]/,important:{pattern:/(^[\t ]*)!(?:addincludedir|addplugindir|appendfile|cd|define|delfile|echo|else|endif|error|execute|finalize|getdllversion|gettlbversion|if|ifdef|ifmacrodef|ifmacrondef|ifndef|include|insertmacro|macro|macroend|makensis|packhdr|pragma|searchparse|searchreplace|system|tempfile|undef|verbose|warning)\b/im,lookbehind:!0}}}return AS}var TS,C2;function Hhe(){if(C2)return TS;C2=1;var e=fi();TS=t,t.displayName="objectivec",t.aliases=["objc"];function t(n){n.register(e),n.languages.objectivec=n.languages.extend("c",{string:{pattern:/@?"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:asm|auto|break|case|char|const|continue|default|do|double|else|enum|extern|float|for|goto|if|in|inline|int|long|register|return|self|short|signed|sizeof|static|struct|super|switch|typedef|typeof|union|unsigned|void|volatile|while)\b|(?:@interface|@end|@implementation|@protocol|@class|@public|@protected|@private|@property|@try|@catch|@finally|@throw|@synthesize|@dynamic|@selector)\b/,operator:/-[->]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|\|?|[~^%?*\/@]/}),delete n.languages.objectivec["class-name"],n.languages.objc=n.languages.objectivec}return TS}var _S,N2;function $he(){if(N2)return _S;N2=1,_S=e,e.displayName="ocaml",e.aliases=[];function e(t){t.languages.ocaml={comment:{pattern:/\(\*[\s\S]*?\*\)/,greedy:!0},char:{pattern:/'(?:[^\\\r\n']|\\(?:.|[ox]?[0-9a-f]{1,3}))'/i,greedy:!0},string:[{pattern:/"(?:\\(?:[\s\S]|\r\n)|[^\\\r\n"])*"/,greedy:!0},{pattern:/\{([a-z_]*)\|[\s\S]*?\|\1\}/,greedy:!0}],number:[/\b(?:0b[01][01_]*|0o[0-7][0-7_]*)\b/i,/\b0x[a-f0-9][a-f0-9_]*(?:\.[a-f0-9_]*)?(?:p[+-]?\d[\d_]*)?(?!\w)/i,/\b\d[\d_]*(?:\.[\d_]*)?(?:e[+-]?\d[\d_]*)?(?!\w)/i],directive:{pattern:/\B#\w+/,alias:"property"},label:{pattern:/\B~\w+/,alias:"property"},"type-variable":{pattern:/\B'\w+/,alias:"function"},variant:{pattern:/`\w+/,alias:"symbol"},keyword:/\b(?:as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|match|method|module|mutable|new|nonrec|object|of|open|private|rec|sig|struct|then|to|try|type|val|value|virtual|when|where|while|with)\b/,boolean:/\b(?:false|true)\b/,"operator-like-punctuation":{pattern:/\[[<>|]|[>|]\]|\{<|>\}/,alias:"punctuation"},operator:/\.[.~]|:[=>]|[=<>@^|&+\-*\/$%!?~][!$%&*+\-.\/:<=>?@^|~]*|\b(?:and|asr|land|lor|lsl|lsr|lxor|mod|or)\b/,punctuation:/;;|::|[(){}\[\].,:;#]|\b_\b/}}return _S}var RS,O2;function qhe(){if(O2)return RS;O2=1;var e=fi();RS=t,t.displayName="opencl",t.aliases=[];function t(n){n.register(e),function(r){r.languages.opencl=r.languages.extend("c",{keyword:/\b(?:(?:__)?(?:constant|global|kernel|local|private|read_only|read_write|write_only)|__attribute__|auto|(?:bool|u?(?:char|int|long|short)|half|quad)(?:2|3|4|8|16)?|break|case|complex|const|continue|(?:double|float)(?:16(?:x(?:1|2|4|8|16))?|1x(?:1|2|4|8|16)|2(?:x(?:1|2|4|8|16))?|3|4(?:x(?:1|2|4|8|16))?|8(?:x(?:1|2|4|8|16))?)?|default|do|else|enum|extern|for|goto|if|imaginary|inline|packed|pipe|register|restrict|return|signed|sizeof|static|struct|switch|typedef|uniform|union|unsigned|void|volatile|while)\b/,number:/(?:\b0x(?:[\da-f]+(?:\.[\da-f]*)?|\.[\da-f]+)(?:p[+-]?\d+)?|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)[fuhl]{0,4}/i,boolean:/\b(?:false|true)\b/,"constant-opencl-kernel":{pattern:/\b(?:CHAR_(?:BIT|MAX|MIN)|CLK_(?:ADDRESS_(?:CLAMP(?:_TO_EDGE)?|NONE|REPEAT)|FILTER_(?:LINEAR|NEAREST)|(?:GLOBAL|LOCAL)_MEM_FENCE|NORMALIZED_COORDS_(?:FALSE|TRUE))|CL_(?:BGRA|(?:HALF_)?FLOAT|INTENSITY|LUMINANCE|A?R?G?B?[Ax]?|(?:(?:UN)?SIGNED|[US]NORM)_(?:INT(?:8|16|32))|UNORM_(?:INT_101010|SHORT_(?:555|565)))|(?:DBL|FLT|HALF)_(?:DIG|EPSILON|(?:MAX|MIN)(?:(?:_10)?_EXP)?|MANT_DIG)|FLT_RADIX|HUGE_VALF?|(?:INT|LONG|SCHAR|SHRT)_(?:MAX|MIN)|INFINITY|MAXFLOAT|M_(?:[12]_PI|2_SQRTPI|E|LN(?:2|10)|LOG(?:2|10)E?|PI(?:_[24])?|SQRT(?:1_2|2))(?:_F|_H)?|NAN|(?:UCHAR|UINT|ULONG|USHRT)_MAX)\b/,alias:"constant"}}),r.languages.insertBefore("opencl","class-name",{"builtin-type":{pattern:/\b(?:_cl_(?:command_queue|context|device_id|event|kernel|mem|platform_id|program|sampler)|cl_(?:image_format|mem_fence_flags)|clk_event_t|event_t|image(?:1d_(?:array_|buffer_)?t|2d_(?:array_(?:depth_|msaa_depth_|msaa_)?|depth_|msaa_depth_|msaa_)?t|3d_t)|intptr_t|ndrange_t|ptrdiff_t|queue_t|reserve_id_t|sampler_t|size_t|uintptr_t)\b/,alias:"keyword"}});var a={"type-opencl-host":{pattern:/\b(?:cl_(?:GLenum|GLint|GLuin|addressing_mode|bitfield|bool|buffer_create_type|build_status|channel_(?:order|type)|(?:u?(?:char|int|long|short)|double|float)(?:2|3|4|8|16)?|command_(?:queue(?:_info|_properties)?|type)|context(?:_info|_properties)?|device_(?:exec_capabilities|fp_config|id|info|local_mem_type|mem_cache_type|type)|(?:event|sampler)(?:_info)?|filter_mode|half|image_info|kernel(?:_info|_work_group_info)?|map_flags|mem(?:_flags|_info|_object_type)?|platform_(?:id|info)|profiling_info|program(?:_build_info|_info)?))\b/,alias:"keyword"},"boolean-opencl-host":{pattern:/\bCL_(?:FALSE|TRUE)\b/,alias:"boolean"},"constant-opencl-host":{pattern:/\bCL_(?:A|ABGR|ADDRESS_(?:CLAMP(?:_TO_EDGE)?|MIRRORED_REPEAT|NONE|REPEAT)|ARGB|BGRA|BLOCKING|BUFFER_CREATE_TYPE_REGION|BUILD_(?:ERROR|IN_PROGRESS|NONE|PROGRAM_FAILURE|SUCCESS)|COMMAND_(?:ACQUIRE_GL_OBJECTS|BARRIER|COPY_(?:BUFFER(?:_RECT|_TO_IMAGE)?|IMAGE(?:_TO_BUFFER)?)|FILL_(?:BUFFER|IMAGE)|MAP(?:_BUFFER|_IMAGE)|MARKER|MIGRATE(?:_SVM)?_MEM_OBJECTS|NATIVE_KERNEL|NDRANGE_KERNEL|READ_(?:BUFFER(?:_RECT)?|IMAGE)|RELEASE_GL_OBJECTS|SVM_(?:FREE|MAP|MEMCPY|MEMFILL|UNMAP)|TASK|UNMAP_MEM_OBJECT|USER|WRITE_(?:BUFFER(?:_RECT)?|IMAGE))|COMPILER_NOT_AVAILABLE|COMPILE_PROGRAM_FAILURE|COMPLETE|CONTEXT_(?:DEVICES|INTEROP_USER_SYNC|NUM_DEVICES|PLATFORM|PROPERTIES|REFERENCE_COUNT)|DEPTH(?:_STENCIL)?|DEVICE_(?:ADDRESS_BITS|AFFINITY_DOMAIN_(?:L[1-4]_CACHE|NEXT_PARTITIONABLE|NUMA)|AVAILABLE|BUILT_IN_KERNELS|COMPILER_AVAILABLE|DOUBLE_FP_CONFIG|ENDIAN_LITTLE|ERROR_CORRECTION_SUPPORT|EXECUTION_CAPABILITIES|EXTENSIONS|GLOBAL_(?:MEM_(?:CACHELINE_SIZE|CACHE_SIZE|CACHE_TYPE|SIZE)|VARIABLE_PREFERRED_TOTAL_SIZE)|HOST_UNIFIED_MEMORY|IL_VERSION|IMAGE(?:2D_MAX_(?:HEIGHT|WIDTH)|3D_MAX_(?:DEPTH|HEIGHT|WIDTH)|_BASE_ADDRESS_ALIGNMENT|_MAX_ARRAY_SIZE|_MAX_BUFFER_SIZE|_PITCH_ALIGNMENT|_SUPPORT)|LINKER_AVAILABLE|LOCAL_MEM_SIZE|LOCAL_MEM_TYPE|MAX_(?:CLOCK_FREQUENCY|COMPUTE_UNITS|CONSTANT_ARGS|CONSTANT_BUFFER_SIZE|GLOBAL_VARIABLE_SIZE|MEM_ALLOC_SIZE|NUM_SUB_GROUPS|ON_DEVICE_(?:EVENTS|QUEUES)|PARAMETER_SIZE|PIPE_ARGS|READ_IMAGE_ARGS|READ_WRITE_IMAGE_ARGS|SAMPLERS|WORK_GROUP_SIZE|WORK_ITEM_DIMENSIONS|WORK_ITEM_SIZES|WRITE_IMAGE_ARGS)|MEM_BASE_ADDR_ALIGN|MIN_DATA_TYPE_ALIGN_SIZE|NAME|NATIVE_VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT)|NOT_(?:AVAILABLE|FOUND)|OPENCL_C_VERSION|PARENT_DEVICE|PARTITION_(?:AFFINITY_DOMAIN|BY_AFFINITY_DOMAIN|BY_COUNTS|BY_COUNTS_LIST_END|EQUALLY|FAILED|MAX_SUB_DEVICES|PROPERTIES|TYPE)|PIPE_MAX_(?:ACTIVE_RESERVATIONS|PACKET_SIZE)|PLATFORM|PREFERRED_(?:GLOBAL_ATOMIC_ALIGNMENT|INTEROP_USER_SYNC|LOCAL_ATOMIC_ALIGNMENT|PLATFORM_ATOMIC_ALIGNMENT|VECTOR_WIDTH_(?:CHAR|DOUBLE|FLOAT|HALF|INT|LONG|SHORT))|PRINTF_BUFFER_SIZE|PROFILE|PROFILING_TIMER_RESOLUTION|QUEUE_(?:ON_(?:DEVICE_(?:MAX_SIZE|PREFERRED_SIZE|PROPERTIES)|HOST_PROPERTIES)|PROPERTIES)|REFERENCE_COUNT|SINGLE_FP_CONFIG|SUB_GROUP_INDEPENDENT_FORWARD_PROGRESS|SVM_(?:ATOMICS|CAPABILITIES|COARSE_GRAIN_BUFFER|FINE_GRAIN_BUFFER|FINE_GRAIN_SYSTEM)|TYPE(?:_ACCELERATOR|_ALL|_CPU|_CUSTOM|_DEFAULT|_GPU)?|VENDOR(?:_ID)?|VERSION)|DRIVER_VERSION|EVENT_(?:COMMAND_(?:EXECUTION_STATUS|QUEUE|TYPE)|CONTEXT|REFERENCE_COUNT)|EXEC_(?:KERNEL|NATIVE_KERNEL|STATUS_ERROR_FOR_EVENTS_IN_WAIT_LIST)|FILTER_(?:LINEAR|NEAREST)|FLOAT|FP_(?:CORRECTLY_ROUNDED_DIVIDE_SQRT|DENORM|FMA|INF_NAN|ROUND_TO_INF|ROUND_TO_NEAREST|ROUND_TO_ZERO|SOFT_FLOAT)|GLOBAL|HALF_FLOAT|IMAGE_(?:ARRAY_SIZE|BUFFER|DEPTH|ELEMENT_SIZE|FORMAT|FORMAT_MISMATCH|FORMAT_NOT_SUPPORTED|HEIGHT|NUM_MIP_LEVELS|NUM_SAMPLES|ROW_PITCH|SLICE_PITCH|WIDTH)|INTENSITY|INVALID_(?:ARG_INDEX|ARG_SIZE|ARG_VALUE|BINARY|BUFFER_SIZE|BUILD_OPTIONS|COMMAND_QUEUE|COMPILER_OPTIONS|CONTEXT|DEVICE|DEVICE_PARTITION_COUNT|DEVICE_QUEUE|DEVICE_TYPE|EVENT|EVENT_WAIT_LIST|GLOBAL_OFFSET|GLOBAL_WORK_SIZE|GL_OBJECT|HOST_PTR|IMAGE_DESCRIPTOR|IMAGE_FORMAT_DESCRIPTOR|IMAGE_SIZE|KERNEL|KERNEL_ARGS|KERNEL_DEFINITION|KERNEL_NAME|LINKER_OPTIONS|MEM_OBJECT|MIP_LEVEL|OPERATION|PIPE_SIZE|PLATFORM|PROGRAM|PROGRAM_EXECUTABLE|PROPERTY|QUEUE_PROPERTIES|SAMPLER|VALUE|WORK_DIMENSION|WORK_GROUP_SIZE|WORK_ITEM_SIZE)|KERNEL_(?:ARG_(?:ACCESS_(?:NONE|QUALIFIER|READ_ONLY|READ_WRITE|WRITE_ONLY)|ADDRESS_(?:CONSTANT|GLOBAL|LOCAL|PRIVATE|QUALIFIER)|INFO_NOT_AVAILABLE|NAME|TYPE_(?:CONST|NAME|NONE|PIPE|QUALIFIER|RESTRICT|VOLATILE))|ATTRIBUTES|COMPILE_NUM_SUB_GROUPS|COMPILE_WORK_GROUP_SIZE|CONTEXT|EXEC_INFO_SVM_FINE_GRAIN_SYSTEM|EXEC_INFO_SVM_PTRS|FUNCTION_NAME|GLOBAL_WORK_SIZE|LOCAL_MEM_SIZE|LOCAL_SIZE_FOR_SUB_GROUP_COUNT|MAX_NUM_SUB_GROUPS|MAX_SUB_GROUP_SIZE_FOR_NDRANGE|NUM_ARGS|PREFERRED_WORK_GROUP_SIZE_MULTIPLE|PRIVATE_MEM_SIZE|PROGRAM|REFERENCE_COUNT|SUB_GROUP_COUNT_FOR_NDRANGE|WORK_GROUP_SIZE)|LINKER_NOT_AVAILABLE|LINK_PROGRAM_FAILURE|LOCAL|LUMINANCE|MAP_(?:FAILURE|READ|WRITE|WRITE_INVALIDATE_REGION)|MEM_(?:ALLOC_HOST_PTR|ASSOCIATED_MEMOBJECT|CONTEXT|COPY_HOST_PTR|COPY_OVERLAP|FLAGS|HOST_NO_ACCESS|HOST_PTR|HOST_READ_ONLY|HOST_WRITE_ONLY|KERNEL_READ_AND_WRITE|MAP_COUNT|OBJECT_(?:ALLOCATION_FAILURE|BUFFER|IMAGE1D|IMAGE1D_ARRAY|IMAGE1D_BUFFER|IMAGE2D|IMAGE2D_ARRAY|IMAGE3D|PIPE)|OFFSET|READ_ONLY|READ_WRITE|REFERENCE_COUNT|SIZE|SVM_ATOMICS|SVM_FINE_GRAIN_BUFFER|TYPE|USES_SVM_POINTER|USE_HOST_PTR|WRITE_ONLY)|MIGRATE_MEM_OBJECT_(?:CONTENT_UNDEFINED|HOST)|MISALIGNED_SUB_BUFFER_OFFSET|NONE|NON_BLOCKING|OUT_OF_(?:HOST_MEMORY|RESOURCES)|PIPE_(?:MAX_PACKETS|PACKET_SIZE)|PLATFORM_(?:EXTENSIONS|HOST_TIMER_RESOLUTION|NAME|PROFILE|VENDOR|VERSION)|PROFILING_(?:COMMAND_(?:COMPLETE|END|QUEUED|START|SUBMIT)|INFO_NOT_AVAILABLE)|PROGRAM_(?:BINARIES|BINARY_SIZES|BINARY_TYPE(?:_COMPILED_OBJECT|_EXECUTABLE|_LIBRARY|_NONE)?|BUILD_(?:GLOBAL_VARIABLE_TOTAL_SIZE|LOG|OPTIONS|STATUS)|CONTEXT|DEVICES|IL|KERNEL_NAMES|NUM_DEVICES|NUM_KERNELS|REFERENCE_COUNT|SOURCE)|QUEUED|QUEUE_(?:CONTEXT|DEVICE|DEVICE_DEFAULT|ON_DEVICE|ON_DEVICE_DEFAULT|OUT_OF_ORDER_EXEC_MODE_ENABLE|PROFILING_ENABLE|PROPERTIES|REFERENCE_COUNT|SIZE)|R|RA|READ_(?:ONLY|WRITE)_CACHE|RG|RGB|RGBA|RGBx|RGx|RUNNING|Rx|SAMPLER_(?:ADDRESSING_MODE|CONTEXT|FILTER_MODE|LOD_MAX|LOD_MIN|MIP_FILTER_MODE|NORMALIZED_COORDS|REFERENCE_COUNT)|(?:UN)?SIGNED_INT(?:8|16|32)|SNORM_INT(?:8|16)|SUBMITTED|SUCCESS|UNORM_INT(?:8|16|24|_101010|_101010_2)|UNORM_SHORT_(?:555|565)|VERSION_(?:1_0|1_1|1_2|2_0|2_1)|sBGRA|sRGB|sRGBA|sRGBx)\b/,alias:"constant"},"function-opencl-host":{pattern:/\bcl(?:BuildProgram|CloneKernel|CompileProgram|Create(?:Buffer|CommandQueue(?:WithProperties)?|Context|ContextFromType|Image|Image2D|Image3D|Kernel|KernelsInProgram|Pipe|ProgramWith(?:Binary|BuiltInKernels|IL|Source)|Sampler|SamplerWithProperties|SubBuffer|SubDevices|UserEvent)|Enqueue(?:(?:Barrier|Marker)(?:WithWaitList)?|Copy(?:Buffer(?:Rect|ToImage)?|Image(?:ToBuffer)?)|(?:Fill|Map)(?:Buffer|Image)|MigrateMemObjects|NDRangeKernel|NativeKernel|(?:Read|Write)(?:Buffer(?:Rect)?|Image)|SVM(?:Free|Map|MemFill|Memcpy|MigrateMem|Unmap)|Task|UnmapMemObject|WaitForEvents)|Finish|Flush|Get(?:CommandQueueInfo|ContextInfo|Device(?:AndHostTimer|IDs|Info)|Event(?:Profiling)?Info|ExtensionFunctionAddress(?:ForPlatform)?|HostTimer|ImageInfo|Kernel(?:ArgInfo|Info|SubGroupInfo|WorkGroupInfo)|MemObjectInfo|PipeInfo|Platform(?:IDs|Info)|Program(?:Build)?Info|SamplerInfo|SupportedImageFormats)|LinkProgram|(?:Release|Retain)(?:CommandQueue|Context|Device|Event|Kernel|MemObject|Program|Sampler)|SVM(?:Alloc|Free)|Set(?:CommandQueueProperty|DefaultDeviceCommandQueue|EventCallback|Kernel|Kernel(?:Arg(?:SVMPointer)?|ExecInfo)|MemObjectDestructorCallback|UserEventStatus)|Unload(?:Platform)?Compiler|WaitForEvents)\b/,alias:"function"}};r.languages.insertBefore("c","keyword",a),r.languages.cpp&&(a["type-opencl-host-cpp"]={pattern:/\b(?:Buffer|BufferGL|BufferRenderGL|CommandQueue|Context|Device|DeviceCommandQueue|EnqueueArgs|Event|Image|Image1D|Image1DArray|Image1DBuffer|Image2D|Image2DArray|Image2DGL|Image3D|Image3DGL|ImageFormat|ImageGL|Kernel|KernelFunctor|LocalSpaceArg|Memory|NDRange|Pipe|Platform|Program|SVMAllocator|SVMTraitAtomic|SVMTraitCoarse|SVMTraitFine|SVMTraitReadOnly|SVMTraitReadWrite|SVMTraitWriteOnly|Sampler|UserEvent)\b/,alias:"keyword"},r.languages.insertBefore("cpp","keyword",a))}(n)}return RS}var CS,D2;function Vhe(){if(D2)return CS;D2=1,CS=e,e.displayName="openqasm",e.aliases=["qasm"];function e(t){t.languages.openqasm={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"[^"\r\n\t]*"|'[^'\r\n\t]*'/,greedy:!0},keyword:/\b(?:CX|OPENQASM|U|barrier|boxas|boxto|break|const|continue|ctrl|def|defcal|defcalgrammar|delay|else|end|for|gate|gphase|if|in|include|inv|kernel|lengthof|let|measure|pow|reset|return|rotary|stretchinf|while)\b|#pragma\b/,"class-name":/\b(?:angle|bit|bool|creg|fixed|float|int|length|qreg|qubit|stretch|uint)\b/,function:/\b(?:cos|exp|ln|popcount|rotl|rotr|sin|sqrt|tan)\b(?=\s*\()/,constant:/\b(?:euler|pi|tau)\b|π|𝜏|ℇ/,number:{pattern:/(^|[^.\w$])(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?(?:dt|ns|us|µs|ms|s)?/i,lookbehind:!0},operator:/->|>>=?|<<=?|&&|\|\||\+\+|--|[!=<>&|~^+\-*/%]=?|@/,punctuation:/[(){}\[\];,:.]/},t.languages.qasm=t.languages.openqasm}return CS}var NS,I2;function Whe(){if(I2)return NS;I2=1,NS=e,e.displayName="oz",e.aliases=[];function e(t){t.languages.oz={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/"(?:[^"\\]|\\[\s\S])*"/,greedy:!0},atom:{pattern:/'(?:[^'\\]|\\[\s\S])*'/,greedy:!0,alias:"builtin"},keyword:/\$|\[\]|\b(?:_|at|attr|case|catch|choice|class|cond|declare|define|dis|else(?:case|if)?|end|export|fail|false|feat|finally|from|fun|functor|if|import|in|local|lock|meth|nil|not|of|or|prepare|proc|prop|raise|require|self|skip|then|thread|true|try|unit)\b/,function:[/\b[a-z][A-Za-z\d]*(?=\()/,{pattern:/(\{)[A-Z][A-Za-z\d]*\b/,lookbehind:!0}],number:/\b(?:0[bx][\da-f]+|\d+(?:\.\d*)?(?:e~?\d+)?)\b|&(?:[^\\]|\\(?:\d{3}|.))/i,variable:/`(?:[^`\\]|\\.)+`/,"attr-name":/\b\w+(?=[ \t]*:(?![:=]))/,operator:/:(?:=|::?)|<[-:=]?|=(?:=|<?:?)|>=?:?|\\=:?|!!?|[|#+\-*\/,~^@]|\b(?:andthen|div|mod|orelse)\b/,punctuation:/[\[\](){}.:;?]/}}return NS}var OS,L2;function Yhe(){if(L2)return OS;L2=1,OS=e,e.displayName="parigp",e.aliases=[];function e(t){t.languages.parigp={comment:/\/\*[\s\S]*?\*\/|\\\\.*/,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"/,greedy:!0},keyword:function(){var n=["breakpoint","break","dbg_down","dbg_err","dbg_up","dbg_x","forcomposite","fordiv","forell","forpart","forprime","forstep","forsubgroup","forvec","for","iferr","if","local","my","next","return","until","while"];return n=n.map(function(r){return r.split("").join(" *")}).join("|"),RegExp("\\b(?:"+n+")\\b")}(),function:/\b\w(?:[\w ]*\w)?(?= *\()/,number:{pattern:/((?:\. *\. *)?)(?:\b\d(?: *\d)*(?: *(?!\. *\.)\.(?: *\d)*)?|\. *\d(?: *\d)*)(?: *e *(?:[+-] *)?\d(?: *\d)*)?/i,lookbehind:!0},operator:/\. *\.|[*\/!](?: *=)?|%(?: *=|(?: *#)?(?: *')*)?|\+(?: *[+=])?|-(?: *[-=>])?|<(?: *>|(?: *<)?(?: *=)?)?|>(?: *>)?(?: *=)?|=(?: *=){0,2}|\\(?: *\/)?(?: *=)?|&(?: *&)?|\| *\||['#~^]/,punctuation:/[\[\]{}().,:;|]/}}return OS}var DS,M2;function Khe(){if(M2)return DS;M2=1,DS=e,e.displayName="parser",e.aliases=[];function e(t){(function(n){var r=n.languages.parser=n.languages.extend("markup",{keyword:{pattern:/(^|[^^])(?:\^(?:case|eval|for|if|switch|throw)\b|@(?:BASE|CLASS|GET(?:_DEFAULT)?|OPTIONS|SET_DEFAULT|USE)\b)/,lookbehind:!0},variable:{pattern:/(^|[^^])\B\$(?:\w+|(?=[.{]))(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{punctuation:/\.|:+/}},function:{pattern:/(^|[^^])\B[@^]\w+(?:(?:\.|::?)\w+)*(?:\.|::?)?/,lookbehind:!0,inside:{keyword:{pattern:/(^@)(?:GET_|SET_)/,lookbehind:!0},punctuation:/\.|:+/}},escape:{pattern:/\^(?:[$^;@()\[\]{}"':]|#[a-f\d]*)/i,alias:"builtin"},punctuation:/[\[\](){};]/});r=n.languages.insertBefore("parser","keyword",{"parser-comment":{pattern:/(\s)#.*/,lookbehind:!0,alias:"comment"},expression:{pattern:/(^|[^^])\((?:[^()]|\((?:[^()]|\((?:[^()])*\))*\))*\)/,greedy:!0,lookbehind:!0,inside:{string:{pattern:/(^|[^^])(["'])(?:(?!\2)[^^]|\^[\s\S])*\2/,lookbehind:!0},keyword:r.keyword,variable:r.variable,function:r.function,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[a-f\d]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?)\b/i,escape:r.escape,operator:/[~+*\/\\%]|!(?:\|\|?|=)?|&&?|\|\|?|==|<[<=]?|>[>=]?|-[fd]?|\b(?:def|eq|ge|gt|in|is|le|lt|ne)\b/,punctuation:r.punctuation}}}),n.languages.insertBefore("inside","punctuation",{expression:r.expression,keyword:r.keyword,variable:r.variable,function:r.function,escape:r.escape,"parser-punctuation":{pattern:r.punctuation,alias:"punctuation"}},r.tag.inside["attr-value"])})(t)}return DS}var IS,F2;function Xhe(){if(F2)return IS;F2=1,IS=e,e.displayName="pascal",e.aliases=["objectpascal"];function e(t){t.languages.pascal={directive:{pattern:/\{\$[\s\S]*?\}/,greedy:!0,alias:["marco","property"]},comment:{pattern:/\(\*[\s\S]*?\*\)|\{[\s\S]*?\}|\/\/.*/,greedy:!0},string:{pattern:/(?:'(?:''|[^'\r\n])*'(?!')|#[&$%]?[a-f\d]+)+|\^[a-z]/i,greedy:!0},asm:{pattern:/(\basm\b)[\s\S]+?(?=\bend\s*[;[])/i,lookbehind:!0,greedy:!0,inside:null},keyword:[{pattern:/(^|[^&])\b(?:absolute|array|asm|begin|case|const|constructor|destructor|do|downto|else|end|file|for|function|goto|if|implementation|inherited|inline|interface|label|nil|object|of|operator|packed|procedure|program|record|reintroduce|repeat|self|set|string|then|to|type|unit|until|uses|var|while|with)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:dispose|exit|false|new|true)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:class|dispinterface|except|exports|finalization|finally|initialization|inline|library|on|out|packed|property|raise|resourcestring|threadvar|try)\b/i,lookbehind:!0},{pattern:/(^|[^&])\b(?:absolute|abstract|alias|assembler|bitpacked|break|cdecl|continue|cppdecl|cvar|default|deprecated|dynamic|enumerator|experimental|export|external|far|far16|forward|generic|helper|implements|index|interrupt|iochecks|local|message|name|near|nodefault|noreturn|nostackframe|oldfpccall|otherwise|overload|override|pascal|platform|private|protected|public|published|read|register|reintroduce|result|safecall|saveregisters|softfloat|specialize|static|stdcall|stored|strict|unaligned|unimplemented|varargs|virtual|write)\b/i,lookbehind:!0}],number:[/(?:[&%]\d+|\$[a-f\d]+)/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?/i],operator:[/\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=]/,{pattern:/(^|[^&])\b(?:and|as|div|exclude|in|include|is|mod|not|or|shl|shr|xor)\b/,lookbehind:!0}],punctuation:/\(\.|\.\)|[()\[\]:;,.]/},t.languages.pascal.asm.inside=t.languages.extend("pascal",{asm:void 0,keyword:void 0,operator:void 0}),t.languages.objectpascal=t.languages.pascal}return IS}var LS,z2;function Zhe(){if(z2)return LS;z2=1,LS=e,e.displayName="pascaligo",e.aliases=[];function e(t){(function(n){var r=/\((?:[^()]|\((?:[^()]|\([^()]*\))*\))*\)/.source,a=/(?:\b\w+(?:<braces>)?|<braces>)/.source.replace(/<braces>/g,function(){return r}),i=n.languages.pascaligo={comment:/\(\*[\s\S]+?\*\)|\/\/.*/,string:{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1|\^[a-z]/i,greedy:!0},"class-name":[{pattern:RegExp(/(\btype\s+\w+\s+is\s+)<type>/.source.replace(/<type>/g,function(){return a}),"i"),lookbehind:!0,inside:null},{pattern:RegExp(/<type>(?=\s+is\b)/.source.replace(/<type>/g,function(){return a}),"i"),inside:null},{pattern:RegExp(/(:\s*)<type>/.source.replace(/<type>/g,function(){return a})),lookbehind:!0,inside:null}],keyword:{pattern:/(^|[^&])\b(?:begin|block|case|const|else|end|fail|for|from|function|if|is|nil|of|remove|return|skip|then|type|var|while|with)\b/i,lookbehind:!0},boolean:{pattern:/(^|[^&])\b(?:False|True)\b/i,lookbehind:!0},builtin:{pattern:/(^|[^&])\b(?:bool|int|list|map|nat|record|string|unit)\b/i,lookbehind:!0},function:/\b\w+(?=\s*\()/,number:[/%[01]+|&[0-7]+|\$[a-f\d]+/i,/\b\d+(?:\.\d+)?(?:e[+-]?\d+)?(?:mtz|n)?/i],operator:/->|=\/=|\.\.|\*\*|:=|<[<=>]?|>[>=]?|[+\-*\/]=?|[@^=|]|\b(?:and|mod|or)\b/,punctuation:/\(\.|\.\)|[()\[\]:;,.{}]/},l=["comment","keyword","builtin","operator","punctuation"].reduce(function(u,c){return u[c]=i[c],u},{});i["class-name"].forEach(function(u){u.inside=l})})(t)}return LS}var MS,P2;function Qhe(){if(P2)return MS;P2=1,MS=e,e.displayName="pcaxis",e.aliases=["px"];function e(t){t.languages.pcaxis={string:/"[^"]*"/,keyword:{pattern:/((?:^|;)\s*)[-A-Z\d]+(?:\s*\[[-\w]+\])?(?:\s*\("[^"]*"(?:,\s*"[^"]*")*\))?(?=\s*=)/,lookbehind:!0,greedy:!0,inside:{keyword:/^[-A-Z\d]+/,language:{pattern:/^(\s*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/^\[|\]$/,property:/[-\w]+/}},"sub-key":{pattern:/^(\s*)\S[\s\S]*/,lookbehind:!0,inside:{parameter:{pattern:/"[^"]*"/,alias:"property"},punctuation:/^\(|\)$|,/}}}},operator:/=/,tlist:{pattern:/TLIST\s*\(\s*\w+(?:(?:\s*,\s*"[^"]*")+|\s*,\s*"[^"]*"-"[^"]*")?\s*\)/,greedy:!0,inside:{function:/^TLIST/,property:{pattern:/^(\s*\(\s*)\w+/,lookbehind:!0},string:/"[^"]*"/,punctuation:/[(),]/,operator:/-/}},punctuation:/[;,]/,number:{pattern:/(^|\s)\d+(?:\.\d+)?(?!\S)/,lookbehind:!0},boolean:/NO|YES/},t.languages.px=t.languages.pcaxis}return MS}var FS,B2;function Jhe(){if(B2)return FS;B2=1,FS=e,e.displayName="peoplecode",e.aliases=["pcode"];function e(t){t.languages.peoplecode={comment:RegExp([/\/\*[\s\S]*?\*\//.source,/\bREM[^;]*;/.source,/<\*(?:[^<*]|\*(?!>)|<(?!\*)|<\*(?:(?!\*>)[\s\S])*\*>)*\*>/.source,/\/\+[\s\S]*?\+\//.source].join("|")),string:{pattern:/'(?:''|[^'\r\n])*'(?!')|"(?:""|[^"\r\n])*"(?!")/,greedy:!0},variable:/%\w+/,"function-definition":{pattern:/((?:^|[^\w-])(?:function|method)\s+)\w+/i,lookbehind:!0,alias:"function"},"class-name":{pattern:/((?:^|[^-\w])(?:as|catch|class|component|create|extends|global|implements|instance|local|of|property|returns)\s+)\w+(?::\w+)*/i,lookbehind:!0,inside:{punctuation:/:/}},keyword:/\b(?:abstract|alias|as|catch|class|component|constant|create|declare|else|end-(?:class|evaluate|for|function|get|if|method|set|try|while)|evaluate|extends|for|function|get|global|if|implements|import|instance|library|local|method|null|of|out|peopleCode|private|program|property|protected|readonly|ref|repeat|returns?|set|step|then|throw|to|try|until|value|when(?:-other)?|while)\b/i,"operator-keyword":{pattern:/\b(?:and|not|or)\b/i,alias:"operator"},function:/[_a-z]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/i,number:/\b\d+(?:\.\d+)?\b/,operator:/<>|[<>]=?|!=|\*\*|[-+*/|=@]/,punctuation:/[:.;,()[\]]/},t.languages.pcode=t.languages.peoplecode}return FS}var zS,U2;function eme(){if(U2)return zS;U2=1,zS=e,e.displayName="perl",e.aliases=[];function e(t){(function(n){var r=/(?:\((?:[^()\\]|\\[\s\S])*\)|\{(?:[^{}\\]|\\[\s\S])*\}|\[(?:[^[\]\\]|\\[\s\S])*\]|<(?:[^<>\\]|\\[\s\S])*>)/.source;n.languages.perl={comment:[{pattern:/(^\s*)=\w[\s\S]*?=cut.*/m,lookbehind:!0,greedy:!0},{pattern:/(^|[^\\$])#.*/,lookbehind:!0,greedy:!0}],string:[{pattern:RegExp(/\b(?:q|qq|qw|qx)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,r].join("|")+")"),greedy:!0},{pattern:/("|`)(?:(?!\1)[^\\]|\\[\s\S])*\1/,greedy:!0},{pattern:/'(?:[^'\\\r\n]|\\.)*'/,greedy:!0}],regex:[{pattern:RegExp(/\b(?:m|qr)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\1)[^\\]|\\[\s\S])*\1/.source,/([a-zA-Z0-9])(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,r].join("|")+")"+/[msixpodualngc]*/.source),greedy:!0},{pattern:RegExp(/(^|[^-])\b(?:s|tr|y)(?![a-zA-Z0-9])\s*/.source+"(?:"+[/([^a-zA-Z0-9\s{(\[<])(?:(?!\2)[^\\]|\\[\s\S])*\2(?:(?!\2)[^\\]|\\[\s\S])*\2/.source,/([a-zA-Z0-9])(?:(?!\3)[^\\]|\\[\s\S])*\3(?:(?!\3)[^\\]|\\[\s\S])*\3/.source,r+/\s*/.source+r].join("|")+")"+/[msixpodualngcer]*/.source),lookbehind:!0,greedy:!0},{pattern:/\/(?:[^\/\\\r\n]|\\.)*\/[msixpodualngc]*(?=\s*(?:$|[\r\n,.;})&|\-+*~<>!?^]|(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|x|xor)\b))/,greedy:!0}],variable:[/[&*$@%]\{\^[A-Z]+\}/,/[&*$@%]\^[A-Z_]/,/[&*$@%]#?(?=\{)/,/[&*$@%]#?(?:(?:::)*'?(?!\d)[\w$]+(?![\w$]))+(?:::)*/,/[&*$@%]\d+/,/(?!%=)[$@%][!"#$%&'()*+,\-.\/:;<=>?@[\\\]^_`{|}~]/],filehandle:{pattern:/<(?![<=])\S*?>|\b_\b/,alias:"symbol"},"v-string":{pattern:/v\d+(?:\.\d+)*|\d+(?:\.\d+){2,}/,alias:"string"},function:{pattern:/(\bsub[ \t]+)\w+/,lookbehind:!0},keyword:/\b(?:any|break|continue|default|delete|die|do|else|elsif|eval|for|foreach|given|goto|if|last|local|my|next|our|package|print|redo|require|return|say|state|sub|switch|undef|unless|until|use|when|while)\b/,number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)\b/,operator:/-[rwxoRWXOezsfdlpSbctugkTBMAC]\b|\+[+=]?|-[-=>]?|\*\*?=?|\/\/?=?|=[=~>]?|~[~=]?|\|\|?=?|&&?=?|<(?:=>?|<=?)?|>>?=?|![~=]?|[%^]=?|\.(?:=|\.\.?)?|[\\?]|\bx(?:=|\b)|\b(?:and|cmp|eq|ge|gt|le|lt|ne|not|or|xor)\b/,punctuation:/[{}[\];(),:]/}})(t)}return zS}var PS,j2;function tme(){if(j2)return PS;j2=1;var e=Kf();PS=t,t.displayName="phpExtras",t.aliases=[];function t(n){n.register(e),n.languages.insertBefore("php","variable",{this:{pattern:/\$this\b/,alias:"keyword"},global:/\$(?:GLOBALS|HTTP_RAW_POST_DATA|_(?:COOKIE|ENV|FILES|GET|POST|REQUEST|SERVER|SESSION)|argc|argv|http_response_header|php_errormsg)\b/,scope:{pattern:/\b[\w\\]+::/,inside:{keyword:/\b(?:parent|self|static)\b/,punctuation:/::|\\/}}})}return PS}var BS,G2;function nme(){if(G2)return BS;G2=1;var e=Kf(),t=Yf();BS=n,n.displayName="phpdoc",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var i=/(?:\b[a-zA-Z]\w*|[|\\[\]])+/.source;a.languages.phpdoc=a.languages.extend("javadoclike",{parameter:{pattern:RegExp("(@(?:global|param|property(?:-read|-write)?|var)\\s+(?:"+i+"\\s+)?)\\$\\w+"),lookbehind:!0}}),a.languages.insertBefore("phpdoc","keyword",{"class-name":[{pattern:RegExp("(@(?:global|package|param|property(?:-read|-write)?|return|subpackage|throws|var)\\s+)"+i),lookbehind:!0,inside:{keyword:/\b(?:array|bool|boolean|callback|double|false|float|int|integer|mixed|null|object|resource|self|string|true|void)\b/,punctuation:/[|\\[\]()]/}}]}),a.languages.javadoclike.addSupport("php",a.languages.phpdoc)}(r)}return BS}var US,H2;function rme(){if(H2)return US;H2=1;var e=sA();US=t,t.displayName="plsql",t.aliases=[];function t(n){n.register(e),n.languages.plsql=n.languages.extend("sql",{comment:{pattern:/\/\*[\s\S]*?\*\/|--.*/,greedy:!0},keyword:/\b(?:A|ACCESSIBLE|ADD|AGENT|AGGREGATE|ALL|ALTER|AND|ANY|ARRAY|AS|ASC|AT|ATTRIBUTE|AUTHID|AVG|BEGIN|BETWEEN|BFILE_BASE|BINARY|BLOB_BASE|BLOCK|BODY|BOTH|BOUND|BULK|BY|BYTE|C|CALL|CALLING|CASCADE|CASE|CHAR|CHARACTER|CHARSET|CHARSETFORM|CHARSETID|CHAR_BASE|CHECK|CLOB_BASE|CLONE|CLOSE|CLUSTER|CLUSTERS|COLAUTH|COLLECT|COLUMNS|COMMENT|COMMIT|COMMITTED|COMPILED|COMPRESS|CONNECT|CONSTANT|CONSTRUCTOR|CONTEXT|CONTINUE|CONVERT|COUNT|CRASH|CREATE|CREDENTIAL|CURRENT|CURSOR|CUSTOMDATUM|DANGLING|DATA|DATE|DATE_BASE|DAY|DECLARE|DEFAULT|DEFINE|DELETE|DESC|DETERMINISTIC|DIRECTORY|DISTINCT|DOUBLE|DROP|DURATION|ELEMENT|ELSE|ELSIF|EMPTY|END|ESCAPE|EXCEPT|EXCEPTION|EXCEPTIONS|EXCLUSIVE|EXECUTE|EXISTS|EXIT|EXTERNAL|FETCH|FINAL|FIRST|FIXED|FLOAT|FOR|FORALL|FORCE|FROM|FUNCTION|GENERAL|GOTO|GRANT|GROUP|HASH|HAVING|HEAP|HIDDEN|HOUR|IDENTIFIED|IF|IMMEDIATE|IMMUTABLE|IN|INCLUDING|INDEX|INDEXES|INDICATOR|INDICES|INFINITE|INSERT|INSTANTIABLE|INT|INTERFACE|INTERSECT|INTERVAL|INTO|INVALIDATE|IS|ISOLATION|JAVA|LANGUAGE|LARGE|LEADING|LENGTH|LEVEL|LIBRARY|LIKE|LIKE2|LIKE4|LIKEC|LIMIT|LIMITED|LOCAL|LOCK|LONG|LOOP|MAP|MAX|MAXLEN|MEMBER|MERGE|MIN|MINUS|MINUTE|MOD|MODE|MODIFY|MONTH|MULTISET|MUTABLE|NAME|NAN|NATIONAL|NATIVE|NCHAR|NEW|NOCOMPRESS|NOCOPY|NOT|NOWAIT|NULL|NUMBER_BASE|OBJECT|OCICOLL|OCIDATE|OCIDATETIME|OCIDURATION|OCIINTERVAL|OCILOBLOCATOR|OCINUMBER|OCIRAW|OCIREF|OCIREFCURSOR|OCIROWID|OCISTRING|OCITYPE|OF|OLD|ON|ONLY|OPAQUE|OPEN|OPERATOR|OPTION|OR|ORACLE|ORADATA|ORDER|ORGANIZATION|ORLANY|ORLVARY|OTHERS|OUT|OVERLAPS|OVERRIDING|PACKAGE|PARALLEL_ENABLE|PARAMETER|PARAMETERS|PARENT|PARTITION|PASCAL|PERSISTABLE|PIPE|PIPELINED|PLUGGABLE|POLYMORPHIC|PRAGMA|PRECISION|PRIOR|PRIVATE|PROCEDURE|PUBLIC|RAISE|RANGE|RAW|READ|RECORD|REF|REFERENCE|RELIES_ON|REM|REMAINDER|RENAME|RESOURCE|RESULT|RESULT_CACHE|RETURN|RETURNING|REVERSE|REVOKE|ROLLBACK|ROW|SAMPLE|SAVE|SAVEPOINT|SB1|SB2|SB4|SECOND|SEGMENT|SELECT|SELF|SEPARATE|SEQUENCE|SERIALIZABLE|SET|SHARE|SHORT|SIZE|SIZE_T|SOME|SPARSE|SQL|SQLCODE|SQLDATA|SQLNAME|SQLSTATE|STANDARD|START|STATIC|STDDEV|STORED|STRING|STRUCT|STYLE|SUBMULTISET|SUBPARTITION|SUBSTITUTABLE|SUBTYPE|SUM|SYNONYM|TABAUTH|TABLE|TDO|THE|THEN|TIME|TIMESTAMP|TIMEZONE_ABBR|TIMEZONE_HOUR|TIMEZONE_MINUTE|TIMEZONE_REGION|TO|TRAILING|TRANSACTION|TRANSACTIONAL|TRUSTED|TYPE|UB1|UB2|UB4|UNDER|UNION|UNIQUE|UNPLUG|UNSIGNED|UNTRUSTED|UPDATE|USE|USING|VALIST|VALUE|VALUES|VARIABLE|VARIANCE|VARRAY|VARYING|VIEW|VIEWS|VOID|WHEN|WHERE|WHILE|WITH|WORK|WRAPPED|WRITE|YEAR|ZONE)\b/i,operator:/:=?|=>|[<>^~!]=|\.\.|\|\||\*\*|[-+*/%<>=@]/}),n.languages.insertBefore("plsql","operator",{label:{pattern:/<<\s*\w+\s*>>/,alias:"symbol"}})}return US}var jS,$2;function ame(){if($2)return jS;$2=1,jS=e,e.displayName="powerquery",e.aliases=[];function e(t){t.languages.powerquery={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},"quoted-identifier":{pattern:/#"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},string:{pattern:/(?:#!)?"(?:[^"\r\n]|"")*"(?!")/,greedy:!0},constant:[/\bDay\.(?:Friday|Monday|Saturday|Sunday|Thursday|Tuesday|Wednesday)\b/,/\bTraceLevel\.(?:Critical|Error|Information|Verbose|Warning)\b/,/\bOccurrence\.(?:All|First|Last)\b/,/\bOrder\.(?:Ascending|Descending)\b/,/\bRoundingMode\.(?:AwayFromZero|Down|ToEven|TowardZero|Up)\b/,/\bMissingField\.(?:Error|Ignore|UseNull)\b/,/\bQuoteStyle\.(?:Csv|None)\b/,/\bJoinKind\.(?:FullOuter|Inner|LeftAnti|LeftOuter|RightAnti|RightOuter)\b/,/\bGroupKind\.(?:Global|Local)\b/,/\bExtraValues\.(?:Error|Ignore|List)\b/,/\bJoinAlgorithm\.(?:Dynamic|LeftHash|LeftIndex|PairwiseHash|RightHash|RightIndex|SortMerge)\b/,/\bJoinSide\.(?:Left|Right)\b/,/\bPrecision\.(?:Decimal|Double)\b/,/\bRelativePosition\.From(?:End|Start)\b/,/\bTextEncoding\.(?:Ascii|BigEndianUnicode|Unicode|Utf16|Utf8|Windows)\b/,/\b(?:Any|Binary|Date|DateTime|DateTimeZone|Duration|Function|Int16|Int32|Int64|Int8|List|Logical|None|Number|Record|Table|Text|Time)\.Type\b/,/\bnull\b/],boolean:/\b(?:false|true)\b/,keyword:/\b(?:and|as|each|else|error|if|in|is|let|meta|not|nullable|optional|or|otherwise|section|shared|then|try|type)\b|#(?:binary|date|datetime|datetimezone|duration|infinity|nan|sections|shared|table|time)\b/,function:{pattern:/(^|[^#\w.])[a-z_][\w.]*(?=\s*\()/i,lookbehind:!0},"data-type":{pattern:/\b(?:any|anynonnull|binary|date|datetime|datetimezone|duration|function|list|logical|none|number|record|table|text|time)\b/,alias:"class-name"},number:{pattern:/\b0x[\da-f]+\b|(?:[+-]?(?:\b\d+\.)?\b\d+|[+-]\.\d+|(^|[^.])\B\.\d+)(?:e[+-]?\d+)?\b/i,lookbehind:!0},operator:/[-+*\/&?@^]|<(?:=>?|>)?|>=?|=>?|\.\.\.?/,punctuation:/[,;\[\](){}]/},t.languages.pq=t.languages.powerquery,t.languages.mscript=t.languages.powerquery}return jS}var GS,q2;function ome(){if(q2)return GS;q2=1,GS=e,e.displayName="powershell",e.aliases=[];function e(t){(function(n){var r=n.languages.powershell={comment:[{pattern:/(^|[^`])<#[\s\S]*?#>/,lookbehind:!0},{pattern:/(^|[^`])#.*/,lookbehind:!0}],string:[{pattern:/"(?:`[\s\S]|[^`"])*"/,greedy:!0,inside:null},{pattern:/'(?:[^']|'')*'/,greedy:!0}],namespace:/\[[a-z](?:\[(?:\[[^\]]*\]|[^\[\]])*\]|[^\[\]])*\]/i,boolean:/\$(?:false|true)\b/i,variable:/\$\w+\b/,function:[/\b(?:Add|Approve|Assert|Backup|Block|Checkpoint|Clear|Close|Compare|Complete|Compress|Confirm|Connect|Convert|ConvertFrom|ConvertTo|Copy|Debug|Deny|Disable|Disconnect|Dismount|Edit|Enable|Enter|Exit|Expand|Export|Find|ForEach|Format|Get|Grant|Group|Hide|Import|Initialize|Install|Invoke|Join|Limit|Lock|Measure|Merge|Move|New|Open|Optimize|Out|Ping|Pop|Protect|Publish|Push|Read|Receive|Redo|Register|Remove|Rename|Repair|Request|Reset|Resize|Resolve|Restart|Restore|Resume|Revoke|Save|Search|Select|Send|Set|Show|Skip|Sort|Split|Start|Step|Stop|Submit|Suspend|Switch|Sync|Tee|Test|Trace|Unblock|Undo|Uninstall|Unlock|Unprotect|Unpublish|Unregister|Update|Use|Wait|Watch|Where|Write)-[a-z]+\b/i,/\b(?:ac|cat|chdir|clc|cli|clp|clv|compare|copy|cp|cpi|cpp|cvpa|dbp|del|diff|dir|ebp|echo|epal|epcsv|epsn|erase|fc|fl|ft|fw|gal|gbp|gc|gci|gcs|gdr|gi|gl|gm|gp|gps|group|gsv|gu|gv|gwmi|iex|ii|ipal|ipcsv|ipsn|irm|iwmi|iwr|kill|lp|ls|measure|mi|mount|move|mp|mv|nal|ndr|ni|nv|ogv|popd|ps|pushd|pwd|rbp|rd|rdr|ren|ri|rm|rmdir|rni|rnp|rp|rv|rvpa|rwmi|sal|saps|sasv|sbp|sc|select|set|shcm|si|sl|sleep|sls|sort|sp|spps|spsv|start|sv|swmi|tee|trcm|type|write)\b/i],keyword:/\b(?:Begin|Break|Catch|Class|Continue|Data|Define|Do|DynamicParam|Else|ElseIf|End|Exit|Filter|Finally|For|ForEach|From|Function|If|InlineScript|Parallel|Param|Process|Return|Sequence|Switch|Throw|Trap|Try|Until|Using|Var|While|Workflow)\b/i,operator:{pattern:/(^|\W)(?:!|-(?:b?(?:and|x?or)|as|(?:Not)?(?:Contains|In|Like|Match)|eq|ge|gt|is(?:Not)?|Join|le|lt|ne|not|Replace|sh[lr])\b|-[-=]?|\+[+=]?|[*\/%]=?)/i,lookbehind:!0},punctuation:/[|{}[\];(),.]/};r.string[0].inside={function:{pattern:/(^|[^`])\$\((?:\$\([^\r\n()]*\)|(?!\$\()[^\r\n)])*\)/,lookbehind:!0,inside:r},boolean:r.boolean,variable:r.variable}})(t)}return GS}var HS,V2;function ime(){if(V2)return HS;V2=1,HS=e,e.displayName="processing",e.aliases=[];function e(t){t.languages.processing=t.languages.extend("clike",{keyword:/\b(?:break|case|catch|class|continue|default|else|extends|final|for|if|implements|import|new|null|private|public|return|static|super|switch|this|try|void|while)\b/,function:/\b\w+(?=\s*\()/,operator:/<[<=]?|>[>=]?|&&?|\|\|?|[%?]|[!=+\-*\/]=?/}),t.languages.insertBefore("processing","number",{constant:/\b(?!XML\b)[A-Z][A-Z\d_]+\b/,type:{pattern:/\b(?:boolean|byte|char|color|double|float|int|[A-Z]\w*)\b/,alias:"class-name"}})}return HS}var $S,W2;function lme(){if(W2)return $S;W2=1,$S=e,e.displayName="prolog",e.aliases=[];function e(t){t.languages.prolog={comment:{pattern:/\/\*[\s\S]*?\*\/|%.*/,greedy:!0},string:{pattern:/(["'])(?:\1\1|\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1(?!\1)/,greedy:!0},builtin:/\b(?:fx|fy|xf[xy]?|yfx?)\b/,function:/\b[a-z]\w*(?:(?=\()|\/\d+)/,number:/\b\d+(?:\.\d*)?/,operator:/[:\\=><\-?*@\/;+^|!$.]+|\b(?:is|mod|not|xor)\b/,punctuation:/[(){}\[\],]/}}return $S}var qS,Y2;function sme(){if(Y2)return qS;Y2=1,qS=e,e.displayName="promql",e.aliases=[];function e(t){(function(n){var r=["sum","min","max","avg","group","stddev","stdvar","count","count_values","bottomk","topk","quantile"],a=["on","ignoring","group_right","group_left","by","without"],i=["offset"],l=r.concat(a,i);n.languages.promql={comment:{pattern:/(^[ \t]*)#.*/m,lookbehind:!0},"vector-match":{pattern:new RegExp("((?:"+a.join("|")+")\\s*)\\([^)]*\\)"),lookbehind:!0,inside:{"label-key":{pattern:/\b[^,]+\b/,alias:"attr-name"},punctuation:/[(),]/}},"context-labels":{pattern:/\{[^{}]*\}/,inside:{"label-key":{pattern:/\b[a-z_]\w*(?=\s*(?:=|![=~]))/,alias:"attr-name"},"label-value":{pattern:/(["'`])(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0,alias:"attr-value"},punctuation:/\{|\}|=~?|![=~]|,/}},"context-range":[{pattern:/\[[\w\s:]+\]/,inside:{punctuation:/\[|\]|:/,"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}},{pattern:/(\boffset\s+)\w+/,lookbehind:!0,inside:{"range-duration":{pattern:/\b(?:\d+(?:[smhdwy]|ms))+\b/i,alias:"number"}}}],keyword:new RegExp("\\b(?:"+l.join("|")+")\\b","i"),function:/\b[a-z_]\w*(?=\s*\()/i,number:/[-+]?(?:(?:\b\d+(?:\.\d+)?|\B\.\d+)(?:e[-+]?\d+)?\b|\b(?:0x[0-9a-f]+|nan|inf)\b)/i,operator:/[\^*/%+-]|==|!=|<=|<|>=|>|\b(?:and|or|unless)\b/i,punctuation:/[{};()`,.[\]]/}})(t)}return qS}var VS,K2;function ume(){if(K2)return VS;K2=1,VS=e,e.displayName="properties",e.aliases=[];function e(t){t.languages.properties={comment:/^[ \t]*[#!].*$/m,"attr-value":{pattern:/(^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?: *[=:] *(?! )| ))(?:\\(?:\r\n|[\s\S])|[^\\\r\n])+/m,lookbehind:!0},"attr-name":/^[ \t]*(?:\\(?:\r\n|[\s\S])|[^\\\s:=])+(?= *[=:]| )/m,punctuation:/[=:]/}}return VS}var WS,X2;function cme(){if(X2)return WS;X2=1,WS=e,e.displayName="protobuf",e.aliases=[];function e(t){(function(n){var r=/\b(?:bool|bytes|double|s?fixed(?:32|64)|float|[su]?int(?:32|64)|string)\b/;n.languages.protobuf=n.languages.extend("clike",{"class-name":[{pattern:/(\b(?:enum|extend|message|service)\s+)[A-Za-z_]\w*(?=\s*\{)/,lookbehind:!0},{pattern:/(\b(?:rpc\s+\w+|returns)\s*\(\s*(?:stream\s+)?)\.?[A-Za-z_]\w*(?:\.[A-Za-z_]\w*)*(?=\s*\))/,lookbehind:!0}],keyword:/\b(?:enum|extend|extensions|import|message|oneof|option|optional|package|public|repeated|required|reserved|returns|rpc(?=\s+\w)|service|stream|syntax|to)\b(?!\s*=\s*\d)/,function:/\b[a-z_]\w*(?=\s*\()/i}),n.languages.insertBefore("protobuf","operator",{map:{pattern:/\bmap<\s*[\w.]+\s*,\s*[\w.]+\s*>(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/[<>.,]/,builtin:r}},builtin:r,"positional-class-name":{pattern:/(?:\b|\B\.)[a-z_]\w*(?:\.[a-z_]\w*)*(?=\s+[a-z_]\w*\s*[=;])/i,alias:"class-name",inside:{punctuation:/\./}},annotation:{pattern:/(\[\s*)[a-z_]\w*(?=\s*=)/i,lookbehind:!0}})})(t)}return WS}var YS,Z2;function dme(){if(Z2)return YS;Z2=1,YS=e,e.displayName="psl",e.aliases=[];function e(t){t.languages.psl={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0,inside:{symbol:/\\[ntrbA-Z"\\]/}},"heredoc-string":{pattern:/<<<([a-zA-Z_]\w*)[\r\n](?:.*[\r\n])*?\1\b/,alias:"string",greedy:!0},keyword:/\b(?:__multi|__single|case|default|do|else|elsif|exit|export|for|foreach|function|if|last|line|local|next|requires|return|switch|until|while|word)\b/,constant:/\b(?:ALARM|CHART_ADD_GRAPH|CHART_DELETE_GRAPH|CHART_DESTROY|CHART_LOAD|CHART_PRINT|EOF|OFFLINE|OK|PSL_PROF_LOG|R_CHECK_HORIZ|R_CHECK_VERT|R_CLICKER|R_COLUMN|R_FRAME|R_ICON|R_LABEL|R_LABEL_CENTER|R_LIST_MULTIPLE|R_LIST_MULTIPLE_ND|R_LIST_SINGLE|R_LIST_SINGLE_ND|R_MENU|R_POPUP|R_POPUP_SCROLLED|R_RADIO_HORIZ|R_RADIO_VERT|R_ROW|R_SCALE_HORIZ|R_SCALE_VERT|R_SEP_HORIZ|R_SEP_VERT|R_SPINNER|R_TEXT_FIELD|R_TEXT_FIELD_LABEL|R_TOGGLE|TRIM_LEADING|TRIM_LEADING_AND_TRAILING|TRIM_REDUNDANT|TRIM_TRAILING|VOID|WARN)\b/,boolean:/\b(?:FALSE|False|NO|No|TRUE|True|YES|Yes|false|no|true|yes)\b/,variable:/\b(?:PslDebug|errno|exit_status)\b/,builtin:{pattern:/\b(?:PslExecute|PslFunctionCall|PslFunctionExists|PslSetOptions|_snmp_debug|acos|add_diary|annotate|annotate_get|ascii_to_ebcdic|asctime|asin|atan|atexit|batch_set|blackout|cat|ceil|chan_exists|change_state|close|code_cvt|cond_signal|cond_wait|console_type|convert_base|convert_date|convert_locale_date|cos|cosh|create|date|dcget_text|destroy|destroy_lock|dget_text|difference|dump_hist|ebcdic_to_ascii|encrypt|event_archive|event_catalog_get|event_check|event_query|event_range_manage|event_range_query|event_report|event_schedule|event_trigger|event_trigger2|execute|exists|exp|fabs|file|floor|fmod|fopen|fseek|ftell|full_discovery|get|get_chan_info|get_ranges|get_text|get_vars|getenv|gethostinfo|getpid|getpname|grep|history|history_get_retention|in_transition|index|int|internal|intersection|is_var|isnumber|join|kill|length|lines|lock|lock_info|log|log10|loge|matchline|msg_check|msg_get_format|msg_get_severity|msg_printf|msg_sprintf|ntharg|nthargf|nthline|nthlinef|num_bytes|num_consoles|pconfig|popen|poplines|pow|print|printf|proc_exists|process|random|read|readln|refresh_parameters|remote_check|remote_close|remote_event_query|remote_event_trigger|remote_file_send|remote_open|remove|replace|rindex|sec_check_priv|sec_store_get|sec_store_set|set|set_alarm_ranges|set_locale|share|sin|sinh|sleep|snmp_agent_config|snmp_agent_start|snmp_agent_stop|snmp_close|snmp_config|snmp_get|snmp_get_next|snmp_h_get|snmp_h_get_next|snmp_h_set|snmp_open|snmp_set|snmp_trap_ignore|snmp_trap_listen|snmp_trap_raise_std_trap|snmp_trap_receive|snmp_trap_register_im|snmp_trap_send|snmp_walk|sopen|sort|splitline|sprintf|sqrt|srandom|str_repeat|strcasecmp|subset|substr|system|tail|tan|tanh|text_domain|time|tmpnam|tolower|toupper|trace_psl_process|trim|union|unique|unlock|unset|va_arg|va_start|write)\b/,alias:"builtin-function"},"foreach-variable":{pattern:/(\bforeach\s+(?:(?:\w+\b|"(?:\\.|[^\\"])*")\s+){0,2})[_a-zA-Z]\w*(?=\s*\()/,lookbehind:!0,greedy:!0},function:/\b[_a-z]\w*\b(?=\s*\()/i,number:/\b(?:0x[0-9a-f]+|\d+(?:\.\d+)?)\b/i,operator:/--|\+\+|&&=?|\|\|=?|<<=?|>>=?|[=!]~|[-+*/%&|^!=<>]=?|\.|[:?]/,punctuation:/[(){}\[\];,]/}}return YS}var KS,Q2;function fme(){if(Q2)return KS;Q2=1,KS=e,e.displayName="pug",e.aliases=[];function e(t){(function(n){n.languages.pug={comment:{pattern:/(^([\t ]*))\/\/.*(?:(?:\r?\n|\r)\2[\t ].+)*/m,lookbehind:!0},"multiline-script":{pattern:/(^([\t ]*)script\b.*\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:n.languages.javascript},filter:{pattern:/(^([\t ]*)):.+(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:/\S[\s\S]*/}},"multiline-plain-text":{pattern:/(^([\t ]*)[\w\-#.]+\.[\t ]*)(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/m,lookbehind:!0},markup:{pattern:/(^[\t ]*)<.+/m,lookbehind:!0,inside:n.languages.markup},doctype:{pattern:/((?:^|\n)[\t ]*)doctype(?: .+)?/,lookbehind:!0},"flow-control":{pattern:/(^[\t ]*)(?:case|default|each|else|if|unless|when|while)\b(?: .+)?/m,lookbehind:!0,inside:{each:{pattern:/^each .+? in\b/,inside:{keyword:/\b(?:each|in)\b/,punctuation:/,/}},branch:{pattern:/^(?:case|default|else|if|unless|when|while)\b/,alias:"keyword"},rest:n.languages.javascript}},keyword:{pattern:/(^[\t ]*)(?:append|block|extends|include|prepend)\b.+/m,lookbehind:!0},mixin:[{pattern:/(^[\t ]*)mixin .+/m,lookbehind:!0,inside:{keyword:/^mixin/,function:/\w+(?=\s*\(|\s*$)/,punctuation:/[(),.]/}},{pattern:/(^[\t ]*)\+.+/m,lookbehind:!0,inside:{name:{pattern:/^\+\w+/,alias:"function"},rest:n.languages.javascript}}],script:{pattern:/(^[\t ]*script(?:(?:&[^(]+)?\([^)]+\))*[\t ]).+/m,lookbehind:!0,inside:n.languages.javascript},"plain-text":{pattern:/(^[\t ]*(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?[\t ]).+/m,lookbehind:!0},tag:{pattern:/(^[\t ]*)(?!-)[\w\-#.]*[\w\-](?:(?:&[^(]+)?\([^)]+\))*\/?:?/m,lookbehind:!0,inside:{attributes:[{pattern:/&[^(]+\([^)]+\)/,inside:n.languages.javascript},{pattern:/\([^)]+\)/,inside:{"attr-value":{pattern:/(=\s*(?!\s))(?:\{[^}]*\}|[^,)\r\n]+)/,lookbehind:!0,inside:n.languages.javascript},"attr-name":/[\w-]+(?=\s*!?=|\s*[,)])/,punctuation:/[!=(),]+/}}],punctuation:/:/,"attr-id":/#[\w\-]+/,"attr-class":/\.[\w\-]+/}},code:[{pattern:/(^[\t ]*(?:-|!?=)).+/m,lookbehind:!0,inside:n.languages.javascript}],punctuation:/[.\-!=|]+/};for(var r=/(^([\t ]*)):<filter_name>(?:(?:\r?\n|\r(?!\n))(?:\2[\t ].+|\s*?(?=\r?\n|\r)))+/.source,a=[{filter:"atpl",language:"twig"},{filter:"coffee",language:"coffeescript"},"ejs","handlebars","less","livescript","markdown",{filter:"sass",language:"scss"},"stylus"],i={},l=0,u=a.length;l<u;l++){var c=a[l];c=typeof c=="string"?{filter:c,language:c}:c,n.languages[c.language]&&(i["filter-"+c.filter]={pattern:RegExp(r.replace("<filter_name>",function(){return c.filter}),"m"),lookbehind:!0,inside:{"filter-name":{pattern:/^:[\w-]+/,alias:"variable"},text:{pattern:/\S[\s\S]*/,alias:[c.language,"language-"+c.language],inside:n.languages[c.language]}}})}n.languages.insertBefore("pug","filter",i)})(t)}return KS}var XS,J2;function pme(){if(J2)return XS;J2=1,XS=e,e.displayName="puppet",e.aliases=[];function e(t){(function(n){n.languages.puppet={heredoc:[{pattern:/(@\("([^"\r\n\/):]+)"(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/(@\(([^"\r\n\/):]+)(?:\/[nrts$uL]*)?\).*(?:\r?\n|\r))(?:.*(?:\r?\n|\r(?!\n)))*?[ \t]*(?:\|[ \t]*)?(?:-[ \t]*)?\2/,lookbehind:!0,greedy:!0,alias:"string",inside:{punctuation:/(?=\S).*\S(?= *$)/}},{pattern:/@\("?(?:[^"\r\n\/):]+)"?(?:\/[nrts$uL]*)?\)/,alias:"string",inside:{punctuation:{pattern:/(\().+?(?=\))/,lookbehind:!0}}}],"multiline-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,greedy:!0,alias:"comment"},regex:{pattern:/((?:\bnode\s+|[~=\(\[\{,]\s*|[=+]>\s*|^\s*))\/(?:[^\/\\]|\\[\s\S])+\/(?:[imx]+\b|\B)/,lookbehind:!0,greedy:!0,inside:{"extended-regex":{pattern:/^\/(?:[^\/\\]|\\[\s\S])+\/[im]*x[im]*$/,inside:{comment:/#.*/}}}},comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},string:{pattern:/(["'])(?:\$\{(?:[^'"}]|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}|\$(?!\{)|(?!\1)[^\\$]|\\[\s\S])*\1/,greedy:!0,inside:{"double-quoted":{pattern:/^"[\s\S]*"$/,inside:{}}}},variable:{pattern:/\$(?:::)?\w+(?:::\w+)*/,inside:{punctuation:/::/}},"attr-name":/(?:\b\w+|\*)(?=\s*=>)/,function:[{pattern:/(\.)(?!\d)\w+/,lookbehind:!0},/\b(?:contain|debug|err|fail|include|info|notice|realize|require|tag|warning)\b|\b(?!\d)\w+(?=\()/],number:/\b(?:0x[a-f\d]+|\d+(?:\.\d+)?(?:e-?\d+)?)\b/i,boolean:/\b(?:false|true)\b/,keyword:/\b(?:application|attr|case|class|consumes|default|define|else|elsif|function|if|import|inherits|node|private|produces|type|undef|unless)\b/,datatype:{pattern:/\b(?:Any|Array|Boolean|Callable|Catalogentry|Class|Collection|Data|Default|Enum|Float|Hash|Integer|NotUndef|Numeric|Optional|Pattern|Regexp|Resource|Runtime|Scalar|String|Struct|Tuple|Type|Undef|Variant)\b/,alias:"symbol"},operator:/=[=~>]?|![=~]?|<(?:<\|?|[=~|-])?|>[>=]?|->?|~>|\|>?>?|[*\/%+?]|\b(?:and|in|or)\b/,punctuation:/[\[\]{}().,;]|:+/};var r=[{pattern:/(^|[^\\])\$\{(?:[^'"{}]|\{[^}]*\}|(["'])(?:(?!\2)[^\\]|\\[\s\S])*\2)+\}/,lookbehind:!0,inside:{"short-variable":{pattern:/(^\$\{)(?!\w+\()(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}},delimiter:{pattern:/^\$/,alias:"variable"},rest:n.languages.puppet}},{pattern:/(^|[^\\])\$(?:::)?\w+(?:::\w+)*/,lookbehind:!0,alias:"variable",inside:{punctuation:/::/}}];n.languages.puppet.heredoc[0].inside.interpolation=r,n.languages.puppet.string.inside["double-quoted"].inside.interpolation=r})(t)}return XS}var ZS,eM;function gme(){if(eM)return ZS;eM=1,ZS=e,e.displayName="pure",e.aliases=[];function e(t){(function(n){n.languages.pure={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0},/#!.+/],"inline-lang":{pattern:/%<[\s\S]+?%>/,greedy:!0,inside:{lang:{pattern:/(^%< *)-\*-.+?-\*-/,lookbehind:!0,alias:"comment"},delimiter:{pattern:/^%<.*|%>$/,alias:"punctuation"}}},string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},number:{pattern:/((?:\.\.)?)(?:\b(?:inf|nan)\b|\b0x[\da-f]+|(?:\b(?:0b)?\d+(?:\.\d+)?|\B\.\d+)(?:e[+-]?\d+)?L?)/i,lookbehind:!0},keyword:/\b(?:NULL|ans|break|bt|case|catch|cd|clear|const|def|del|dump|else|end|exit|extern|false|force|help|if|infix[lr]?|interface|let|ls|mem|namespace|nonfix|of|otherwise|outfix|override|postfix|prefix|private|public|pwd|quit|run|save|show|stats|then|throw|trace|true|type|underride|using|when|with)\b/,function:/\b(?:abs|add_(?:addr|constdef|(?:fundef|interface|macdef|typedef)(?:_at)?|vardef)|all|any|applp?|arity|bigintp?|blob(?:_crc|_size|p)?|boolp?|byte_c?string(?:_pointer)?|byte_(?:matrix|pointer)|calloc|cat|catmap|ceil|char[ps]?|check_ptrtag|chr|clear_sentry|clearsym|closurep?|cmatrixp?|cols?|colcat(?:map)?|colmap|colrev|colvector(?:p|seq)?|complex(?:_float_(?:matrix|pointer)|_matrix(?:_view)?|_pointer|p)?|conj|cookedp?|cst|cstring(?:_(?:dup|list|vector))?|curry3?|cyclen?|del_(?:constdef|fundef|interface|macdef|typedef|vardef)|delete|diag(?:mat)?|dim|dmatrixp?|do|double(?:_matrix(?:_view)?|_pointer|p)?|dowith3?|drop|dropwhile|eval(?:cmd)?|exactp|filter|fix|fixity|flip|float(?:_matrix|_pointer)|floor|fold[lr]1?|frac|free|funp?|functionp?|gcd|get(?:_(?:byte|constdef|double|float|fundef|int(?:64)?|interface(?:_typedef)?|long|macdef|pointer|ptrtag|sentry|short|string|typedef|vardef))?|globsym|hash|head|id|im|imatrixp?|index|inexactp|infp|init|insert|int(?:_matrix(?:_view)?|_pointer|p)?|int64_(?:matrix|pointer)|integerp?|iteraten?|iterwhile|join|keys?|lambdap?|last(?:err(?:pos)?)?|lcd|list[2p]?|listmap|make_ptrtag|malloc|map|matcat|matrixp?|max|member|min|nanp|nargs|nmatrixp?|null|numberp?|ord|pack(?:ed)?|pointer(?:_cast|_tag|_type|p)?|pow|pred|ptrtag|put(?:_(?:byte|double|float|int(?:64)?|long|pointer|short|string))?|rationalp?|re|realp?|realloc|recordp?|redim|reduce(?:_with)?|refp?|repeatn?|reverse|rlistp?|round|rows?|rowcat(?:map)?|rowmap|rowrev|rowvector(?:p|seq)?|same|scan[lr]1?|sentry|sgn|short_(?:matrix|pointer)|slice|smatrixp?|sort|split|str|strcat|stream|stride|string(?:_(?:dup|list|vector)|p)?|subdiag(?:mat)?|submat|subseq2?|substr|succ|supdiag(?:mat)?|symbolp?|tail|take|takewhile|thunkp?|transpose|trunc|tuplep?|typep|ubyte|uint(?:64)?|ulong|uncurry3?|unref|unzip3?|update|ushort|vals?|varp?|vector(?:p|seq)?|void|zip3?|zipwith3?)\b/,special:{pattern:/\b__[a-z]+__\b/i,alias:"builtin"},operator:/(?:[!"#$%&'*+,\-.\/:<=>?@\\^`|~\u00a1-\u00bf\u00d7-\u00f7\u20d0-\u2bff]|\b_+\b)+|\b(?:and|div|mod|not|or)\b/,punctuation:/[(){}\[\];,|]/};var r=["c",{lang:"c++",alias:"cpp"},"fortran"],a=/%< *-\*- *<lang>\d* *-\*-[\s\S]+?%>/.source;r.forEach(function(i){var l=i;if(typeof i!="string"&&(l=i.alias,i=i.lang),n.languages[l]){var u={};u["inline-lang-"+l]={pattern:RegExp(a.replace("<lang>",i.replace(/([.+*?\/\\(){}\[\]])/g,"\\$1")),"i"),inside:n.util.clone(n.languages.pure["inline-lang"].inside)},u["inline-lang-"+l].inside.rest=n.util.clone(n.languages[l]),n.languages.insertBefore("pure","inline-lang",u)}}),n.languages.c&&(n.languages.pure["inline-lang"].inside.rest=n.util.clone(n.languages.c))})(t)}return ZS}var QS,tM;function hme(){if(tM)return QS;tM=1,QS=e,e.displayName="purebasic",e.aliases=[];function e(t){t.languages.purebasic=t.languages.extend("clike",{comment:/;.*/,keyword:/\b(?:align|and|as|break|calldebugger|case|compilercase|compilerdefault|compilerelse|compilerelseif|compilerendif|compilerendselect|compilererror|compilerif|compilerselect|continue|data|datasection|debug|debuglevel|declare|declarec|declarecdll|declaredll|declaremodule|default|define|dim|disableasm|disabledebugger|disableexplicit|else|elseif|enableasm|enabledebugger|enableexplicit|end|enddatasection|enddeclaremodule|endenumeration|endif|endimport|endinterface|endmacro|endmodule|endprocedure|endselect|endstructure|endstructureunion|endwith|enumeration|extends|fakereturn|for|foreach|forever|global|gosub|goto|if|import|importc|includebinary|includefile|includepath|interface|macro|module|newlist|newmap|next|not|or|procedure|procedurec|procedurecdll|proceduredll|procedurereturn|protected|prototype|prototypec|read|redim|repeat|restore|return|runtime|select|shared|static|step|structure|structureunion|swap|threaded|to|until|wend|while|with|xincludefile|xor)\b/i,function:/\b\w+(?:\.\w+)?\s*(?=\()/,number:/(?:\$[\da-f]+|\b-?(?:\d+(?:\.\d+)?|\.\d+)(?:e[+-]?\d+)?)\b/i,operator:/(?:@\*?|\?|\*)\w+|-[>-]?|\+\+?|!=?|<<?=?|>>?=?|==?|&&?|\|?\||[~^%?*/@]/}),t.languages.insertBefore("purebasic","keyword",{tag:/#\w+\$?/,asm:{pattern:/(^[\t ]*)!.*/m,lookbehind:!0,alias:"tag",inside:{comment:/;.*/,string:{pattern:/(["'`])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"label-reference-anonymous":{pattern:/(!\s*j[a-z]+\s+)@[fb]/i,lookbehind:!0,alias:"fasm-label"},"label-reference-addressed":{pattern:/(!\s*j[a-z]+\s+)[A-Z._?$@][\w.?$@~#]*/i,lookbehind:!0,alias:"fasm-label"},keyword:[/\b(?:extern|global)\b[^;\r\n]*/i,/\b(?:CPU|DEFAULT|FLOAT)\b.*/],function:{pattern:/^([\t ]*!\s*)[\da-z]+(?=\s|$)/im,lookbehind:!0},"function-inline":{pattern:/(:\s*)[\da-z]+(?=\s)/i,lookbehind:!0,alias:"function"},label:{pattern:/^([\t ]*!\s*)[A-Za-z._?$@][\w.?$@~#]*(?=:)/m,lookbehind:!0,alias:"fasm-label"},register:/\b(?:st\d|[xyz]mm\d\d?|[cdt]r\d|r\d\d?[bwd]?|[er]?[abcd]x|[abcd][hl]|[er]?(?:bp|di|si|sp)|[cdefgs]s|mm\d+)\b/i,number:/(?:\b|-|(?=\$))(?:0[hx](?:[\da-f]*\.)?[\da-f]+(?:p[+-]?\d+)?|\d[\da-f]+[hx]|\$\d[\da-f]*|0[oq][0-7]+|[0-7]+[oq]|0[by][01]+|[01]+[by]|0[dt]\d+|(?:\d+(?:\.\d+)?|\.\d+)(?:\.?e[+-]?\d+)?[dt]?)\b/i,operator:/[\[\]*+\-/%<>=&|$!,.:]/}}}),delete t.languages.purebasic["class-name"],delete t.languages.purebasic.boolean,t.languages.pbfasm=t.languages.purebasic}return QS}var JS,nM;function mme(){if(nM)return JS;nM=1;var e=cA();JS=t,t.displayName="purescript",t.aliases=["purs"];function t(n){n.register(e),n.languages.purescript=n.languages.extend("haskell",{keyword:/\b(?:ado|case|class|data|derive|do|else|forall|if|in|infixl|infixr|instance|let|module|newtype|of|primitive|then|type|where)\b|∀/,"import-statement":{pattern:/(^[\t ]*)import\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*(?:\s+as\s+[A-Z][\w']*(?:\.[A-Z][\w']*)*)?(?:\s+hiding\b)?/m,lookbehind:!0,inside:{keyword:/\b(?:as|hiding|import)\b/,punctuation:/\./}},builtin:/\b(?:absurd|add|ap|append|apply|between|bind|bottom|clamp|compare|comparing|compose|conj|const|degree|discard|disj|div|eq|flap|flip|gcd|identity|ifM|join|lcm|liftA1|liftM1|map|max|mempty|min|mod|mul|negate|not|notEq|one|otherwise|recip|show|sub|top|unit|unless|unlessM|void|when|whenM|zero)\b/,operator:[n.languages.haskell.operator[0],n.languages.haskell.operator[2],/[\xa2-\xa6\xa8\xa9\xac\xae-\xb1\xb4\xb8\xd7\xf7\u02c2-\u02c5\u02d2-\u02df\u02e5-\u02eb\u02ed\u02ef-\u02ff\u0375\u0384\u0385\u03f6\u0482\u058d-\u058f\u0606-\u0608\u060b\u060e\u060f\u06de\u06e9\u06fd\u06fe\u07f6\u07fe\u07ff\u09f2\u09f3\u09fa\u09fb\u0af1\u0b70\u0bf3-\u0bfa\u0c7f\u0d4f\u0d79\u0e3f\u0f01-\u0f03\u0f13\u0f15-\u0f17\u0f1a-\u0f1f\u0f34\u0f36\u0f38\u0fbe-\u0fc5\u0fc7-\u0fcc\u0fce\u0fcf\u0fd5-\u0fd8\u109e\u109f\u1390-\u1399\u166d\u17db\u1940\u19de-\u19ff\u1b61-\u1b6a\u1b74-\u1b7c\u1fbd\u1fbf-\u1fc1\u1fcd-\u1fcf\u1fdd-\u1fdf\u1fed-\u1fef\u1ffd\u1ffe\u2044\u2052\u207a-\u207c\u208a-\u208c\u20a0-\u20bf\u2100\u2101\u2103-\u2106\u2108\u2109\u2114\u2116-\u2118\u211e-\u2123\u2125\u2127\u2129\u212e\u213a\u213b\u2140-\u2144\u214a-\u214d\u214f\u218a\u218b\u2190-\u2307\u230c-\u2328\u232b-\u2426\u2440-\u244a\u249c-\u24e9\u2500-\u2767\u2794-\u27c4\u27c7-\u27e5\u27f0-\u2982\u2999-\u29d7\u29dc-\u29fb\u29fe-\u2b73\u2b76-\u2b95\u2b97-\u2bff\u2ce5-\u2cea\u2e50\u2e51\u2e80-\u2e99\u2e9b-\u2ef3\u2f00-\u2fd5\u2ff0-\u2ffb\u3004\u3012\u3013\u3020\u3036\u3037\u303e\u303f\u309b\u309c\u3190\u3191\u3196-\u319f\u31c0-\u31e3\u3200-\u321e\u322a-\u3247\u3250\u3260-\u327f\u328a-\u32b0\u32c0-\u33ff\u4dc0-\u4dff\ua490-\ua4c6\ua700-\ua716\ua720\ua721\ua789\ua78a\ua828-\ua82b\ua836-\ua839\uaa77-\uaa79\uab5b\uab6a\uab6b\ufb29\ufbb2-\ufbc1\ufdfc\ufdfd\ufe62\ufe64-\ufe66\ufe69\uff04\uff0b\uff1c-\uff1e\uff3e\uff40\uff5c\uff5e\uffe0-\uffe6\uffe8-\uffee\ufffc\ufffd]/]}),n.languages.purs=n.languages.purescript}return JS}var eE,rM;function bme(){if(rM)return eE;rM=1,eE=e,e.displayName="python",e.aliases=["py"];function e(t){t.languages.python={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0,greedy:!0},"string-interpolation":{pattern:/(?:f|fr|rf)(?:("""|''')[\s\S]*?\1|("|')(?:\\.|(?!\2)[^\\\r\n])*\2)/i,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^{])(?:\{\{)*)\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}]|\{(?!\{)(?:[^{}])+\})+\})+\}/,lookbehind:!0,inside:{"format-spec":{pattern:/(:)[^:(){}]+(?=\}$)/,lookbehind:!0},"conversion-option":{pattern:/![sra](?=[:}]$)/,alias:"punctuation"},rest:null}},string:/[\s\S]+/}},"triple-quoted-string":{pattern:/(?:[rub]|br|rb)?("""|''')[\s\S]*?\1/i,greedy:!0,alias:"string"},string:{pattern:/(?:[rub]|br|rb)?("|')(?:\\.|(?!\1)[^\\\r\n])*\1/i,greedy:!0},function:{pattern:/((?:^|\s)def[ \t]+)[a-zA-Z_]\w*(?=\s*\()/g,lookbehind:!0},"class-name":{pattern:/(\bclass\s+)\w+/i,lookbehind:!0},decorator:{pattern:/(^[\t ]*)@\w+(?:\.\w+)*/m,lookbehind:!0,alias:["annotation","punctuation"],inside:{punctuation:/\./}},keyword:/\b(?:_(?=\s*:)|and|as|assert|async|await|break|case|class|continue|def|del|elif|else|except|exec|finally|for|from|global|if|import|in|is|lambda|match|nonlocal|not|or|pass|print|raise|return|try|while|with|yield)\b/,builtin:/\b(?:__import__|abs|all|any|apply|ascii|basestring|bin|bool|buffer|bytearray|bytes|callable|chr|classmethod|cmp|coerce|compile|complex|delattr|dict|dir|divmod|enumerate|eval|execfile|file|filter|float|format|frozenset|getattr|globals|hasattr|hash|help|hex|id|input|int|intern|isinstance|issubclass|iter|len|list|locals|long|map|max|memoryview|min|next|object|oct|open|ord|pow|property|range|raw_input|reduce|reload|repr|reversed|round|set|setattr|slice|sorted|staticmethod|str|sum|super|tuple|type|unichr|unicode|vars|xrange|zip)\b/,boolean:/\b(?:False|None|True)\b/,number:/\b0(?:b(?:_?[01])+|o(?:_?[0-7])+|x(?:_?[a-f0-9])+)\b|(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:e[+-]?\d+(?:_\d+)*)?j?(?!\w)/i,operator:/[-+%=]=?|!=|:=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},t.languages.python["string-interpolation"].inside.interpolation.inside.rest=t.languages.python,t.languages.py=t.languages.python}return eE}var tE,aM;function yme(){if(aM)return tE;aM=1,tE=e,e.displayName="q",e.aliases=[];function e(t){t.languages.q={string:/"(?:\\.|[^"\\\r\n])*"/,comment:[{pattern:/([\t )\]}])\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|\r?\n|\r)\/[\t ]*(?:(?:\r?\n|\r)(?:.*(?:\r?\n|\r(?!\n)))*?(?:\\(?=[\t ]*(?:\r?\n|\r))|$)|\S.*)/,lookbehind:!0,greedy:!0},{pattern:/^\\[\t ]*(?:\r?\n|\r)[\s\S]+/m,greedy:!0},{pattern:/^#!.+/m,greedy:!0}],symbol:/`(?::\S+|[\w.]*)/,datetime:{pattern:/0N[mdzuvt]|0W[dtz]|\d{4}\.\d\d(?:m|\.\d\d(?:T(?:\d\d(?::\d\d(?::\d\d(?:[.:]\d\d\d)?)?)?)?)?[dz]?)|\d\d:\d\d(?::\d\d(?:[.:]\d\d\d)?)?[uvt]?/,alias:"number"},number:/\b(?![01]:)(?:0N[hje]?|0W[hj]?|0[wn]|0x[\da-fA-F]+|\d+(?:\.\d*)?(?:e[+-]?\d+)?[hjfeb]?)/,keyword:/\\\w+\b|\b(?:abs|acos|aj0?|all|and|any|asc|asin|asof|atan|attr|avgs?|binr?|by|ceiling|cols|cor|cos|count|cov|cross|csv|cut|delete|deltas|desc|dev|differ|distinct|div|do|dsave|ej|enlist|eval|except|exec|exit|exp|fby|fills|first|fkeys|flip|floor|from|get|getenv|group|gtime|hclose|hcount|hdel|hopen|hsym|iasc|identity|idesc|if|ij|in|insert|inter|inv|keys?|last|like|list|ljf?|load|log|lower|lsq|ltime|ltrim|mavg|maxs?|mcount|md5|mdev|med|meta|mins?|mmax|mmin|mmu|mod|msum|neg|next|not|null|or|over|parse|peach|pj|plist|prds?|prev|prior|rand|rank|ratios|raze|read0|read1|reciprocal|reval|reverse|rload|rotate|rsave|rtrim|save|scan|scov|sdev|select|set|setenv|show|signum|sin|sqrt|ssr?|string|sublist|sums?|sv|svar|system|tables|tan|til|trim|txf|type|uj|ungroup|union|update|upper|upsert|value|var|views?|vs|wavg|where|while|within|wj1?|wsum|ww|xasc|xbar|xcols?|xdesc|xexp|xgroup|xkey|xlog|xprev|xrank)\b/,adverb:{pattern:/['\/\\]:?|\beach\b/,alias:"function"},verb:{pattern:/(?:\B\.\B|\b[01]:|<[=>]?|>=?|[:+\-*%,!?~=|$&#@^]):?|\b_\b:?/,alias:"operator"},punctuation:/[(){}\[\];.]/}}return tE}var nE,oM;function vme(){if(oM)return nE;oM=1,nE=e,e.displayName="qml",e.aliases=[];function e(t){(function(n){for(var r=/"(?:\\.|[^\\"\r\n])*"|'(?:\\.|[^\\'\r\n])*'/.source,a=/\/\/.*(?!.)|\/\*(?:[^*]|\*(?!\/))*\*\//.source,i=/(?:[^\\()[\]{}"'/]|<string>|\/(?![*/])|<comment>|\(<expr>*\)|\[<expr>*\]|\{<expr>*\}|\\[\s\S])/.source.replace(/<string>/g,function(){return r}).replace(/<comment>/g,function(){return a}),l=0;l<2;l++)i=i.replace(/<expr>/g,function(){return i});i=i.replace(/<expr>/g,"[^\\s\\S]"),n.languages.qml={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},"javascript-function":{pattern:RegExp(/((?:^|;)[ \t]*)function\s+(?!\s)[_$a-zA-Z\xA0-\uFFFF](?:(?!\s)[$\w\xA0-\uFFFF])*\s*\(<js>*\)\s*\{<js>*\}/.source.replace(/<js>/g,function(){return i}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:n.languages.javascript},"class-name":{pattern:/((?:^|[:;])[ \t]*)(?!\d)\w+(?=[ \t]*\{|[ \t]+on\b)/m,lookbehind:!0},property:[{pattern:/((?:^|[;{])[ \t]*)(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0},{pattern:/((?:^|[;{])[ \t]*)property[ \t]+(?!\d)\w+(?:\.\w+)*[ \t]+(?!\d)\w+(?:\.\w+)*(?=[ \t]*:)/m,lookbehind:!0,inside:{keyword:/^property/,property:/\w+(?:\.\w+)*/}}],"javascript-expression":{pattern:RegExp(/(:[ \t]*)(?![\s;}[])(?:(?!$|[;}])<js>)+/.source.replace(/<js>/g,function(){return i}),"m"),lookbehind:!0,greedy:!0,alias:"language-javascript",inside:n.languages.javascript},string:{pattern:/"(?:\\.|[^\\"\r\n])*"/,greedy:!0},keyword:/\b(?:as|import|on)\b/,punctuation:/[{}[\]:;,]/}})(t)}return nE}var rE,iM;function Sme(){if(iM)return rE;iM=1,rE=e,e.displayName="qore",e.aliases=[];function e(t){t.languages.qore=t.languages.extend("clike",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:\/\/|#).*)/,lookbehind:!0},string:{pattern:/("|')(?:\\[\s\S]|(?!\1)[^\\])*\1/,greedy:!0},keyword:/\b(?:abstract|any|assert|binary|bool|boolean|break|byte|case|catch|char|class|code|const|continue|data|default|do|double|else|enum|extends|final|finally|float|for|goto|hash|if|implements|import|inherits|instanceof|int|interface|long|my|native|new|nothing|null|object|our|own|private|reference|rethrow|return|short|soft(?:bool|date|float|int|list|number|string)|static|strictfp|string|sub|super|switch|synchronized|this|throw|throws|transient|try|void|volatile|while)\b/,boolean:/\b(?:false|true)\b/i,function:/\$?\b(?!\d)\w+(?=\()/,number:/\b(?:0b[01]+|0x(?:[\da-f]*\.)?[\da-fp\-]+|(?:\d+(?:\.\d+)?|\.\d+)(?:e\d+)?[df]|(?:\d+(?:\.\d+)?|\.\d+))\b/i,operator:{pattern:/(^|[^.])(?:\+[+=]?|-[-=]?|[!=](?:==?|~)?|>>?=?|<(?:=>?|<=?)?|&[&=]?|\|[|=]?|[*\/%^]=?|[~?])/,lookbehind:!0},variable:/\$(?!\d)\w+\b/})}return rE}var aE,lM;function Eme(){if(lM)return aE;lM=1,aE=e,e.displayName="qsharp",e.aliases=["qs"];function e(t){(function(n){function r(S,v){return S.replace(/<<(\d+)>>/g,function(A,R){return"(?:"+v[+R]+")"})}function a(S,v,A){return RegExp(r(S,v),"")}function i(S,v){for(var A=0;A<v;A++)S=S.replace(/<<self>>/g,function(){return"(?:"+S+")"});return S.replace(/<<self>>/g,"[^\\s\\S]")}var l={type:"Adj BigInt Bool Ctl Double false Int One Pauli PauliI PauliX PauliY PauliZ Qubit Range Result String true Unit Zero",other:"Adjoint adjoint apply as auto body borrow borrowing Controlled controlled distribute elif else fail fixup for function if in internal intrinsic invert is let mutable namespace new newtype open operation repeat return self set until use using while within"};function u(S){return"\\b(?:"+S.trim().replace(/ /g,"|")+")\\b"}var c=RegExp(u(l.type+" "+l.other)),f=/\b[A-Za-z_]\w*\b/.source,p=r(/<<0>>(?:\s*\.\s*<<0>>)*/.source,[f]),g={keyword:c,punctuation:/[<>()?,.:[\]]/},b=/"(?:\\.|[^\\"])*"/.source;n.languages.qsharp=n.languages.extend("clike",{comment:/\/\/.*/,string:[{pattern:a(/(^|[^$\\])<<0>>/.source,[b]),lookbehind:!0,greedy:!0}],"class-name":[{pattern:a(/(\b(?:as|open)\s+)<<0>>(?=\s*(?:;|as\b))/.source,[p]),lookbehind:!0,inside:g},{pattern:a(/(\bnamespace\s+)<<0>>(?=\s*\{)/.source,[p]),lookbehind:!0,inside:g}],keyword:c,number:/(?:\b0(?:x[\da-f]+|b[01]+|o[0-7]+)|(?:\B\.\d+|\b\d+(?:\.\d*)?)(?:e[-+]?\d+)?)l?\b/i,operator:/\band=|\bor=|\band\b|\bnot\b|\bor\b|<[-=]|[-=]>|>>>=?|<<<=?|\^\^\^=?|\|\|\|=?|&&&=?|w\/=?|~~~|[*\/+\-^=!%]=?/,punctuation:/::|[{}[\];(),.:]/}),n.languages.insertBefore("qsharp","number",{range:{pattern:/\.\./,alias:"operator"}});var m=i(r(/\{(?:[^"{}]|<<0>>|<<self>>)*\}/.source,[b]),2);n.languages.insertBefore("qsharp","string",{"interpolation-string":{pattern:a(/\$"(?:\\.|<<0>>|[^\\"{])*"/.source,[m]),greedy:!0,inside:{interpolation:{pattern:a(/((?:^|[^\\])(?:\\\\)*)<<0>>/.source,[m]),lookbehind:!0,inside:{punctuation:/^\{|\}$/,expression:{pattern:/[\s\S]+/,alias:"language-qsharp",inside:n.languages.qsharp}}},string:/[\s\S]+/}}})})(t),t.languages.qs=t.languages.qsharp}return aE}var oE,sM;function wme(){if(sM)return oE;sM=1,oE=e,e.displayName="r",e.aliases=[];function e(t){t.languages.r={comment:/#.*/,string:{pattern:/(['"])(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},"percent-operator":{pattern:/%[^%\s]*%/,alias:"operator"},boolean:/\b(?:FALSE|TRUE)\b/,ellipsis:/\.\.(?:\.|\d+)/,number:[/\b(?:Inf|NaN)\b/,/(?:\b0x[\dA-Fa-f]+(?:\.\d*)?|\b\d+(?:\.\d*)?|\B\.\d+)(?:[EePp][+-]?\d+)?[iL]?/],keyword:/\b(?:NA|NA_character_|NA_complex_|NA_integer_|NA_real_|NULL|break|else|for|function|if|in|next|repeat|while)\b/,operator:/->?>?|<(?:=|<?-)?|[>=!]=?|::?|&&?|\|\|?|[+*\/^$@~]/,punctuation:/[(){}\[\],;]/}}return oE}var iE,uM;function xme(){if(uM)return iE;uM=1;var e=gA();iE=t,t.displayName="racket",t.aliases=["rkt"];function t(n){n.register(e),n.languages.racket=n.languages.extend("scheme",{"lambda-parameter":{pattern:/([(\[]lambda\s+[(\[])[^()\[\]'\s]+/,lookbehind:!0}}),n.languages.insertBefore("racket","string",{lang:{pattern:/^#lang.+/m,greedy:!0,alias:"keyword"}}),n.languages.rkt=n.languages.racket}return iE}var lE,cM;function kme(){if(cM)return lE;cM=1,lE=e,e.displayName="reason",e.aliases=[];function e(t){t.languages.reason=t.languages.extend("clike",{string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^\\\r\n"])*"/,greedy:!0},"class-name":/\b[A-Z]\w*/,keyword:/\b(?:and|as|assert|begin|class|constraint|do|done|downto|else|end|exception|external|for|fun|function|functor|if|in|include|inherit|initializer|lazy|let|method|module|mutable|new|nonrec|object|of|open|or|private|rec|sig|struct|switch|then|to|try|type|val|virtual|when|while|with)\b/,operator:/\.{3}|:[:=]|\|>|->|=(?:==?|>)?|<=?|>=?|[|^?'#!~`]|[+\-*\/]\.?|\b(?:asr|land|lor|lsl|lsr|lxor|mod)\b/}),t.languages.insertBefore("reason","class-name",{char:{pattern:/'(?:\\x[\da-f]{2}|\\o[0-3][0-7][0-7]|\\\d{3}|\\.|[^'\\\r\n])'/,greedy:!0},constructor:/\b[A-Z]\w*\b(?!\s*\.)/,label:{pattern:/\b[a-z]\w*(?=::)/,alias:"symbol"}}),delete t.languages.reason.function}return lE}var sE,dM;function Ame(){if(dM)return sE;dM=1,sE=e,e.displayName="regex",e.aliases=[];function e(t){(function(n){var r={pattern:/\\[\\(){}[\]^$+*?|.]/,alias:"escape"},a=/\\(?:x[\da-fA-F]{2}|u[\da-fA-F]{4}|u\{[\da-fA-F]+\}|0[0-7]{0,2}|[123][0-7]{2}|c[a-zA-Z]|.)/,i={pattern:/\.|\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},l={pattern:/\\[wsd]|\\p\{[^{}]+\}/i,alias:"class-name"},u="(?:[^\\\\-]|"+a.source+")",c=RegExp(u+"-"+u),f={pattern:/(<|')[^<>']+(?=[>']$)/,lookbehind:!0,alias:"variable"};n.languages.regex={"char-class":{pattern:/((?:^|[^\\])(?:\\\\)*)\[(?:[^\\\]]|\\[\s\S])*\]/,lookbehind:!0,inside:{"char-class-negation":{pattern:/(^\[)\^/,lookbehind:!0,alias:"operator"},"char-class-punctuation":{pattern:/^\[|\]$/,alias:"punctuation"},range:{pattern:c,inside:{escape:a,"range-punctuation":{pattern:/-/,alias:"operator"}}},"special-escape":r,"char-set":l,escape:a}},"special-escape":r,"char-set":i,backreference:[{pattern:/\\(?![123][0-7]{2})[1-9]/,alias:"keyword"},{pattern:/\\k<[^<>']+>/,alias:"keyword",inside:{"group-name":f}}],anchor:{pattern:/[$^]|\\[ABbGZz]/,alias:"function"},escape:a,group:[{pattern:/\((?:\?(?:<[^<>']+>|'[^<>']+'|[>:]|<?[=!]|[idmnsuxU]+(?:-[idmnsuxU]+)?:?))?/,alias:"punctuation",inside:{"group-name":f}},{pattern:/\)/,alias:"punctuation"}],quantifier:{pattern:/(?:[+*?]|\{\d+(?:,\d*)?\})[?+]?/,alias:"number"},alternation:{pattern:/\|/,alias:"keyword"}}})(t)}return sE}var uE,fM;function Tme(){if(fM)return uE;fM=1,uE=e,e.displayName="rego",e.aliases=[];function e(t){t.languages.rego={comment:/#.*/,property:{pattern:/(^|[^\\.])(?:"(?:\\.|[^\\"\r\n])*"|`[^`]*`|\b[a-z_]\w*\b)(?=\s*:(?!=))/i,lookbehind:!0,greedy:!0},string:{pattern:/(^|[^\\])"(?:\\.|[^\\"\r\n])*"|`[^`]*`/,lookbehind:!0,greedy:!0},keyword:/\b(?:as|default|else|import|not|null|package|set(?=\s*\()|some|with)\b/,boolean:/\b(?:false|true)\b/,function:{pattern:/\b[a-z_]\w*\b(?:\s*\.\s*\b[a-z_]\w*\b)*(?=\s*\()/i,inside:{namespace:/\b\w+\b(?=\s*\.)/,punctuation:/\./}},number:/-?\b\d+(?:\.\d+)?(?:e[+-]?\d+)?\b/i,operator:/[-+*/%|&]|[<>:=]=?|!=|\b_\b/,punctuation:/[,;.\[\]{}()]/}}return uE}var cE,pM;function _me(){if(pM)return cE;pM=1,cE=e,e.displayName="renpy",e.aliases=["rpy"];function e(t){t.languages.renpy={comment:{pattern:/(^|[^\\])#.+/,lookbehind:!0},string:{pattern:/("""|''')[\s\S]+?\1|("|')(?:\\.|(?!\2)[^\\])*\2|(?:^#?(?:(?:[0-9a-fA-F]){3}|[0-9a-fA-F]{6})$)/m,greedy:!0},function:/\b[a-z_]\w*(?=\()/i,property:/\b(?:Update|UpdateVersion|action|activate_sound|adv_nvl_transition|after_load_transition|align|alpha|alt|anchor|antialias|area|auto|background|bar_invert|bar_resizing|bar_vertical|black_color|bold|bottom_bar|bottom_gutter|bottom_margin|bottom_padding|box_reverse|box_wrap|can_update|caret|child|color|crop|default_afm_enable|default_afm_time|default_fullscreen|default_text_cps|developer|directory_name|drag_handle|drag_joined|drag_name|drag_raise|draggable|dragged|drop_shadow|drop_shadow_color|droppable|dropped|easein|easeout|edgescroll|end_game_transition|end_splash_transition|enter_replay_transition|enter_sound|enter_transition|enter_yesno_transition|executable_name|exit_replay_transition|exit_sound|exit_transition|exit_yesno_transition|fadein|fadeout|first_indent|first_spacing|fit_first|focus|focus_mask|font|foreground|game_main_transition|get_installed_packages|google_play_key|google_play_salt|ground|has_music|has_sound|has_voice|height|help|hinting|hover|hover_background|hover_color|hover_sound|hovered|hyperlink_functions|idle|idle_color|image_style|include_update|insensitive|insensitive_background|insensitive_color|inside|intra_transition|italic|justify|kerning|keyboard_focus|language|layer_clipping|layers|layout|left_bar|left_gutter|left_margin|left_padding|length|line_leading|line_overlap_split|line_spacing|linear|main_game_transition|main_menu_music|maximum|min_width|minimum|minwidth|modal|mouse|mousewheel|name|narrator_menu|newline_indent|nvl_adv_transition|offset|order_reverse|outlines|overlay_functions|pos|position|prefix|radius|range|rest_indent|right_bar|right_gutter|right_margin|right_padding|rotate|rotate_pad|ruby_style|sample_sound|save_directory|say_attribute_transition|screen_height|screen_width|scrollbars|selected_hover|selected_hover_color|selected_idle|selected_idle_color|selected_insensitive|show_side_image|show_two_window|side_spacing|side_xpos|side_ypos|size|size_group|slow_cps|slow_cps_multiplier|spacing|strikethrough|subpixel|text_align|text_style|text_xpos|text_y_fudge|text_ypos|thumb|thumb_offset|thumb_shadow|thumbnail_height|thumbnail_width|time|top_bar|top_gutter|top_margin|top_padding|translations|underline|unscrollable|update|value|version|version_name|version_tuple|vertical|width|window_hide_transition|window_icon|window_left_padding|window_show_transition|window_title|windows_icon|xadjustment|xalign|xanchor|xanchoraround|xaround|xcenter|xfill|xinitial|xmargin|xmaximum|xminimum|xoffset|xofsset|xpadding|xpos|xsize|xzoom|yadjustment|yalign|yanchor|yanchoraround|yaround|ycenter|yfill|yinitial|ymargin|ymaximum|yminimum|yoffset|ypadding|ypos|ysize|ysizexysize|yzoom|zoom|zorder)\b/,tag:/\b(?:bar|block|button|buttoscreenn|drag|draggroup|fixed|frame|grid|[hv]box|hotbar|hotspot|image|imagebutton|imagemap|input|key|label|menu|mm_menu_frame|mousearea|nvl|parallel|screen|self|side|tag|text|textbutton|timer|vbar|viewport|window)\b|\$/,keyword:/\b(?:None|add|adjustment|alignaround|allow|angle|animation|around|as|assert|behind|box_layout|break|build|cache|call|center|changed|child_size|choice|circles|class|clear|clicked|clipping|clockwise|config|contains|continue|corner1|corner2|counterclockwise|def|default|define|del|delay|disabled|disabled_text|dissolve|elif|else|event|except|exclude|exec|expression|fade|finally|for|from|function|global|gm_root|has|hide|id|if|import|in|init|is|jump|knot|lambda|left|less_rounded|mm_root|movie|music|null|on|onlayer|pass|pause|persistent|play|print|python|queue|raise|random|renpy|repeat|return|right|rounded_window|scene|scope|set|show|slow|slow_abortable|slow_done|sound|stop|store|style|style_group|substitute|suffix|theme|transform|transform_anchor|transpose|try|ui|unhovered|updater|use|voice|while|widget|widget_hover|widget_selected|widget_text|yield)\b/,boolean:/\b(?:[Ff]alse|[Tt]rue)\b/,number:/(?:\b(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?)|\B\.\d+)(?:e[+-]?\d+)?j?/i,operator:/[-+%=]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]|\b(?:and|at|not|or|with)\b/,punctuation:/[{}[\];(),.:]/},t.languages.rpy=t.languages.renpy}return cE}var dE,gM;function Rme(){if(gM)return dE;gM=1,dE=e,e.displayName="rest",e.aliases=[];function e(t){t.languages.rest={table:[{pattern:/(^[\t ]*)(?:\+[=-]+)+\+(?:\r?\n|\r)(?:\1[+|].+[+|](?:\r?\n|\r))+\1(?:\+[=-]+)+\+/m,lookbehind:!0,inside:{punctuation:/\||(?:\+[=-]+)+\+/}},{pattern:/(^[\t ]*)=+ [ =]*=(?:(?:\r?\n|\r)\1.+)+(?:\r?\n|\r)\1=+ [ =]*=(?=(?:\r?\n|\r){2}|\s*$)/m,lookbehind:!0,inside:{punctuation:/[=-]+/}}],"substitution-def":{pattern:/(^[\t ]*\.\. )\|(?:[^|\s](?:[^|]*[^|\s])?)\| [^:]+::/m,lookbehind:!0,inside:{substitution:{pattern:/^\|(?:[^|\s]|[^|\s][^|]*[^|\s])\|/,alias:"attr-value",inside:{punctuation:/^\||\|$/}},directive:{pattern:/( )(?! )[^:]+::/,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}}}},"link-target":[{pattern:/(^[\t ]*\.\. )\[[^\]]+\]/m,lookbehind:!0,alias:"string",inside:{punctuation:/^\[|\]$/}},{pattern:/(^[\t ]*\.\. )_(?:`[^`]+`|(?:[^:\\]|\\.)+):/m,lookbehind:!0,alias:"string",inside:{punctuation:/^_|:$/}}],directive:{pattern:/(^[\t ]*\.\. )[^:]+::/m,lookbehind:!0,alias:"function",inside:{punctuation:/::$/}},comment:{pattern:/(^[\t ]*\.\.)(?:(?: .+)?(?:(?:\r?\n|\r).+)+| .+)(?=(?:\r?\n|\r){2}|$)/m,lookbehind:!0},title:[{pattern:/^(([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+)(?:\r?\n|\r).+(?:\r?\n|\r)\1$/m,inside:{punctuation:/^[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+|[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}},{pattern:/(^|(?:\r?\n|\r){2}).+(?:\r?\n|\r)([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2+(?=\r?\n|\r|$)/,lookbehind:!0,inside:{punctuation:/[!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]+$/,important:/.+/}}],hr:{pattern:/((?:\r?\n|\r){2})([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\2{3,}(?=(?:\r?\n|\r){2})/,lookbehind:!0,alias:"punctuation"},field:{pattern:/(^[\t ]*):[^:\r\n]+:(?= )/m,lookbehind:!0,alias:"attr-name"},"command-line-option":{pattern:/(^[\t ]*)(?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?(?:, (?:[+-][a-z\d]|(?:--|\/)[a-z\d-]+)(?:[ =](?:[a-z][\w-]*|<[^<>]+>))?)*(?=(?:\r?\n|\r)? {2,}\S)/im,lookbehind:!0,alias:"symbol"},"literal-block":{pattern:/::(?:\r?\n|\r){2}([ \t]+)(?![ \t]).+(?:(?:\r?\n|\r)\1.+)*/,inside:{"literal-block-punctuation":{pattern:/^::/,alias:"punctuation"}}},"quoted-literal-block":{pattern:/::(?:\r?\n|\r){2}([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~]).*(?:(?:\r?\n|\r)\1.*)*/,inside:{"literal-block-punctuation":{pattern:/^(?:::|([!"#$%&'()*+,\-.\/:;<=>?@\[\\\]^_`{|}~])\1*)/m,alias:"punctuation"}}},"list-bullet":{pattern:/(^[\t ]*)(?:[*+\-•‣⁃]|\(?(?:\d+|[a-z]|[ivxdclm]+)\)|(?:\d+|[a-z]|[ivxdclm]+)\.)(?= )/im,lookbehind:!0,alias:"punctuation"},"doctest-block":{pattern:/(^[\t ]*)>>> .+(?:(?:\r?\n|\r).+)*/m,lookbehind:!0,inside:{punctuation:/^>>>/}},inline:[{pattern:/(^|[\s\-:\/'"<(\[{])(?::[^:]+:`.*?`|`.*?`:[^:]+:|(\*\*?|``?|\|)(?!\s)(?:(?!\2).)*\S\2(?=[\s\-.,:;!?\\\/'")\]}]|$))/m,lookbehind:!0,inside:{bold:{pattern:/(^\*\*).+(?=\*\*$)/,lookbehind:!0},italic:{pattern:/(^\*).+(?=\*$)/,lookbehind:!0},"inline-literal":{pattern:/(^``).+(?=``$)/,lookbehind:!0,alias:"symbol"},role:{pattern:/^:[^:]+:|:[^:]+:$/,alias:"function",inside:{punctuation:/^:|:$/}},"interpreted-text":{pattern:/(^`).+(?=`$)/,lookbehind:!0,alias:"attr-value"},substitution:{pattern:/(^\|).+(?=\|$)/,lookbehind:!0,alias:"attr-value"},punctuation:/\*\*?|``?|\|/}}],link:[{pattern:/\[[^\[\]]+\]_(?=[\s\-.,:;!?\\\/'")\]}]|$)/,alias:"string",inside:{punctuation:/^\[|\]_$/}},{pattern:/(?:\b[a-z\d]+(?:[_.:+][a-z\d]+)*_?_|`[^`]+`_?_|_`[^`]+`)(?=[\s\-.,:;!?\\\/'")\]}]|$)/i,alias:"string",inside:{punctuation:/^_?`|`$|`?_?_$/}}],punctuation:{pattern:/(^[\t ]*)(?:\|(?= |$)|(?:---?|—|\.\.|__)(?= )|\.\.$)/m,lookbehind:!0}}}return dE}var fE,hM;function Cme(){if(hM)return fE;hM=1,fE=e,e.displayName="rip",e.aliases=[];function e(t){t.languages.rip={comment:{pattern:/#.*/,greedy:!0},char:{pattern:/\B`[^\s`'",.:;#\/\\()<>\[\]{}]\b/,greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},regex:{pattern:/(^|[^/])\/(?!\/)(?:\[[^\n\r\]]*\]|\\.|[^/\\\r\n\[])+\/(?=\s*(?:$|[\r\n,.;})]))/,lookbehind:!0,greedy:!0},keyword:/(?:=>|->)|\b(?:case|catch|class|else|exit|finally|if|raise|return|switch|try)\b/,builtin:/@|\bSystem\b/,boolean:/\b(?:false|true)\b/,date:/\b\d{4}-\d{2}-\d{2}\b/,time:/\b\d{2}:\d{2}:\d{2}\b/,datetime:/\b\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\b/,symbol:/:[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/,number:/[+-]?\b(?:\d+\.\d+|\d+)\b/,punctuation:/(?:\.{2,3})|[`,.:;=\/\\()<>\[\]{}]/,reference:/[^\d\s`'",.:;#\/\\()<>\[\]{}][^\s`'",.:;#\/\\()<>\[\]{}]*/}}return fE}var pE,mM;function Nme(){if(mM)return pE;mM=1,pE=e,e.displayName="roboconf",e.aliases=[];function e(t){t.languages.roboconf={comment:/#.*/,keyword:{pattern:/(^|\s)(?:(?:external|import)\b|(?:facet|instance of)(?=[ \t]+[\w-]+[ \t]*\{))/,lookbehind:!0},component:{pattern:/[\w-]+(?=[ \t]*\{)/,alias:"variable"},property:/[\w.-]+(?=[ \t]*:)/,value:{pattern:/(=[ \t]*(?![ \t]))[^,;]+/,lookbehind:!0,alias:"attr-value"},optional:{pattern:/\(optional\)/,alias:"builtin"},wildcard:{pattern:/(\.)\*/,lookbehind:!0,alias:"operator"},punctuation:/[{},.;:=]/}}return pE}var gE,bM;function Ome(){if(bM)return gE;bM=1,gE=e,e.displayName="robotframework",e.aliases=[];function e(t){(function(n){var r={pattern:/(^[ \t]*| {2}|\t)#.*/m,lookbehind:!0,greedy:!0},a={pattern:/((?:^|[^\\])(?:\\{2})*)[$@&%]\{(?:[^{}\r\n]|\{[^{}\r\n]*\})*\}/,lookbehind:!0,inside:{punctuation:/^[$@&%]\{|\}$/}};function i(f,p){var g={};g["section-header"]={pattern:/^ ?\*{3}.+?\*{3}/,alias:"keyword"};for(var b in p)g[b]=p[b];return g.tag={pattern:/([\r\n](?: {2}|\t)[ \t]*)\[[-\w]+\]/,lookbehind:!0,inside:{punctuation:/\[|\]/}},g.variable=a,g.comment=r,{pattern:RegExp(/^ ?\*{3}[ \t]*<name>[ \t]*\*{3}(?:.|[\r\n](?!\*{3}))*/.source.replace(/<name>/g,function(){return f}),"im"),alias:"section",inside:g}}var l={pattern:/(\[Documentation\](?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},u={pattern:/([\r\n] ?)(?!#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,alias:"function",inside:{variable:a}},c={pattern:/([\r\n](?: {2}|\t)[ \t]*)(?!\[|\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0,inside:{variable:a}};n.languages.robotframework={settings:i("Settings",{documentation:{pattern:/([\r\n] ?Documentation(?: {2}|\t)[ \t]*)(?![ \t]|#)(?:.|(?:\r\n?|\n)[ \t]*\.{3})+/,lookbehind:!0,alias:"string"},property:{pattern:/([\r\n] ?)(?!\.{3}|#)(?:\S(?:[ \t]\S)*)+/,lookbehind:!0}}),variables:i("Variables"),"test-cases":i("Test Cases",{"test-name":u,documentation:l,property:c}),keywords:i("Keywords",{"keyword-name":u,documentation:l,property:c}),tasks:i("Tasks",{"task-name":u,documentation:l,property:c}),comment:r},n.languages.robot=n.languages.robotframework})(t)}return gE}var hE,yM;function Dme(){if(yM)return hE;yM=1,hE=e,e.displayName="rust",e.aliases=[];function e(t){(function(n){for(var r=/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|<self>)*\*\//.source,a=0;a<2;a++)r=r.replace(/<self>/g,function(){return r});r=r.replace(/<self>/g,function(){return/[^\s\S]/.source}),n.languages.rust={comment:[{pattern:RegExp(/(^|[^\\])/.source+r),lookbehind:!0,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],string:{pattern:/b?"(?:\\[\s\S]|[^\\"])*"|b?r(#*)"(?:[^"]|"(?!\1))*"\1/,greedy:!0},char:{pattern:/b?'(?:\\(?:x[0-7][\da-fA-F]|u\{(?:[\da-fA-F]_*){1,6}\}|.)|[^\\\r\n\t'])'/,greedy:!0},attribute:{pattern:/#!?\[(?:[^\[\]"]|"(?:\\[\s\S]|[^\\"])*")*\]/,greedy:!0,alias:"attr-name",inside:{string:null}},"closure-params":{pattern:/([=(,:]\s*|\bmove\s*)\|[^|]*\||\|[^|]*\|(?=\s*(?:\{|->))/,lookbehind:!0,greedy:!0,inside:{"closure-punctuation":{pattern:/^\||\|$/,alias:"punctuation"},rest:null}},"lifetime-annotation":{pattern:/'\w+/,alias:"symbol"},"fragment-specifier":{pattern:/(\$\w+:)[a-z]+/,lookbehind:!0,alias:"punctuation"},variable:/\$\w+/,"function-definition":{pattern:/(\bfn\s+)\w+/,lookbehind:!0,alias:"function"},"type-definition":{pattern:/(\b(?:enum|struct|trait|type|union)\s+)\w+/,lookbehind:!0,alias:"class-name"},"module-declaration":[{pattern:/(\b(?:crate|mod)\s+)[a-z][a-z_\d]*/,lookbehind:!0,alias:"namespace"},{pattern:/(\b(?:crate|self|super)\s*)::\s*[a-z][a-z_\d]*\b(?:\s*::(?:\s*[a-z][a-z_\d]*\s*::)*)?/,lookbehind:!0,alias:"namespace",inside:{punctuation:/::/}}],keyword:[/\b(?:Self|abstract|as|async|await|become|box|break|const|continue|crate|do|dyn|else|enum|extern|final|fn|for|if|impl|in|let|loop|macro|match|mod|move|mut|override|priv|pub|ref|return|self|static|struct|super|trait|try|type|typeof|union|unsafe|unsized|use|virtual|where|while|yield)\b/,/\b(?:bool|char|f(?:32|64)|[ui](?:8|16|32|64|128|size)|str)\b/],function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())/,macro:{pattern:/\b\w+!/,alias:"property"},constant:/\b[A-Z_][A-Z_\d]+\b/,"class-name":/\b[A-Z]\w*\b/,namespace:{pattern:/(?:\b[a-z][a-z_\d]*\s*::\s*)*\b[a-z][a-z_\d]*\s*::(?!\s*<)/,inside:{punctuation:/::/}},number:/\b(?:0x[\dA-Fa-f](?:_?[\dA-Fa-f])*|0o[0-7](?:_?[0-7])*|0b[01](?:_?[01])*|(?:(?:\d(?:_?\d)*)?\.)?\d(?:_?\d)*(?:[Ee][+-]?\d+)?)(?:_?(?:f32|f64|[iu](?:8|16|32|64|size)?))?\b/,boolean:/\b(?:false|true)\b/,punctuation:/->|\.\.=|\.{1,3}|::|[{}[\];(),:]/,operator:/[-+*\/%!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?=?|[@?]/},n.languages.rust["closure-params"].inside.rest=n.languages.rust,n.languages.rust.attribute.inside.string=n.languages.rust.string})(t)}return hE}var mE,vM;function Ime(){if(vM)return mE;vM=1,mE=e,e.displayName="sas",e.aliases=[];function e(t){(function(n){var r=/(?:"(?:""|[^"])*"(?!")|'(?:''|[^'])*'(?!'))/.source,a=/\b(?:\d[\da-f]*x|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,i={pattern:RegExp(r+"[bx]"),alias:"number"},l={pattern:/&[a-z_]\w*/i},u={pattern:/((?:^|\s|=|\())%(?:ABORT|BY|CMS|COPY|DISPLAY|DO|ELSE|END|EVAL|GLOBAL|GO|GOTO|IF|INC|INCLUDE|INDEX|INPUT|KTRIM|LENGTH|LET|LIST|LOCAL|PUT|QKTRIM|QSCAN|QSUBSTR|QSYSFUNC|QUPCASE|RETURN|RUN|SCAN|SUBSTR|SUPERQ|SYMDEL|SYMEXIST|SYMGLOBL|SYMLOCAL|SYSCALL|SYSEVALF|SYSEXEC|SYSFUNC|SYSGET|SYSRPUT|THEN|TO|TSO|UNQUOTE|UNTIL|UPCASE|WHILE|WINDOW)\b/i,lookbehind:!0,alias:"keyword"},c={pattern:/(^|\s)(?:proc\s+\w+|data(?!=)|quit|run)\b/i,alias:"keyword",lookbehind:!0},f=[/\/\*[\s\S]*?\*\//,{pattern:/(^[ \t]*|;\s*)\*[^;]*;/m,lookbehind:!0}],p={pattern:RegExp(r),greedy:!0},g=/[$%@.(){}\[\];,\\]/,b={pattern:/%?\b\w+(?=\()/,alias:"keyword"},m={function:b,"arg-value":{pattern:/(=\s*)[A-Z\.]+/i,lookbehind:!0},operator:/=/,"macro-variable":l,arg:{pattern:/[A-Z]+/i,alias:"keyword"},number:a,"numeric-constant":i,punctuation:g,string:p},S={pattern:/\b(?:format|put)\b=?[\w'$.]+/i,inside:{keyword:/^(?:format|put)(?==)/i,equals:/=/,format:{pattern:/(?:\w|\$\d)+\.\d?/,alias:"number"}}},v={pattern:/\b(?:format|put)\s+[\w']+(?:\s+[$.\w]+)+(?=;)/i,inside:{keyword:/^(?:format|put)/i,format:{pattern:/[\w$]+\.\d?/,alias:"number"}}},A={pattern:/((?:^|\s)=?)(?:catname|checkpoint execute_always|dm|endsas|filename|footnote|%include|libname|%list|lock|missing|options|page|resetline|%run|sasfile|skip|sysecho|title\d?)\b/i,lookbehind:!0,alias:"keyword"},R={pattern:/(^|\s)(?:submit(?:\s+(?:load|norun|parseonly))?|endsubmit)\b/i,lookbehind:!0,alias:"keyword"},x=/aStore|accessControl|aggregation|audio|autotune|bayesianNetClassifier|bioMedImage|boolRule|builtins|cardinality|cdm|clustering|conditionalRandomFields|configuration|copula|countreg|dataDiscovery|dataPreprocess|dataSciencePilot|dataStep|decisionTree|deduplication|deepLearn|deepNeural|deepRnn|ds2|ecm|entityRes|espCluster|explainModel|factmac|fastKnn|fcmpact|fedSql|freqTab|gVarCluster|gam|gleam|graphSemiSupLearn|hiddenMarkovModel|hyperGroup|ica|image|iml|kernalPca|langModel|ldaTopic|loadStreams|mbc|mixed|mlTools|modelPublishing|network|neuralNet|nmf|nonParametricBayes|nonlinear|optNetwork|optimization|panel|pca|percentile|phreg|pls|qkb|qlim|quantreg|recommend|regression|reinforcementLearn|robustPca|ruleMining|sampling|sandwich|sccasl|search(?:Analytics)?|sentimentAnalysis|sequence|session(?:Prop)?|severity|simSystem|simple|smartData|sparkEmbeddedProcess|sparseML|spatialreg|spc|stabilityMonitoring|svDataDescription|svm|table|text(?:Filters|Frequency|Mining|Parse|Rule(?:Develop|Score)|Topic|Util)|timeData|transpose|tsInfo|tsReconcile|uniTimeSeries|varReduce/.source,T={pattern:RegExp(/(^|\s)(?:action\s+)?(?:<act>)\.[a-z]+\b[^;]+/.source.replace(/<act>/g,function(){return x}),"i"),lookbehind:!0,inside:{keyword:RegExp(/(?:<act>)\.[a-z]+\b/.source.replace(/<act>/g,function(){return x}),"i"),action:{pattern:/(?:action)/i,alias:"keyword"},comment:f,function:b,"arg-value":m["arg-value"],operator:m.operator,argument:m.arg,number:a,"numeric-constant":i,punctuation:g,string:p}},C={pattern:/((?:^|\s)=?)(?:after|analysis|and|array|barchart|barwidth|begingraph|by|call|cas|cbarline|cfill|class(?:lev)?|close|column|computed?|contains|continue|data(?==)|define|delete|describe|document|do\s+over|do|dol|drop|dul|else|end(?:comp|source)?|entryTitle|eval(?:uate)?|exec(?:ute)?|exit|file(?:name)?|fill(?:attrs)?|flist|fnc|function(?:list)?|global|goto|group(?:by)?|headline|headskip|histogram|if|infile|keep|keylabel|keyword|label|layout|leave|legendlabel|length|libname|loadactionset|merge|midpoints|_?null_|name|noobs|nowd|ods|options|or|otherwise|out(?:put)?|over(?:lay)?|plot|print|put|raise|ranexp|rannor|rbreak|retain|return|select|session|sessref|set|source|statgraph|sum|summarize|table|temp|terminate|then\s+do|then|title\d?|to|var|when|where|xaxisopts|y2axisopts|yaxisopts)\b/i,lookbehind:!0};n.languages.sas={datalines:{pattern:/^([ \t]*)(?:cards|(?:data)?lines);[\s\S]+?^[ \t]*;/im,lookbehind:!0,alias:"string",inside:{keyword:{pattern:/^(?:cards|(?:data)?lines)/i},punctuation:/;/}},"proc-sql":{pattern:/(^proc\s+(?:fed)?sql(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{sql:{pattern:RegExp(/^[ \t]*(?:select|alter\s+table|(?:create|describe|drop)\s+(?:index|table(?:\s+constraints)?|view)|create\s+unique\s+index|insert\s+into|update)(?:<str>|[^;"'])+;/.source.replace(/<str>/g,function(){return r}),"im"),alias:"language-sql",inside:n.languages.sql},"global-statements":A,"sql-statements":{pattern:/(^|\s)(?:disconnect\s+from|begin|commit|exec(?:ute)?|reset|rollback|validate)\b/i,lookbehind:!0,alias:"keyword"},number:a,"numeric-constant":i,punctuation:g,string:p}},"proc-groovy":{pattern:/(^proc\s+groovy(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:f,groovy:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,alias:"language-groovy",inside:n.languages.groovy},keyword:C,"submit-statement":R,"global-statements":A,number:a,"numeric-constant":i,punctuation:g,string:p}},"proc-lua":{pattern:/(^proc\s+lua(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|data|quit|run);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:f,lua:{pattern:RegExp(/(^[ \t]*submit(?:\s+(?:load|norun|parseonly))?)(?:<str>|[^"'])+?(?=endsubmit;)/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,alias:"language-lua",inside:n.languages.lua},keyword:C,"submit-statement":R,"global-statements":A,number:a,"numeric-constant":i,punctuation:g,string:p}},"proc-cas":{pattern:/(^proc\s+cas(?:\s+[\w|=]+)?;)[\s\S]+?(?=^(?:proc\s+\w+|quit|data);|(?![\s\S]))/im,lookbehind:!0,inside:{comment:f,"statement-var":{pattern:/((?:^|\s)=?)saveresult\s[^;]+/im,lookbehind:!0,inside:{statement:{pattern:/^saveresult\s+\S+/i,inside:{keyword:/^(?:saveresult)/i}},rest:m}},"cas-actions":T,statement:{pattern:/((?:^|\s)=?)(?:default|(?:un)?set|on|output|upload)[^;]+/im,lookbehind:!0,inside:m},step:c,keyword:C,function:b,format:S,altformat:v,"global-statements":A,number:a,"numeric-constant":i,punctuation:g,string:p}},"proc-args":{pattern:RegExp(/(^proc\s+\w+\s+)(?!\s)(?:[^;"']|<str>)+;/.source.replace(/<str>/g,function(){return r}),"im"),lookbehind:!0,inside:m},"macro-keyword":u,"macro-variable":l,"macro-string-functions":{pattern:/((?:^|\s|=))%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)\(.*?(?:[^%]\))/i,lookbehind:!0,inside:{function:{pattern:/%(?:BQUOTE|NRBQUOTE|NRQUOTE|NRSTR|QUOTE|STR)/i,alias:"keyword"},"macro-keyword":u,"macro-variable":l,"escaped-char":{pattern:/%['"()<>=¬^~;,#]/},punctuation:g}},"macro-declaration":{pattern:/^%macro[^;]+(?=;)/im,inside:{keyword:/%macro/i}},"macro-end":{pattern:/^%mend[^;]+(?=;)/im,inside:{keyword:/%mend/i}},macro:{pattern:/%_\w+(?=\()/,alias:"keyword"},input:{pattern:/\binput\s[-\w\s/*.$&]+;/i,inside:{input:{alias:"keyword",pattern:/^input/i},comment:f,number:a,"numeric-constant":i}},"options-args":{pattern:/(^options)[-'"|/\\<>*+=:()\w\s]*(?=;)/im,lookbehind:!0,inside:m},"cas-actions":T,comment:f,function:b,format:S,altformat:v,"numeric-constant":i,datetime:{pattern:RegExp(r+"(?:dt?|t)"),alias:"number"},string:p,step:c,keyword:C,"operator-keyword":{pattern:/\b(?:eq|ge|gt|in|le|lt|ne|not)\b/i,alias:"operator"},number:a,operator:/\*\*?|\|\|?|!!?|¦¦?|<[>=]?|>[<=]?|[-+\/=&]|[~¬^]=?/,punctuation:g}})(t)}return mE}var bE,SM;function Lme(){if(SM)return bE;SM=1,bE=e,e.displayName="sass",e.aliases=[];function e(t){(function(n){n.languages.sass=n.languages.extend("css",{comment:{pattern:/^([ \t]*)\/[\/*].*(?:(?:\r?\n|\r)\1[ \t].+)*/m,lookbehind:!0,greedy:!0}}),n.languages.insertBefore("sass","atrule",{"atrule-line":{pattern:/^(?:[ \t]*)[@+=].+/m,greedy:!0,inside:{atrule:/(?:@[\w-]+|[+=])/}}}),delete n.languages.sass.atrule;var r=/\$[-\w]+|#\{\$[-\w]+\}/,a=[/[+*\/%]|[=!]=|<=?|>=?|\b(?:and|not|or)\b/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}];n.languages.insertBefore("sass","property",{"variable-line":{pattern:/^[ \t]*\$.+/m,greedy:!0,inside:{punctuation:/:/,variable:r,operator:a}},"property-line":{pattern:/^[ \t]*(?:[^:\s]+ *:.*|:[^:\s].*)/m,greedy:!0,inside:{property:[/[^:\s]+(?=\s*:)/,{pattern:/(:)[^:\s]+/,lookbehind:!0}],punctuation:/:/,variable:r,operator:a,important:n.languages.sass.important}}}),delete n.languages.sass.property,delete n.languages.sass.important,n.languages.insertBefore("sass","punctuation",{selector:{pattern:/^([ \t]*)\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*(?:,(?:\r?\n|\r)\1[ \t]+\S(?:,[^,\r\n]+|[^,\r\n]*)(?:,[^,\r\n]+)*)*/m,lookbehind:!0,greedy:!0}})})(t)}return bE}var yE,EM;function Mme(){if(EM)return yE;EM=1;var e=dA();yE=t,t.displayName="scala",t.aliases=[];function t(n){n.register(e),n.languages.scala=n.languages.extend("java",{"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,greedy:!0},keyword:/<-|=>|\b(?:abstract|case|catch|class|def|do|else|extends|final|finally|for|forSome|if|implicit|import|lazy|match|new|null|object|override|package|private|protected|return|sealed|self|super|this|throw|trait|try|type|val|var|while|with|yield)\b/,number:/\b0x(?:[\da-f]*\.)?[\da-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e\d+)?[dfl]?/i,builtin:/\b(?:Any|AnyRef|AnyVal|Boolean|Byte|Char|Double|Float|Int|Long|Nothing|Short|String|Unit)\b/,symbol:/'[^\d\s\\]\w*/}),n.languages.insertBefore("scala","triple-quoted-string",{"string-interpolation":{pattern:/\b[a-z]\w*(?:"""(?:[^$]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*?"""|"(?:[^$"\r\n]|\$(?:[^{]|\{(?:[^{}]|\{[^{}]*\})*\}))*")/i,greedy:!0,inside:{id:{pattern:/^\w+/,greedy:!0,alias:"function"},escape:{pattern:/\\\$"|\$[$"]/,greedy:!0,alias:"symbol"},interpolation:{pattern:/\$(?:\w+|\{(?:[^{}]|\{[^{}]*\})*\})/,greedy:!0,inside:{punctuation:/^\$\{?|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.scala}}},string:/[\s\S]+/}}}),delete n.languages.scala["class-name"],delete n.languages.scala.function}return yE}var vE,wM;function Fme(){if(wM)return vE;wM=1,vE=e,e.displayName="scss",e.aliases=[];function e(t){t.languages.scss=t.languages.extend("css",{comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},atrule:{pattern:/@[\w-](?:\([^()]+\)|[^()\s]|\s+(?!\s))*?(?=\s+[{;])/,inside:{rule:/@[\w-]+/}},url:/(?:[-a-z]+-)?url(?=\()/i,selector:{pattern:/(?=\S)[^@;{}()]?(?:[^@;{}()\s]|\s+(?!\s)|#\{\$[-\w]+\})+(?=\s*\{(?:\}|\s|[^}][^:{}]*[:{][^}]))/,inside:{parent:{pattern:/&/,alias:"important"},placeholder:/%[-\w]+/,variable:/\$[-\w]+|#\{\$[-\w]+\}/}},property:{pattern:/(?:[-\w]|\$[-\w]|#\{\$[-\w]+\})+(?=\s*:)/,inside:{variable:/\$[-\w]+|#\{\$[-\w]+\}/}}}),t.languages.insertBefore("scss","atrule",{keyword:[/@(?:content|debug|each|else(?: if)?|extend|for|forward|function|if|import|include|mixin|return|use|warn|while)\b/i,{pattern:/( )(?:from|through)(?= )/,lookbehind:!0}]}),t.languages.insertBefore("scss","important",{variable:/\$[-\w]+|#\{\$[-\w]+\}/}),t.languages.insertBefore("scss","function",{"module-modifier":{pattern:/\b(?:as|hide|show|with)\b/i,alias:"keyword"},placeholder:{pattern:/%[-\w]+/,alias:"selector"},statement:{pattern:/\B!(?:default|optional)\b/i,alias:"keyword"},boolean:/\b(?:false|true)\b/,null:{pattern:/\bnull\b/,alias:"keyword"},operator:{pattern:/(\s)(?:[-+*\/%]|[=!]=|<=?|>=?|and|not|or)(?=\s)/,lookbehind:!0}}),t.languages.scss.atrule.inside.rest=t.languages.scss}return vE}var SE,xM;function zme(){if(xM)return SE;xM=1;var e=V5();SE=t,t.displayName="shellSession",t.aliases=[];function t(n){n.register(e),function(r){var a=[/"(?:\\[\s\S]|\$\([^)]+\)|\$(?!\()|`[^`]+`|[^"\\`$])*"/.source,/'[^']*'/.source,/\$'(?:[^'\\]|\\[\s\S])*'/.source,/<<-?\s*(["']?)(\w+)\1\s[\s\S]*?[\r\n]\2/.source].join("|");r.languages["shell-session"]={command:{pattern:RegExp(/^/.source+"(?:"+(/[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+(?::[^\0-\x1F$#%*?"<>:;|]+)?/.source+"|"+/[/~.][^\0-\x1F$#%*?"<>@:;|]*/.source)+")?"+/[$#%](?=\s)/.source+/(?:[^\\\r\n \t'"<$]|[ \t](?:(?!#)|#.*$)|\\(?:[^\r]|\r\n?)|\$(?!')|<(?!<)|<<str>>)+/.source.replace(/<<str>>/g,function(){return a}),"m"),greedy:!0,inside:{info:{pattern:/^[^#$%]+/,alias:"punctuation",inside:{user:/^[^\s@:$#%*!/\\]+@[^\r\n@:$#%*!/\\]+/,punctuation:/:/,path:/[\s\S]+/}},bash:{pattern:/(^[$#%]\s*)\S[\s\S]*/,lookbehind:!0,alias:"language-bash",inside:r.languages.bash},"shell-symbol":{pattern:/^[$#%]/,alias:"important"}}},output:/.(?:.*(?:[\r\n]|.$))*/},r.languages["sh-session"]=r.languages.shellsession=r.languages["shell-session"]}(n)}return SE}var EE,kM;function Pme(){if(kM)return EE;kM=1,EE=e,e.displayName="smali",e.aliases=[];function e(t){t.languages.smali={comment:/#.*/,string:{pattern:/"(?:[^\r\n\\"]|\\.)*"|'(?:[^\r\n\\']|\\(?:.|u[\da-fA-F]{4}))'/,greedy:!0},"class-name":{pattern:/(^|[^L])L(?:(?:\w+|`[^`\r\n]*`)\/)*(?:[\w$]+|`[^`\r\n]*`)(?=\s*;)/,lookbehind:!0,inside:{"class-name":{pattern:/(^L|\/)(?:[\w$]+|`[^`\r\n]*`)$/,lookbehind:!0},namespace:{pattern:/^(L)(?:(?:\w+|`[^`\r\n]*`)\/)+/,lookbehind:!0,inside:{punctuation:/\//}},builtin:/^L/}},builtin:[{pattern:/([();\[])[BCDFIJSVZ]+/,lookbehind:!0},{pattern:/([\w$>]:)[BCDFIJSVZ]/,lookbehind:!0}],keyword:[{pattern:/(\.end\s+)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])\.(?!\d)[\w-]+/,lookbehind:!0},{pattern:/(^|[^\w.-])(?:abstract|annotation|bridge|constructor|enum|final|interface|private|protected|public|runtime|static|synthetic|system|transient)(?![\w.-])/,lookbehind:!0}],function:{pattern:/(^|[^\w.-])(?:\w+|<[\w$-]+>)(?=\()/,lookbehind:!0},field:{pattern:/[\w$]+(?=:)/,alias:"variable"},register:{pattern:/(^|[^\w.-])[vp]\d(?![\w.-])/,lookbehind:!0,alias:"variable"},boolean:{pattern:/(^|[^\w.-])(?:false|true)(?![\w.-])/,lookbehind:!0},number:{pattern:/(^|[^/\w.-])-?(?:NAN|INFINITY|0x(?:[\dA-F]+(?:\.[\dA-F]*)?|\.[\dA-F]+)(?:p[+-]?[\dA-F]+)?|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?)[dflst]?(?![\w.-])/i,lookbehind:!0},label:{pattern:/(:)\w+/,lookbehind:!0,alias:"property"},operator:/->|\.\.|[\[=]/,punctuation:/[{}(),;:]/}}return EE}var wE,AM;function Bme(){if(AM)return wE;AM=1,wE=e,e.displayName="smalltalk",e.aliases=[];function e(t){t.languages.smalltalk={comment:{pattern:/"(?:""|[^"])*"/,greedy:!0},char:{pattern:/\$./,greedy:!0},string:{pattern:/'(?:''|[^'])*'/,greedy:!0},symbol:/#[\da-z]+|#(?:-|([+\/\\*~<>=@%|&?!])\1?)|#(?=\()/i,"block-arguments":{pattern:/(\[\s*):[^\[|]*\|/,lookbehind:!0,inside:{variable:/:[\da-z]+/i,punctuation:/\|/}},"temporary-variables":{pattern:/\|[^|]+\|/,inside:{variable:/[\da-z]+/i,punctuation:/\|/}},keyword:/\b(?:new|nil|self|super)\b/,boolean:/\b(?:false|true)\b/,number:[/\d+r-?[\dA-Z]+(?:\.[\dA-Z]+)?(?:e-?\d+)?/,/\b\d+(?:\.\d+)?(?:e-?\d+)?/],operator:/[<=]=?|:=|~[~=]|\/\/?|\\\\|>[>=]?|[!^+\-*&|,@]/,punctuation:/[.;:?\[\](){}]/}}return wE}var xE,TM;function Ume(){if(TM)return xE;TM=1;var e=Gn();xE=t,t.displayName="smarty",t.aliases=[];function t(n){n.register(e),function(r){r.languages.smarty={comment:{pattern:/^\{\*[\s\S]*?\*\}/,greedy:!0},"embedded-php":{pattern:/^\{php\}[\s\S]*?\{\/php\}/,greedy:!0,inside:{smarty:{pattern:/^\{php\}|\{\/php\}$/,inside:null},php:{pattern:/[\s\S]+/,alias:"language-php",inside:r.languages.php}}},string:[{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0,inside:{interpolation:{pattern:/\{[^{}]*\}|`[^`]*`/,inside:{"interpolation-punctuation":{pattern:/^[{`]|[`}]$/,alias:"punctuation"},expression:{pattern:/[\s\S]+/,inside:null}}},variable:/\$\w+/}},{pattern:/'(?:\\.|[^'\\\r\n])*'/,greedy:!0}],keyword:{pattern:/(^\{\/?)[a-z_]\w*\b(?!\()/i,lookbehind:!0,greedy:!0},delimiter:{pattern:/^\{\/?|\}$/,greedy:!0,alias:"punctuation"},number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,variable:[/\$(?!\d)\w+/,/#(?!\d)\w+#/,{pattern:/(\.|->|\w\s*=)(?!\d)\w+\b(?!\()/,lookbehind:!0},{pattern:/(\[)(?!\d)\w+(?=\])/,lookbehind:!0}],function:{pattern:/(\|\s*)@?[a-z_]\w*|\b[a-z_]\w*(?=\()/i,lookbehind:!0},"attr-name":/\b[a-z_]\w*(?=\s*=)/i,boolean:/\b(?:false|no|off|on|true|yes)\b/,punctuation:/[\[\](){}.,:`]|->/,operator:[/[+\-*\/%]|==?=?|[!<>]=?|&&|\|\|?/,/\bis\s+(?:not\s+)?(?:div|even|odd)(?:\s+by)?\b/,/\b(?:and|eq|gt?e|gt|lt?e|lt|mod|neq?|not|or)\b/]},r.languages.smarty["embedded-php"].inside.smarty.inside=r.languages.smarty,r.languages.smarty.string[0].inside.interpolation.inside.expression.inside=r.languages.smarty;var a=/"(?:\\.|[^"\\\r\n])*"|'(?:\\.|[^'\\\r\n])*'/,i=RegExp(/\{\*[\s\S]*?\*\}/.source+"|"+/\{php\}[\s\S]*?\{\/php\}/.source+"|"+/\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>|\{(?:[^{}"']|<str>)*\})*\})*\}/.source.replace(/<str>/g,function(){return a.source}),"g");r.hooks.add("before-tokenize",function(l){var u="{literal}",c="{/literal}",f=!1;r.languages["markup-templating"].buildPlaceholders(l,"smarty",i,function(p){return p===c&&(f=!1),f?!1:(p===u&&(f=!0),!0)})}),r.hooks.add("after-tokenize",function(l){r.languages["markup-templating"].tokenizePlaceholders(l,"smarty")})}(n)}return xE}var kE,_M;function jme(){if(_M)return kE;_M=1,kE=e,e.displayName="sml",e.aliases=["smlnj"];function e(t){(function(n){var r=/\b(?:abstype|and|andalso|as|case|datatype|do|else|end|eqtype|exception|fn|fun|functor|handle|if|in|include|infix|infixr|let|local|nonfix|of|op|open|orelse|raise|rec|sharing|sig|signature|struct|structure|then|type|val|where|while|with|withtype)\b/i;n.languages.sml={comment:/\(\*(?:[^*(]|\*(?!\))|\((?!\*)|\(\*(?:[^*(]|\*(?!\))|\((?!\*))*\*\))*\*\)/,string:{pattern:/#?"(?:[^"\\]|\\.)*"/,greedy:!0},"class-name":[{pattern:RegExp(/((?:^|[^:]):\s*)<TERMINAL>(?:\s*(?:(?:\*|->)\s*<TERMINAL>|,\s*<TERMINAL>(?:(?=<NOT-LAST>)|(?!<NOT-LAST>)\s+<LONG-ID>)))*/.source.replace(/<NOT-LAST>/g,function(){return/\s*(?:[*,]|->)/.source}).replace(/<TERMINAL>/g,function(){return/(?:'[\w']*|<LONG-ID>|\((?:[^()]|\([^()]*\))*\)|\{(?:[^{}]|\{[^{}]*\})*\})(?:\s+<LONG-ID>)*/.source}).replace(/<LONG-ID>/g,function(){return/(?!<KEYWORD>)[a-z\d_][\w'.]*/.source}).replace(/<KEYWORD>/g,function(){return r.source}),"i"),lookbehind:!0,greedy:!0,inside:null},{pattern:/((?:^|[^\w'])(?:datatype|exception|functor|signature|structure|type)\s+)[a-z_][\w'.]*/i,lookbehind:!0}],function:{pattern:/((?:^|[^\w'])fun\s+)[a-z_][\w'.]*/i,lookbehind:!0},keyword:r,variable:{pattern:/(^|[^\w'])'[\w']*/,lookbehind:!0},number:/~?\b(?:\d+(?:\.\d+)?(?:e~?\d+)?|0x[\da-f]+)\b/i,word:{pattern:/\b0w(?:\d+|x[\da-f]+)\b/i,alias:"constant"},boolean:/\b(?:false|true)\b/i,operator:/\.\.\.|:[>=:]|=>?|->|[<>]=?|[!+\-*/^#|@~]/,punctuation:/[(){}\[\].:,;]/},n.languages.sml["class-name"][0].inside=n.languages.sml,n.languages.smlnj=n.languages.sml})(t)}return kE}var AE,RM;function Gme(){if(RM)return AE;RM=1,AE=e,e.displayName="solidity",e.aliases=["sol"];function e(t){t.languages.solidity=t.languages.extend("clike",{"class-name":{pattern:/(\b(?:contract|enum|interface|library|new|struct|using)\s+)(?!\d)[\w$]+/,lookbehind:!0},keyword:/\b(?:_|anonymous|as|assembly|assert|break|calldata|case|constant|constructor|continue|contract|default|delete|do|else|emit|enum|event|external|for|from|function|if|import|indexed|inherited|interface|internal|is|let|library|mapping|memory|modifier|new|payable|pragma|private|public|pure|require|returns?|revert|selfdestruct|solidity|storage|struct|suicide|switch|this|throw|using|var|view|while)\b/,operator:/=>|->|:=|=:|\*\*|\+\+|--|\|\||&&|<<=?|>>=?|[-+*/%^&|<>!=]=?|[~?]/}),t.languages.insertBefore("solidity","keyword",{builtin:/\b(?:address|bool|byte|u?int(?:8|16|24|32|40|48|56|64|72|80|88|96|104|112|120|128|136|144|152|160|168|176|184|192|200|208|216|224|232|240|248|256)?|string|bytes(?:[1-9]|[12]\d|3[0-2])?)\b/}),t.languages.insertBefore("solidity","number",{version:{pattern:/([<>]=?|\^)\d+\.\d+\.\d+\b/,lookbehind:!0,alias:"number"}}),t.languages.sol=t.languages.solidity}return AE}var TE,CM;function Hme(){if(CM)return TE;CM=1,TE=e,e.displayName="solutionFile",e.aliases=[];function e(t){(function(n){var r={pattern:/\{[\da-f]{8}-[\da-f]{4}-[\da-f]{4}-[\da-f]{4}-[\da-f]{12}\}/i,alias:"constant",inside:{punctuation:/[{}]/}};n.languages["solution-file"]={comment:{pattern:/#.*/,greedy:!0},string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,greedy:!0,inside:{guid:r}},object:{pattern:/^([ \t]*)(?:([A-Z]\w*)\b(?=.*(?:\r\n?|\n)(?:\1[ \t].*(?:\r\n?|\n))*\1End\2(?=[ \t]*$))|End[A-Z]\w*(?=[ \t]*$))/m,lookbehind:!0,greedy:!0,alias:"keyword"},property:{pattern:/^([ \t]*)(?!\s)[^\r\n"#=()]*[^\s"#=()](?=\s*=)/m,lookbehind:!0,inside:{guid:r}},guid:r,number:/\b\d+(?:\.\d+)*\b/,boolean:/\b(?:FALSE|TRUE)\b/,operator:/=/,punctuation:/[(),]/},n.languages.sln=n.languages["solution-file"]})(t)}return TE}var _E,NM;function $me(){if(NM)return _E;NM=1;var e=Gn();_E=t,t.displayName="soy",t.aliases=[];function t(n){n.register(e),function(r){var a=/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,i=/\b\d+(?:\.\d+)?(?:[eE][+-]?\d+)?\b|\b0x[\dA-F]+\b/;r.languages.soy={comment:[/\/\*[\s\S]*?\*\//,{pattern:/(\s)\/\/.*/,lookbehind:!0,greedy:!0}],"command-arg":{pattern:/(\{+\/?\s*(?:alias|call|delcall|delpackage|deltemplate|namespace|template)\s+)\.?[\w.]+/,lookbehind:!0,alias:"string",inside:{punctuation:/\./}},parameter:{pattern:/(\{+\/?\s*@?param\??\s+)\.?[\w.]+/,lookbehind:!0,alias:"variable"},keyword:[{pattern:/(\{+\/?[^\S\r\n]*)(?:\\[nrt]|alias|call|case|css|default|delcall|delpackage|deltemplate|else(?:if)?|fallbackmsg|for(?:each)?|if(?:empty)?|lb|let|literal|msg|namespace|nil|@?param\??|rb|sp|switch|template|xid)/,lookbehind:!0},/\b(?:any|as|attributes|bool|css|float|html|in|int|js|list|map|null|number|string|uri)\b/],delimiter:{pattern:/^\{+\/?|\/?\}+$/,alias:"punctuation"},property:/\w+(?==)/,variable:{pattern:/\$[^\W\d]\w*(?:\??(?:\.\w+|\[[^\]]+\]))*/,inside:{string:{pattern:a,greedy:!0},number:i,punctuation:/[\[\].?]/}},string:{pattern:a,greedy:!0},function:[/\w+(?=\()/,{pattern:/(\|[^\S\r\n]*)\w+/,lookbehind:!0}],boolean:/\b(?:false|true)\b/,number:i,operator:/\?:?|<=?|>=?|==?|!=|[+*/%-]|\b(?:and|not|or)\b/,punctuation:/[{}()\[\]|.,:]/},r.hooks.add("before-tokenize",function(l){var u=/\{\{.+?\}\}|\{.+?\}|\s\/\/.*|\/\*[\s\S]*?\*\//g,c="{literal}",f="{/literal}",p=!1;r.languages["markup-templating"].buildPlaceholders(l,"soy",u,function(g){return g===f&&(p=!1),p?!1:(g===c&&(p=!0),!0)})}),r.hooks.add("after-tokenize",function(l){r.languages["markup-templating"].tokenizePlaceholders(l,"soy")})}(n)}return _E}var RE,OM;function X5(){if(OM)return RE;OM=1,RE=e,e.displayName="turtle",e.aliases=[];function e(t){t.languages.turtle={comment:{pattern:/#.*/,greedy:!0},"multiline-string":{pattern:/"""(?:(?:""?)?(?:[^"\\]|\\.))*"""|'''(?:(?:''?)?(?:[^'\\]|\\.))*'''/,greedy:!0,alias:"string",inside:{comment:/#.*/}},string:{pattern:/"(?:[^\\"\r\n]|\\.)*"|'(?:[^\\'\r\n]|\\.)*'/,greedy:!0},url:{pattern:/<(?:[^\x00-\x20<>"{}|^`\\]|\\(?:u[\da-fA-F]{4}|U[\da-fA-F]{8}))*>/,greedy:!0,inside:{punctuation:/[<>]/}},function:{pattern:/(?:(?![-.\d\xB7])[-.\w\xB7\xC0-\uFFFD]+)?:(?:(?![-.])(?:[-.:\w\xC0-\uFFFD]|%[\da-f]{2}|\\.)+)?/i,inside:{"local-name":{pattern:/([^:]*:)[\s\S]+/,lookbehind:!0},prefix:{pattern:/[\s\S]+/,inside:{punctuation:/:/}}}},number:/[+-]?\b\d+(?:\.\d*)?(?:e[+-]?\d+)?/i,punctuation:/[{}.,;()[\]]|\^\^/,boolean:/\b(?:false|true)\b/,keyword:[/(?:\ba|@prefix|@base)\b|=/,/\b(?:base|graph|prefix)\b/i],tag:{pattern:/@[a-z]+(?:-[a-z\d]+)*/i,inside:{punctuation:/@/}}},t.languages.trig=t.languages.turtle}return RE}var CE,DM;function qme(){if(DM)return CE;DM=1;var e=X5();CE=t,t.displayName="sparql",t.aliases=["rq"];function t(n){n.register(e),n.languages.sparql=n.languages.extend("turtle",{boolean:/\b(?:false|true)\b/i,variable:{pattern:/[?$]\w+/,greedy:!0}}),n.languages.insertBefore("sparql","punctuation",{keyword:[/\b(?:A|ADD|ALL|AS|ASC|ASK|BNODE|BY|CLEAR|CONSTRUCT|COPY|CREATE|DATA|DEFAULT|DELETE|DESC|DESCRIBE|DISTINCT|DROP|EXISTS|FILTER|FROM|GROUP|HAVING|INSERT|INTO|LIMIT|LOAD|MINUS|MOVE|NAMED|NOT|NOW|OFFSET|OPTIONAL|ORDER|RAND|REDUCED|SELECT|SEPARATOR|SERVICE|SILENT|STRUUID|UNION|USING|UUID|VALUES|WHERE)\b/i,/\b(?:ABS|AVG|BIND|BOUND|CEIL|COALESCE|CONCAT|CONTAINS|COUNT|DATATYPE|DAY|ENCODE_FOR_URI|FLOOR|GROUP_CONCAT|HOURS|IF|IRI|isBLANK|isIRI|isLITERAL|isNUMERIC|isURI|LANG|LANGMATCHES|LCASE|MAX|MD5|MIN|MINUTES|MONTH|REGEX|REPLACE|ROUND|sameTerm|SAMPLE|SECONDS|SHA1|SHA256|SHA384|SHA512|STR|STRAFTER|STRBEFORE|STRDT|STRENDS|STRLANG|STRLEN|STRSTARTS|SUBSTR|SUM|TIMEZONE|TZ|UCASE|URI|YEAR)\b(?=\s*\()/i,/\b(?:BASE|GRAPH|PREFIX)\b/i]}),n.languages.rq=n.languages.sparql}return CE}var NE,IM;function Vme(){if(IM)return NE;IM=1,NE=e,e.displayName="splunkSpl",e.aliases=[];function e(t){t.languages["splunk-spl"]={comment:/`comment\("(?:\\.|[^\\"])*"\)`/,string:{pattern:/"(?:\\.|[^\\"])*"/,greedy:!0},keyword:/\b(?:abstract|accum|addcoltotals|addinfo|addtotals|analyzefields|anomalies|anomalousvalue|anomalydetection|append|appendcols|appendcsv|appendlookup|appendpipe|arules|associate|audit|autoregress|bin|bucket|bucketdir|chart|cluster|cofilter|collect|concurrency|contingency|convert|correlate|datamodel|dbinspect|dedup|delete|delta|diff|erex|eval|eventcount|eventstats|extract|fieldformat|fields|fieldsummary|filldown|fillnull|findtypes|folderize|foreach|format|from|gauge|gentimes|geom|geomfilter|geostats|head|highlight|history|iconify|input|inputcsv|inputlookup|iplocation|join|kmeans|kv|kvform|loadjob|localize|localop|lookup|makecontinuous|makemv|makeresults|map|mcollect|metadata|metasearch|meventcollect|mstats|multikv|multisearch|mvcombine|mvexpand|nomv|outlier|outputcsv|outputlookup|outputtext|overlap|pivot|predict|rangemap|rare|regex|relevancy|reltime|rename|replace|rest|return|reverse|rex|rtorder|run|savedsearch|script|scrub|search|searchtxn|selfjoin|sendemail|set|setfields|sichart|sirare|sistats|sitimechart|sitop|sort|spath|stats|strcat|streamstats|table|tags|tail|timechart|timewrap|top|transaction|transpose|trendline|tscollect|tstats|typeahead|typelearner|typer|union|uniq|untable|where|x11|xmlkv|xmlunescape|xpath|xyseries)\b/i,"operator-word":{pattern:/\b(?:and|as|by|not|or|xor)\b/i,alias:"operator"},function:/\b\w+(?=\s*\()/,property:/\b\w+(?=\s*=(?!=))/,date:{pattern:/\b\d{1,2}\/\d{1,2}\/\d{1,4}(?:(?::\d{1,2}){3})?\b/,alias:"number"},number:/\b\d+(?:\.\d+)?\b/,boolean:/\b(?:f|false|t|true)\b/i,operator:/[<>=]=?|[-+*/%|]/,punctuation:/[()[\],]/}}return NE}var OE,LM;function Wme(){if(LM)return OE;LM=1,OE=e,e.displayName="sqf",e.aliases=[];function e(t){t.languages.sqf=t.languages.extend("clike",{string:{pattern:/"(?:(?:"")?[^"])*"(?!")|'(?:[^'])*'/,greedy:!0},keyword:/\b(?:breakOut|breakTo|call|case|catch|default|do|echo|else|execFSM|execVM|exitWith|for|forEach|forEachMember|forEachMemberAgent|forEachMemberTeam|from|goto|if|nil|preprocessFile|preprocessFileLineNumbers|private|scopeName|spawn|step|switch|then|throw|to|try|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\b(?:abs|accTime|acos|action|actionIDs|actionKeys|actionKeysImages|actionKeysNames|actionKeysNamesArray|actionName|actionParams|activateAddons|activatedAddons|activateKey|add3DENConnection|add3DENEventHandler|add3DENLayer|addAction|addBackpack|addBackpackCargo|addBackpackCargoGlobal|addBackpackGlobal|addCamShake|addCuratorAddons|addCuratorCameraArea|addCuratorEditableObjects|addCuratorEditingArea|addCuratorPoints|addEditorObject|addEventHandler|addForce|addForceGeneratorRTD|addGoggles|addGroupIcon|addHandgunItem|addHeadgear|addItem|addItemCargo|addItemCargoGlobal|addItemPool|addItemToBackpack|addItemToUniform|addItemToVest|addLiveStats|addMagazine|addMagazineAmmoCargo|addMagazineCargo|addMagazineCargoGlobal|addMagazineGlobal|addMagazinePool|addMagazines|addMagazineTurret|addMenu|addMenuItem|addMissionEventHandler|addMPEventHandler|addMusicEventHandler|addOwnedMine|addPlayerScores|addPrimaryWeaponItem|addPublicVariableEventHandler|addRating|addResources|addScore|addScoreSide|addSecondaryWeaponItem|addSwitchableUnit|addTeamMember|addToRemainsCollector|addTorque|addUniform|addVehicle|addVest|addWaypoint|addWeapon|addWeaponCargo|addWeaponCargoGlobal|addWeaponGlobal|addWeaponItem|addWeaponPool|addWeaponTurret|admin|agent|agents|AGLToASL|aimedAtTarget|aimPos|airDensityCurveRTD|airDensityRTD|airplaneThrottle|airportSide|AISFinishHeal|alive|all3DENEntities|allAirports|allControls|allCurators|allCutLayers|allDead|allDeadMen|allDisplays|allGroups|allMapMarkers|allMines|allMissionObjects|allow3DMode|allowCrewInImmobile|allowCuratorLogicIgnoreAreas|allowDamage|allowDammage|allowFileOperations|allowFleeing|allowGetIn|allowSprint|allPlayers|allSimpleObjects|allSites|allTurrets|allUnits|allUnitsUAV|allVariables|ammo|ammoOnPylon|animate|animateBay|animateDoor|animatePylon|animateSource|animationNames|animationPhase|animationSourcePhase|animationState|append|apply|armoryPoints|arrayIntersect|asin|ASLToAGL|ASLToATL|assert|assignAsCargo|assignAsCargoIndex|assignAsCommander|assignAsDriver|assignAsGunner|assignAsTurret|assignCurator|assignedCargo|assignedCommander|assignedDriver|assignedGunner|assignedItems|assignedTarget|assignedTeam|assignedVehicle|assignedVehicleRole|assignItem|assignTeam|assignToAirport|atan|atan2|atg|ATLToASL|attachedObject|attachedObjects|attachedTo|attachObject|attachTo|attackEnabled|backpack|backpackCargo|backpackContainer|backpackItems|backpackMagazines|backpackSpaceFor|behaviour|benchmark|binocular|blufor|boundingBox|boundingBoxReal|boundingCenter|briefingName|buildingExit|buildingPos|buldozer_EnableRoadDiag|buldozer_IsEnabledRoadDiag|buldozer_LoadNewRoads|buldozer_reloadOperMap|buttonAction|buttonSetAction|cadetMode|callExtension|camCommand|camCommit|camCommitPrepared|camCommitted|camConstuctionSetParams|camCreate|camDestroy|cameraEffect|cameraEffectEnableHUD|cameraInterest|cameraOn|cameraView|campaignConfigFile|camPreload|camPreloaded|camPrepareBank|camPrepareDir|camPrepareDive|camPrepareFocus|camPrepareFov|camPrepareFovRange|camPreparePos|camPrepareRelPos|camPrepareTarget|camSetBank|camSetDir|camSetDive|camSetFocus|camSetFov|camSetFovRange|camSetPos|camSetRelPos|camSetTarget|camTarget|camUseNVG|canAdd|canAddItemToBackpack|canAddItemToUniform|canAddItemToVest|cancelSimpleTaskDestination|canFire|canMove|canSlingLoad|canStand|canSuspend|canTriggerDynamicSimulation|canUnloadInCombat|canVehicleCargo|captive|captiveNum|cbChecked|cbSetChecked|ceil|channelEnabled|cheatsEnabled|checkAIFeature|checkVisibility|civilian|className|clear3DENAttribute|clear3DENInventory|clearAllItemsFromBackpack|clearBackpackCargo|clearBackpackCargoGlobal|clearForcesRTD|clearGroupIcons|clearItemCargo|clearItemCargoGlobal|clearItemPool|clearMagazineCargo|clearMagazineCargoGlobal|clearMagazinePool|clearOverlay|clearRadio|clearVehicleInit|clearWeaponCargo|clearWeaponCargoGlobal|clearWeaponPool|clientOwner|closeDialog|closeDisplay|closeOverlay|collapseObjectTree|collect3DENHistory|collectiveRTD|combatMode|commandArtilleryFire|commandChat|commander|commandFire|commandFollow|commandFSM|commandGetOut|commandingMenu|commandMove|commandRadio|commandStop|commandSuppressiveFire|commandTarget|commandWatch|comment|commitOverlay|compile|compileFinal|completedFSM|composeText|configClasses|configFile|configHierarchy|configName|configNull|configProperties|configSourceAddonList|configSourceMod|configSourceModList|confirmSensorTarget|connectTerminalToUAV|controlNull|controlsGroupCtrl|copyFromClipboard|copyToClipboard|copyWaypoints|cos|count|countEnemy|countFriendly|countSide|countType|countUnknown|create3DENComposition|create3DENEntity|createAgent|createCenter|createDialog|createDiaryLink|createDiaryRecord|createDiarySubject|createDisplay|createGearDialog|createGroup|createGuardedPoint|createLocation|createMarker|createMarkerLocal|createMenu|createMine|createMissionDisplay|createMPCampaignDisplay|createSimpleObject|createSimpleTask|createSite|createSoundSource|createTask|createTeam|createTrigger|createUnit|createVehicle|createVehicleCrew|createVehicleLocal|crew|ctAddHeader|ctAddRow|ctClear|ctCurSel|ctData|ctFindHeaderRows|ctFindRowHeader|ctHeaderControls|ctHeaderCount|ctRemoveHeaders|ctRemoveRows|ctrlActivate|ctrlAddEventHandler|ctrlAngle|ctrlAutoScrollDelay|ctrlAutoScrollRewind|ctrlAutoScrollSpeed|ctrlChecked|ctrlClassName|ctrlCommit|ctrlCommitted|ctrlCreate|ctrlDelete|ctrlEnable|ctrlEnabled|ctrlFade|ctrlHTMLLoaded|ctrlIDC|ctrlIDD|ctrlMapAnimAdd|ctrlMapAnimClear|ctrlMapAnimCommit|ctrlMapAnimDone|ctrlMapCursor|ctrlMapMouseOver|ctrlMapScale|ctrlMapScreenToWorld|ctrlMapWorldToScreen|ctrlModel|ctrlModelDirAndUp|ctrlModelScale|ctrlParent|ctrlParentControlsGroup|ctrlPosition|ctrlRemoveAllEventHandlers|ctrlRemoveEventHandler|ctrlScale|ctrlSetActiveColor|ctrlSetAngle|ctrlSetAutoScrollDelay|ctrlSetAutoScrollRewind|ctrlSetAutoScrollSpeed|ctrlSetBackgroundColor|ctrlSetChecked|ctrlSetDisabledColor|ctrlSetEventHandler|ctrlSetFade|ctrlSetFocus|ctrlSetFont|ctrlSetFontH1|ctrlSetFontH1B|ctrlSetFontH2|ctrlSetFontH2B|ctrlSetFontH3|ctrlSetFontH3B|ctrlSetFontH4|ctrlSetFontH4B|ctrlSetFontH5|ctrlSetFontH5B|ctrlSetFontH6|ctrlSetFontH6B|ctrlSetFontHeight|ctrlSetFontHeightH1|ctrlSetFontHeightH2|ctrlSetFontHeightH3|ctrlSetFontHeightH4|ctrlSetFontHeightH5|ctrlSetFontHeightH6|ctrlSetFontHeightSecondary|ctrlSetFontP|ctrlSetFontPB|ctrlSetFontSecondary|ctrlSetForegroundColor|ctrlSetModel|ctrlSetModelDirAndUp|ctrlSetModelScale|ctrlSetPixelPrecision|ctrlSetPosition|ctrlSetScale|ctrlSetStructuredText|ctrlSetText|ctrlSetTextColor|ctrlSetTextColorSecondary|ctrlSetTextSecondary|ctrlSetTooltip|ctrlSetTooltipColorBox|ctrlSetTooltipColorShade|ctrlSetTooltipColorText|ctrlShow|ctrlShown|ctrlText|ctrlTextHeight|ctrlTextSecondary|ctrlTextWidth|ctrlType|ctrlVisible|ctRowControls|ctRowCount|ctSetCurSel|ctSetData|ctSetHeaderTemplate|ctSetRowTemplate|ctSetValue|ctValue|curatorAddons|curatorCamera|curatorCameraArea|curatorCameraAreaCeiling|curatorCoef|curatorEditableObjects|curatorEditingArea|curatorEditingAreaType|curatorMouseOver|curatorPoints|curatorRegisteredObjects|curatorSelected|curatorWaypointCost|current3DENOperation|currentChannel|currentCommand|currentMagazine|currentMagazineDetail|currentMagazineDetailTurret|currentMagazineTurret|currentMuzzle|currentNamespace|currentTask|currentTasks|currentThrowable|currentVisionMode|currentWaypoint|currentWeapon|currentWeaponMode|currentWeaponTurret|currentZeroing|cursorObject|cursorTarget|customChat|customRadio|cutFadeOut|cutObj|cutRsc|cutText|damage|date|dateToNumber|daytime|deActivateKey|debriefingText|debugFSM|debugLog|deg|delete3DENEntities|deleteAt|deleteCenter|deleteCollection|deleteEditorObject|deleteGroup|deleteGroupWhenEmpty|deleteIdentity|deleteLocation|deleteMarker|deleteMarkerLocal|deleteRange|deleteResources|deleteSite|deleteStatus|deleteTeam|deleteVehicle|deleteVehicleCrew|deleteWaypoint|detach|detectedMines|diag_activeMissionFSMs|diag_activeScripts|diag_activeSQFScripts|diag_activeSQSScripts|diag_captureFrame|diag_captureFrameToFile|diag_captureSlowFrame|diag_codePerformance|diag_drawMode|diag_dynamicSimulationEnd|diag_enable|diag_enabled|diag_fps|diag_fpsMin|diag_frameNo|diag_lightNewLoad|diag_list|diag_log|diag_logSlowFrame|diag_mergeConfigFile|diag_recordTurretLimits|diag_setLightNew|diag_tickTime|diag_toggle|dialog|diarySubjectExists|didJIP|didJIPOwner|difficulty|difficultyEnabled|difficultyEnabledRTD|difficultyOption|direction|directSay|disableAI|disableCollisionWith|disableConversation|disableDebriefingStats|disableMapIndicators|disableNVGEquipment|disableRemoteSensors|disableSerialization|disableTIEquipment|disableUAVConnectability|disableUserInput|displayAddEventHandler|displayCtrl|displayNull|displayParent|displayRemoveAllEventHandlers|displayRemoveEventHandler|displaySetEventHandler|dissolveTeam|distance|distance2D|distanceSqr|distributionRegion|do3DENAction|doArtilleryFire|doFire|doFollow|doFSM|doGetOut|doMove|doorPhase|doStop|doSuppressiveFire|doTarget|doWatch|drawArrow|drawEllipse|drawIcon|drawIcon3D|drawLine|drawLine3D|drawLink|drawLocation|drawPolygon|drawRectangle|drawTriangle|driver|drop|dynamicSimulationDistance|dynamicSimulationDistanceCoef|dynamicSimulationEnabled|dynamicSimulationSystemEnabled|east|edit3DENMissionAttributes|editObject|editorSetEventHandler|effectiveCommander|emptyPositions|enableAI|enableAIFeature|enableAimPrecision|enableAttack|enableAudioFeature|enableAutoStartUpRTD|enableAutoTrimRTD|enableCamShake|enableCaustics|enableChannel|enableCollisionWith|enableCopilot|enableDebriefingStats|enableDiagLegend|enableDynamicSimulation|enableDynamicSimulationSystem|enableEndDialog|enableEngineArtillery|enableEnvironment|enableFatigue|enableGunLights|enableInfoPanelComponent|enableIRLasers|enableMimics|enablePersonTurret|enableRadio|enableReload|enableRopeAttach|enableSatNormalOnDetail|enableSaving|enableSentences|enableSimulation|enableSimulationGlobal|enableStamina|enableStressDamage|enableTeamSwitch|enableTraffic|enableUAVConnectability|enableUAVWaypoints|enableVehicleCargo|enableVehicleSensor|enableWeaponDisassembly|endl|endLoadingScreen|endMission|engineOn|enginesIsOnRTD|enginesPowerRTD|enginesRpmRTD|enginesTorqueRTD|entities|environmentEnabled|estimatedEndServerTime|estimatedTimeLeft|evalObjectArgument|everyBackpack|everyContainer|exec|execEditorScript|exp|expectedDestination|exportJIPMessages|eyeDirection|eyePos|face|faction|fadeMusic|fadeRadio|fadeSound|fadeSpeech|failMission|fillWeaponsFromPool|find|findCover|findDisplay|findEditorObject|findEmptyPosition|findEmptyPositionReady|findIf|findNearestEnemy|finishMissionInit|finite|fire|fireAtTarget|firstBackpack|flag|flagAnimationPhase|flagOwner|flagSide|flagTexture|fleeing|floor|flyInHeight|flyInHeightASL|fog|fogForecast|fogParams|forceAddUniform|forceAtPositionRTD|forcedMap|forceEnd|forceFlagTexture|forceFollowRoad|forceGeneratorRTD|forceMap|forceRespawn|forceSpeed|forceWalk|forceWeaponFire|forceWeatherChange|forgetTarget|format|formation|formationDirection|formationLeader|formationMembers|formationPosition|formationTask|formatText|formLeader|freeLook|fromEditor|fuel|fullCrew|gearIDCAmmoCount|gearSlotAmmoCount|gearSlotData|get3DENActionState|get3DENAttribute|get3DENCamera|get3DENConnections|get3DENEntity|get3DENEntityID|get3DENGrid|get3DENIconsVisible|get3DENLayerEntities|get3DENLinesVisible|get3DENMissionAttribute|get3DENMouseOver|get3DENSelected|getAimingCoef|getAllEnvSoundControllers|getAllHitPointsDamage|getAllOwnedMines|getAllSoundControllers|getAmmoCargo|getAnimAimPrecision|getAnimSpeedCoef|getArray|getArtilleryAmmo|getArtilleryComputerSettings|getArtilleryETA|getAssignedCuratorLogic|getAssignedCuratorUnit|getBackpackCargo|getBleedingRemaining|getBurningValue|getCameraViewDirection|getCargoIndex|getCenterOfMass|getClientState|getClientStateNumber|getCompatiblePylonMagazines|getConnectedUAV|getContainerMaxLoad|getCursorObjectParams|getCustomAimCoef|getDammage|getDescription|getDir|getDirVisual|getDLCAssetsUsage|getDLCAssetsUsageByName|getDLCs|getDLCUsageTime|getEditorCamera|getEditorMode|getEditorObjectScope|getElevationOffset|getEngineTargetRpmRTD|getEnvSoundController|getFatigue|getFieldManualStartPage|getForcedFlagTexture|getFriend|getFSMVariable|getFuelCargo|getGroupIcon|getGroupIconParams|getGroupIcons|getHideFrom|getHit|getHitIndex|getHitPointDamage|getItemCargo|getMagazineCargo|getMarkerColor|getMarkerPos|getMarkerSize|getMarkerType|getMass|getMissionConfig|getMissionConfigValue|getMissionDLCs|getMissionLayerEntities|getMissionLayers|getModelInfo|getMousePosition|getMusicPlayedTime|getNumber|getObjectArgument|getObjectChildren|getObjectDLC|getObjectMaterials|getObjectProxy|getObjectTextures|getObjectType|getObjectViewDistance|getOxygenRemaining|getPersonUsedDLCs|getPilotCameraDirection|getPilotCameraPosition|getPilotCameraRotation|getPilotCameraTarget|getPlateNumber|getPlayerChannel|getPlayerScores|getPlayerUID|getPlayerUIDOld|getPos|getPosASL|getPosASLVisual|getPosASLW|getPosATL|getPosATLVisual|getPosVisual|getPosWorld|getPylonMagazines|getRelDir|getRelPos|getRemoteSensorsDisabled|getRepairCargo|getResolution|getRotorBrakeRTD|getShadowDistance|getShotParents|getSlingLoad|getSoundController|getSoundControllerResult|getSpeed|getStamina|getStatValue|getSuppression|getTerrainGrid|getTerrainHeightASL|getText|getTotalDLCUsageTime|getTrimOffsetRTD|getUnitLoadout|getUnitTrait|getUserMFDText|getUserMFDValue|getVariable|getVehicleCargo|getWeaponCargo|getWeaponSway|getWingsOrientationRTD|getWingsPositionRTD|getWPPos|glanceAt|globalChat|globalRadio|goggles|group|groupChat|groupFromNetId|groupIconSelectable|groupIconsVisible|groupId|groupOwner|groupRadio|groupSelectedUnits|groupSelectUnit|grpNull|gunner|gusts|halt|handgunItems|handgunMagazine|handgunWeapon|handsHit|hasInterface|hasPilotCamera|hasWeapon|hcAllGroups|hcGroupParams|hcLeader|hcRemoveAllGroups|hcRemoveGroup|hcSelected|hcSelectGroup|hcSetGroup|hcShowBar|hcShownBar|headgear|hideBody|hideObject|hideObjectGlobal|hideSelection|hint|hintC|hintCadet|hintSilent|hmd|hostMission|htmlLoad|HUDMovementLevels|humidity|image|importAllGroups|importance|in|inArea|inAreaArray|incapacitatedState|independent|inflame|inflamed|infoPanel|infoPanelComponentEnabled|infoPanelComponents|infoPanels|inGameUISetEventHandler|inheritsFrom|initAmbientLife|inPolygon|inputAction|inRangeOfArtillery|insertEditorObject|intersect|is3DEN|is3DENMultiplayer|isAbleToBreathe|isAgent|isAimPrecisionEnabled|isArray|isAutoHoverOn|isAutonomous|isAutoStartUpEnabledRTD|isAutotest|isAutoTrimOnRTD|isBleeding|isBurning|isClass|isCollisionLightOn|isCopilotEnabled|isDamageAllowed|isDedicated|isDLCAvailable|isEngineOn|isEqualTo|isEqualType|isEqualTypeAll|isEqualTypeAny|isEqualTypeArray|isEqualTypeParams|isFilePatchingEnabled|isFlashlightOn|isFlatEmpty|isForcedWalk|isFormationLeader|isGroupDeletedWhenEmpty|isHidden|isInRemainsCollector|isInstructorFigureEnabled|isIRLaserOn|isKeyActive|isKindOf|isLaserOn|isLightOn|isLocalized|isManualFire|isMarkedForCollection|isMultiplayer|isMultiplayerSolo|isNil|isNull|isNumber|isObjectHidden|isObjectRTD|isOnRoad|isPipEnabled|isPlayer|isRealTime|isRemoteExecuted|isRemoteExecutedJIP|isServer|isShowing3DIcons|isSimpleObject|isSprintAllowed|isStaminaEnabled|isSteamMission|isStreamFriendlyUIEnabled|isStressDamageEnabled|isText|isTouchingGround|isTurnedOut|isTutHintsEnabled|isUAVConnectable|isUAVConnected|isUIContext|isUniformAllowed|isVehicleCargo|isVehicleRadarOn|isVehicleSensorEnabled|isWalking|isWeaponDeployed|isWeaponRested|itemCargo|items|itemsWithMagazines|join|joinAs|joinAsSilent|joinSilent|joinString|kbAddDatabase|kbAddDatabaseTargets|kbAddTopic|kbHasTopic|kbReact|kbRemoveTopic|kbTell|kbWasSaid|keyImage|keyName|knowsAbout|land|landAt|landResult|language|laserTarget|lbAdd|lbClear|lbColor|lbColorRight|lbCurSel|lbData|lbDelete|lbIsSelected|lbPicture|lbPictureRight|lbSelection|lbSetColor|lbSetColorRight|lbSetCurSel|lbSetData|lbSetPicture|lbSetPictureColor|lbSetPictureColorDisabled|lbSetPictureColorSelected|lbSetPictureRight|lbSetPictureRightColor|lbSetPictureRightColorDisabled|lbSetPictureRightColorSelected|lbSetSelectColor|lbSetSelectColorRight|lbSetSelected|lbSetText|lbSetTextRight|lbSetTooltip|lbSetValue|lbSize|lbSort|lbSortByValue|lbText|lbTextRight|lbValue|leader|leaderboardDeInit|leaderboardGetRows|leaderboardInit|leaderboardRequestRowsFriends|leaderboardRequestRowsGlobal|leaderboardRequestRowsGlobalAroundUser|leaderboardsRequestUploadScore|leaderboardsRequestUploadScoreKeepBest|leaderboardState|leaveVehicle|libraryCredits|libraryDisclaimers|lifeState|lightAttachObject|lightDetachObject|lightIsOn|lightnings|limitSpeed|linearConversion|lineBreak|lineIntersects|lineIntersectsObjs|lineIntersectsSurfaces|lineIntersectsWith|linkItem|list|listObjects|listRemoteTargets|listVehicleSensors|ln|lnbAddArray|lnbAddColumn|lnbAddRow|lnbClear|lnbColor|lnbColorRight|lnbCurSelRow|lnbData|lnbDeleteColumn|lnbDeleteRow|lnbGetColumnsPosition|lnbPicture|lnbPictureRight|lnbSetColor|lnbSetColorRight|lnbSetColumnsPos|lnbSetCurSelRow|lnbSetData|lnbSetPicture|lnbSetPictureColor|lnbSetPictureColorRight|lnbSetPictureColorSelected|lnbSetPictureColorSelectedRight|lnbSetPictureRight|lnbSetText|lnbSetTextRight|lnbSetValue|lnbSize|lnbSort|lnbSortByValue|lnbText|lnbTextRight|lnbValue|load|loadAbs|loadBackpack|loadFile|loadGame|loadIdentity|loadMagazine|loadOverlay|loadStatus|loadUniform|loadVest|local|localize|locationNull|locationPosition|lock|lockCameraTo|lockCargo|lockDriver|locked|lockedCargo|lockedDriver|lockedTurret|lockIdentity|lockTurret|lockWP|log|logEntities|logNetwork|logNetworkTerminate|lookAt|lookAtPos|magazineCargo|magazines|magazinesAllTurrets|magazinesAmmo|magazinesAmmoCargo|magazinesAmmoFull|magazinesDetail|magazinesDetailBackpack|magazinesDetailUniform|magazinesDetailVest|magazinesTurret|magazineTurretAmmo|mapAnimAdd|mapAnimClear|mapAnimCommit|mapAnimDone|mapCenterOnCamera|mapGridPosition|markAsFinishedOnSteam|markerAlpha|markerBrush|markerColor|markerDir|markerPos|markerShape|markerSize|markerText|markerType|max|members|menuAction|menuAdd|menuChecked|menuClear|menuCollapse|menuData|menuDelete|menuEnable|menuEnabled|menuExpand|menuHover|menuPicture|menuSetAction|menuSetCheck|menuSetData|menuSetPicture|menuSetValue|menuShortcut|menuShortcutText|menuSize|menuSort|menuText|menuURL|menuValue|min|mineActive|mineDetectedBy|missionConfigFile|missionDifficulty|missionName|missionNamespace|missionStart|missionVersion|modelToWorld|modelToWorldVisual|modelToWorldVisualWorld|modelToWorldWorld|modParams|moonIntensity|moonPhase|morale|move|move3DENCamera|moveInAny|moveInCargo|moveInCommander|moveInDriver|moveInGunner|moveInTurret|moveObjectToEnd|moveOut|moveTime|moveTo|moveToCompleted|moveToFailed|musicVolume|name|nameSound|nearEntities|nearestBuilding|nearestLocation|nearestLocations|nearestLocationWithDubbing|nearestObject|nearestObjects|nearestTerrainObjects|nearObjects|nearObjectsReady|nearRoads|nearSupplies|nearTargets|needReload|netId|netObjNull|newOverlay|nextMenuItemIndex|nextWeatherChange|nMenuItems|numberOfEnginesRTD|numberToDate|objectCurators|objectFromNetId|objectParent|objNull|objStatus|onBriefingGear|onBriefingGroup|onBriefingNotes|onBriefingPlan|onBriefingTeamSwitch|onCommandModeChanged|onDoubleClick|onEachFrame|onGroupIconClick|onGroupIconOverEnter|onGroupIconOverLeave|onHCGroupSelectionChanged|onMapSingleClick|onPlayerConnected|onPlayerDisconnected|onPreloadFinished|onPreloadStarted|onShowNewObject|onTeamSwitch|openCuratorInterface|openDLCPage|openDSInterface|openMap|openSteamApp|openYoutubeVideo|opfor|orderGetIn|overcast|overcastForecast|owner|param|params|parseNumber|parseSimpleArray|parseText|parsingNamespace|particlesQuality|pi|pickWeaponPool|pitch|pixelGrid|pixelGridBase|pixelGridNoUIScale|pixelH|pixelW|playableSlotsNumber|playableUnits|playAction|playActionNow|player|playerRespawnTime|playerSide|playersNumber|playGesture|playMission|playMove|playMoveNow|playMusic|playScriptedMission|playSound|playSound3D|position|positionCameraToWorld|posScreenToWorld|posWorldToScreen|ppEffectAdjust|ppEffectCommit|ppEffectCommitted|ppEffectCreate|ppEffectDestroy|ppEffectEnable|ppEffectEnabled|ppEffectForceInNVG|precision|preloadCamera|preloadObject|preloadSound|preloadTitleObj|preloadTitleRsc|primaryWeapon|primaryWeaponItems|primaryWeaponMagazine|priority|processDiaryLink|processInitCommands|productVersion|profileName|profileNamespace|profileNameSteam|progressLoadingScreen|progressPosition|progressSetPosition|publicVariable|publicVariableClient|publicVariableServer|pushBack|pushBackUnique|putWeaponPool|queryItemsPool|queryMagazinePool|queryWeaponPool|rad|radioChannelAdd|radioChannelCreate|radioChannelRemove|radioChannelSetCallSign|radioChannelSetLabel|radioVolume|rain|rainbow|random|rank|rankId|rating|rectangular|registeredTasks|registerTask|reload|reloadEnabled|remoteControl|remoteExec|remoteExecCall|remoteExecutedOwner|remove3DENConnection|remove3DENEventHandler|remove3DENLayer|removeAction|removeAll3DENEventHandlers|removeAllActions|removeAllAssignedItems|removeAllContainers|removeAllCuratorAddons|removeAllCuratorCameraAreas|removeAllCuratorEditingAreas|removeAllEventHandlers|removeAllHandgunItems|removeAllItems|removeAllItemsWithMagazines|removeAllMissionEventHandlers|removeAllMPEventHandlers|removeAllMusicEventHandlers|removeAllOwnedMines|removeAllPrimaryWeaponItems|removeAllWeapons|removeBackpack|removeBackpackGlobal|removeCuratorAddons|removeCuratorCameraArea|removeCuratorEditableObjects|removeCuratorEditingArea|removeDrawIcon|removeDrawLinks|removeEventHandler|removeFromRemainsCollector|removeGoggles|removeGroupIcon|removeHandgunItem|removeHeadgear|removeItem|removeItemFromBackpack|removeItemFromUniform|removeItemFromVest|removeItems|removeMagazine|removeMagazineGlobal|removeMagazines|removeMagazinesTurret|removeMagazineTurret|removeMenuItem|removeMissionEventHandler|removeMPEventHandler|removeMusicEventHandler|removeOwnedMine|removePrimaryWeaponItem|removeSecondaryWeaponItem|removeSimpleTask|removeSwitchableUnit|removeTeamMember|removeUniform|removeVest|removeWeapon|removeWeaponAttachmentCargo|removeWeaponCargo|removeWeaponGlobal|removeWeaponTurret|reportRemoteTarget|requiredVersion|resetCamShake|resetSubgroupDirection|resistance|resize|resources|respawnVehicle|restartEditorCamera|reveal|revealMine|reverse|reversedMouseY|roadAt|roadsConnectedTo|roleDescription|ropeAttachedObjects|ropeAttachedTo|ropeAttachEnabled|ropeAttachTo|ropeCreate|ropeCut|ropeDestroy|ropeDetach|ropeEndPosition|ropeLength|ropes|ropeUnwind|ropeUnwound|rotorsForcesRTD|rotorsRpmRTD|round|runInitScript|safeZoneH|safeZoneW|safeZoneWAbs|safeZoneX|safeZoneXAbs|safeZoneY|save3DENInventory|saveGame|saveIdentity|saveJoysticks|saveOverlay|saveProfileNamespace|saveStatus|saveVar|savingEnabled|say|say2D|say3D|score|scoreSide|screenshot|screenToWorld|scriptDone|scriptName|scriptNull|scudState|secondaryWeapon|secondaryWeaponItems|secondaryWeaponMagazine|select|selectBestPlaces|selectDiarySubject|selectedEditorObjects|selectEditorObject|selectionNames|selectionPosition|selectLeader|selectMax|selectMin|selectNoPlayer|selectPlayer|selectRandom|selectRandomWeighted|selectWeapon|selectWeaponTurret|sendAUMessage|sendSimpleCommand|sendTask|sendTaskResult|sendUDPMessage|serverCommand|serverCommandAvailable|serverCommandExecutable|serverName|serverTime|set|set3DENAttribute|set3DENAttributes|set3DENGrid|set3DENIconsVisible|set3DENLayer|set3DENLinesVisible|set3DENLogicType|set3DENMissionAttribute|set3DENMissionAttributes|set3DENModelsVisible|set3DENObjectType|set3DENSelected|setAccTime|setActualCollectiveRTD|setAirplaneThrottle|setAirportSide|setAmmo|setAmmoCargo|setAmmoOnPylon|setAnimSpeedCoef|setAperture|setApertureNew|setArmoryPoints|setAttributes|setAutonomous|setBehaviour|setBleedingRemaining|setBrakesRTD|setCameraInterest|setCamShakeDefParams|setCamShakeParams|setCamUseTI|setCaptive|setCenterOfMass|setCollisionLight|setCombatMode|setCompassOscillation|setConvoySeparation|setCuratorCameraAreaCeiling|setCuratorCoef|setCuratorEditingAreaType|setCuratorWaypointCost|setCurrentChannel|setCurrentTask|setCurrentWaypoint|setCustomAimCoef|setCustomWeightRTD|setDamage|setDammage|setDate|setDebriefingText|setDefaultCamera|setDestination|setDetailMapBlendPars|setDir|setDirection|setDrawIcon|setDriveOnPath|setDropInterval|setDynamicSimulationDistance|setDynamicSimulationDistanceCoef|setEditorMode|setEditorObjectScope|setEffectCondition|setEngineRpmRTD|setFace|setFaceAnimation|setFatigue|setFeatureType|setFlagAnimationPhase|setFlagOwner|setFlagSide|setFlagTexture|setFog|setForceGeneratorRTD|setFormation|setFormationTask|setFormDir|setFriend|setFromEditor|setFSMVariable|setFuel|setFuelCargo|setGroupIcon|setGroupIconParams|setGroupIconsSelectable|setGroupIconsVisible|setGroupId|setGroupIdGlobal|setGroupOwner|setGusts|setHideBehind|setHit|setHitIndex|setHitPointDamage|setHorizonParallaxCoef|setHUDMovementLevels|setIdentity|setImportance|setInfoPanel|setLeader|setLightAmbient|setLightAttenuation|setLightBrightness|setLightColor|setLightDayLight|setLightFlareMaxDistance|setLightFlareSize|setLightIntensity|setLightnings|setLightUseFlare|setLocalWindParams|setMagazineTurretAmmo|setMarkerAlpha|setMarkerAlphaLocal|setMarkerBrush|setMarkerBrushLocal|setMarkerColor|setMarkerColorLocal|setMarkerDir|setMarkerDirLocal|setMarkerPos|setMarkerPosLocal|setMarkerShape|setMarkerShapeLocal|setMarkerSize|setMarkerSizeLocal|setMarkerText|setMarkerTextLocal|setMarkerType|setMarkerTypeLocal|setMass|setMimic|setMousePosition|setMusicEffect|setMusicEventHandler|setName|setNameSound|setObjectArguments|setObjectMaterial|setObjectMaterialGlobal|setObjectProxy|setObjectTexture|setObjectTextureGlobal|setObjectViewDistance|setOvercast|setOwner|setOxygenRemaining|setParticleCircle|setParticleClass|setParticleFire|setParticleParams|setParticleRandom|setPilotCameraDirection|setPilotCameraRotation|setPilotCameraTarget|setPilotLight|setPiPEffect|setPitch|setPlateNumber|setPlayable|setPlayerRespawnTime|setPos|setPosASL|setPosASL2|setPosASLW|setPosATL|setPosition|setPosWorld|setPylonLoadOut|setPylonsPriority|setRadioMsg|setRain|setRainbow|setRandomLip|setRank|setRectangular|setRepairCargo|setRotorBrakeRTD|setShadowDistance|setShotParents|setSide|setSimpleTaskAlwaysVisible|setSimpleTaskCustomData|setSimpleTaskDescription|setSimpleTaskDestination|setSimpleTaskTarget|setSimpleTaskType|setSimulWeatherLayers|setSize|setSkill|setSlingLoad|setSoundEffect|setSpeaker|setSpeech|setSpeedMode|setStamina|setStaminaScheme|setStatValue|setSuppression|setSystemOfUnits|setTargetAge|setTaskMarkerOffset|setTaskResult|setTaskState|setTerrainGrid|setText|setTimeMultiplier|setTitleEffect|setToneMapping|setToneMappingParams|setTrafficDensity|setTrafficDistance|setTrafficGap|setTrafficSpeed|setTriggerActivation|setTriggerArea|setTriggerStatements|setTriggerText|setTriggerTimeout|setTriggerType|setType|setUnconscious|setUnitAbility|setUnitLoadout|setUnitPos|setUnitPosWeak|setUnitRank|setUnitRecoilCoefficient|setUnitTrait|setUnloadInCombat|setUserActionText|setUserMFDText|setUserMFDValue|setVariable|setVectorDir|setVectorDirAndUp|setVectorUp|setVehicleAmmo|setVehicleAmmoDef|setVehicleArmor|setVehicleCargo|setVehicleId|setVehicleInit|setVehicleLock|setVehiclePosition|setVehicleRadar|setVehicleReceiveRemoteTargets|setVehicleReportOwnPosition|setVehicleReportRemoteTargets|setVehicleTIPars|setVehicleVarName|setVelocity|setVelocityModelSpace|setVelocityTransformation|setViewDistance|setVisibleIfTreeCollapsed|setWantedRpmRTD|setWaves|setWaypointBehaviour|setWaypointCombatMode|setWaypointCompletionRadius|setWaypointDescription|setWaypointForceBehaviour|setWaypointFormation|setWaypointHousePosition|setWaypointLoiterRadius|setWaypointLoiterType|setWaypointName|setWaypointPosition|setWaypointScript|setWaypointSpeed|setWaypointStatements|setWaypointTimeout|setWaypointType|setWaypointVisible|setWeaponReloadingTime|setWind|setWindDir|setWindForce|setWindStr|setWingForceScaleRTD|setWPPos|show3DIcons|showChat|showCinemaBorder|showCommandingMenu|showCompass|showCuratorCompass|showGPS|showHUD|showLegend|showMap|shownArtilleryComputer|shownChat|shownCompass|shownCuratorCompass|showNewEditorObject|shownGPS|shownHUD|shownMap|shownPad|shownRadio|shownScoretable|shownUAVFeed|shownWarrant|shownWatch|showPad|showRadio|showScoretable|showSubtitles|showUAVFeed|showWarrant|showWatch|showWaypoint|showWaypoints|side|sideAmbientLife|sideChat|sideEmpty|sideEnemy|sideFriendly|sideLogic|sideRadio|sideUnknown|simpleTasks|simulationEnabled|simulCloudDensity|simulCloudOcclusion|simulInClouds|simulWeatherSync|sin|size|sizeOf|skill|skillFinal|skipTime|sleep|sliderPosition|sliderRange|sliderSetPosition|sliderSetRange|sliderSetSpeed|sliderSpeed|slingLoadAssistantShown|soldierMagazines|someAmmo|sort|soundVolume|speaker|speed|speedMode|splitString|sqrt|squadParams|stance|startLoadingScreen|stop|stopEngineRTD|stopped|str|sunOrMoon|supportInfo|suppressFor|surfaceIsWater|surfaceNormal|surfaceType|swimInDepth|switchableUnits|switchAction|switchCamera|switchGesture|switchLight|switchMove|synchronizedObjects|synchronizedTriggers|synchronizedWaypoints|synchronizeObjectsAdd|synchronizeObjectsRemove|synchronizeTrigger|synchronizeWaypoint|systemChat|systemOfUnits|tan|targetKnowledge|targets|targetsAggregate|targetsQuery|taskAlwaysVisible|taskChildren|taskCompleted|taskCustomData|taskDescription|taskDestination|taskHint|taskMarkerOffset|taskNull|taskParent|taskResult|taskState|taskType|teamMember|teamMemberNull|teamName|teams|teamSwitch|teamSwitchEnabled|teamType|terminate|terrainIntersect|terrainIntersectASL|terrainIntersectAtASL|text|textLog|textLogFormat|tg|time|timeMultiplier|titleCut|titleFadeOut|titleObj|titleRsc|titleText|toArray|toFixed|toLower|toString|toUpper|triggerActivated|triggerActivation|triggerArea|triggerAttachedVehicle|triggerAttachObject|triggerAttachVehicle|triggerDynamicSimulation|triggerStatements|triggerText|triggerTimeout|triggerTimeoutCurrent|triggerType|turretLocal|turretOwner|turretUnit|tvAdd|tvClear|tvCollapse|tvCollapseAll|tvCount|tvCurSel|tvData|tvDelete|tvExpand|tvExpandAll|tvPicture|tvPictureRight|tvSetColor|tvSetCurSel|tvSetData|tvSetPicture|tvSetPictureColor|tvSetPictureColorDisabled|tvSetPictureColorSelected|tvSetPictureRight|tvSetPictureRightColor|tvSetPictureRightColorDisabled|tvSetPictureRightColorSelected|tvSetSelectColor|tvSetText|tvSetTooltip|tvSetValue|tvSort|tvSortByValue|tvText|tvTooltip|tvValue|type|typeName|typeOf|UAVControl|uiNamespace|uiSleep|unassignCurator|unassignItem|unassignTeam|unassignVehicle|underwater|uniform|uniformContainer|uniformItems|uniformMagazines|unitAddons|unitAimPosition|unitAimPositionVisual|unitBackpack|unitIsUAV|unitPos|unitReady|unitRecoilCoefficient|units|unitsBelowHeight|unlinkItem|unlockAchievement|unregisterTask|updateDrawIcon|updateMenuItem|updateObjectTree|useAIOperMapObstructionTest|useAISteeringComponent|useAudioTimeForMoves|userInputDisabled|vectorAdd|vectorCos|vectorCrossProduct|vectorDiff|vectorDir|vectorDirVisual|vectorDistance|vectorDistanceSqr|vectorDotProduct|vectorFromTo|vectorMagnitude|vectorMagnitudeSqr|vectorModelToWorld|vectorModelToWorldVisual|vectorMultiply|vectorNormalized|vectorUp|vectorUpVisual|vectorWorldToModel|vectorWorldToModelVisual|vehicle|vehicleCargoEnabled|vehicleChat|vehicleRadio|vehicleReceiveRemoteTargets|vehicleReportOwnPosition|vehicleReportRemoteTargets|vehicles|vehicleVarName|velocity|velocityModelSpace|verifySignature|vest|vestContainer|vestItems|vestMagazines|viewDistance|visibleCompass|visibleGPS|visibleMap|visiblePosition|visiblePositionASL|visibleScoretable|visibleWatch|waitUntil|waves|waypointAttachedObject|waypointAttachedVehicle|waypointAttachObject|waypointAttachVehicle|waypointBehaviour|waypointCombatMode|waypointCompletionRadius|waypointDescription|waypointForceBehaviour|waypointFormation|waypointHousePosition|waypointLoiterRadius|waypointLoiterType|waypointName|waypointPosition|waypoints|waypointScript|waypointsEnabledUAV|waypointShow|waypointSpeed|waypointStatements|waypointTimeout|waypointTimeoutCurrent|waypointType|waypointVisible|weaponAccessories|weaponAccessoriesCargo|weaponCargo|weaponDirection|weaponInertia|weaponLowered|weapons|weaponsItems|weaponsItemsCargo|weaponState|weaponsTurret|weightRTD|west|WFSideText|wind|windDir|windRTD|windStr|wingsForcesRTD|worldName|worldSize|worldToModel|worldToModelVisual|worldToScreen)\b/i,number:/(?:\$|\b0x)[\da-f]+\b|(?:\B\.\d+|\b\d+(?:\.\d+)?)(?:e[+-]?\d+)?\b/i,operator:/##|>>|&&|\|\||[!=<>]=?|[-+*/%#^]|\b(?:and|mod|not|or)\b/i,"magic-variable":{pattern:/\b(?:this|thisList|thisTrigger|_exception|_fnc_scriptName|_fnc_scriptNameParent|_forEachIndex|_this|_thisEventHandler|_thisFSM|_thisScript|_x)\b/i,alias:"keyword"},constant:/\bDIK(?:_[a-z\d]+)+\b/i}),t.languages.insertBefore("sqf","string",{macro:{pattern:/(^[ \t]*)#[a-z](?:[^\r\n\\]|\\(?:\r\n|[\s\S]))*/im,lookbehind:!0,greedy:!0,alias:"property",inside:{directive:{pattern:/#[a-z]+\b/i,alias:"keyword"},comment:t.languages.sqf.comment}}}),delete t.languages.sqf["class-name"]}return OE}var DE,MM;function Yme(){if(MM)return DE;MM=1,DE=e,e.displayName="squirrel",e.aliases=[];function e(t){t.languages.squirrel=t.languages.extend("clike",{comment:[t.languages.clike.comment[0],{pattern:/(^|[^\\:])(?:\/\/|#).*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^\\"'@])(?:@"(?:[^"]|"")*"(?!")|"(?:[^\\\r\n"]|\\.)*")/,lookbehind:!0,greedy:!0},"class-name":{pattern:/(\b(?:class|enum|extends|instanceof)\s+)\w+(?:\.\w+)*/,lookbehind:!0,inside:{punctuation:/\./}},keyword:/\b(?:__FILE__|__LINE__|base|break|case|catch|class|clone|const|constructor|continue|default|delete|else|enum|extends|for|foreach|function|if|in|instanceof|local|null|resume|return|static|switch|this|throw|try|typeof|while|yield)\b/,number:/\b(?:0x[0-9a-fA-F]+|\d+(?:\.(?:\d+|[eE][+-]?\d+))?)\b/,operator:/\+\+|--|<=>|<[-<]|>>>?|&&?|\|\|?|[-+*/%!=<>]=?|[~^]|::?/,punctuation:/[(){}\[\],;.]/}),t.languages.insertBefore("squirrel","string",{char:{pattern:/(^|[^\\"'])'(?:[^\\']|\\(?:[xuU][0-9a-fA-F]{0,8}|[\s\S]))'/,lookbehind:!0,greedy:!0}}),t.languages.insertBefore("squirrel","operator",{"attribute-punctuation":{pattern:/<\/|\/>/,alias:"important"},lambda:{pattern:/@(?=\()/,alias:"operator"}})}return DE}var IE,FM;function Kme(){if(FM)return IE;FM=1,IE=e,e.displayName="stan",e.aliases=[];function e(t){(function(n){var r=/\b(?:algebra_solver|algebra_solver_newton|integrate_1d|integrate_ode|integrate_ode_bdf|integrate_ode_rk45|map_rect|ode_(?:adams|bdf|ckrk|rk45)(?:_tol)?|ode_adjoint_tol_ctl|reduce_sum|reduce_sum_static)\b/;n.languages.stan={comment:/\/\/.*|\/\*[\s\S]*?\*\/|#(?!include).*/,string:{pattern:/"[\x20\x21\x23-\x5B\x5D-\x7E]*"/,greedy:!0},directive:{pattern:/^([ \t]*)#include\b.*/m,lookbehind:!0,alias:"property"},"function-arg":{pattern:RegExp("("+r.source+/\s*\(\s*/.source+")"+/[a-zA-Z]\w*/.source),lookbehind:!0,alias:"function"},constraint:{pattern:/(\b(?:int|matrix|real|row_vector|vector)\s*)<[^<>]*>/,lookbehind:!0,inside:{expression:{pattern:/(=\s*)\S(?:\S|\s+(?!\s))*?(?=\s*(?:>$|,\s*\w+\s*=))/,lookbehind:!0,inside:null},property:/\b[a-z]\w*(?=\s*=)/i,operator:/=/,punctuation:/^<|>$|,/}},keyword:[{pattern:/\bdata(?=\s*\{)|\b(?:functions|generated|model|parameters|quantities|transformed)\b/,alias:"program-block"},/\b(?:array|break|cholesky_factor_corr|cholesky_factor_cov|complex|continue|corr_matrix|cov_matrix|data|else|for|if|in|increment_log_prob|int|matrix|ordered|positive_ordered|print|real|reject|return|row_vector|simplex|target|unit_vector|vector|void|while)\b/,r],function:/\b[a-z]\w*(?=\s*\()/i,number:/(?:\b\d+(?:_\d+)*(?:\.(?:\d+(?:_\d+)*)?)?|\B\.\d+(?:_\d+)*)(?:E[+-]?\d+(?:_\d+)*)?i?(?!\w)/i,boolean:/\b(?:false|true)\b/,operator:/<-|\.[*/]=?|\|\|?|&&|[!=<>+\-*/]=?|['^%~?:]/,punctuation:/[()\[\]{},;]/},n.languages.stan.constraint.inside.expression.inside=n.languages.stan})(t)}return IE}var LE,zM;function Xme(){if(zM)return LE;zM=1,LE=e,e.displayName="stylus",e.aliases=[];function e(t){(function(n){var r={pattern:/(\b\d+)(?:%|[a-z]+)/,lookbehind:!0},a={pattern:/(^|[^\w.-])-?(?:\d+(?:\.\d+)?|\.\d+)/,lookbehind:!0},i={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0},url:{pattern:/\burl\((["']?).*?\1\)/i,greedy:!0},string:{pattern:/("|')(?:(?!\1)[^\\\r\n]|\\(?:\r\n|[\s\S]))*\1/,greedy:!0},interpolation:null,func:null,important:/\B!(?:important|optional)\b/i,keyword:{pattern:/(^|\s+)(?:(?:else|for|if|return|unless)(?=\s|$)|@[\w-]+)/,lookbehind:!0},hexcode:/#[\da-f]{3,6}/i,color:[/\b(?:AliceBlue|AntiqueWhite|Aqua|Aquamarine|Azure|Beige|Bisque|Black|BlanchedAlmond|Blue|BlueViolet|Brown|BurlyWood|CadetBlue|Chartreuse|Chocolate|Coral|CornflowerBlue|Cornsilk|Crimson|Cyan|DarkBlue|DarkCyan|DarkGoldenRod|DarkGr[ae]y|DarkGreen|DarkKhaki|DarkMagenta|DarkOliveGreen|DarkOrange|DarkOrchid|DarkRed|DarkSalmon|DarkSeaGreen|DarkSlateBlue|DarkSlateGr[ae]y|DarkTurquoise|DarkViolet|DeepPink|DeepSkyBlue|DimGr[ae]y|DodgerBlue|FireBrick|FloralWhite|ForestGreen|Fuchsia|Gainsboro|GhostWhite|Gold|GoldenRod|Gr[ae]y|Green|GreenYellow|HoneyDew|HotPink|IndianRed|Indigo|Ivory|Khaki|Lavender|LavenderBlush|LawnGreen|LemonChiffon|LightBlue|LightCoral|LightCyan|LightGoldenRodYellow|LightGr[ae]y|LightGreen|LightPink|LightSalmon|LightSeaGreen|LightSkyBlue|LightSlateGr[ae]y|LightSteelBlue|LightYellow|Lime|LimeGreen|Linen|Magenta|Maroon|MediumAquaMarine|MediumBlue|MediumOrchid|MediumPurple|MediumSeaGreen|MediumSlateBlue|MediumSpringGreen|MediumTurquoise|MediumVioletRed|MidnightBlue|MintCream|MistyRose|Moccasin|NavajoWhite|Navy|OldLace|Olive|OliveDrab|Orange|OrangeRed|Orchid|PaleGoldenRod|PaleGreen|PaleTurquoise|PaleVioletRed|PapayaWhip|PeachPuff|Peru|Pink|Plum|PowderBlue|Purple|Red|RosyBrown|RoyalBlue|SaddleBrown|Salmon|SandyBrown|SeaGreen|SeaShell|Sienna|Silver|SkyBlue|SlateBlue|SlateGr[ae]y|Snow|SpringGreen|SteelBlue|Tan|Teal|Thistle|Tomato|Transparent|Turquoise|Violet|Wheat|White|WhiteSmoke|Yellow|YellowGreen)\b/i,{pattern:/\b(?:hsl|rgb)\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*\)\B|\b(?:hsl|rgb)a\(\s*\d{1,3}\s*,\s*\d{1,3}%?\s*,\s*\d{1,3}%?\s*,\s*(?:0|0?\.\d+|1)\s*\)\B/i,inside:{unit:r,number:a,function:/[\w-]+(?=\()/,punctuation:/[(),]/}}],entity:/\\[\da-f]{1,8}/i,unit:r,boolean:/\b(?:false|true)\b/,operator:[/~|[+!\/%<>?=]=?|[-:]=|\*[*=]?|\.{2,3}|&&|\|\||\B-\B|\b(?:and|in|is(?: a| defined| not|nt)?|not|or)\b/],number:a,punctuation:/[{}()\[\];:,]/};i.interpolation={pattern:/\{[^\r\n}:]+\}/,alias:"variable",inside:{delimiter:{pattern:/^\{|\}$/,alias:"punctuation"},rest:i}},i.func={pattern:/[\w-]+\([^)]*\).*/,inside:{function:/^[^(]+/,rest:i}},n.languages.stylus={"atrule-declaration":{pattern:/(^[ \t]*)@.+/m,lookbehind:!0,inside:{atrule:/^@[\w-]+/,rest:i}},"variable-declaration":{pattern:/(^[ \t]*)[\w$-]+\s*.?=[ \t]*(?:\{[^{}]*\}|\S.*|$)/m,lookbehind:!0,inside:{variable:/^\S+/,rest:i}},statement:{pattern:/(^[ \t]*)(?:else|for|if|return|unless)[ \t].+/m,lookbehind:!0,inside:{keyword:/^\S+/,rest:i}},"property-declaration":{pattern:/((?:^|\{)([ \t]*))(?:[\w-]|\{[^}\r\n]+\})+(?:\s*:\s*|[ \t]+)(?!\s)[^{\r\n]*(?:;|[^{\r\n,]$(?!(?:\r?\n|\r)(?:\{|\2[ \t])))/m,lookbehind:!0,inside:{property:{pattern:/^[^\s:]+/,inside:{interpolation:i.interpolation}},rest:i}},selector:{pattern:/(^[ \t]*)(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)(?:(?:\r?\n|\r)(?:\1(?:(?=\S)(?:[^{}\r\n:()]|::?[\w-]+(?:\([^)\r\n]*\)|(?![\w-]))|\{[^}\r\n]+\})+)))*(?:,$|\{|(?=(?:\r?\n|\r)(?:\{|\1[ \t])))/m,lookbehind:!0,inside:{interpolation:i.interpolation,comment:i.comment,punctuation:/[{},]/}},func:i.func,string:i.string,comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|\/\/.*)/,lookbehind:!0,greedy:!0},interpolation:i.interpolation,punctuation:/[{}()\[\];:.]/}})(t)}return LE}var ME,PM;function Zme(){if(PM)return ME;PM=1,ME=e,e.displayName="swift",e.aliases=[];function e(t){t.languages.swift={comment:{pattern:/(^|[^\\:])(?:\/\/.*|\/\*(?:[^/*]|\/(?!\*)|\*(?!\/)|\/\*(?:[^*]|\*(?!\/))*\*\/)*\*\/)/,lookbehind:!0,greedy:!0},"string-literal":[{pattern:RegExp(/(^|[^"#])/.source+"(?:"+/"(?:\\(?:\((?:[^()]|\([^()]*\))*\)|\r\n|[^(])|[^\\\r\n"])*"/.source+"|"+/"""(?:\\(?:\((?:[^()]|\([^()]*\))*\)|[^(])|[^\\"]|"(?!""))*"""/.source+")"+/(?!["#])/.source),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\\($/,alias:"punctuation"},punctuation:/\\(?=[\r\n])/,string:/[\s\S]+/}},{pattern:RegExp(/(^|[^"#])(#+)/.source+"(?:"+/"(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|\r\n|[^#])|[^\\\r\n])*?"/.source+"|"+/"""(?:\\(?:#+\((?:[^()]|\([^()]*\))*\)|[^#])|[^\\])*?"""/.source+")\\2"),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/(\\#+\()(?:[^()]|\([^()]*\))*(?=\))/,lookbehind:!0,inside:null},"interpolation-punctuation":{pattern:/^\)|\\#+\($/,alias:"punctuation"},string:/[\s\S]+/}}],directive:{pattern:RegExp(/#/.source+"(?:"+(/(?:elseif|if)\b/.source+"(?:[ 	]*"+/(?:![ \t]*)?(?:\b\w+\b(?:[ \t]*\((?:[^()]|\([^()]*\))*\))?|\((?:[^()]|\([^()]*\))*\))(?:[ \t]*(?:&&|\|\|))?/.source+")+")+"|"+/(?:else|endif)\b/.source+")"),alias:"property",inside:{"directive-name":/^#\w+/,boolean:/\b(?:false|true)\b/,number:/\b\d+(?:\.\d+)*\b/,operator:/!|&&|\|\||[<>]=?/,punctuation:/[(),]/}},literal:{pattern:/#(?:colorLiteral|column|dsohandle|file(?:ID|Literal|Path)?|function|imageLiteral|line)\b/,alias:"constant"},"other-directive":{pattern:/#\w+\b/,alias:"property"},attribute:{pattern:/@\w+/,alias:"atrule"},"function-definition":{pattern:/(\bfunc\s+)\w+/,lookbehind:!0,alias:"function"},label:{pattern:/\b(break|continue)\s+\w+|\b[a-zA-Z_]\w*(?=\s*:\s*(?:for|repeat|while)\b)/,lookbehind:!0,alias:"important"},keyword:/\b(?:Any|Protocol|Self|Type|actor|as|assignment|associatedtype|associativity|async|await|break|case|catch|class|continue|convenience|default|defer|deinit|didSet|do|dynamic|else|enum|extension|fallthrough|fileprivate|final|for|func|get|guard|higherThan|if|import|in|indirect|infix|init|inout|internal|is|isolated|lazy|left|let|lowerThan|mutating|none|nonisolated|nonmutating|open|operator|optional|override|postfix|precedencegroup|prefix|private|protocol|public|repeat|required|rethrows|return|right|safe|self|set|some|static|struct|subscript|super|switch|throw|throws|try|typealias|unowned|unsafe|var|weak|where|while|willSet)\b/,boolean:/\b(?:false|true)\b/,nil:{pattern:/\bnil\b/,alias:"constant"},"short-argument":/\$\d+\b/,omit:{pattern:/\b_\b/,alias:"keyword"},number:/\b(?:[\d_]+(?:\.[\de_]+)?|0x[a-f0-9_]+(?:\.[a-f0-9p_]+)?|0b[01_]+|0o[0-7_]+)\b/i,"class-name":/\b[A-Z](?:[A-Z_\d]*[a-z]\w*)?\b/,function:/\b[a-z_]\w*(?=\s*\()/i,constant:/\b(?:[A-Z_]{2,}|k[A-Z][A-Za-z_]+)\b/,operator:/[-+*/%=!<>&|^~?]+|\.[.\-+*/%=!<>&|^~?]+/,punctuation:/[{}[\]();,.:\\]/},t.languages.swift["string-literal"].forEach(function(n){n.inside.interpolation.inside=t.languages.swift})}return ME}var FE,BM;function Qme(){if(BM)return FE;BM=1,FE=e,e.displayName="systemd",e.aliases=[];function e(t){(function(n){var r={pattern:/^[;#].*/m,greedy:!0},a=/"(?:[^\r\n"\\]|\\(?:[^\r]|\r\n?))*"(?!\S)/.source;n.languages.systemd={comment:r,section:{pattern:/^\[[^\n\r\[\]]*\](?=[ \t]*$)/m,greedy:!0,inside:{punctuation:/^\[|\]$/,"section-name":{pattern:/[\s\S]+/,alias:"selector"}}},key:{pattern:/^[^\s=]+(?=[ \t]*=)/m,greedy:!0,alias:"attr-name"},value:{pattern:RegExp(/(=[ \t]*(?!\s))/.source+"(?:"+a+`|(?=[^"\r
]))(?:`+(/[^\s\\]/.source+'|[ 	]+(?:(?![ 	"])|'+a+")|"+/\\[\r\n]+(?:[#;].*[\r\n]+)*(?![#;])/.source)+")*"),lookbehind:!0,greedy:!0,alias:"attr-value",inside:{comment:r,quoted:{pattern:RegExp(/(^|\s)/.source+a),lookbehind:!0,greedy:!0},punctuation:/\\$/m,boolean:{pattern:/^(?:false|no|off|on|true|yes)$/,greedy:!0}}},punctuation:/=/}})(t)}return FE}var zE,UM;function hA(){if(UM)return zE;UM=1,zE=e,e.displayName="t4Templating",e.aliases=[];function e(t){(function(n){function r(i,l,u){return{pattern:RegExp("<#"+i+"[\\s\\S]*?#>"),alias:"block",inside:{delimiter:{pattern:RegExp("^<#"+i+"|#>$"),alias:"important"},content:{pattern:/[\s\S]+/,inside:l,alias:u}}}}function a(i){var l=n.languages[i],u="language-"+i;return{block:{pattern:/<#[\s\S]+?#>/,inside:{directive:r("@",{"attr-value":{pattern:/=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+)/,inside:{punctuation:/^=|^["']|["']$/}},keyword:/\b\w+(?=\s)/,"attr-name":/\b\w+/}),expression:r("=",l,u),"class-feature":r("\\+",l,u),standard:r("",l,u)}}}}n.languages["t4-templating"]=Object.defineProperty({},"createT4",{value:a})})(t)}return zE}var PE,jM;function Jme(){if(jM)return PE;jM=1;var e=hA(),t=Vf();PE=n,n.displayName="t4Cs",n.aliases=[];function n(r){r.register(e),r.register(t),r.languages.t4=r.languages["t4-cs"]=r.languages["t4-templating"].createT4("csharp")}return PE}var BE,GM;function Z5(){if(GM)return BE;GM=1;var e=W5();BE=t,t.displayName="vbnet",t.aliases=[];function t(n){n.register(e),n.languages.vbnet=n.languages.extend("basic",{comment:[{pattern:/(?:!|REM\b).+/i,inside:{keyword:/^REM/i}},{pattern:/(^|[^\\:])'.*/,lookbehind:!0,greedy:!0}],string:{pattern:/(^|[^"])"(?:""|[^"])*"(?!")/,lookbehind:!0,greedy:!0},keyword:/(?:\b(?:ADDHANDLER|ADDRESSOF|ALIAS|AND|ANDALSO|AS|BEEP|BLOAD|BOOLEAN|BSAVE|BYREF|BYTE|BYVAL|CALL(?: ABSOLUTE)?|CASE|CATCH|CBOOL|CBYTE|CCHAR|CDATE|CDBL|CDEC|CHAIN|CHAR|CHDIR|CINT|CLASS|CLEAR|CLNG|CLOSE|CLS|COBJ|COM|COMMON|CONST|CONTINUE|CSBYTE|CSHORT|CSNG|CSTR|CTYPE|CUINT|CULNG|CUSHORT|DATA|DATE|DECIMAL|DECLARE|DEF(?: FN| SEG|DBL|INT|LNG|SNG|STR)|DEFAULT|DELEGATE|DIM|DIRECTCAST|DO|DOUBLE|ELSE|ELSEIF|END|ENUM|ENVIRON|ERASE|ERROR|EVENT|EXIT|FALSE|FIELD|FILES|FINALLY|FOR(?: EACH)?|FRIEND|FUNCTION|GET|GETTYPE|GETXMLNAMESPACE|GLOBAL|GOSUB|GOTO|HANDLES|IF|IMPLEMENTS|IMPORTS|IN|INHERITS|INPUT|INTEGER|INTERFACE|IOCTL|IS|ISNOT|KEY|KILL|LET|LIB|LIKE|LINE INPUT|LOCATE|LOCK|LONG|LOOP|LSET|ME|MKDIR|MOD|MODULE|MUSTINHERIT|MUSTOVERRIDE|MYBASE|MYCLASS|NAME|NAMESPACE|NARROWING|NEW|NEXT|NOT|NOTHING|NOTINHERITABLE|NOTOVERRIDABLE|OBJECT|OF|OFF|ON(?: COM| ERROR| KEY| TIMER)?|OPEN|OPERATOR|OPTION(?: BASE)?|OPTIONAL|OR|ORELSE|OUT|OVERLOADS|OVERRIDABLE|OVERRIDES|PARAMARRAY|PARTIAL|POKE|PRIVATE|PROPERTY|PROTECTED|PUBLIC|PUT|RAISEEVENT|READ|READONLY|REDIM|REM|REMOVEHANDLER|RESTORE|RESUME|RETURN|RMDIR|RSET|RUN|SBYTE|SELECT(?: CASE)?|SET|SHADOWS|SHARED|SHELL|SHORT|SINGLE|SLEEP|STATIC|STEP|STOP|STRING|STRUCTURE|SUB|SWAP|SYNCLOCK|SYSTEM|THEN|THROW|TIMER|TO|TROFF|TRON|TRUE|TRY|TRYCAST|TYPE|TYPEOF|UINTEGER|ULONG|UNLOCK|UNTIL|USHORT|USING|VIEW PRINT|WAIT|WEND|WHEN|WHILE|WIDENING|WITH|WITHEVENTS|WRITE|WRITEONLY|XOR)|\B(?:#CONST|#ELSE|#ELSEIF|#END|#IF))(?:\$|\b)/i,punctuation:/[,;:(){}]/})}return BE}var UE,HM;function ebe(){if(HM)return UE;HM=1;var e=hA(),t=Z5();UE=n,n.displayName="t4Vb",n.aliases=[];function n(r){r.register(e),r.register(t),r.languages["t4-vb"]=r.languages["t4-templating"].createT4("vbnet")}return UE}var jE,$M;function Q5(){if($M)return jE;$M=1,jE=e,e.displayName="yaml",e.aliases=["yml"];function e(t){(function(n){var r=/[*&][^\s[\]{},]+/,a=/!(?:<[\w\-%#;/?:@&=+$,.!~*'()[\]]+>|(?:[a-zA-Z\d-]*!)?[\w\-%#;/?:@&=+$.~*'()]+)?/,i="(?:"+a.source+"(?:[ 	]+"+r.source+")?|"+r.source+"(?:[ 	]+"+a.source+")?)",l=/(?:[^\s\x00-\x08\x0e-\x1f!"#%&'*,\-:>?@[\]`{|}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]|[?:-]<PLAIN>)(?:[ \t]*(?:(?![#:])<PLAIN>|:<PLAIN>))*/.source.replace(/<PLAIN>/g,function(){return/[^\s\x00-\x08\x0e-\x1f,[\]{}\x7f-\x84\x86-\x9f\ud800-\udfff\ufffe\uffff]/.source}),u=/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'/.source;function c(f,p){p=(p||"").replace(/m/g,"")+"m";var g=/([:\-,[{]\s*(?:\s<<prop>>[ \t]+)?)(?:<<value>>)(?=[ \t]*(?:$|,|\]|\}|(?:[\r\n]\s*)?#))/.source.replace(/<<prop>>/g,function(){return i}).replace(/<<value>>/g,function(){return f});return RegExp(g,p)}n.languages.yaml={scalar:{pattern:RegExp(/([\-:]\s*(?:\s<<prop>>[ \t]+)?[|>])[ \t]*(?:((?:\r?\n|\r)[ \t]+)\S[^\r\n]*(?:\2[^\r\n]+)*)/.source.replace(/<<prop>>/g,function(){return i})),lookbehind:!0,alias:"string"},comment:/#.*/,key:{pattern:RegExp(/((?:^|[:\-,[{\r\n?])[ \t]*(?:<<prop>>[ \t]+)?)<<key>>(?=\s*:\s)/.source.replace(/<<prop>>/g,function(){return i}).replace(/<<key>>/g,function(){return"(?:"+l+"|"+u+")"})),lookbehind:!0,greedy:!0,alias:"atrule"},directive:{pattern:/(^[ \t]*)%.+/m,lookbehind:!0,alias:"important"},datetime:{pattern:c(/\d{4}-\d\d?-\d\d?(?:[tT]|[ \t]+)\d\d?:\d{2}:\d{2}(?:\.\d*)?(?:[ \t]*(?:Z|[-+]\d\d?(?::\d{2})?))?|\d{4}-\d{2}-\d{2}|\d\d?:\d{2}(?::\d{2}(?:\.\d*)?)?/.source),lookbehind:!0,alias:"number"},boolean:{pattern:c(/false|true/.source,"i"),lookbehind:!0,alias:"important"},null:{pattern:c(/null|~/.source,"i"),lookbehind:!0,alias:"important"},string:{pattern:c(u),lookbehind:!0,greedy:!0},number:{pattern:c(/[+-]?(?:0x[\da-f]+|0o[0-7]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|\.inf|\.nan)/.source,"i"),lookbehind:!0},tag:a,important:r,punctuation:/---|[:[\]{}\-,|>?]|\.\.\./},n.languages.yml=n.languages.yaml})(t)}return jE}var GE,qM;function tbe(){if(qM)return GE;qM=1;var e=Q5();GE=t,t.displayName="tap",t.aliases=[];function t(n){n.register(e),n.languages.tap={fail:/not ok[^#{\n\r]*/,pass:/ok[^#{\n\r]*/,pragma:/pragma [+-][a-z]+/,bailout:/bail out!.*/i,version:/TAP version \d+/i,plan:/\b\d+\.\.\d+(?: +#.*)?/,subtest:{pattern:/# Subtest(?:: .*)?/,greedy:!0},punctuation:/[{}]/,directive:/#.*/,yamlish:{pattern:/(^[ \t]*)---[\s\S]*?[\r\n][ \t]*\.\.\.$/m,lookbehind:!0,inside:n.languages.yaml,alias:"language-yaml"}}}return GE}var HE,VM;function nbe(){if(VM)return HE;VM=1,HE=e,e.displayName="tcl",e.aliases=[];function e(t){t.languages.tcl={comment:{pattern:/(^|[^\\])#.*/,lookbehind:!0},string:{pattern:/"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*"/,greedy:!0},variable:[{pattern:/(\$)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/,lookbehind:!0},{pattern:/(\$)\{[^}]+\}/,lookbehind:!0},{pattern:/(^[\t ]*set[ \t]+)(?:::)?(?:[a-zA-Z0-9]+::)*\w+/m,lookbehind:!0}],function:{pattern:/(^[\t ]*proc[ \t]+)\S+/m,lookbehind:!0},builtin:[{pattern:/(^[\t ]*)(?:break|class|continue|error|eval|exit|for|foreach|if|proc|return|switch|while)\b/m,lookbehind:!0},/\b(?:else|elseif)\b/],scope:{pattern:/(^[\t ]*)(?:global|upvar|variable)\b/m,lookbehind:!0,alias:"constant"},keyword:{pattern:/(^[\t ]*|\[)(?:Safe_Base|Tcl|after|append|apply|array|auto_(?:execok|import|load|mkindex|qualify|reset)|automkindex_old|bgerror|binary|catch|cd|chan|clock|close|concat|dde|dict|encoding|eof|exec|expr|fblocked|fconfigure|fcopy|file(?:event|name)?|flush|gets|glob|history|http|incr|info|interp|join|lappend|lassign|lindex|linsert|list|llength|load|lrange|lrepeat|lreplace|lreverse|lsearch|lset|lsort|math(?:func|op)|memory|msgcat|namespace|open|package|parray|pid|pkg_mkIndex|platform|puts|pwd|re_syntax|read|refchan|regexp|registry|regsub|rename|scan|seek|set|socket|source|split|string|subst|tcl(?:_endOfWord|_findLibrary|startOf(?:Next|Previous)Word|test|vars|wordBreak(?:After|Before))|tell|time|tm|trace|unknown|unload|unset|update|uplevel|vwait)\b/m,lookbehind:!0},operator:/!=?|\*\*?|==|&&?|\|\|?|<[=<]?|>[=>]?|[-+~\/%?^]|\b(?:eq|in|ne|ni)\b/,punctuation:/[{}()\[\]]/}}return HE}var $E,WM;function rbe(){if(WM)return $E;WM=1,$E=e,e.displayName="textile",e.aliases=[];function e(t){(function(n){var r=/\([^|()\n]+\)|\[[^\]\n]+\]|\{[^}\n]+\}/.source,a=/\)|\((?![^|()\n]+\))/.source;function i(b,m){return RegExp(b.replace(/<MOD>/g,function(){return"(?:"+r+")"}).replace(/<PAR>/g,function(){return"(?:"+a+")"}),m||"")}var l={css:{pattern:/\{[^{}]+\}/,inside:{rest:n.languages.css}},"class-id":{pattern:/(\()[^()]+(?=\))/,lookbehind:!0,alias:"attr-value"},lang:{pattern:/(\[)[^\[\]]+(?=\])/,lookbehind:!0,alias:"attr-value"},punctuation:/[\\\/]\d+|\S/},u=n.languages.textile=n.languages.extend("markup",{phrase:{pattern:/(^|\r|\n)\S[\s\S]*?(?=$|\r?\n\r?\n|\r\r)/,lookbehind:!0,inside:{"block-tag":{pattern:i(/^[a-z]\w*(?:<MOD>|<PAR>|[<>=])*\./.source),inside:{modifier:{pattern:i(/(^[a-z]\w*)(?:<MOD>|<PAR>|[<>=])+(?=\.)/.source),lookbehind:!0,inside:l},tag:/^[a-z]\w*/,punctuation:/\.$/}},list:{pattern:i(/^[*#]+<MOD>*\s+\S.*/.source,"m"),inside:{modifier:{pattern:i(/(^[*#]+)<MOD>+/.source),lookbehind:!0,inside:l},punctuation:/^[*#]+/}},table:{pattern:i(/^(?:(?:<MOD>|<PAR>|[<>=^~])+\.\s*)?(?:\|(?:(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.|(?!(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+\.))[^|]*)+\|/.source,"m"),inside:{modifier:{pattern:i(/(^|\|(?:\r?\n|\r)?)(?:<MOD>|<PAR>|[<>=^~_]|[\\/]\d+)+(?=\.)/.source),lookbehind:!0,inside:l},punctuation:/\||^\./}},inline:{pattern:i(/(^|[^a-zA-Z\d])(\*\*|__|\?\?|[*_%@+\-^~])<MOD>*.+?\2(?![a-zA-Z\d])/.source),lookbehind:!0,inside:{bold:{pattern:i(/(^(\*\*?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},italic:{pattern:i(/(^(__?)<MOD>*).+?(?=\2)/.source),lookbehind:!0},cite:{pattern:i(/(^\?\?<MOD>*).+?(?=\?\?)/.source),lookbehind:!0,alias:"string"},code:{pattern:i(/(^@<MOD>*).+?(?=@)/.source),lookbehind:!0,alias:"keyword"},inserted:{pattern:i(/(^\+<MOD>*).+?(?=\+)/.source),lookbehind:!0},deleted:{pattern:i(/(^-<MOD>*).+?(?=-)/.source),lookbehind:!0},span:{pattern:i(/(^%<MOD>*).+?(?=%)/.source),lookbehind:!0},modifier:{pattern:i(/(^\*\*|__|\?\?|[*_%@+\-^~])<MOD>+/.source),lookbehind:!0,inside:l},punctuation:/[*_%?@+\-^~]+/}},"link-ref":{pattern:/^\[[^\]]+\]\S+$/m,inside:{string:{pattern:/(^\[)[^\]]+(?=\])/,lookbehind:!0},url:{pattern:/(^\])\S+$/,lookbehind:!0},punctuation:/[\[\]]/}},link:{pattern:i(/"<MOD>*[^"]+":.+?(?=[^\w/]?(?:\s|$))/.source),inside:{text:{pattern:i(/(^"<MOD>*)[^"]+(?=")/.source),lookbehind:!0},modifier:{pattern:i(/(^")<MOD>+/.source),lookbehind:!0,inside:l},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[":]/}},image:{pattern:i(/!(?:<MOD>|<PAR>|[<>=])*(?![<>=])[^!\s()]+(?:\([^)]+\))?!(?::.+?(?=[^\w/]?(?:\s|$)))?/.source),inside:{source:{pattern:i(/(^!(?:<MOD>|<PAR>|[<>=])*)(?![<>=])[^!\s()]+(?:\([^)]+\))?(?=!)/.source),lookbehind:!0,alias:"url"},modifier:{pattern:i(/(^!)(?:<MOD>|<PAR>|[<>=])+/.source),lookbehind:!0,inside:l},url:{pattern:/(:).+/,lookbehind:!0},punctuation:/[!:]/}},footnote:{pattern:/\b\[\d+\]/,alias:"comment",inside:{punctuation:/\[|\]/}},acronym:{pattern:/\b[A-Z\d]+\([^)]+\)/,inside:{comment:{pattern:/(\()[^()]+(?=\))/,lookbehind:!0},punctuation:/[()]/}},mark:{pattern:/\b\((?:C|R|TM)\)/,alias:"comment",inside:{punctuation:/[()]/}}}}}),c=u.phrase.inside,f={inline:c.inline,link:c.link,image:c.image,footnote:c.footnote,acronym:c.acronym,mark:c.mark};u.tag.pattern=/<\/?(?!\d)[a-z0-9]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/i;var p=c.inline.inside;p.bold.inside=f,p.italic.inside=f,p.inserted.inside=f,p.deleted.inside=f,p.span.inside=f;var g=c.table.inside;g.inline=f.inline,g.link=f.link,g.image=f.image,g.footnote=f.footnote,g.acronym=f.acronym,g.mark=f.mark})(t)}return $E}var qE,YM;function abe(){if(YM)return qE;YM=1,qE=e,e.displayName="toml",e.aliases=[];function e(t){(function(n){var r=/(?:[\w-]+|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*")/.source;function a(i){return i.replace(/__/g,function(){return r})}n.languages.toml={comment:{pattern:/#.*/,greedy:!0},table:{pattern:RegExp(a(/(^[\t ]*\[\s*(?:\[\s*)?)__(?:\s*\.\s*__)*(?=\s*\])/.source),"m"),lookbehind:!0,greedy:!0,alias:"class-name"},key:{pattern:RegExp(a(/(^[\t ]*|[{,]\s*)__(?:\s*\.\s*__)*(?=\s*=)/.source),"m"),lookbehind:!0,greedy:!0,alias:"property"},string:{pattern:/"""(?:\\[\s\S]|[^\\])*?"""|'''[\s\S]*?'''|'[^'\n\r]*'|"(?:\\.|[^\\"\r\n])*"/,greedy:!0},date:[{pattern:/\b\d{4}-\d{2}-\d{2}(?:[T\s]\d{2}:\d{2}:\d{2}(?:\.\d+)?(?:Z|[+-]\d{2}:\d{2})?)?\b/i,alias:"number"},{pattern:/\b\d{2}:\d{2}:\d{2}(?:\.\d+)?\b/,alias:"number"}],number:/(?:\b0(?:x[\da-zA-Z]+(?:_[\da-zA-Z]+)*|o[0-7]+(?:_[0-7]+)*|b[10]+(?:_[10]+)*))\b|[-+]?\b\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?(?:[eE][+-]?\d+(?:_\d+)*)?\b|[-+]?\b(?:inf|nan)\b/,boolean:/\b(?:false|true)\b/,punctuation:/[.,=[\]{}]/}})(t)}return qE}var VE,KM;function obe(){if(KM)return VE;KM=1,VE=e,e.displayName="tremor",e.aliases=[];function e(t){(function(n){n.languages.tremor={comment:{pattern:/(^|[^\\])(?:\/\*[\s\S]*?\*\/|(?:--|\/\/|#).*)/,lookbehind:!0},"interpolated-string":null,extractor:{pattern:/\b[a-z_]\w*\|(?:[^\r\n\\|]|\\(?:\r\n|[\s\S]))*\|/i,greedy:!0,inside:{regex:{pattern:/(^re)\|[\s\S]+/,lookbehind:!0},function:/^\w+/,value:/\|[\s\S]+/}},identifier:{pattern:/`[^`]*`/,greedy:!0},function:/\b[a-z_]\w*(?=\s*(?:::\s*<|\())\b/,keyword:/\b(?:args|as|by|case|config|connect|connector|const|copy|create|default|define|deploy|drop|each|emit|end|erase|event|flow|fn|for|from|group|having|insert|into|intrinsic|let|links|match|merge|mod|move|of|operator|patch|pipeline|recur|script|select|set|sliding|state|stream|to|tumbling|update|use|when|where|window|with)\b/,boolean:/\b(?:false|null|true)\b/i,number:/\b(?:0b[01_]*|0x[0-9a-fA-F_]*|\d[\d_]*(?:\.\d[\d_]*)?(?:[Ee][+-]?[\d_]+)?)\b/,"pattern-punctuation":{pattern:/%(?=[({[])/,alias:"punctuation"},operator:/[-+*\/%~!^]=?|=[=>]?|&[&=]?|\|[|=]?|<<?=?|>>?>?=?|(?:absent|and|not|or|present|xor)\b/,punctuation:/::|[;\[\]()\{\},.:]/};var r=/#\{(?:[^"{}]|\{[^{}]*\}|"(?:[^"\\\r\n]|\\(?:\r\n|[\s\S]))*")*\}/.source;n.languages.tremor["interpolated-string"]={pattern:RegExp(/(^|[^\\])/.source+'(?:"""(?:'+/[^"\\#]|\\[\s\S]|"(?!"")|#(?!\{)/.source+"|"+r+')*"""|"(?:'+/[^"\\\r\n#]|\\(?:\r\n|[\s\S])|#(?!\{)/.source+"|"+r+')*")'),lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:RegExp(r),inside:{punctuation:/^#\{|\}$/,expression:{pattern:/[\s\S]+/,inside:n.languages.tremor}}},string:/[\s\S]+/}},n.languages.troy=n.languages.tremor,n.languages.trickle=n.languages.tremor})(t)}return VE}var WE,XM;function ibe(){if(XM)return WE;XM=1;var e=K5(),t=fA();WE=n,n.displayName="tsx",n.aliases=[];function n(r){r.register(e),r.register(t),function(a){var i=a.util.clone(a.languages.typescript);a.languages.tsx=a.languages.extend("jsx",i),delete a.languages.tsx.parameter,delete a.languages.tsx["literal-property"];var l=a.languages.tsx.tag;l.pattern=RegExp(/(^|[^\w$]|(?=<\/))/.source+"(?:"+l.pattern.source+")",l.pattern.flags),l.lookbehind=!0}(r)}return WE}var YE,ZM;function lbe(){if(ZM)return YE;ZM=1;var e=Gn();YE=t,t.displayName="tt2",t.aliases=[];function t(n){n.register(e),function(r){r.languages.tt2=r.languages.extend("clike",{comment:/#.*|\[%#[\s\S]*?%\]/,keyword:/\b(?:BLOCK|CALL|CASE|CATCH|CLEAR|DEBUG|DEFAULT|ELSE|ELSIF|END|FILTER|FINAL|FOREACH|GET|IF|IN|INCLUDE|INSERT|LAST|MACRO|META|NEXT|PERL|PROCESS|RAWPERL|RETURN|SET|STOP|SWITCH|TAGS|THROW|TRY|UNLESS|USE|WHILE|WRAPPER)\b/,punctuation:/[[\]{},()]/}),r.languages.insertBefore("tt2","number",{operator:/=[>=]?|!=?|<=?|>=?|&&|\|\|?|\b(?:and|not|or)\b/,variable:{pattern:/\b[a-z]\w*(?:\s*\.\s*(?:\d+|\$?[a-z]\w*))*\b/i}}),r.languages.insertBefore("tt2","keyword",{delimiter:{pattern:/^(?:\[%|%%)-?|-?%\]$/,alias:"punctuation"}}),r.languages.insertBefore("tt2","string",{"single-quoted-string":{pattern:/'[^\\']*(?:\\[\s\S][^\\']*)*'/,greedy:!0,alias:"string"},"double-quoted-string":{pattern:/"[^\\"]*(?:\\[\s\S][^\\"]*)*"/,greedy:!0,alias:"string",inside:{variable:{pattern:/\$(?:[a-z]\w*(?:\.(?:\d+|\$?[a-z]\w*))*)/i}}}}),delete r.languages.tt2.string,r.hooks.add("before-tokenize",function(a){var i=/\[%[\s\S]+?%\]/g;r.languages["markup-templating"].buildPlaceholders(a,"tt2",i)}),r.hooks.add("after-tokenize",function(a){r.languages["markup-templating"].tokenizePlaceholders(a,"tt2")})}(n)}return YE}var KE,QM;function sbe(){if(QM)return KE;QM=1;var e=Gn();KE=t,t.displayName="twig",t.aliases=[];function t(n){n.register(e),n.languages.twig={comment:/^\{#[\s\S]*?#\}$/,"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/}},keyword:/\b(?:even|if|odd)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/},n.hooks.add("before-tokenize",function(r){if(r.language==="twig"){var a=/\{(?:#[\s\S]*?#|%[\s\S]*?%|\{[\s\S]*?\})\}/g;n.languages["markup-templating"].buildPlaceholders(r,"twig",a)}}),n.hooks.add("after-tokenize",function(r){n.languages["markup-templating"].tokenizePlaceholders(r,"twig")})}return KE}var XE,JM;function ube(){if(JM)return XE;JM=1,XE=e,e.displayName="typoscript",e.aliases=["tsconfig"];function e(t){(function(n){var r=/\b(?:ACT|ACTIFSUB|CARRAY|CASE|CLEARGIF|COA|COA_INT|CONSTANTS|CONTENT|CUR|EDITPANEL|EFFECT|EXT|FILE|FLUIDTEMPLATE|FORM|FRAME|FRAMESET|GIFBUILDER|GMENU|GMENU_FOLDOUT|GMENU_LAYERS|GP|HMENU|HRULER|HTML|IENV|IFSUB|IMAGE|IMGMENU|IMGMENUITEM|IMGTEXT|IMG_RESOURCE|INCLUDE_TYPOSCRIPT|JSMENU|JSMENUITEM|LLL|LOAD_REGISTER|NO|PAGE|RECORDS|RESTORE_REGISTER|TEMPLATE|TEXT|TMENU|TMENUITEM|TMENU_LAYERS|USER|USER_INT|_GIFBUILDER|global|globalString|globalVar)\b/;n.languages.typoscript={comment:[{pattern:/(^|[^\\])\/\*[\s\S]*?(?:\*\/|$)/,lookbehind:!0},{pattern:/(^|[^\\:= \t]|(?:^|[^= \t])[ \t]+)\/\/.*/,lookbehind:!0,greedy:!0},{pattern:/(^|[^"'])#.*/,lookbehind:!0,greedy:!0}],function:[{pattern:/<INCLUDE_TYPOSCRIPT:\s*source\s*=\s*(?:"[^"\r\n]*"|'[^'\r\n]*')\s*>/,inside:{string:{pattern:/"[^"\r\n]*"|'[^'\r\n]*'/,inside:{keyword:r}},keyword:{pattern:/INCLUDE_TYPOSCRIPT/}}},{pattern:/@import\s*(?:"[^"\r\n]*"|'[^'\r\n]*')/,inside:{string:/"[^"\r\n]*"|'[^'\r\n]*'/}}],string:{pattern:/^([^=]*=[< ]?)(?:(?!\]\n).)*/,lookbehind:!0,inside:{function:/\{\$.*\}/,keyword:r,number:/^\d+$/,punctuation:/[,|:]/}},keyword:r,number:{pattern:/\b\d+\s*[.{=]/,inside:{operator:/[.{=]/}},tag:{pattern:/\.?[-\w\\]+\.?/,inside:{punctuation:/\./}},punctuation:/[{}[\];(),.:|]/,operator:/[<>]=?|[!=]=?=?|--?|\+\+?|&&?|\|\|?|[?*/~^%]/},n.languages.tsconfig=n.languages.typoscript})(t)}return XE}var ZE,eF;function cbe(){if(eF)return ZE;eF=1,ZE=e,e.displayName="unrealscript",e.aliases=["uc","uscript"];function e(t){t.languages.unrealscript={comment:/\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,greedy:!0},category:{pattern:/(\b(?:(?:autoexpand|hide|show)categories|var)\s*\()[^()]+(?=\))/,lookbehind:!0,greedy:!0,alias:"property"},metadata:{pattern:/(\w\s*)<\s*\w+\s*=[^<>|=\r\n]+(?:\|\s*\w+\s*=[^<>|=\r\n]+)*>/,lookbehind:!0,greedy:!0,inside:{property:/\b\w+(?=\s*=)/,operator:/=/,punctuation:/[<>|]/}},macro:{pattern:/`\w+/,alias:"property"},"class-name":{pattern:/(\b(?:class|enum|extends|interface|state(?:\(\))?|struct|within)\s+)\w+/,lookbehind:!0},keyword:/\b(?:abstract|actor|array|auto|autoexpandcategories|bool|break|byte|case|class|classgroup|client|coerce|collapsecategories|config|const|continue|default|defaultproperties|delegate|dependson|deprecated|do|dontcollapsecategories|editconst|editinlinenew|else|enum|event|exec|export|extends|final|float|for|forcescriptorder|foreach|function|goto|guid|hidecategories|hidedropdown|if|ignores|implements|inherits|input|int|interface|iterator|latent|local|material|name|native|nativereplication|noexport|nontransient|noteditinlinenew|notplaceable|operator|optional|out|pawn|perobjectconfig|perobjectlocalized|placeable|postoperator|preoperator|private|protected|reliable|replication|return|server|showcategories|simulated|singular|state|static|string|struct|structdefault|structdefaultproperties|switch|texture|transient|travel|unreliable|until|var|vector|while|within)\b/,function:/\b[a-z_]\w*(?=\s*\()/i,boolean:/\b(?:false|true)\b/,number:/\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?/i,operator:/>>|<<|--|\+\+|\*\*|[-+*/~!=<>$@]=?|&&?|\|\|?|\^\^?|[?:%]|\b(?:ClockwiseFrom|Cross|Dot)\b/,punctuation:/[()[\]{};,.]/},t.languages.uc=t.languages.uscript=t.languages.unrealscript}return ZE}var QE,tF;function dbe(){if(tF)return QE;tF=1,QE=e,e.displayName="uorazor",e.aliases=[];function e(t){t.languages.uorazor={"comment-hash":{pattern:/#.*/,alias:"comment",greedy:!0},"comment-slash":{pattern:/\/\/.*/,alias:"comment",greedy:!0},string:{pattern:/("|')(?:\\.|(?!\1)[^\\\r\n])*\1/,inside:{punctuation:/^['"]|['"]$/},greedy:!0},"source-layers":{pattern:/\b(?:arms|backpack|blue|bracelet|cancel|clear|cloak|criminal|earrings|enemy|facialhair|friend|friendly|gloves|gray|grey|ground|hair|head|innerlegs|innertorso|innocent|lefthand|middletorso|murderer|neck|nonfriendly|onehandedsecondary|outerlegs|outertorso|pants|red|righthand|ring|self|shirt|shoes|talisman|waist)\b/i,alias:"function"},"source-commands":{pattern:/\b(?:alliance|attack|cast|clearall|clearignore|clearjournal|clearlist|clearsysmsg|createlist|createtimer|dclick|dclicktype|dclickvar|dress|dressconfig|drop|droprelloc|emote|getlabel|guild|gumpclose|gumpresponse|hotkey|ignore|lasttarget|lift|lifttype|menu|menuresponse|msg|org|organize|organizer|overhead|pause|poplist|potion|promptresponse|pushlist|removelist|removetimer|rename|restock|say|scav|scavenger|script|setability|setlasttarget|setskill|settimer|setvar|sysmsg|target|targetloc|targetrelloc|targettype|undress|unignore|unsetvar|useobject|useonce|useskill|usetype|virtue|wait|waitforgump|waitformenu|waitforprompt|waitforstat|waitforsysmsg|waitfortarget|walk|wfsysmsg|wft|whisper|yell)\b/,alias:"function"},"tag-name":{pattern:/(^\{%-?\s*)\w+/,lookbehind:!0,alias:"keyword"},delimiter:{pattern:/^\{[{%]-?|-?[%}]\}$/,alias:"punctuation"},function:/\b(?:atlist|close|closest|count|counter|counttype|dead|dex|diffhits|diffmana|diffstam|diffweight|find|findbuff|finddebuff|findlayer|findtype|findtypelist|followers|gumpexists|hidden|hits|hp|hue|human|humanoid|ingump|inlist|insysmessage|insysmsg|int|invul|lhandempty|list|listexists|mana|maxhits|maxhp|maxmana|maxstam|maxweight|monster|mounted|name|next|noto|paralyzed|poisoned|position|prev|previous|queued|rand|random|rhandempty|skill|stam|str|targetexists|timer|timerexists|varexist|warmode|weight)\b/,keyword:/\b(?:and|as|break|continue|else|elseif|endfor|endif|endwhile|for|if|loop|not|or|replay|stop|while)\b/,boolean:/\b(?:false|null|true)\b/,number:/\b0x[\dA-Fa-f]+|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:[Ee][-+]?\d+)?/,operator:[{pattern:/(\s)(?:and|b-and|b-or|b-xor|ends with|in|is|matches|not|or|same as|starts with)(?=\s)/,lookbehind:!0},/[=<>]=?|!=|\*\*?|\/\/?|\?:?|[-+~%|]/],punctuation:/[()\[\]{}:.,]/}}return QE}var JE,nF;function fbe(){if(nF)return JE;nF=1,JE=e,e.displayName="uri",e.aliases=["url"];function e(t){t.languages.uri={scheme:{pattern:/^[a-z][a-z0-9+.-]*:/im,greedy:!0,inside:{"scheme-delimiter":/:$/}},fragment:{pattern:/#[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"fragment-delimiter":/^#/}},query:{pattern:/\?[\w\-.~!$&'()*+,;=%:@/?]*/,inside:{"query-delimiter":{pattern:/^\?/,greedy:!0},"pair-delimiter":/[&;]/,pair:{pattern:/^[^=][\s\S]*/,inside:{key:/^[^=]+/,value:{pattern:/(^=)[\s\S]+/,lookbehind:!0}}}}},authority:{pattern:RegExp(/^\/\//.source+/(?:[\w\-.~!$&'()*+,;=%:]*@)?/.source+("(?:"+/\[(?:[0-9a-fA-F:.]{2,48}|v[0-9a-fA-F]+\.[\w\-.~!$&'()*+,;=]+)\]/.source+"|"+/[\w\-.~!$&'()*+,;=%]*/.source+")")+/(?::\d*)?/.source,"m"),inside:{"authority-delimiter":/^\/\//,"user-info-segment":{pattern:/^[\w\-.~!$&'()*+,;=%:]*@/,inside:{"user-info-delimiter":/@$/,"user-info":/^[\w\-.~!$&'()*+,;=%:]+/}},"port-segment":{pattern:/:\d*$/,inside:{"port-delimiter":/^:/,port:/^\d+/}},host:{pattern:/[\s\S]+/,inside:{"ip-literal":{pattern:/^\[[\s\S]+\]$/,inside:{"ip-literal-delimiter":/^\[|\]$/,"ipv-future":/^v[\s\S]+/,"ipv6-address":/^[\s\S]+/}},"ipv4-address":/^(?:(?:[03-9]\d?|[12]\d{0,2})\.){3}(?:[03-9]\d?|[12]\d{0,2})$/}}}},path:{pattern:/^[\w\-.~!$&'()*+,;=%:@/]+/m,inside:{"path-separator":/\//}}},t.languages.url=t.languages.uri}return JE}var ew,rF;function pbe(){if(rF)return ew;rF=1,ew=e,e.displayName="v",e.aliases=[];function e(t){(function(n){var r={pattern:/[\s\S]+/,inside:null};n.languages.v=n.languages.extend("clike",{string:{pattern:/r?(["'])(?:\\(?:\r\n|[\s\S])|(?!\1)[^\\\r\n])*\1/,alias:"quoted-string",greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)\$(?:\{[^{}]*\}|\w+(?:\.\w+(?:\([^\(\)]*\))?|\[[^\[\]]+\])*)/,lookbehind:!0,inside:{"interpolation-variable":{pattern:/^\$\w[\s\S]*$/,alias:"variable"},"interpolation-punctuation":{pattern:/^\$\{|\}$/,alias:"punctuation"},"interpolation-expression":r}}}},"class-name":{pattern:/(\b(?:enum|interface|struct|type)\s+)(?:C\.)?\w+/,lookbehind:!0},keyword:/(?:\b(?:__global|as|asm|assert|atomic|break|chan|const|continue|defer|else|embed|enum|fn|for|go(?:to)?|if|import|in|interface|is|lock|match|module|mut|none|or|pub|return|rlock|select|shared|sizeof|static|struct|type(?:of)?|union|unsafe)|\$(?:else|for|if)|#(?:flag|include))\b/,number:/\b(?:0x[a-f\d]+(?:_[a-f\d]+)*|0b[01]+(?:_[01]+)*|0o[0-7]+(?:_[0-7]+)*|\d+(?:_\d+)*(?:\.\d+(?:_\d+)*)?)\b/i,operator:/~|\?|[*\/%^!=]=?|\+[=+]?|-[=-]?|\|[=|]?|&(?:=|&|\^=?)?|>(?:>=?|=)?|<(?:<=?|=|-)?|:=|\.\.\.?/,builtin:/\b(?:any(?:_float|_int)?|bool|byte(?:ptr)?|charptr|f(?:32|64)|i(?:8|16|64|128|nt)|rune|size_t|string|u(?:16|32|64|128)|voidptr)\b/}),r.inside=n.languages.v,n.languages.insertBefore("v","string",{char:{pattern:/`(?:\\`|\\?[^`]{1,2})`/,alias:"rune"}}),n.languages.insertBefore("v","operator",{attribute:{pattern:/(^[\t ]*)\[(?:deprecated|direct_array_access|flag|inline|live|ref_only|typedef|unsafe_fn|windows_stdcall)\]/m,lookbehind:!0,alias:"annotation",inside:{punctuation:/[\[\]]/,keyword:/\w+/}},generic:{pattern:/<\w+>(?=\s*[\)\{])/,inside:{punctuation:/[<>]/,"class-name":/\w+/}}}),n.languages.insertBefore("v","function",{"generic-function":{pattern:/\b\w+\s*<\w+>(?=\()/,inside:{function:/^\w+/,generic:{pattern:/<\w+>/,inside:n.languages.v.generic.inside}}}})})(t)}return ew}var tw,aF;function gbe(){if(aF)return tw;aF=1,tw=e,e.displayName="vala",e.aliases=[];function e(t){t.languages.vala=t.languages.extend("clike",{"class-name":[{pattern:/\b[A-Z]\w*(?:\.\w+)*\b(?=(?:\?\s+|\*?\s+\*?)\w)/,inside:{punctuation:/\./}},{pattern:/(\[)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/(\b(?:class|interface)\s+[A-Z]\w*(?:\.\w+)*\s*:\s*)[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}},{pattern:/((?:\b(?:class|enum|interface|new|struct)\s+)|(?:catch\s+\())[A-Z]\w*(?:\.\w+)*\b/,lookbehind:!0,inside:{punctuation:/\./}}],keyword:/\b(?:abstract|as|assert|async|base|bool|break|case|catch|char|class|const|construct|continue|default|delegate|delete|do|double|dynamic|else|ensures|enum|errordomain|extern|finally|float|for|foreach|get|if|in|inline|int|int16|int32|int64|int8|interface|internal|is|lock|long|namespace|new|null|out|override|owned|params|private|protected|public|ref|requires|return|set|short|signal|sizeof|size_t|ssize_t|static|string|struct|switch|this|throw|throws|try|typeof|uchar|uint|uint16|uint32|uint64|uint8|ulong|unichar|unowned|ushort|using|value|var|virtual|void|volatile|weak|while|yield)\b/i,function:/\b\w+(?=\s*\()/,number:/(?:\b0x[\da-f]+\b|(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:e[+-]?\d+)?)(?:f|u?l?)?/i,operator:/\+\+|--|&&|\|\||<<=?|>>=?|=>|->|~|[+\-*\/%&^|=!<>]=?|\?\??|\.\.\./,punctuation:/[{}[\];(),.:]/,constant:/\b[A-Z0-9_]+\b/}),t.languages.insertBefore("vala","string",{"raw-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"template-string":{pattern:/@"[\s\S]*?"/,greedy:!0,inside:{interpolation:{pattern:/\$(?:\([^)]*\)|[a-zA-Z]\w*)/,inside:{delimiter:{pattern:/^\$\(?|\)$/,alias:"punctuation"},rest:t.languages.vala}},string:/[\s\S]+/}}}),t.languages.insertBefore("vala","keyword",{regex:{pattern:/\/(?:\[(?:[^\]\\\r\n]|\\.)*\]|\\.|[^/\\\[\r\n])+\/[imsx]{0,4}(?=\s*(?:$|[\r\n,.;})\]]))/,greedy:!0,inside:{"regex-source":{pattern:/^(\/)[\s\S]+(?=\/[a-z]*$)/,lookbehind:!0,alias:"language-regex",inside:t.languages.regex},"regex-delimiter":/^\//,"regex-flags":/^[a-z]+$/}}})}return tw}var nw,oF;function hbe(){if(oF)return nw;oF=1,nw=e,e.displayName="velocity",e.aliases=[];function e(t){(function(n){n.languages.velocity=n.languages.extend("markup",{});var r={variable:{pattern:/(^|[^\\](?:\\\\)*)\$!?(?:[a-z][\w-]*(?:\([^)]*\))?(?:\.[a-z][\w-]*(?:\([^)]*\))?|\[[^\]]+\])*|\{[^}]+\})/i,lookbehind:!0,inside:{}},string:{pattern:/"[^"]*"|'[^']*'/,greedy:!0},number:/\b\d+\b/,boolean:/\b(?:false|true)\b/,operator:/[=!<>]=?|[+*/%-]|&&|\|\||\.\.|\b(?:eq|g[et]|l[et]|n(?:e|ot))\b/,punctuation:/[(){}[\]:,.]/};r.variable.inside={string:r.string,function:{pattern:/([^\w-])[a-z][\w-]*(?=\()/,lookbehind:!0},number:r.number,boolean:r.boolean,punctuation:r.punctuation},n.languages.insertBefore("velocity","comment",{unparsed:{pattern:/(^|[^\\])#\[\[[\s\S]*?\]\]#/,lookbehind:!0,greedy:!0,inside:{punctuation:/^#\[\[|\]\]#$/}},"velocity-comment":[{pattern:/(^|[^\\])#\*[\s\S]*?\*#/,lookbehind:!0,greedy:!0,alias:"comment"},{pattern:/(^|[^\\])##.*/,lookbehind:!0,greedy:!0,alias:"comment"}],directive:{pattern:/(^|[^\\](?:\\\\)*)#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})(?:\s*\((?:[^()]|\([^()]*\))*\))?/i,lookbehind:!0,inside:{keyword:{pattern:/^#@?(?:[a-z][\w-]*|\{[a-z][\w-]*\})|\bin\b/,inside:{punctuation:/[{}]/}},rest:r}},variable:r.variable}),n.languages.velocity.tag.inside["attr-value"].inside.rest=n.languages.velocity})(t)}return nw}var rw,iF;function mbe(){if(iF)return rw;iF=1,rw=e,e.displayName="verilog",e.aliases=[];function e(t){t.languages.verilog={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"(?:\\(?:\r\n|[\s\S])|[^"\\\r\n])*"/,greedy:!0},"kernel-function":{pattern:/\B\$\w+\b/,alias:"property"},constant:/\B`\w+\b/,function:/\b\w+(?=\()/,keyword:/\b(?:alias|and|assert|assign|assume|automatic|before|begin|bind|bins|binsof|bit|break|buf|bufif0|bufif1|byte|case|casex|casez|cell|chandle|class|clocking|cmos|config|const|constraint|context|continue|cover|covergroup|coverpoint|cross|deassign|default|defparam|design|disable|dist|do|edge|else|end|endcase|endclass|endclocking|endconfig|endfunction|endgenerate|endgroup|endinterface|endmodule|endpackage|endprimitive|endprogram|endproperty|endsequence|endspecify|endtable|endtask|enum|event|expect|export|extends|extern|final|first_match|for|force|foreach|forever|fork|forkjoin|function|generate|genvar|highz0|highz1|if|iff|ifnone|ignore_bins|illegal_bins|import|incdir|include|initial|inout|input|inside|instance|int|integer|interface|intersect|join|join_any|join_none|large|liblist|library|local|localparam|logic|longint|macromodule|matches|medium|modport|module|nand|negedge|new|nmos|nor|noshowcancelled|not|notif0|notif1|null|or|output|package|packed|parameter|pmos|posedge|primitive|priority|program|property|protected|pull0|pull1|pulldown|pullup|pulsestyle_ondetect|pulsestyle_onevent|pure|rand|randc|randcase|randsequence|rcmos|real|realtime|ref|reg|release|repeat|return|rnmos|rpmos|rtran|rtranif0|rtranif1|scalared|sequence|shortint|shortreal|showcancelled|signed|small|solve|specify|specparam|static|string|strong0|strong1|struct|super|supply0|supply1|table|tagged|task|this|throughout|time|timeprecision|timeunit|tran|tranif0|tranif1|tri|tri0|tri1|triand|trior|trireg|type|typedef|union|unique|unsigned|use|uwire|var|vectored|virtual|void|wait|wait_order|wand|weak0|weak1|while|wildcard|wire|with|within|wor|xnor|xor)\b/,important:/\b(?:always|always_comb|always_ff|always_latch)\b(?: *@)?/,number:/\B##?\d+|(?:\b\d+)?'[odbh] ?[\da-fzx_?]+|\b(?:\d*[._])?\d+(?:e[-+]?\d+)?/i,operator:/[-+{}^~%*\/?=!<>&|]+/,punctuation:/[[\];(),.:]/}}return rw}var aw,lF;function bbe(){if(lF)return aw;lF=1,aw=e,e.displayName="vhdl",e.aliases=[];function e(t){t.languages.vhdl={comment:/--.+/,"vhdl-vectors":{pattern:/\b[oxb]"[\da-f_]+"|"[01uxzwlh-]+"/i,alias:"number"},"quoted-function":{pattern:/"\S+?"(?=\()/,alias:"function"},string:/"(?:[^\\"\r\n]|\\(?:\r\n|[\s\S]))*"/,constant:/\b(?:library|use)\b/i,keyword:/\b(?:'active|'ascending|'base|'delayed|'driving|'driving_value|'event|'high|'image|'instance_name|'last_active|'last_event|'last_value|'left|'leftof|'length|'low|'path_name|'pos|'pred|'quiet|'range|'reverse_range|'right|'rightof|'simple_name|'stable|'succ|'transaction|'val|'value|access|after|alias|all|architecture|array|assert|attribute|begin|block|body|buffer|bus|case|component|configuration|constant|disconnect|downto|else|elsif|end|entity|exit|file|for|function|generate|generic|group|guarded|if|impure|in|inertial|inout|is|label|library|linkage|literal|loop|map|new|next|null|of|on|open|others|out|package|port|postponed|procedure|process|pure|range|record|register|reject|report|return|select|severity|shared|signal|subtype|then|to|transport|type|unaffected|units|until|use|variable|wait|when|while|with)\b/i,boolean:/\b(?:false|true)\b/i,function:/\w+(?=\()/,number:/'[01uxzwlh-]'|\b(?:\d+#[\da-f_.]+#|\d[\d_.]*)(?:e[-+]?\d+)?/i,operator:/[<>]=?|:=|[-+*/&=]|\b(?:abs|and|mod|nand|nor|not|or|rem|rol|ror|sla|sll|sra|srl|xnor|xor)\b/i,punctuation:/[{}[\];(),.:]/}}return aw}var ow,sF;function ybe(){if(sF)return ow;sF=1,ow=e,e.displayName="vim",e.aliases=[];function e(t){t.languages.vim={string:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\r\n]|'')*'/,comment:/".*/,function:/\b\w+(?=\()/,keyword:/\b(?:N|Next|P|Print|X|XMLent|XMLns|ab|abbreviate|abc|abclear|abo|aboveleft|al|all|ar|arga|argadd|argd|argdelete|argdo|arge|argedit|argg|argglobal|argl|arglocal|args|argu|argument|as|ascii|b|bN|bNext|ba|bad|badd|ball|bd|bdelete|be|bel|belowright|bf|bfirst|bl|blast|bm|bmodified|bn|bnext|bo|botright|bp|bprevious|br|brea|break|breaka|breakadd|breakd|breakdel|breakl|breaklist|brewind|bro|browse|bufdo|buffer|buffers|bun|bunload|bw|bwipeout|c|cN|cNext|cNfcNfile|ca|cabbrev|cabc|cabclear|cad|caddb|caddbuffer|caddexpr|caddf|caddfile|cal|call|cat|catch|cb|cbuffer|cc|ccl|cclose|cd|ce|center|cex|cexpr|cf|cfile|cfir|cfirst|cg|cgetb|cgetbuffer|cgete|cgetexpr|cgetfile|change|changes|chd|chdir|che|checkpath|checkt|checktime|cl|cla|clast|clist|clo|close|cmapc|cmapclear|cn|cnew|cnewer|cnext|cnf|cnfile|cnorea|cnoreabbrev|co|col|colder|colo|colorscheme|comc|comclear|comp|compiler|con|conf|confirm|continue|cope|copen|copy|cp|cpf|cpfile|cprevious|cq|cquit|cr|crewind|cu|cuna|cunabbrev|cunmap|cw|cwindow|d|debugg|debuggreedy|delc|delcommand|delete|delf|delfunction|delm|delmarks|di|diffg|diffget|diffoff|diffpatch|diffpu|diffput|diffsplit|diffthis|diffu|diffupdate|dig|digraphs|display|dj|djump|dl|dlist|dr|drop|ds|dsearch|dsp|dsplit|e|earlier|echoe|echoerr|echom|echomsg|echon|edit|el|else|elsei|elseif|em|emenu|en|endf|endfo|endfor|endfun|endfunction|endif|endt|endtry|endw|endwhile|ene|enew|ex|exi|exit|exu|exusage|f|file|files|filetype|fin|fina|finally|find|fini|finish|fir|first|fix|fixdel|fo|fold|foldc|foldclose|foldd|folddoc|folddoclosed|folddoopen|foldo|foldopen|for|fu|fun|function|go|goto|gr|grep|grepa|grepadd|h|ha|hardcopy|help|helpf|helpfind|helpg|helpgrep|helpt|helptags|hid|hide|his|history|ia|iabbrev|iabc|iabclear|if|ij|ijump|il|ilist|imapc|imapclear|in|inorea|inoreabbrev|isearch|isp|isplit|iu|iuna|iunabbrev|iunmap|j|join|ju|jumps|k|kee|keepalt|keepj|keepjumps|keepmarks|l|lN|lNext|lNf|lNfile|la|lad|laddb|laddbuffer|laddexpr|laddf|laddfile|lan|language|last|later|lb|lbuffer|lc|lcd|lch|lchdir|lcl|lclose|left|lefta|leftabove|let|lex|lexpr|lf|lfile|lfir|lfirst|lg|lgetb|lgetbuffer|lgete|lgetexpr|lgetfile|lgr|lgrep|lgrepa|lgrepadd|lh|lhelpgrep|list|ll|lla|llast|lli|llist|lm|lmak|lmake|lmap|lmapc|lmapclear|ln|lne|lnew|lnewer|lnext|lnf|lnfile|lnoremap|lo|loadview|loc|lockmarks|lockv|lockvar|lol|lolder|lop|lopen|lp|lpf|lpfile|lprevious|lr|lrewind|ls|lt|ltag|lu|lunmap|lv|lvimgrep|lvimgrepa|lvimgrepadd|lw|lwindow|m|ma|mak|make|mark|marks|mat|match|menut|menutranslate|mk|mkexrc|mks|mksession|mksp|mkspell|mkv|mkvie|mkview|mkvimrc|mod|mode|move|mz|mzf|mzfile|mzscheme|n|nbkey|new|next|nmapc|nmapclear|noh|nohlsearch|norea|noreabbrev|nu|number|nun|nunmap|o|omapc|omapclear|on|only|open|opt|options|ou|ounmap|p|pc|pclose|pe|ped|pedit|perl|perld|perldo|po|pop|popu|popup|pp|ppop|pre|preserve|prev|previous|print|prof|profd|profdel|profile|promptf|promptfind|promptr|promptrepl|ps|psearch|ptN|ptNext|pta|ptag|ptf|ptfirst|ptj|ptjump|ptl|ptlast|ptn|ptnext|ptp|ptprevious|ptr|ptrewind|pts|ptselect|pu|put|pw|pwd|py|pyf|pyfile|python|q|qa|qall|quit|quita|quitall|r|read|rec|recover|red|redi|redir|redo|redr|redraw|redraws|redrawstatus|reg|registers|res|resize|ret|retab|retu|return|rew|rewind|ri|right|rightb|rightbelow|ru|rub|ruby|rubyd|rubydo|rubyf|rubyfile|runtime|rv|rviminfo|sN|sNext|sa|sal|sall|san|sandbox|sargument|sav|saveas|sb|sbN|sbNext|sba|sball|sbf|sbfirst|sbl|sblast|sbm|sbmodified|sbn|sbnext|sbp|sbprevious|sbr|sbrewind|sbuffer|scrip|scripte|scriptencoding|scriptnames|se|set|setf|setfiletype|setg|setglobal|setl|setlocal|sf|sfind|sfir|sfirst|sh|shell|sign|sil|silent|sim|simalt|sl|sla|slast|sleep|sm|smagic|smap|smapc|smapclear|sme|smenu|sn|snext|sni|sniff|sno|snomagic|snor|snoremap|snoreme|snoremenu|so|sor|sort|source|sp|spe|spelld|spelldump|spellgood|spelli|spellinfo|spellr|spellrepall|spellu|spellundo|spellw|spellwrong|split|spr|sprevious|sre|srewind|st|sta|stag|star|startg|startgreplace|startinsert|startr|startreplace|stj|stjump|stop|stopi|stopinsert|sts|stselect|sun|sunhide|sunm|sunmap|sus|suspend|sv|sview|syncbind|t|tN|tNext|ta|tab|tabN|tabNext|tabc|tabclose|tabd|tabdo|tabe|tabedit|tabf|tabfind|tabfir|tabfirst|tabl|tablast|tabm|tabmove|tabn|tabnew|tabnext|tabo|tabonly|tabp|tabprevious|tabr|tabrewind|tabs|tag|tags|tc|tcl|tcld|tcldo|tclf|tclfile|te|tearoff|tf|tfirst|th|throw|tj|tjump|tl|tlast|tm|tmenu|tn|tnext|to|topleft|tp|tprevious|tr|trewind|try|ts|tselect|tu|tunmenu|u|una|unabbreviate|undo|undoj|undojoin|undol|undolist|unh|unhide|unlet|unlo|unlockvar|unm|unmap|up|update|ve|verb|verbose|version|vert|vertical|vi|vie|view|vim|vimgrep|vimgrepa|vimgrepadd|visual|viu|viusage|vmapc|vmapclear|vne|vnew|vs|vsplit|vu|vunmap|w|wN|wNext|wa|wall|wh|while|win|winc|wincmd|windo|winp|winpos|winsize|wn|wnext|wp|wprevious|wq|wqa|wqall|write|ws|wsverb|wv|wviminfo|x|xa|xall|xit|xm|xmap|xmapc|xmapclear|xme|xmenu|xn|xnoremap|xnoreme|xnoremenu|xu|xunmap|y|yank)\b/,builtin:/\b(?:acd|ai|akm|aleph|allowrevins|altkeymap|ambiwidth|ambw|anti|antialias|arab|arabic|arabicshape|ari|arshape|autochdir|autocmd|autoindent|autoread|autowrite|autowriteall|aw|awa|background|backspace|backup|backupcopy|backupdir|backupext|backupskip|balloondelay|ballooneval|balloonexpr|bdir|bdlay|beval|bex|bexpr|bg|bh|bin|binary|biosk|bioskey|bk|bkc|bomb|breakat|brk|browsedir|bs|bsdir|bsk|bt|bufhidden|buflisted|buftype|casemap|ccv|cdpath|cedit|cfu|ch|charconvert|ci|cin|cindent|cink|cinkeys|cino|cinoptions|cinw|cinwords|clipboard|cmdheight|cmdwinheight|cmp|cms|columns|com|comments|commentstring|compatible|complete|completefunc|completeopt|consk|conskey|copyindent|cot|cpo|cpoptions|cpt|cscopepathcomp|cscopeprg|cscopequickfix|cscopetag|cscopetagorder|cscopeverbose|cspc|csprg|csqf|cst|csto|csverb|cuc|cul|cursorcolumn|cursorline|cwh|debug|deco|def|define|delcombine|dex|dg|dict|dictionary|diff|diffexpr|diffopt|digraph|dip|dir|directory|dy|ea|ead|eadirection|eb|ed|edcompatible|ef|efm|ei|ek|enc|encoding|endofline|eol|ep|equalalways|equalprg|errorbells|errorfile|errorformat|esckeys|et|eventignore|expandtab|exrc|fcl|fcs|fdc|fde|fdi|fdl|fdls|fdm|fdn|fdo|fdt|fen|fenc|fencs|fex|ff|ffs|fileencoding|fileencodings|fileformat|fileformats|fillchars|fk|fkmap|flp|fml|fmr|foldcolumn|foldenable|foldexpr|foldignore|foldlevel|foldlevelstart|foldmarker|foldmethod|foldminlines|foldnestmax|foldtext|formatexpr|formatlistpat|formatoptions|formatprg|fp|fs|fsync|ft|gcr|gd|gdefault|gfm|gfn|gfs|gfw|ghr|gp|grepformat|grepprg|gtl|gtt|guicursor|guifont|guifontset|guifontwide|guiheadroom|guioptions|guipty|guitablabel|guitabtooltip|helpfile|helpheight|helplang|hf|hh|hi|hidden|highlight|hk|hkmap|hkmapp|hkp|hl|hlg|hls|hlsearch|ic|icon|iconstring|ignorecase|im|imactivatekey|imak|imc|imcmdline|imd|imdisable|imi|iminsert|ims|imsearch|inc|include|includeexpr|incsearch|inde|indentexpr|indentkeys|indk|inex|inf|infercase|insertmode|invacd|invai|invakm|invallowrevins|invaltkeymap|invanti|invantialias|invar|invarab|invarabic|invarabicshape|invari|invarshape|invautochdir|invautoindent|invautoread|invautowrite|invautowriteall|invaw|invawa|invbackup|invballooneval|invbeval|invbin|invbinary|invbiosk|invbioskey|invbk|invbl|invbomb|invbuflisted|invcf|invci|invcin|invcindent|invcompatible|invconfirm|invconsk|invconskey|invcopyindent|invcp|invcscopetag|invcscopeverbose|invcst|invcsverb|invcuc|invcul|invcursorcolumn|invcursorline|invdeco|invdelcombine|invdg|invdiff|invdigraph|invdisable|invea|inveb|inved|invedcompatible|invek|invendofline|inveol|invequalalways|inverrorbells|invesckeys|invet|invex|invexpandtab|invexrc|invfen|invfk|invfkmap|invfoldenable|invgd|invgdefault|invguipty|invhid|invhidden|invhk|invhkmap|invhkmapp|invhkp|invhls|invhlsearch|invic|invicon|invignorecase|invim|invimc|invimcmdline|invimd|invincsearch|invinf|invinfercase|invinsertmode|invis|invjoinspaces|invjs|invlazyredraw|invlbr|invlinebreak|invlisp|invlist|invloadplugins|invlpl|invlz|invma|invmacatsui|invmagic|invmh|invml|invmod|invmodeline|invmodifiable|invmodified|invmore|invmousef|invmousefocus|invmousehide|invnu|invnumber|invodev|invopendevice|invpaste|invpi|invpreserveindent|invpreviewwindow|invprompt|invpvw|invreadonly|invremap|invrestorescreen|invrevins|invri|invrightleft|invrightleftcmd|invrl|invrlc|invro|invrs|invru|invruler|invsb|invsc|invscb|invscrollbind|invscs|invsecure|invsft|invshellslash|invshelltemp|invshiftround|invshortname|invshowcmd|invshowfulltag|invshowmatch|invshowmode|invsi|invsm|invsmartcase|invsmartindent|invsmarttab|invsmd|invsn|invsol|invspell|invsplitbelow|invsplitright|invspr|invsr|invssl|invsta|invstartofline|invstmp|invswapfile|invswf|invta|invtagbsearch|invtagrelative|invtagstack|invtbi|invtbidi|invtbs|invtermbidi|invterse|invtextauto|invtextmode|invtf|invtgst|invtildeop|invtimeout|invtitle|invto|invtop|invtr|invttimeout|invttybuiltin|invttyfast|invtx|invvb|invvisualbell|invwa|invwarn|invwb|invweirdinvert|invwfh|invwfw|invwildmenu|invwinfixheight|invwinfixwidth|invwiv|invwmnu|invwrap|invwrapscan|invwrite|invwriteany|invwritebackup|invws|isf|isfname|isi|isident|isk|iskeyword|isprint|joinspaces|js|key|keymap|keymodel|keywordprg|km|kmp|kp|langmap|langmenu|laststatus|lazyredraw|lbr|lcs|linebreak|lines|linespace|lisp|lispwords|listchars|loadplugins|lpl|lsp|lz|macatsui|magic|makeef|makeprg|matchpairs|matchtime|maxcombine|maxfuncdepth|maxmapdepth|maxmem|maxmempattern|maxmemtot|mco|mef|menuitems|mfd|mh|mis|mkspellmem|ml|mls|mm|mmd|mmp|mmt|modeline|modelines|modifiable|modified|more|mouse|mousef|mousefocus|mousehide|mousem|mousemodel|mouses|mouseshape|mouset|mousetime|mp|mps|msm|mzq|mzquantum|nf|noacd|noai|noakm|noallowrevins|noaltkeymap|noanti|noantialias|noar|noarab|noarabic|noarabicshape|noari|noarshape|noautochdir|noautoindent|noautoread|noautowrite|noautowriteall|noaw|noawa|nobackup|noballooneval|nobeval|nobin|nobinary|nobiosk|nobioskey|nobk|nobl|nobomb|nobuflisted|nocf|noci|nocin|nocindent|nocompatible|noconfirm|noconsk|noconskey|nocopyindent|nocp|nocscopetag|nocscopeverbose|nocst|nocsverb|nocuc|nocul|nocursorcolumn|nocursorline|nodeco|nodelcombine|nodg|nodiff|nodigraph|nodisable|noea|noeb|noed|noedcompatible|noek|noendofline|noeol|noequalalways|noerrorbells|noesckeys|noet|noex|noexpandtab|noexrc|nofen|nofk|nofkmap|nofoldenable|nogd|nogdefault|noguipty|nohid|nohidden|nohk|nohkmap|nohkmapp|nohkp|nohls|noic|noicon|noignorecase|noim|noimc|noimcmdline|noimd|noincsearch|noinf|noinfercase|noinsertmode|nois|nojoinspaces|nojs|nolazyredraw|nolbr|nolinebreak|nolisp|nolist|noloadplugins|nolpl|nolz|noma|nomacatsui|nomagic|nomh|noml|nomod|nomodeline|nomodifiable|nomodified|nomore|nomousef|nomousefocus|nomousehide|nonu|nonumber|noodev|noopendevice|nopaste|nopi|nopreserveindent|nopreviewwindow|noprompt|nopvw|noreadonly|noremap|norestorescreen|norevins|nori|norightleft|norightleftcmd|norl|norlc|noro|nors|noru|noruler|nosb|nosc|noscb|noscrollbind|noscs|nosecure|nosft|noshellslash|noshelltemp|noshiftround|noshortname|noshowcmd|noshowfulltag|noshowmatch|noshowmode|nosi|nosm|nosmartcase|nosmartindent|nosmarttab|nosmd|nosn|nosol|nospell|nosplitbelow|nosplitright|nospr|nosr|nossl|nosta|nostartofline|nostmp|noswapfile|noswf|nota|notagbsearch|notagrelative|notagstack|notbi|notbidi|notbs|notermbidi|noterse|notextauto|notextmode|notf|notgst|notildeop|notimeout|notitle|noto|notop|notr|nottimeout|nottybuiltin|nottyfast|notx|novb|novisualbell|nowa|nowarn|nowb|noweirdinvert|nowfh|nowfw|nowildmenu|nowinfixheight|nowinfixwidth|nowiv|nowmnu|nowrap|nowrapscan|nowrite|nowriteany|nowritebackup|nows|nrformats|numberwidth|nuw|odev|oft|ofu|omnifunc|opendevice|operatorfunc|opfunc|osfiletype|pa|para|paragraphs|paste|pastetoggle|patchexpr|patchmode|path|pdev|penc|pex|pexpr|pfn|ph|pheader|pi|pm|pmbcs|pmbfn|popt|preserveindent|previewheight|previewwindow|printdevice|printencoding|printexpr|printfont|printheader|printmbcharset|printmbfont|printoptions|prompt|pt|pumheight|pvh|pvw|qe|quoteescape|readonly|remap|report|restorescreen|revins|rightleft|rightleftcmd|rl|rlc|ro|rs|rtp|ruf|ruler|rulerformat|runtimepath|sbo|sc|scb|scr|scroll|scrollbind|scrolljump|scrolloff|scrollopt|scs|sect|sections|secure|sel|selection|selectmode|sessionoptions|sft|shcf|shellcmdflag|shellpipe|shellquote|shellredir|shellslash|shelltemp|shelltype|shellxquote|shiftround|shiftwidth|shm|shortmess|shortname|showbreak|showcmd|showfulltag|showmatch|showmode|showtabline|shq|si|sidescroll|sidescrolloff|siso|sj|slm|smartcase|smartindent|smarttab|smc|smd|softtabstop|sol|spc|spell|spellcapcheck|spellfile|spelllang|spellsuggest|spf|spl|splitbelow|splitright|sps|sr|srr|ss|ssl|ssop|stal|startofline|statusline|stl|stmp|su|sua|suffixes|suffixesadd|sw|swapfile|swapsync|swb|swf|switchbuf|sws|sxq|syn|synmaxcol|syntax|t_AB|t_AF|t_AL|t_CS|t_CV|t_Ce|t_Co|t_Cs|t_DL|t_EI|t_F1|t_F2|t_F3|t_F4|t_F5|t_F6|t_F7|t_F8|t_F9|t_IE|t_IS|t_K1|t_K3|t_K4|t_K5|t_K6|t_K7|t_K8|t_K9|t_KA|t_KB|t_KC|t_KD|t_KE|t_KF|t_KG|t_KH|t_KI|t_KJ|t_KK|t_KL|t_RI|t_RV|t_SI|t_Sb|t_Sf|t_WP|t_WS|t_ZH|t_ZR|t_al|t_bc|t_cd|t_ce|t_cl|t_cm|t_cs|t_da|t_db|t_dl|t_fs|t_k1|t_k2|t_k3|t_k4|t_k5|t_k6|t_k7|t_k8|t_k9|t_kB|t_kD|t_kI|t_kN|t_kP|t_kb|t_kd|t_ke|t_kh|t_kl|t_kr|t_ks|t_ku|t_le|t_mb|t_md|t_me|t_mr|t_ms|t_nd|t_op|t_se|t_so|t_sr|t_te|t_ti|t_ts|t_ue|t_us|t_ut|t_vb|t_ve|t_vi|t_vs|t_xs|tabline|tabpagemax|tabstop|tagbsearch|taglength|tagrelative|tagstack|tal|tb|tbi|tbidi|tbis|tbs|tenc|term|termbidi|termencoding|terse|textauto|textmode|textwidth|tgst|thesaurus|tildeop|timeout|timeoutlen|title|titlelen|titleold|titlestring|toolbar|toolbariconsize|top|tpm|tsl|tsr|ttimeout|ttimeoutlen|ttm|tty|ttybuiltin|ttyfast|ttym|ttymouse|ttyscroll|ttytype|tw|tx|uc|ul|undolevels|updatecount|updatetime|ut|vb|vbs|vdir|verbosefile|vfile|viewdir|viewoptions|viminfo|virtualedit|visualbell|vop|wak|warn|wb|wc|wcm|wd|weirdinvert|wfh|wfw|whichwrap|wi|wig|wildchar|wildcharm|wildignore|wildmenu|wildmode|wildoptions|wim|winaltkeys|window|winfixheight|winfixwidth|winheight|winminheight|winminwidth|winwidth|wiv|wiw|wm|wmh|wmnu|wmw|wop|wrap|wrapmargin|wrapscan|writeany|writebackup|writedelay|ww)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?)\b/i,operator:/\|\||&&|[-+.]=?|[=!](?:[=~][#?]?)?|[<>]=?[#?]?|[*\/%?]|\b(?:is(?:not)?)\b/,punctuation:/[{}[\](),;:]/}}return ow}var iw,uF;function vbe(){if(uF)return iw;uF=1,iw=e,e.displayName="visualBasic",e.aliases=[];function e(t){t.languages["visual-basic"]={comment:{pattern:/(?:['‘’]|REM\b)(?:[^\r\n_]|_(?:\r\n?|\n)?)*/i,inside:{keyword:/^REM/i}},directive:{pattern:/#(?:Const|Else|ElseIf|End|ExternalChecksum|ExternalSource|If|Region)(?:\b_[ \t]*(?:\r\n?|\n)|.)+/i,alias:"property",greedy:!0},string:{pattern:/\$?["“”](?:["“”]{2}|[^"“”])*["“”]C?/i,greedy:!0},date:{pattern:/#[ \t]*(?:\d+([/-])\d+\1\d+(?:[ \t]+(?:\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?))?|\d+[ \t]*(?:AM|PM)|\d+:\d+(?::\d+)?(?:[ \t]*(?:AM|PM))?)[ \t]*#/i,alias:"number"},number:/(?:(?:\b\d+(?:\.\d+)?|\.\d+)(?:E[+-]?\d+)?|&[HO][\dA-F]+)(?:[FRD]|U?[ILS])?/i,boolean:/\b(?:False|Nothing|True)\b/i,keyword:/\b(?:AddHandler|AddressOf|Alias|And(?:Also)?|As|Boolean|ByRef|Byte|ByVal|Call|Case|Catch|C(?:Bool|Byte|Char|Date|Dbl|Dec|Int|Lng|Obj|SByte|Short|Sng|Str|Type|UInt|ULng|UShort)|Char|Class|Const|Continue|Currency|Date|Decimal|Declare|Default|Delegate|Dim|DirectCast|Do|Double|Each|Else(?:If)?|End(?:If)?|Enum|Erase|Error|Event|Exit|Finally|For|Friend|Function|Get(?:Type|XMLNamespace)?|Global|GoSub|GoTo|Handles|If|Implements|Imports|In|Inherits|Integer|Interface|Is|IsNot|Let|Lib|Like|Long|Loop|Me|Mod|Module|Must(?:Inherit|Override)|My(?:Base|Class)|Namespace|Narrowing|New|Next|Not(?:Inheritable|Overridable)?|Object|Of|On|Operator|Option(?:al)?|Or(?:Else)?|Out|Overloads|Overridable|Overrides|ParamArray|Partial|Private|Property|Protected|Public|RaiseEvent|ReadOnly|ReDim|RemoveHandler|Resume|Return|SByte|Select|Set|Shadows|Shared|short|Single|Static|Step|Stop|String|Structure|Sub|SyncLock|Then|Throw|To|Try|TryCast|Type|TypeOf|U(?:Integer|Long|Short)|Until|Using|Variant|Wend|When|While|Widening|With(?:Events)?|WriteOnly|Xor)\b/i,operator:/[+\-*/\\^<=>&#@$%!]|\b_(?=[ \t]*[\r\n])/,punctuation:/[{}().,:?]/},t.languages.vb=t.languages["visual-basic"],t.languages.vba=t.languages["visual-basic"]}return iw}var lw,cF;function Sbe(){if(cF)return lw;cF=1,lw=e,e.displayName="warpscript",e.aliases=[];function e(t){t.languages.warpscript={comment:/#.*|\/\/.*|\/\*[\s\S]*?\*\//,string:{pattern:/"(?:[^"\\\r\n]|\\.)*"|'(?:[^'\\\r\n]|\\.)*'|<'(?:[^\\']|'(?!>)|\\.)*'>/,greedy:!0},variable:/\$\S+/,macro:{pattern:/@\S+/,alias:"property"},keyword:/\b(?:BREAK|CHECKMACRO|CONTINUE|CUDF|DEFINED|DEFINEDMACRO|EVAL|FAIL|FOR|FOREACH|FORSTEP|IFT|IFTE|MSGFAIL|NRETURN|RETHROW|RETURN|SWITCH|TRY|UDF|UNTIL|WHILE)\b/,number:/[+-]?\b(?:NaN|Infinity|\d+(?:\.\d*)?(?:[Ee][+-]?\d+)?|0x[\da-fA-F]+|0b[01]+)\b/,boolean:/\b(?:F|T|false|true)\b/,punctuation:/<%|%>|[{}[\]()]/,operator:/==|&&?|\|\|?|\*\*?|>>>?|<<|[<>!~]=?|[-/%^]|\+!?|\b(?:AND|NOT|OR)\b/}}return lw}var sw,dF;function Ebe(){if(dF)return sw;dF=1,sw=e,e.displayName="wasm",e.aliases=[];function e(t){t.languages.wasm={comment:[/\(;[\s\S]*?;\)/,{pattern:/;;.*/,greedy:!0}],string:{pattern:/"(?:\\[\s\S]|[^"\\])*"/,greedy:!0},keyword:[{pattern:/\b(?:align|offset)=/,inside:{operator:/=/}},{pattern:/\b(?:(?:f32|f64|i32|i64)(?:\.(?:abs|add|and|ceil|clz|const|convert_[su]\/i(?:32|64)|copysign|ctz|demote\/f64|div(?:_[su])?|eqz?|extend_[su]\/i32|floor|ge(?:_[su])?|gt(?:_[su])?|le(?:_[su])?|load(?:(?:8|16|32)_[su])?|lt(?:_[su])?|max|min|mul|neg?|nearest|or|popcnt|promote\/f32|reinterpret\/[fi](?:32|64)|rem_[su]|rot[lr]|shl|shr_[su]|sqrt|store(?:8|16|32)?|sub|trunc(?:_[su]\/f(?:32|64))?|wrap\/i64|xor))?|memory\.(?:grow|size))\b/,inside:{punctuation:/\./}},/\b(?:anyfunc|block|br(?:_if|_table)?|call(?:_indirect)?|data|drop|elem|else|end|export|func|get_(?:global|local)|global|if|import|local|loop|memory|module|mut|nop|offset|param|result|return|select|set_(?:global|local)|start|table|tee_local|then|type|unreachable)\b/],variable:/\$[\w!#$%&'*+\-./:<=>?@\\^`|~]+/,number:/[+-]?\b(?:\d(?:_?\d)*(?:\.\d(?:_?\d)*)?(?:[eE][+-]?\d(?:_?\d)*)?|0x[\da-fA-F](?:_?[\da-fA-F])*(?:\.[\da-fA-F](?:_?[\da-fA-D])*)?(?:[pP][+-]?\d(?:_?\d)*)?)\b|\binf\b|\bnan(?::0x[\da-fA-F](?:_?[\da-fA-D])*)?\b/,punctuation:/[()]/}}return sw}var uw,fF;function wbe(){if(fF)return uw;fF=1,uw=e,e.displayName="webIdl",e.aliases=[];function e(t){(function(n){var r=/(?:\B-|\b_|\b)[A-Za-z][\w-]*(?![\w-])/.source,a="(?:"+/\b(?:unsigned\s+)?long\s+long(?![\w-])/.source+"|"+/\b(?:unrestricted|unsigned)\s+[a-z]+(?![\w-])/.source+"|"+/(?!(?:unrestricted|unsigned)\b)/.source+r+/(?:\s*<(?:[^<>]|<[^<>]*>)*>)?/.source+")"+/(?:\s*\?)?/.source,i={};n.languages["web-idl"]={comment:{pattern:/\/\/.*|\/\*[\s\S]*?\*\//,greedy:!0},string:{pattern:/"[^"]*"/,greedy:!0},namespace:{pattern:RegExp(/(\bnamespace\s+)/.source+r),lookbehind:!0},"class-name":[{pattern:/(^|[^\w-])(?:iterable|maplike|setlike)\s*<(?:[^<>]|<[^<>]*>)*>/,lookbehind:!0,inside:i},{pattern:RegExp(/(\b(?:attribute|const|deleter|getter|optional|setter)\s+)/.source+a),lookbehind:!0,inside:i},{pattern:RegExp("("+/\bcallback\s+/.source+r+/\s*=\s*/.source+")"+a),lookbehind:!0,inside:i},{pattern:RegExp(/(\btypedef\b\s*)/.source+a),lookbehind:!0,inside:i},{pattern:RegExp(/(\b(?:callback|dictionary|enum|interface(?:\s+mixin)?)\s+)(?!(?:interface|mixin)\b)/.source+r),lookbehind:!0},{pattern:RegExp(/(:\s*)/.source+r),lookbehind:!0},RegExp(r+/(?=\s+(?:implements|includes)\b)/.source),{pattern:RegExp(/(\b(?:implements|includes)\s+)/.source+r),lookbehind:!0},{pattern:RegExp(a+"(?="+/\s*(?:\.{3}\s*)?/.source+r+/\s*[(),;=]/.source+")"),inside:i}],builtin:/\b(?:ArrayBuffer|BigInt64Array|BigUint64Array|ByteString|DOMString|DataView|Float32Array|Float64Array|FrozenArray|Int16Array|Int32Array|Int8Array|ObservableArray|Promise|USVString|Uint16Array|Uint32Array|Uint8Array|Uint8ClampedArray)\b/,keyword:[/\b(?:async|attribute|callback|const|constructor|deleter|dictionary|enum|getter|implements|includes|inherit|interface|mixin|namespace|null|optional|or|partial|readonly|required|setter|static|stringifier|typedef|unrestricted)\b/,/\b(?:any|bigint|boolean|byte|double|float|iterable|long|maplike|object|octet|record|sequence|setlike|short|symbol|undefined|unsigned|void)\b/],boolean:/\b(?:false|true)\b/,number:{pattern:/(^|[^\w-])-?(?:0x[0-9a-f]+|(?:\d+(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?|NaN|Infinity)(?![\w-])/i,lookbehind:!0},operator:/\.{3}|[=:?<>-]/,punctuation:/[(){}[\].,;]/};for(var l in n.languages["web-idl"])l!=="class-name"&&(i[l]=n.languages["web-idl"][l]);n.languages.webidl=n.languages["web-idl"]})(t)}return uw}var cw,pF;function xbe(){if(pF)return cw;pF=1,cw=e,e.displayName="wiki",e.aliases=[];function e(t){t.languages.wiki=t.languages.extend("markup",{"block-comment":{pattern:/(^|[^\\])\/\*[\s\S]*?\*\//,lookbehind:!0,alias:"comment"},heading:{pattern:/^(=+)[^=\r\n].*?\1/m,inside:{punctuation:/^=+|=+$/,important:/.+/}},emphasis:{pattern:/('{2,5}).+?\1/,inside:{"bold-italic":{pattern:/(''''').+?(?=\1)/,lookbehind:!0,alias:["bold","italic"]},bold:{pattern:/(''')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},italic:{pattern:/('')[^'](?:.*?[^'])?(?=\1)/,lookbehind:!0},punctuation:/^''+|''+$/}},hr:{pattern:/^-{4,}/m,alias:"punctuation"},url:[/ISBN +(?:97[89][ -]?)?(?:\d[ -]?){9}[\dx]\b|(?:PMID|RFC) +\d+/i,/\[\[.+?\]\]|\[.+?\]/],variable:[/__[A-Z]+__/,/\{{3}.+?\}{3}/,/\{\{.+?\}\}/],symbol:[/^#redirect/im,/~{3,5}/],"table-tag":{pattern:/((?:^|[|!])[|!])[^|\r\n]+\|(?!\|)/m,lookbehind:!0,inside:{"table-bar":{pattern:/\|$/,alias:"punctuation"},rest:t.languages.markup.tag.inside}},punctuation:/^(?:\{\||\|\}|\|-|[*#:;!|])|\|\||!!/m}),t.languages.insertBefore("wiki","tag",{nowiki:{pattern:/<(nowiki|pre|source)\b[^>]*>[\s\S]*?<\/\1>/i,inside:{tag:{pattern:/<(?:nowiki|pre|source)\b[^>]*>|<\/(?:nowiki|pre|source)>/i,inside:t.languages.markup.tag.inside}}}})}return cw}var dw,gF;function kbe(){if(gF)return dw;gF=1,dw=e,e.displayName="wolfram",e.aliases=["mathematica","wl","nb"];function e(t){t.languages.wolfram={comment:/\(\*(?:\(\*(?:[^*]|\*(?!\)))*\*\)|(?!\(\*)[\s\S])*?\*\)/,string:{pattern:/"(?:\\.|[^"\\\r\n])*"/,greedy:!0},keyword:/\b(?:Abs|AbsArg|Accuracy|Block|Do|For|Function|If|Manipulate|Module|Nest|NestList|None|Return|Switch|Table|Which|While)\b/,context:{pattern:/\b\w+`+\w*/,alias:"class-name"},blank:{pattern:/\b\w+_\b/,alias:"regex"},"global-variable":{pattern:/\$\w+/,alias:"variable"},boolean:/\b(?:False|True)\b/,number:/(?:\b(?=\d)|\B(?=\.))(?:0[bo])?(?:(?:\d|0x[\da-f])[\da-f]*(?:\.\d*)?|\.\d+)(?:e[+-]?\d+)?j?\b/i,operator:/\/\.|;|=\.|\^=|\^:=|:=|<<|>>|<\||\|>|:>|\|->|->|<-|@@@|@@|@|\/@|=!=|===|==|=|\+|-|\^|\[\/-+%=\]=?|!=|\*\*?=?|\/\/?=?|<[<=>]?|>[=>]?|[&|^~]/,punctuation:/[{}[\];(),.:]/},t.languages.mathematica=t.languages.wolfram,t.languages.wl=t.languages.wolfram,t.languages.nb=t.languages.wolfram}return dw}var fw,hF;function Abe(){if(hF)return fw;hF=1,fw=e,e.displayName="wren",e.aliases=[];function e(t){t.languages.wren={comment:[{pattern:/\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*)|\/\*(?:[^*/]|\*(?!\/)|\/(?!\*))*\*\/)*\*\/)*\*\//,greedy:!0},{pattern:/(^|[^\\:])\/\/.*/,lookbehind:!0,greedy:!0}],"triple-quoted-string":{pattern:/"""[\s\S]*?"""/,greedy:!0,alias:"string"},"string-literal":null,hashbang:{pattern:/^#!\/.+/,greedy:!0,alias:"comment"},attribute:{pattern:/#!?[ \t\u3000]*\w+/,alias:"keyword"},"class-name":[{pattern:/(\bclass\s+)\w+/,lookbehind:!0},/\b[A-Z][a-z\d_]*\b/],constant:/\b[A-Z][A-Z\d_]*\b/,null:{pattern:/\bnull\b/,alias:"keyword"},keyword:/\b(?:as|break|class|construct|continue|else|for|foreign|if|import|in|is|return|static|super|this|var|while)\b/,boolean:/\b(?:false|true)\b/,number:/\b(?:0x[\da-f]+|\d+(?:\.\d+)?(?:e[+-]?\d+)?)\b/i,function:/\b[a-z_]\w*(?=\s*[({])/i,operator:/<<|>>|[=!<>]=?|&&|\|\||[-+*/%~^&|?:]|\.{2,3}/,punctuation:/[\[\](){}.,;]/},t.languages.wren["string-literal"]={pattern:/(^|[^\\"])"(?:[^\\"%]|\\[\s\S]|%(?!\()|%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\))*"/,lookbehind:!0,greedy:!0,inside:{interpolation:{pattern:/((?:^|[^\\])(?:\\{2})*)%\((?:[^()]|\((?:[^()]|\([^)]*\))*\))*\)/,lookbehind:!0,inside:{expression:{pattern:/^(%\()[\s\S]+(?=\)$)/,lookbehind:!0,inside:t.languages.wren},"interpolation-punctuation":{pattern:/^%\(|\)$/,alias:"punctuation"}}},string:/[\s\S]+/}}}return fw}var pw,mF;function Tbe(){if(mF)return pw;mF=1,pw=e,e.displayName="xeora",e.aliases=["xeoracube"];function e(t){(function(n){n.languages.xeora=n.languages.extend("markup",{constant:{pattern:/\$(?:DomainContents|PageRenderDuration)\$/,inside:{punctuation:{pattern:/\$/}}},variable:{pattern:/\$@?(?:#+|[-+*~=^])?[\w.]+\$/,inside:{punctuation:{pattern:/[$.]/},operator:{pattern:/#+|[-+*~=^@]/}}},"function-inline":{pattern:/\$F:[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\$/,inside:{variable:{pattern:/(?:[,|])@?(?:#+|[-+*~=^])?[\w.]+/,inside:{punctuation:{pattern:/[,.|]/},operator:{pattern:/#+|[-+*~=^@]/}}},punctuation:{pattern:/\$\w:|[$:?.,|]/}},alias:"function"},"function-block":{pattern:/\$XF:\{[-\w.]+\?[-\w.]+(?:,(?:(?:@[-#]*\w+\.[\w+.]\.*)*\|)*(?:(?:[\w+]|[-#*.~^]+[\w+]|=\S)(?:[^$=]|=+[^=])*=*|(?:@[-#]*\w+\.[\w+.]\.*)+(?:(?:[\w+]|[-#*~^][-#*.~^]*[\w+]|=\S)(?:[^$=]|=+[^=])*=*)?)?)?\}:XF\$/,inside:{punctuation:{pattern:/[$:{}?.,|]/}},alias:"function"},"directive-inline":{pattern:/\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\/\w.]+\$/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}}},alias:"function"},"directive-block-open":{pattern:/\$\w+:\{|\$\w(?:#\d+\+?)?(?:\[[-\w.]+\])?:[-\w.]+:\{(?:![A-Z]+)?/,inside:{punctuation:{pattern:/\$(?:\w:|C(?:\[|#\d))?|[:{[\]]/,inside:{tag:{pattern:/#\d/}}},attribute:{pattern:/![A-Z]+$/,inside:{punctuation:{pattern:/!/}},alias:"keyword"}},alias:"function"},"directive-block-separator":{pattern:/\}:[-\w.]+:\{/,inside:{punctuation:{pattern:/[:{}]/}},alias:"function"},"directive-block-close":{pattern:/\}:[-\w.]+\$/,inside:{punctuation:{pattern:/[:{}$]/}},alias:"function"}}),n.languages.insertBefore("inside","punctuation",{variable:n.languages.xeora["function-inline"].inside.variable},n.languages.xeora["function-block"]),n.languages.xeoracube=n.languages.xeora})(t)}return pw}var gw,bF;function _be(){if(bF)return gw;bF=1,gw=e,e.displayName="xmlDoc",e.aliases=[];function e(t){(function(n){function r(u,c){n.languages[u]&&n.languages.insertBefore(u,"comment",{"doc-comment":c})}var a=n.languages.markup.tag,i={pattern:/\/\/\/.*/,greedy:!0,alias:"comment",inside:{tag:a}},l={pattern:/'''.*/,greedy:!0,alias:"comment",inside:{tag:a}};r("csharp",i),r("fsharp",i),r("vbnet",l)})(t)}return gw}var hw,yF;function Rbe(){if(yF)return hw;yF=1,hw=e,e.displayName="xojo",e.aliases=[];function e(t){t.languages.xojo={comment:{pattern:/(?:'|\/\/|Rem\b).+/i,greedy:!0},string:{pattern:/"(?:""|[^"])*"/,greedy:!0},number:[/(?:\b\d+(?:\.\d*)?|\B\.\d+)(?:E[+-]?\d+)?/i,/&[bchou][a-z\d]+/i],directive:{pattern:/#(?:Else|ElseIf|Endif|If|Pragma)\b/i,alias:"property"},keyword:/\b(?:AddHandler|App|Array|As(?:signs)?|Auto|Boolean|Break|By(?:Ref|Val)|Byte|Call|Case|Catch|CFStringRef|CGFloat|Class|Color|Const|Continue|CString|Currency|CurrentMethodName|Declare|Delegate|Dim|Do(?:uble|wnTo)?|Each|Else(?:If)?|End|Enumeration|Event|Exception|Exit|Extends|False|Finally|For|Function|Get|GetTypeInfo|Global|GOTO|If|Implements|In|Inherits|Int(?:8|16|32|64|eger|erface)?|Lib|Loop|Me|Module|Next|Nil|Object|Optional|OSType|ParamArray|Private|Property|Protected|PString|Ptr|Raise(?:Event)?|ReDim|RemoveHandler|Return|Select(?:or)?|Self|Set|Shared|Short|Single|Soft|Static|Step|String|Sub|Super|Text|Then|To|True|Try|Ubound|UInt(?:8|16|32|64|eger)?|Until|Using|Var(?:iant)?|Wend|While|WindowPtr|WString)\b/i,operator:/<[=>]?|>=?|[+\-*\/\\^=]|\b(?:AddressOf|And|Ctype|IsA?|Mod|New|Not|Or|WeakAddressOf|Xor)\b/i,punctuation:/[.,;:()]/}}return hw}var mw,vF;function Cbe(){if(vF)return mw;vF=1,mw=e,e.displayName="xquery",e.aliases=[];function e(t){(function(n){n.languages.xquery=n.languages.extend("markup",{"xquery-comment":{pattern:/\(:[\s\S]*?:\)/,greedy:!0,alias:"comment"},string:{pattern:/(["'])(?:\1\1|(?!\1)[\s\S])*\1/,greedy:!0},extension:{pattern:/\(#.+?#\)/,alias:"symbol"},variable:/\$[-\w:]+/,axis:{pattern:/(^|[^-])(?:ancestor(?:-or-self)?|attribute|child|descendant(?:-or-self)?|following(?:-sibling)?|parent|preceding(?:-sibling)?|self)(?=::)/,lookbehind:!0,alias:"operator"},"keyword-operator":{pattern:/(^|[^:-])\b(?:and|castable as|div|eq|except|ge|gt|idiv|instance of|intersect|is|le|lt|mod|ne|or|union)\b(?=$|[^:-])/,lookbehind:!0,alias:"operator"},keyword:{pattern:/(^|[^:-])\b(?:as|ascending|at|base-uri|boundary-space|case|cast as|collation|construction|copy-namespaces|declare|default|descending|else|empty (?:greatest|least)|encoding|every|external|for|function|if|import|in|inherit|lax|let|map|module|namespace|no-inherit|no-preserve|option|order(?: by|ed|ing)?|preserve|return|satisfies|schema|some|stable|strict|strip|then|to|treat as|typeswitch|unordered|validate|variable|version|where|xquery)\b(?=$|[^:-])/,lookbehind:!0},function:/[\w-]+(?::[\w-]+)*(?=\s*\()/,"xquery-element":{pattern:/(element\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"tag"},"xquery-attribute":{pattern:/(attribute\s+)[\w-]+(?::[\w-]+)*/,lookbehind:!0,alias:"attr-name"},builtin:{pattern:/(^|[^:-])\b(?:attribute|comment|document|element|processing-instruction|text|xs:(?:ENTITIES|ENTITY|ID|IDREFS?|NCName|NMTOKENS?|NOTATION|Name|QName|anyAtomicType|anyType|anyURI|base64Binary|boolean|byte|date|dateTime|dayTimeDuration|decimal|double|duration|float|gDay|gMonth|gMonthDay|gYear|gYearMonth|hexBinary|int|integer|language|long|negativeInteger|nonNegativeInteger|nonPositiveInteger|normalizedString|positiveInteger|short|string|time|token|unsigned(?:Byte|Int|Long|Short)|untyped(?:Atomic)?|yearMonthDuration))\b(?=$|[^:-])/,lookbehind:!0},number:/\b\d+(?:\.\d+)?(?:E[+-]?\d+)?/,operator:[/[+*=?|@]|\.\.?|:=|!=|<[=<]?|>[=>]?/,{pattern:/(\s)-(?=\s)/,lookbehind:!0}],punctuation:/[[\](){},;:/]/}),n.languages.xquery.tag.pattern=/<\/?(?!\d)[^\s>\/=$<%]+(?:\s+[^\s>\/=]+(?:=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+))?)*\s*\/?>/,n.languages.xquery.tag.inside["attr-value"].pattern=/=(?:("|')(?:\\[\s\S]|\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}|(?!\1)[^\\])*\1|[^\s'">=]+)/,n.languages.xquery.tag.inside["attr-value"].inside.punctuation=/^="|"$/,n.languages.xquery.tag.inside["attr-value"].inside.expression={pattern:/\{(?!\{)(?:\{(?:\{[^{}]*\}|[^{}])*\}|[^{}])+\}/,inside:n.languages.xquery,alias:"language-xquery"};var r=function(i){return typeof i=="string"?i:typeof i.content=="string"?i.content:i.content.map(r).join("")},a=function(i){for(var l=[],u=0;u<i.length;u++){var c=i[u],f=!1;if(typeof c!="string"&&(c.type==="tag"&&c.content[0]&&c.content[0].type==="tag"?c.content[0].content[0].content==="</"?l.length>0&&l[l.length-1].tagName===r(c.content[0].content[1])&&l.pop():c.content[c.content.length-1].content==="/>"||l.push({tagName:r(c.content[0].content[1]),openedBraces:0}):l.length>0&&c.type==="punctuation"&&c.content==="{"&&(!i[u+1]||i[u+1].type!=="punctuation"||i[u+1].content!=="{")&&(!i[u-1]||i[u-1].type!=="plain-text"||i[u-1].content!=="{")?l[l.length-1].openedBraces++:l.length>0&&l[l.length-1].openedBraces>0&&c.type==="punctuation"&&c.content==="}"?l[l.length-1].openedBraces--:c.type!=="comment"&&(f=!0)),(f||typeof c=="string")&&l.length>0&&l[l.length-1].openedBraces===0){var p=r(c);u<i.length-1&&(typeof i[u+1]=="string"||i[u+1].type==="plain-text")&&(p+=r(i[u+1]),i.splice(u+1,1)),u>0&&(typeof i[u-1]=="string"||i[u-1].type==="plain-text")&&(p=r(i[u-1])+p,i.splice(u-1,1),u--),/^\s+$/.test(p)?i[u]=p:i[u]=new n.Token("plain-text",p,null,p)}c.content&&typeof c.content!="string"&&a(c.content)}};n.hooks.add("after-tokenize",function(i){i.language==="xquery"&&a(i.tokens)})})(t)}return mw}var bw,SF;function Nbe(){if(SF)return bw;SF=1,bw=e,e.displayName="yang",e.aliases=[];function e(t){t.languages.yang={comment:/\/\*[\s\S]*?\*\/|\/\/.*/,string:{pattern:/"(?:[^\\"]|\\.)*"|'[^']*'/,greedy:!0},keyword:{pattern:/(^|[{};\r\n][ \t]*)[a-z_][\w.-]*/i,lookbehind:!0},namespace:{pattern:/(\s)[a-z_][\w.-]*(?=:)/i,lookbehind:!0},boolean:/\b(?:false|true)\b/,operator:/\+/,punctuation:/[{};:]/}}return bw}var yw,EF;function Obe(){if(EF)return yw;EF=1,yw=e,e.displayName="zig",e.aliases=[];function e(t){(function(n){function r(p){return function(){return p}}var a=/\b(?:align|allowzero|and|anyframe|anytype|asm|async|await|break|cancel|catch|comptime|const|continue|defer|else|enum|errdefer|error|export|extern|fn|for|if|inline|linksection|nakedcc|noalias|nosuspend|null|or|orelse|packed|promise|pub|resume|return|stdcallcc|struct|suspend|switch|test|threadlocal|try|undefined|union|unreachable|usingnamespace|var|volatile|while)\b/,i="\\b(?!"+a.source+")(?!\\d)\\w+\\b",l=/align\s*\((?:[^()]|\([^()]*\))*\)/.source,u=/(?:\?|\bpromise->|(?:\[[^[\]]*\]|\*(?!\*)|\*\*)(?:\s*<ALIGN>|\s*const\b|\s*volatile\b|\s*allowzero\b)*)/.source.replace(/<ALIGN>/g,r(l)),c=/(?:\bpromise\b|(?:\berror\.)?<ID>(?:\.<ID>)*(?!\s+<ID>))/.source.replace(/<ID>/g,r(i)),f="(?!\\s)(?:!?\\s*(?:"+u+"\\s*)*"+c+")+";n.languages.zig={comment:[{pattern:/\/\/[/!].*/,alias:"doc-comment"},/\/{2}.*/],string:[{pattern:/(^|[^\\@])c?"(?:[^"\\\r\n]|\\.)*"/,lookbehind:!0,greedy:!0},{pattern:/([\r\n])([ \t]+c?\\{2}).*(?:(?:\r\n?|\n)\2.*)*/,lookbehind:!0,greedy:!0}],char:{pattern:/(^|[^\\])'(?:[^'\\\r\n]|[\uD800-\uDFFF]{2}|\\(?:.|x[a-fA-F\d]{2}|u\{[a-fA-F\d]{1,6}\}))'/,lookbehind:!0,greedy:!0},builtin:/\B@(?!\d)\w+(?=\s*\()/,label:{pattern:/(\b(?:break|continue)\s*:\s*)\w+\b|\b(?!\d)\w+\b(?=\s*:\s*(?:\{|while\b))/,lookbehind:!0},"class-name":[/\b(?!\d)\w+(?=\s*=\s*(?:(?:extern|packed)\s+)?(?:enum|struct|union)\s*[({])/,{pattern:RegExp(/(:\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?[=;,)])|<TYPE>(?=\s*(?:<ALIGN>\s*)?\{)/.source.replace(/<TYPE>/g,r(f)).replace(/<ALIGN>/g,r(l))),lookbehind:!0,inside:null},{pattern:RegExp(/(\)\s*)<TYPE>(?=\s*(?:<ALIGN>\s*)?;)/.source.replace(/<TYPE>/g,r(f)).replace(/<ALIGN>/g,r(l))),lookbehind:!0,inside:null}],"builtin-type":{pattern:/\b(?:anyerror|bool|c_u?(?:int|long|longlong|short)|c_longdouble|c_void|comptime_(?:float|int)|f(?:16|32|64|128)|[iu](?:8|16|32|64|128|size)|noreturn|type|void)\b/,alias:"keyword"},keyword:a,function:/\b(?!\d)\w+(?=\s*\()/,number:/\b(?:0b[01]+|0o[0-7]+|0x[a-fA-F\d]+(?:\.[a-fA-F\d]*)?(?:[pP][+-]?[a-fA-F\d]+)?|\d+(?:\.\d*)?(?:[eE][+-]?\d+)?)\b/,boolean:/\b(?:false|true)\b/,operator:/\.[*?]|\.{2,3}|[-=]>|\*\*|\+\+|\|\||(?:<<|>>|[-+*]%|[-+*/%^&|<>!=])=?|[?~]/,punctuation:/[.:,;(){}[\]]/},n.languages.zig["class-name"].forEach(function(p){p.inside===null&&(p.inside=n.languages.zig)})})(t)}return yw}var vw,wF;function Dbe(){if(wF)return vw;wF=1;var e=Yfe();return vw=e,e.register(Xfe()),e.register(Zfe()),e.register(Qfe()),e.register(Jfe()),e.register(epe()),e.register(tpe()),e.register(npe()),e.register(rpe()),e.register(ape()),e.register(ope()),e.register(ipe()),e.register(lpe()),e.register(spe()),e.register(upe()),e.register(cpe()),e.register(dpe()),e.register(fpe()),e.register(ppe()),e.register(gpe()),e.register(hpe()),e.register(mpe()),e.register(bpe()),e.register(V5()),e.register(W5()),e.register(ype()),e.register(vpe()),e.register(Spe()),e.register(Epe()),e.register(wpe()),e.register(xpe()),e.register(kpe()),e.register(Ape()),e.register(Tpe()),e.register(_pe()),e.register(fi()),e.register(Rpe()),e.register(Cpe()),e.register(Npe()),e.register(Ope()),e.register(Dpe()),e.register(Ipe()),e.register(Lpe()),e.register(Mpe()),e.register(Fpe()),e.register(uA()),e.register(zpe()),e.register(Vf()),e.register(Ppe()),e.register(Bpe()),e.register(Upe()),e.register(jpe()),e.register(Gpe()),e.register(Hpe()),e.register($pe()),e.register(qpe()),e.register(Vpe()),e.register(Wpe()),e.register(Ype()),e.register(Kpe()),e.register(Xpe()),e.register(Zpe()),e.register(Qpe()),e.register(Jpe()),e.register(ege()),e.register(tge()),e.register(nge()),e.register(rge()),e.register(age()),e.register(oge()),e.register(ige()),e.register(lge()),e.register(sge()),e.register(uge()),e.register(cge()),e.register(dge()),e.register(fge()),e.register(pge()),e.register(gge()),e.register(hge()),e.register(mge()),e.register(bge()),e.register(yge()),e.register(vge()),e.register(Sge()),e.register(Ege()),e.register(wge()),e.register(xge()),e.register(kge()),e.register(Age()),e.register(Tge()),e.register(_ge()),e.register(Rge()),e.register(Cge()),e.register(Nge()),e.register(cA()),e.register(Oge()),e.register(Dge()),e.register(Ige()),e.register(Lge()),e.register(Mge()),e.register(Fge()),e.register(zge()),e.register(Pge()),e.register(Bge()),e.register(Uge()),e.register(jge()),e.register(Gge()),e.register(Hge()),e.register($ge()),e.register(qge()),e.register(Vge()),e.register(Wge()),e.register(dA()),e.register(Yge()),e.register(Yf()),e.register(Kge()),e.register(Xge()),e.register(Zge()),e.register(Qge()),e.register(Jge()),e.register(ehe()),e.register(the()),e.register(pA()),e.register(nhe()),e.register(rhe()),e.register(ahe()),e.register(K5()),e.register(ohe()),e.register(ihe()),e.register(lhe()),e.register(she()),e.register(uhe()),e.register(che()),e.register(dhe()),e.register(fhe()),e.register(phe()),e.register(ghe()),e.register(hhe()),e.register(mhe()),e.register(bhe()),e.register(yhe()),e.register(vhe()),e.register(She()),e.register(Y5()),e.register(Ehe()),e.register(whe()),e.register(xhe()),e.register(Gn()),e.register(khe()),e.register(Ahe()),e.register(The()),e.register(_he()),e.register(Rhe()),e.register(Che()),e.register(Nhe()),e.register(Ohe()),e.register(Dhe()),e.register(Ihe()),e.register(Lhe()),e.register(Mhe()),e.register(Fhe()),e.register(zhe()),e.register(Phe()),e.register(Bhe()),e.register(Uhe()),e.register(jhe()),e.register(Ghe()),e.register(Hhe()),e.register($he()),e.register(qhe()),e.register(Vhe()),e.register(Whe()),e.register(Yhe()),e.register(Khe()),e.register(Xhe()),e.register(Zhe()),e.register(Qhe()),e.register(Jhe()),e.register(eme()),e.register(tme()),e.register(Kf()),e.register(nme()),e.register(rme()),e.register(ame()),e.register(ome()),e.register(ime()),e.register(lme()),e.register(sme()),e.register(ume()),e.register(cme()),e.register(dme()),e.register(fme()),e.register(pme()),e.register(gme()),e.register(hme()),e.register(mme()),e.register(bme()),e.register(yme()),e.register(vme()),e.register(Sme()),e.register(Eme()),e.register(wme()),e.register(xme()),e.register(kme()),e.register(Ame()),e.register(Tme()),e.register(_me()),e.register(Rme()),e.register(Cme()),e.register(Nme()),e.register(Ome()),e.register(Wf()),e.register(Dme()),e.register(Ime()),e.register(Lme()),e.register(Mme()),e.register(gA()),e.register(Fme()),e.register(zme()),e.register(Pme()),e.register(Bme()),e.register(Ume()),e.register(jme()),e.register(Gme()),e.register(Hme()),e.register($me()),e.register(qme()),e.register(Vme()),e.register(Wme()),e.register(sA()),e.register(Yme()),e.register(Kme()),e.register(Xme()),e.register(Zme()),e.register(Qme()),e.register(Jme()),e.register(hA()),e.register(ebe()),e.register(tbe()),e.register(nbe()),e.register(rbe()),e.register(abe()),e.register(obe()),e.register(ibe()),e.register(lbe()),e.register(X5()),e.register(sbe()),e.register(fA()),e.register(ube()),e.register(cbe()),e.register(dbe()),e.register(fbe()),e.register(pbe()),e.register(gbe()),e.register(Z5()),e.register(hbe()),e.register(mbe()),e.register(bbe()),e.register(ybe()),e.register(vbe()),e.register(Sbe()),e.register(Ebe()),e.register(wbe()),e.register(xbe()),e.register(kbe()),e.register(Abe()),e.register(Tbe()),e.register(_be()),e.register(Rbe()),e.register(Cbe()),e.register(Q5()),e.register(Nbe()),e.register(Obe()),vw}var Ibe=Dbe();const Lbe=an(Ibe);var J5=Sce(Lbe,Kfe);J5.supportedLanguages=Ece;var Sw={},Ew={exports:{}},xF;function Mbe(){return xF||(xF=1,function(e){function t(n){return n&&n.__esModule?n:{default:n}}e.exports=t,e.exports.__esModule=!0,e.exports.default=e.exports}(Ew)),Ew.exports}var ww={},kF;function Fbe(){return kF||(kF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",maxHeight:"inherit",height:"inherit",padding:"0 1em",display:"block",overflow:"auto"},'pre[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",position:"relative",margin:".5em 0",overflow:"visible",padding:"1px",backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box",marginBottom:"1em"},'pre[class*="language-"] > code':{position:"relative",zIndex:"1",borderLeft:"10px solid #358ccb",boxShadow:"-1px 0px 0px 0px #358ccb, 0px 0px 0px 1px #dfdfdf",backgroundColor:"#fdfdfd",backgroundImage:"linear-gradient(transparent 50%, rgba(69, 142, 209, 0.04) 50%)",backgroundSize:"3em 3em",backgroundOrigin:"content-box",backgroundAttachment:"local"},':not(pre) > code[class*="language-"]':{backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box",marginBottom:"1em",position:"relative",padding:".2em",borderRadius:"0.3em",color:"#c92c2c",border:"1px solid rgba(0, 0, 0, 0.1)",display:"inline",whiteSpace:"normal"},'pre[class*="language-"]:before':{content:"''",display:"block",position:"absolute",bottom:"0.75em",left:"0.18em",width:"40%",height:"20%",maxHeight:"13em",boxShadow:"0px 13px 8px #979797",WebkitTransform:"rotate(-2deg)",MozTransform:"rotate(-2deg)",msTransform:"rotate(-2deg)",OTransform:"rotate(-2deg)",transform:"rotate(-2deg)"},'pre[class*="language-"]:after':{content:"''",display:"block",position:"absolute",bottom:"0.75em",left:"auto",width:"40%",height:"20%",maxHeight:"13em",boxShadow:"0px 13px 8px #979797",WebkitTransform:"rotate(2deg)",MozTransform:"rotate(2deg)",msTransform:"rotate(2deg)",OTransform:"rotate(2deg)",transform:"rotate(2deg)",right:"0.75em"},comment:{color:"#7D8B99"},"block-comment":{color:"#7D8B99"},prolog:{color:"#7D8B99"},doctype:{color:"#7D8B99"},cdata:{color:"#7D8B99"},punctuation:{color:"#5F6364"},property:{color:"#c92c2c"},tag:{color:"#c92c2c"},boolean:{color:"#c92c2c"},number:{color:"#c92c2c"},"function-name":{color:"#c92c2c"},constant:{color:"#c92c2c"},symbol:{color:"#c92c2c"},deleted:{color:"#c92c2c"},selector:{color:"#2f9c0a"},"attr-name":{color:"#2f9c0a"},string:{color:"#2f9c0a"},char:{color:"#2f9c0a"},function:{color:"#2f9c0a"},builtin:{color:"#2f9c0a"},inserted:{color:"#2f9c0a"},operator:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},entity:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)",cursor:"help"},url:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},variable:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},atrule:{color:"#1990b8"},"attr-value":{color:"#1990b8"},keyword:{color:"#1990b8"},"class-name":{color:"#1990b8"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"normal"},".language-css .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},".style .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:".7"},'pre[class*="language-"].line-numbers.line-numbers':{paddingLeft:"0"},'pre[class*="language-"].line-numbers.line-numbers code':{paddingLeft:"3.8em"},'pre[class*="language-"].line-numbers.line-numbers .line-numbers-rows':{left:"0"},'pre[class*="language-"][data-line]':{paddingTop:"0",paddingBottom:"0",paddingLeft:"0"},"pre[data-line] code":{position:"relative",paddingLeft:"4em"},"pre .line-highlight":{marginTop:"0"}}}(ww)),ww}var xw={},AF;function zbe(){return AF||(AF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"white",background:"none",textShadow:"0 -.1em .2em black",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",background:"hsl(30, 20%, 25%)",textShadow:"0 -.1em .2em black",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:".3em solid hsl(30, 20%, 40%)",borderRadius:".5em",boxShadow:"1px 1px .5em black inset"},':not(pre) > code[class*="language-"]':{background:"hsl(30, 20%, 25%)",padding:".15em .2em .05em",borderRadius:".3em",border:".13em solid hsl(30, 20%, 40%)",boxShadow:"1px 1px .3em -.1em black inset",whiteSpace:"normal"},comment:{color:"hsl(30, 20%, 50%)"},prolog:{color:"hsl(30, 20%, 50%)"},doctype:{color:"hsl(30, 20%, 50%)"},cdata:{color:"hsl(30, 20%, 50%)"},punctuation:{Opacity:".7"},namespace:{Opacity:".7"},property:{color:"hsl(350, 40%, 70%)"},tag:{color:"hsl(350, 40%, 70%)"},boolean:{color:"hsl(350, 40%, 70%)"},number:{color:"hsl(350, 40%, 70%)"},constant:{color:"hsl(350, 40%, 70%)"},symbol:{color:"hsl(350, 40%, 70%)"},selector:{color:"hsl(75, 70%, 60%)"},"attr-name":{color:"hsl(75, 70%, 60%)"},string:{color:"hsl(75, 70%, 60%)"},char:{color:"hsl(75, 70%, 60%)"},builtin:{color:"hsl(75, 70%, 60%)"},inserted:{color:"hsl(75, 70%, 60%)"},operator:{color:"hsl(40, 90%, 60%)"},entity:{color:"hsl(40, 90%, 60%)",cursor:"help"},url:{color:"hsl(40, 90%, 60%)"},".language-css .token.string":{color:"hsl(40, 90%, 60%)"},".style .token.string":{color:"hsl(40, 90%, 60%)"},variable:{color:"hsl(40, 90%, 60%)"},atrule:{color:"hsl(350, 40%, 70%)"},"attr-value":{color:"hsl(350, 40%, 70%)"},keyword:{color:"hsl(350, 40%, 70%)"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},deleted:{color:"red"}}}(xw)),xw}var kw={},TF;function Pbe(){return TF||(TF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"black",color:"white",boxShadow:"-.3em 0 0 .3em black, .3em 0 0 .3em black"},'pre[class*="language-"]':{fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:".4em .8em",margin:".5em 0",overflow:"auto",background:`url('data:image/svg+xml;charset=utf-8,<svg%20version%3D"1.1"%20xmlns%3D"http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg"%20width%3D"100"%20height%3D"100"%20fill%3D"rgba(0%2C0%2C0%2C.2)">%0D%0A<polygon%20points%3D"0%2C50%2050%2C0%200%2C0"%20%2F>%0D%0A<polygon%20points%3D"0%2C100%2050%2C100%20100%2C50%20100%2C0"%20%2F>%0D%0A<%2Fsvg>')`,backgroundSize:"1em 1em"},':not(pre) > code[class*="language-"]':{padding:".2em",borderRadius:".3em",boxShadow:"none",whiteSpace:"normal"},comment:{color:"#aaa"},prolog:{color:"#aaa"},doctype:{color:"#aaa"},cdata:{color:"#aaa"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#0cf"},tag:{color:"#0cf"},boolean:{color:"#0cf"},number:{color:"#0cf"},constant:{color:"#0cf"},symbol:{color:"#0cf"},selector:{color:"yellow"},"attr-name":{color:"yellow"},string:{color:"yellow"},char:{color:"yellow"},builtin:{color:"yellow"},operator:{color:"yellowgreen"},entity:{color:"yellowgreen",cursor:"help"},url:{color:"yellowgreen"},".language-css .token.string":{color:"yellowgreen"},variable:{color:"yellowgreen"},inserted:{color:"yellowgreen"},atrule:{color:"deeppink"},"attr-value":{color:"deeppink"},keyword:{color:"deeppink"},regex:{color:"orange"},important:{color:"orange",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},deleted:{color:"red"},"pre.diff-highlight.diff-highlight > code .token.deleted:not(.prefix)":{backgroundColor:"rgba(255, 0, 0, .3)",display:"inline"},"pre > code.diff-highlight.diff-highlight .token.deleted:not(.prefix)":{backgroundColor:"rgba(255, 0, 0, .3)",display:"inline"},"pre.diff-highlight.diff-highlight > code .token.inserted:not(.prefix)":{backgroundColor:"rgba(0, 255, 128, .3)",display:"inline"},"pre > code.diff-highlight.diff-highlight .token.inserted:not(.prefix)":{backgroundColor:"rgba(0, 255, 128, .3)",display:"inline"}}}(kw)),kw}var Aw={},_F;function Bbe(){return _F||(_F=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#272822",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#272822",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#8292a2"},prolog:{color:"#8292a2"},doctype:{color:"#8292a2"},cdata:{color:"#8292a2"},punctuation:{color:"#f8f8f2"},namespace:{Opacity:".7"},property:{color:"#f92672"},tag:{color:"#f92672"},constant:{color:"#f92672"},symbol:{color:"#f92672"},deleted:{color:"#f92672"},boolean:{color:"#ae81ff"},number:{color:"#ae81ff"},selector:{color:"#a6e22e"},"attr-name":{color:"#a6e22e"},string:{color:"#a6e22e"},char:{color:"#a6e22e"},builtin:{color:"#a6e22e"},inserted:{color:"#a6e22e"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#e6db74"},"attr-value":{color:"#e6db74"},function:{color:"#e6db74"},"class-name":{color:"#e6db74"},keyword:{color:"#66d9ef"},regex:{color:"#fd971f"},important:{color:"#fd971f",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Aw)),Aw}var Tw={},RF;function Ube(){return RF||(RF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#657b83",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#657b83",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",backgroundColor:"#fdf6e3"},'pre[class*="language-"]::-moz-selection':{background:"#073642"},'pre[class*="language-"] ::-moz-selection':{background:"#073642"},'code[class*="language-"]::-moz-selection':{background:"#073642"},'code[class*="language-"] ::-moz-selection':{background:"#073642"},'pre[class*="language-"]::selection':{background:"#073642"},'pre[class*="language-"] ::selection':{background:"#073642"},'code[class*="language-"]::selection':{background:"#073642"},'code[class*="language-"] ::selection':{background:"#073642"},':not(pre) > code[class*="language-"]':{backgroundColor:"#fdf6e3",padding:".1em",borderRadius:".3em"},comment:{color:"#93a1a1"},prolog:{color:"#93a1a1"},doctype:{color:"#93a1a1"},cdata:{color:"#93a1a1"},punctuation:{color:"#586e75"},namespace:{Opacity:".7"},property:{color:"#268bd2"},tag:{color:"#268bd2"},boolean:{color:"#268bd2"},number:{color:"#268bd2"},constant:{color:"#268bd2"},symbol:{color:"#268bd2"},deleted:{color:"#268bd2"},selector:{color:"#2aa198"},"attr-name":{color:"#2aa198"},string:{color:"#2aa198"},char:{color:"#2aa198"},builtin:{color:"#2aa198"},url:{color:"#2aa198"},inserted:{color:"#2aa198"},entity:{color:"#657b83",background:"#eee8d5",cursor:"help"},atrule:{color:"#859900"},"attr-value":{color:"#859900"},keyword:{color:"#859900"},function:{color:"#b58900"},"class-name":{color:"#b58900"},regex:{color:"#cb4b16"},important:{color:"#cb4b16",fontWeight:"bold"},variable:{color:"#cb4b16"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Tw)),Tw}var _w={},CF;function jbe(){return CF||(CF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#ccc",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#ccc",background:"#2d2d2d",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},':not(pre) > code[class*="language-"]':{background:"#2d2d2d",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#999"},"block-comment":{color:"#999"},prolog:{color:"#999"},doctype:{color:"#999"},cdata:{color:"#999"},punctuation:{color:"#ccc"},tag:{color:"#e2777a"},"attr-name":{color:"#e2777a"},namespace:{color:"#e2777a"},deleted:{color:"#e2777a"},"function-name":{color:"#6196cc"},boolean:{color:"#f08d49"},number:{color:"#f08d49"},function:{color:"#f08d49"},property:{color:"#f8c555"},"class-name":{color:"#f8c555"},constant:{color:"#f8c555"},symbol:{color:"#f8c555"},selector:{color:"#cc99cd"},important:{color:"#cc99cd",fontWeight:"bold"},atrule:{color:"#cc99cd"},keyword:{color:"#cc99cd"},builtin:{color:"#cc99cd"},string:{color:"#7ec699"},char:{color:"#7ec699"},"attr-value":{color:"#7ec699"},regex:{color:"#7ec699"},variable:{color:"#7ec699"},operator:{color:"#67cdcc"},entity:{color:"#67cdcc",cursor:"help"},url:{color:"#67cdcc"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{color:"green"}}}(_w)),_w}var Rw={},NF;function Gbe(){return NF||(NF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"white",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",textShadow:"0 -.1em .2em black",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",background:"hsl(0, 0%, 8%)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",textShadow:"0 -.1em .2em black",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",borderRadius:".5em",border:".3em solid hsl(0, 0%, 33%)",boxShadow:"1px 1px .5em black inset",margin:".5em 0",overflow:"auto",padding:"1em"},':not(pre) > code[class*="language-"]':{background:"hsl(0, 0%, 8%)",borderRadius:".3em",border:".13em solid hsl(0, 0%, 33%)",boxShadow:"1px 1px .3em -.1em black inset",padding:".15em .2em .05em",whiteSpace:"normal"},'pre[class*="language-"]::-moz-selection':{background:"hsla(0, 0%, 93%, 0.15)",textShadow:"none"},'pre[class*="language-"]::selection':{background:"hsla(0, 0%, 93%, 0.15)",textShadow:"none"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"]::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"hsla(0, 0%, 93%, 0.15)"},comment:{color:"hsl(0, 0%, 47%)"},prolog:{color:"hsl(0, 0%, 47%)"},doctype:{color:"hsl(0, 0%, 47%)"},cdata:{color:"hsl(0, 0%, 47%)"},punctuation:{Opacity:".7"},namespace:{Opacity:".7"},tag:{color:"hsl(14, 58%, 55%)"},boolean:{color:"hsl(14, 58%, 55%)"},number:{color:"hsl(14, 58%, 55%)"},deleted:{color:"hsl(14, 58%, 55%)"},keyword:{color:"hsl(53, 89%, 79%)"},property:{color:"hsl(53, 89%, 79%)"},selector:{color:"hsl(53, 89%, 79%)"},constant:{color:"hsl(53, 89%, 79%)"},symbol:{color:"hsl(53, 89%, 79%)"},builtin:{color:"hsl(53, 89%, 79%)"},"attr-name":{color:"hsl(76, 21%, 52%)"},"attr-value":{color:"hsl(76, 21%, 52%)"},string:{color:"hsl(76, 21%, 52%)"},char:{color:"hsl(76, 21%, 52%)"},operator:{color:"hsl(76, 21%, 52%)"},entity:{color:"hsl(76, 21%, 52%)",cursor:"help"},url:{color:"hsl(76, 21%, 52%)"},".language-css .token.string":{color:"hsl(76, 21%, 52%)"},".style .token.string":{color:"hsl(76, 21%, 52%)"},variable:{color:"hsl(76, 21%, 52%)"},inserted:{color:"hsl(76, 21%, 52%)"},atrule:{color:"hsl(218, 22%, 55%)"},regex:{color:"hsl(42, 75%, 65%)"},important:{color:"hsl(42, 75%, 65%)",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},".language-markup .token.tag":{color:"hsl(33, 33%, 52%)"},".language-markup .token.attr-name":{color:"hsl(33, 33%, 52%)"},".language-markup .token.punctuation":{color:"hsl(33, 33%, 52%)"},"":{position:"relative",zIndex:"1"},".line-highlight.line-highlight":{background:"linear-gradient(to right, hsla(0, 0%, 33%, .1) 70%, hsla(0, 0%, 33%, 0))",borderBottom:"1px dashed hsl(0, 0%, 33%)",borderTop:"1px dashed hsl(0, 0%, 33%)",marginTop:"0.75em",zIndex:"0"},".line-highlight.line-highlight:before":{backgroundColor:"hsl(215, 15%, 59%)",color:"hsl(24, 20%, 95%)"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"hsl(215, 15%, 59%)",color:"hsl(24, 20%, 95%)"}}}(Rw)),Rw}var Cw={},OF;function Hbe(){return OF||(OF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"#f5f2f0",textShadow:"0 1px white",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"]::selection':{textShadow:"none",background:"#b3d4fc"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{background:"#f5f2f0",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"slategray"},prolog:{color:"slategray"},doctype:{color:"slategray"},cdata:{color:"slategray"},punctuation:{color:"#999"},namespace:{Opacity:".7"},property:{color:"#905"},tag:{color:"#905"},boolean:{color:"#905"},number:{color:"#905"},constant:{color:"#905"},symbol:{color:"#905"},deleted:{color:"#905"},selector:{color:"#690"},"attr-name":{color:"#690"},string:{color:"#690"},char:{color:"#690"},builtin:{color:"#690"},inserted:{color:"#690"},operator:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},entity:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)",cursor:"help"},url:{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".language-css .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},".style .token.string":{color:"#9a6e3a",background:"hsla(0, 0%, 100%, .5)"},atrule:{color:"#07a"},"attr-value":{color:"#07a"},keyword:{color:"#07a"},function:{color:"#DD4A68"},"class-name":{color:"#DD4A68"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"bold"},variable:{color:"#e90"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Cw)),Cw}var Nw={},DF;function $be(){return DF||(DF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#2b2b2b",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#2b2b2b",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#d4d0ab"},prolog:{color:"#d4d0ab"},doctype:{color:"#d4d0ab"},cdata:{color:"#d4d0ab"},punctuation:{color:"#fefefe"},property:{color:"#ffa07a"},tag:{color:"#ffa07a"},constant:{color:"#ffa07a"},symbol:{color:"#ffa07a"},deleted:{color:"#ffa07a"},boolean:{color:"#00e0e0"},number:{color:"#00e0e0"},selector:{color:"#abe338"},"attr-name":{color:"#abe338"},string:{color:"#abe338"},char:{color:"#abe338"},builtin:{color:"#abe338"},inserted:{color:"#abe338"},operator:{color:"#00e0e0"},entity:{color:"#00e0e0",cursor:"help"},url:{color:"#00e0e0"},".language-css .token.string":{color:"#00e0e0"},".style .token.string":{color:"#00e0e0"},variable:{color:"#00e0e0"},atrule:{color:"#ffd700"},"attr-value":{color:"#ffd700"},function:{color:"#ffd700"},keyword:{color:"#00e0e0"},regex:{color:"#ffd700"},important:{color:"#ffd700",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Nw)),Nw}var Ow={},IF;function qbe(){return IF||(IF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#c5c8c6",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#c5c8c6",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",background:"#1d1f21"},':not(pre) > code[class*="language-"]':{background:"#1d1f21",padding:".1em",borderRadius:".3em"},comment:{color:"#7C7C7C"},prolog:{color:"#7C7C7C"},doctype:{color:"#7C7C7C"},cdata:{color:"#7C7C7C"},punctuation:{color:"#c5c8c6"},".namespace":{Opacity:".7"},property:{color:"#96CBFE"},keyword:{color:"#96CBFE"},tag:{color:"#96CBFE"},"class-name":{color:"#FFFFB6",textDecoration:"underline"},boolean:{color:"#99CC99"},constant:{color:"#99CC99"},symbol:{color:"#f92672"},deleted:{color:"#f92672"},number:{color:"#FF73FD"},selector:{color:"#A8FF60"},"attr-name":{color:"#A8FF60"},string:{color:"#A8FF60"},char:{color:"#A8FF60"},builtin:{color:"#A8FF60"},inserted:{color:"#A8FF60"},variable:{color:"#C6C5FE"},operator:{color:"#EDEDED"},entity:{color:"#FFFFB6",cursor:"help"},url:{color:"#96CBFE"},".language-css .token.string":{color:"#87C38A"},".style .token.string":{color:"#87C38A"},atrule:{color:"#F9EE98"},"attr-value":{color:"#F9EE98"},function:{color:"#DAD085"},regex:{color:"#E9C062"},important:{color:"#fd971f",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Ow)),Ow}var Dw={},LF;function Vbe(){return LF||(LF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#f5f7ff",color:"#5e6687"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#f5f7ff",color:"#5e6687",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#dfe2f1"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"]::selection':{textShadow:"none",background:"#dfe2f1"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#dfe2f1"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#898ea4"},prolog:{color:"#898ea4"},doctype:{color:"#898ea4"},cdata:{color:"#898ea4"},punctuation:{color:"#5e6687"},namespace:{Opacity:".7"},operator:{color:"#c76b29"},boolean:{color:"#c76b29"},number:{color:"#c76b29"},property:{color:"#c08b30"},tag:{color:"#3d8fd1"},string:{color:"#22a2c9"},selector:{color:"#6679cc"},"attr-name":{color:"#c76b29"},entity:{color:"#22a2c9",cursor:"help"},url:{color:"#22a2c9"},".language-css .token.string":{color:"#22a2c9"},".style .token.string":{color:"#22a2c9"},"attr-value":{color:"#ac9739"},keyword:{color:"#ac9739"},control:{color:"#ac9739"},directive:{color:"#ac9739"},unit:{color:"#ac9739"},statement:{color:"#22a2c9"},regex:{color:"#22a2c9"},atrule:{color:"#22a2c9"},placeholder:{color:"#3d8fd1"},variable:{color:"#3d8fd1"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #202746",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#c94922"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:"0.4em solid #c94922",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#dfe2f1"},".line-numbers .line-numbers-rows > span:before":{color:"#979db4"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(107, 115, 148, 0.2) 70%, rgba(107, 115, 148, 0))"}}}(Dw)),Dw}var Iw={},MF;function Wbe(){return MF||(MF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#fff",textShadow:"0 1px 1px #000",fontFamily:'Menlo, Monaco, "Courier New", monospace',direction:"ltr",textAlign:"left",wordSpacing:"normal",whiteSpace:"pre",wordWrap:"normal",lineHeight:"1.4",background:"none",border:"0",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#fff",textShadow:"0 1px 1px #000",fontFamily:'Menlo, Monaco, "Courier New", monospace',direction:"ltr",textAlign:"left",wordSpacing:"normal",whiteSpace:"pre",wordWrap:"normal",lineHeight:"1.4",background:"#222",border:"0",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"15px",margin:"1em 0",overflow:"auto",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},'pre[class*="language-"] code':{float:"left",padding:"0 15px 0 0"},':not(pre) > code[class*="language-"]':{background:"#222",padding:"5px 10px",lineHeight:"1",MozBorderRadius:"3px",WebkitBorderRadius:"3px",borderRadius:"3px"},comment:{color:"#797979"},prolog:{color:"#797979"},doctype:{color:"#797979"},cdata:{color:"#797979"},selector:{color:"#fff"},operator:{color:"#fff"},punctuation:{color:"#fff"},namespace:{Opacity:".7"},tag:{color:"#ffd893"},boolean:{color:"#ffd893"},atrule:{color:"#B0C975"},"attr-value":{color:"#B0C975"},hex:{color:"#B0C975"},string:{color:"#B0C975"},property:{color:"#c27628"},entity:{color:"#c27628",cursor:"help"},url:{color:"#c27628"},"attr-name":{color:"#c27628"},keyword:{color:"#c27628"},regex:{color:"#9B71C6"},function:{color:"#e5a638"},constant:{color:"#e5a638"},variable:{color:"#fdfba8"},number:{color:"#8799B0"},important:{color:"#E45734"},deliminator:{color:"#E45734"},".line-highlight.line-highlight":{background:"rgba(255, 255, 255, .2)"},".line-highlight.line-highlight:before":{top:".3em",backgroundColor:"rgba(255, 255, 255, .3)",color:"#fff",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},".line-highlight.line-highlight[data-end]:after":{top:".3em",backgroundColor:"rgba(255, 255, 255, .3)",color:"#fff",MozBorderRadius:"8px",WebkitBorderRadius:"8px",borderRadius:"8px"},".line-numbers .line-numbers-rows > span":{borderRight:"3px #d9d336 solid"}}}(Iw)),Iw}var Lw={},FF;function Ybe(){return FF||(FF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#111b27",background:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#111b27",background:"#e3eaf2",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{background:"#8da1b9"},'pre[class*="language-"] ::-moz-selection':{background:"#8da1b9"},'code[class*="language-"]::-moz-selection':{background:"#8da1b9"},'code[class*="language-"] ::-moz-selection':{background:"#8da1b9"},'pre[class*="language-"]::selection':{background:"#8da1b9"},'pre[class*="language-"] ::selection':{background:"#8da1b9"},'code[class*="language-"]::selection':{background:"#8da1b9"},'code[class*="language-"] ::selection':{background:"#8da1b9"},':not(pre) > code[class*="language-"]':{background:"#e3eaf2",padding:"0.1em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#3c526d"},prolog:{color:"#3c526d"},doctype:{color:"#3c526d"},cdata:{color:"#3c526d"},punctuation:{color:"#111b27"},"delimiter.important":{color:"#006d6d",fontWeight:"inherit"},"selector.parent":{color:"#006d6d"},tag:{color:"#006d6d"},"tag.punctuation":{color:"#006d6d"},"attr-name":{color:"#755f00"},boolean:{color:"#755f00"},"boolean.important":{color:"#755f00"},number:{color:"#755f00"},constant:{color:"#755f00"},"selector.attribute":{color:"#755f00"},"class-name":{color:"#005a8e"},key:{color:"#005a8e"},parameter:{color:"#005a8e"},property:{color:"#005a8e"},"property-access":{color:"#005a8e"},variable:{color:"#005a8e"},"attr-value":{color:"#116b00"},inserted:{color:"#116b00"},color:{color:"#116b00"},"selector.value":{color:"#116b00"},string:{color:"#116b00"},"string.url-link":{color:"#116b00"},builtin:{color:"#af00af"},"keyword-array":{color:"#af00af"},package:{color:"#af00af"},regex:{color:"#af00af"},function:{color:"#7c00aa"},"selector.class":{color:"#7c00aa"},"selector.id":{color:"#7c00aa"},"atrule.rule":{color:"#a04900"},combinator:{color:"#a04900"},keyword:{color:"#a04900"},operator:{color:"#a04900"},"pseudo-class":{color:"#a04900"},"pseudo-element":{color:"#a04900"},selector:{color:"#a04900"},unit:{color:"#a04900"},deleted:{color:"#c22f2e"},important:{color:"#c22f2e",fontWeight:"bold"},"keyword-this":{color:"#005a8e",fontWeight:"bold"},this:{color:"#005a8e",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},entity:{cursor:"help"},".language-markdown .token.title":{color:"#005a8e",fontWeight:"bold"},".language-markdown .token.title .token.punctuation":{color:"#005a8e",fontWeight:"bold"},".language-markdown .token.blockquote.punctuation":{color:"#af00af"},".language-markdown .token.code":{color:"#006d6d"},".language-markdown .token.hr.punctuation":{color:"#005a8e"},".language-markdown .token.url > .token.content":{color:"#116b00"},".language-markdown .token.url-link":{color:"#755f00"},".language-markdown .token.list.punctuation":{color:"#af00af"},".language-markdown .token.table-header":{color:"#111b27"},".language-json .token.operator":{color:"#111b27"},".language-scss .token.variable":{color:"#006d6d"},"token.tab:not(:empty):before":{color:"#3c526d"},"token.cr:before":{color:"#3c526d"},"token.lf:before":{color:"#3c526d"},"token.space:before":{color:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{color:"#e3eaf2",background:"#005a8e"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{color:"#e3eaf2",background:"#005a8e"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{color:"#e3eaf2",background:"#005a8eda",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{color:"#e3eaf2",background:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{color:"#e3eaf2",background:"#3c526d"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{color:"#e3eaf2",background:"#3c526d"},".line-highlight.line-highlight":{background:"linear-gradient(to right, #8da1b92f 70%, #8da1b925)"},".line-highlight.line-highlight:before":{backgroundColor:"#3c526d",color:"#e3eaf2",boxShadow:"0 1px #8da1b9"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"#3c526d",color:"#e3eaf2",boxShadow:"0 1px #8da1b9"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"#3c526d1f"},".line-numbers.line-numbers .line-numbers-rows":{borderRight:"1px solid #8da1b97a",background:"#d0dae77a"},".line-numbers .line-numbers-rows > span:before":{color:"#3c526dda"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"#755f00"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"#af00af"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"#005a8e"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"#7c00aa"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"#7c00aa"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"#7c00aa"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"#c22f2e1f"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"#c22f2e1f"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"#116b001f"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"#116b001f"},".command-line .command-line-prompt":{borderRight:"1px solid #8da1b97a"},".command-line .command-line-prompt > span:before":{color:"#3c526dda"}}}(Lw)),Lw}var Mw={},zF;function Kbe(){return zF||(zF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#e3eaf2",background:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#e3eaf2",background:"#111b27",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto"},'pre[class*="language-"]::-moz-selection':{background:"#3c526d"},'pre[class*="language-"] ::-moz-selection':{background:"#3c526d"},'code[class*="language-"]::-moz-selection':{background:"#3c526d"},'code[class*="language-"] ::-moz-selection':{background:"#3c526d"},'pre[class*="language-"]::selection':{background:"#3c526d"},'pre[class*="language-"] ::selection':{background:"#3c526d"},'code[class*="language-"]::selection':{background:"#3c526d"},'code[class*="language-"] ::selection':{background:"#3c526d"},':not(pre) > code[class*="language-"]':{background:"#111b27",padding:"0.1em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"#8da1b9"},prolog:{color:"#8da1b9"},doctype:{color:"#8da1b9"},cdata:{color:"#8da1b9"},punctuation:{color:"#e3eaf2"},"delimiter.important":{color:"#66cccc",fontWeight:"inherit"},"selector.parent":{color:"#66cccc"},tag:{color:"#66cccc"},"tag.punctuation":{color:"#66cccc"},"attr-name":{color:"#e6d37a"},boolean:{color:"#e6d37a"},"boolean.important":{color:"#e6d37a"},number:{color:"#e6d37a"},constant:{color:"#e6d37a"},"selector.attribute":{color:"#e6d37a"},"class-name":{color:"#6cb8e6"},key:{color:"#6cb8e6"},parameter:{color:"#6cb8e6"},property:{color:"#6cb8e6"},"property-access":{color:"#6cb8e6"},variable:{color:"#6cb8e6"},"attr-value":{color:"#91d076"},inserted:{color:"#91d076"},color:{color:"#91d076"},"selector.value":{color:"#91d076"},string:{color:"#91d076"},"string.url-link":{color:"#91d076"},builtin:{color:"#f4adf4"},"keyword-array":{color:"#f4adf4"},package:{color:"#f4adf4"},regex:{color:"#f4adf4"},function:{color:"#c699e3"},"selector.class":{color:"#c699e3"},"selector.id":{color:"#c699e3"},"atrule.rule":{color:"#e9ae7e"},combinator:{color:"#e9ae7e"},keyword:{color:"#e9ae7e"},operator:{color:"#e9ae7e"},"pseudo-class":{color:"#e9ae7e"},"pseudo-element":{color:"#e9ae7e"},selector:{color:"#e9ae7e"},unit:{color:"#e9ae7e"},deleted:{color:"#cd6660"},important:{color:"#cd6660",fontWeight:"bold"},"keyword-this":{color:"#6cb8e6",fontWeight:"bold"},this:{color:"#6cb8e6",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},entity:{cursor:"help"},".language-markdown .token.title":{color:"#6cb8e6",fontWeight:"bold"},".language-markdown .token.title .token.punctuation":{color:"#6cb8e6",fontWeight:"bold"},".language-markdown .token.blockquote.punctuation":{color:"#f4adf4"},".language-markdown .token.code":{color:"#66cccc"},".language-markdown .token.hr.punctuation":{color:"#6cb8e6"},".language-markdown .token.url .token.content":{color:"#91d076"},".language-markdown .token.url-link":{color:"#e6d37a"},".language-markdown .token.list.punctuation":{color:"#f4adf4"},".language-markdown .token.table-header":{color:"#e3eaf2"},".language-json .token.operator":{color:"#e3eaf2"},".language-scss .token.variable":{color:"#66cccc"},"token.tab:not(:empty):before":{color:"#8da1b9"},"token.cr:before":{color:"#8da1b9"},"token.lf:before":{color:"#8da1b9"},"token.space:before":{color:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{color:"#111b27",background:"#6cb8e6"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{color:"#111b27",background:"#6cb8e6"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{color:"#111b27",background:"#6cb8e6da",textDecoration:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{color:"#111b27",background:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{color:"#111b27",background:"#8da1b9"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{color:"#111b27",background:"#8da1b9"},".line-highlight.line-highlight":{background:"linear-gradient(to right, #3c526d5f 70%, #3c526d55)"},".line-highlight.line-highlight:before":{backgroundColor:"#8da1b9",color:"#111b27",boxShadow:"0 1px #3c526d"},".line-highlight.line-highlight[data-end]:after":{backgroundColor:"#8da1b9",color:"#111b27",boxShadow:"0 1px #3c526d"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"#8da1b918"},".line-numbers.line-numbers .line-numbers-rows":{borderRight:"1px solid #0b121b",background:"#0b121b7a"},".line-numbers .line-numbers-rows > span:before":{color:"#8da1b9da"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"#e6d37a"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"#f4adf4"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"#6cb8e6"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"#c699e3"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"#c699e3"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"#c699e3"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"#cd66601f"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"#cd66601f"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"#91d0761f"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"#91d0761f"},".command-line .command-line-prompt":{borderRight:"1px solid #0b121b"},".command-line .command-line-prompt > span:before":{color:"#8da1b9da"}}}(Mw)),Mw}var Fw={},PF;function Xbe(){return PF||(PF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"black",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",position:"relative",borderLeft:"10px solid #358ccb",boxShadow:"-1px 0 0 0 #358ccb, 0 0 0 1px #dfdfdf",backgroundColor:"#fdfdfd",backgroundImage:"linear-gradient(transparent 50%, rgba(69, 142, 209, 0.04) 50%)",backgroundSize:"3em 3em",backgroundOrigin:"content-box",backgroundAttachment:"local",margin:".5em 0",padding:"0 1em"},'pre[class*="language-"] > code':{display:"block"},':not(pre) > code[class*="language-"]':{position:"relative",padding:".2em",borderRadius:"0.3em",color:"#c92c2c",border:"1px solid rgba(0, 0, 0, 0.1)",display:"inline",whiteSpace:"normal",backgroundColor:"#fdfdfd",WebkitBoxSizing:"border-box",MozBoxSizing:"border-box",boxSizing:"border-box"},comment:{color:"#7D8B99"},"block-comment":{color:"#7D8B99"},prolog:{color:"#7D8B99"},doctype:{color:"#7D8B99"},cdata:{color:"#7D8B99"},punctuation:{color:"#5F6364"},property:{color:"#c92c2c"},tag:{color:"#c92c2c"},boolean:{color:"#c92c2c"},number:{color:"#c92c2c"},"function-name":{color:"#c92c2c"},constant:{color:"#c92c2c"},symbol:{color:"#c92c2c"},deleted:{color:"#c92c2c"},selector:{color:"#2f9c0a"},"attr-name":{color:"#2f9c0a"},string:{color:"#2f9c0a"},char:{color:"#2f9c0a"},function:{color:"#2f9c0a"},builtin:{color:"#2f9c0a"},inserted:{color:"#2f9c0a"},operator:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},entity:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)",cursor:"help"},url:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},variable:{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},atrule:{color:"#1990b8"},"attr-value":{color:"#1990b8"},keyword:{color:"#1990b8"},"class-name":{color:"#1990b8"},regex:{color:"#e90"},important:{color:"#e90",fontWeight:"normal"},".language-css .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},".style .token.string":{color:"#a67f59",background:"rgba(255, 255, 255, 0.5)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:".7"}}}(Fw)),Fw}var zw={},BF;function Zbe(){return BF||(BF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#a9b7c6",fontFamily:"Consolas, Monaco, 'Andale Mono', monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#a9b7c6",fontFamily:"Consolas, Monaco, 'Andale Mono', monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",background:"#2b2b2b"},'pre[class*="language-"]::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"] ::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"]::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"] ::-moz-selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"]::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'pre[class*="language-"] ::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"]::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},'code[class*="language-"] ::selection':{color:"inherit",background:"rgba(33, 66, 131, .85)"},':not(pre) > code[class*="language-"]':{background:"#2b2b2b",padding:".1em",borderRadius:".3em"},comment:{color:"#808080"},prolog:{color:"#808080"},cdata:{color:"#808080"},delimiter:{color:"#cc7832"},boolean:{color:"#cc7832"},keyword:{color:"#cc7832"},selector:{color:"#cc7832"},important:{color:"#cc7832"},atrule:{color:"#cc7832"},operator:{color:"#a9b7c6"},punctuation:{color:"#a9b7c6"},"attr-name":{color:"#a9b7c6"},tag:{color:"#e8bf6a"},"tag.punctuation":{color:"#e8bf6a"},doctype:{color:"#e8bf6a"},builtin:{color:"#e8bf6a"},entity:{color:"#6897bb"},number:{color:"#6897bb"},symbol:{color:"#6897bb"},property:{color:"#9876aa"},constant:{color:"#9876aa"},variable:{color:"#9876aa"},string:{color:"#6a8759"},char:{color:"#6a8759"},"attr-value":{color:"#a5c261"},"attr-value.punctuation":{color:"#a5c261"},"attr-value.punctuation:first-child":{color:"#a9b7c6"},url:{color:"#287bde",textDecoration:"underline"},function:{color:"#ffc66d"},regex:{background:"#364135"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#294436"},deleted:{background:"#484a4a"},"code.language-css .token.property":{color:"#a9b7c6"},"code.language-css .token.property + .token.punctuation":{color:"#a9b7c6"},"code.language-css .token.id":{color:"#ffc66d"},"code.language-css .token.selector > .token.class":{color:"#ffc66d"},"code.language-css .token.selector > .token.attribute":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-class":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-element":{color:"#ffc66d"}}}(zw)),zw}var Pw={},UF;function Qbe(){return UF||(UF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#282a36",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#282a36",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#6272a4"},prolog:{color:"#6272a4"},doctype:{color:"#6272a4"},cdata:{color:"#6272a4"},punctuation:{color:"#f8f8f2"},".namespace":{Opacity:".7"},property:{color:"#ff79c6"},tag:{color:"#ff79c6"},constant:{color:"#ff79c6"},symbol:{color:"#ff79c6"},deleted:{color:"#ff79c6"},boolean:{color:"#bd93f9"},number:{color:"#bd93f9"},selector:{color:"#50fa7b"},"attr-name":{color:"#50fa7b"},string:{color:"#50fa7b"},char:{color:"#50fa7b"},builtin:{color:"#50fa7b"},inserted:{color:"#50fa7b"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#f1fa8c"},"attr-value":{color:"#f1fa8c"},function:{color:"#f1fa8c"},"class-name":{color:"#f1fa8c"},keyword:{color:"#8be9fd"},regex:{color:"#ffb86c"},important:{color:"#ffb86c",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Pw)),Pw}var Bw={},jF;function Jbe(){return jF||(jF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2734",color:"#9a86fd"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2734",color:"#9a86fd",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#6a51e6"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"]::selection':{textShadow:"none",background:"#6a51e6"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#6a51e6"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#6c6783"},prolog:{color:"#6c6783"},doctype:{color:"#6c6783"},cdata:{color:"#6c6783"},punctuation:{color:"#6c6783"},namespace:{Opacity:".7"},tag:{color:"#e09142"},operator:{color:"#e09142"},number:{color:"#e09142"},property:{color:"#9a86fd"},function:{color:"#9a86fd"},"tag-id":{color:"#eeebff"},selector:{color:"#eeebff"},"atrule-id":{color:"#eeebff"},"code.language-javascript":{color:"#c4b9fe"},"attr-name":{color:"#c4b9fe"},"code.language-css":{color:"#ffcc99"},"code.language-scss":{color:"#ffcc99"},boolean:{color:"#ffcc99"},string:{color:"#ffcc99"},entity:{color:"#ffcc99",cursor:"help"},url:{color:"#ffcc99"},".language-css .token.string":{color:"#ffcc99"},".language-scss .token.string":{color:"#ffcc99"},".style .token.string":{color:"#ffcc99"},"attr-value":{color:"#ffcc99"},keyword:{color:"#ffcc99"},control:{color:"#ffcc99"},directive:{color:"#ffcc99"},unit:{color:"#ffcc99"},statement:{color:"#ffcc99"},regex:{color:"#ffcc99"},atrule:{color:"#ffcc99"},placeholder:{color:"#ffcc99"},variable:{color:"#ffcc99"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #eeebff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#c4b9fe"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #8a75f5",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#2c2937"},".line-numbers .line-numbers-rows > span:before":{color:"#3c3949"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(224, 145, 66, 0.2) 70%, rgba(224, 145, 66, 0))"}}}(Bw)),Bw}var Uw={},GF;function eye(){return GF||(GF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#322d29",color:"#88786d"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#322d29",color:"#88786d",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#6f5849"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"]::selection':{textShadow:"none",background:"#6f5849"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#6f5849"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#6a5f58"},prolog:{color:"#6a5f58"},doctype:{color:"#6a5f58"},cdata:{color:"#6a5f58"},punctuation:{color:"#6a5f58"},namespace:{Opacity:".7"},tag:{color:"#bfa05a"},operator:{color:"#bfa05a"},number:{color:"#bfa05a"},property:{color:"#88786d"},function:{color:"#88786d"},"tag-id":{color:"#fff3eb"},selector:{color:"#fff3eb"},"atrule-id":{color:"#fff3eb"},"code.language-javascript":{color:"#a48774"},"attr-name":{color:"#a48774"},"code.language-css":{color:"#fcc440"},"code.language-scss":{color:"#fcc440"},boolean:{color:"#fcc440"},string:{color:"#fcc440"},entity:{color:"#fcc440",cursor:"help"},url:{color:"#fcc440"},".language-css .token.string":{color:"#fcc440"},".language-scss .token.string":{color:"#fcc440"},".style .token.string":{color:"#fcc440"},"attr-value":{color:"#fcc440"},keyword:{color:"#fcc440"},control:{color:"#fcc440"},directive:{color:"#fcc440"},unit:{color:"#fcc440"},statement:{color:"#fcc440"},regex:{color:"#fcc440"},atrule:{color:"#fcc440"},placeholder:{color:"#fcc440"},variable:{color:"#fcc440"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #fff3eb",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#a48774"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #816d5f",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#35302b"},".line-numbers .line-numbers-rows > span:before":{color:"#46403d"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(191, 160, 90, 0.2) 70%, rgba(191, 160, 90, 0))"}}}(Uw)),Uw}var jw={},HF;function tye(){return HF||(HF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2d2a",color:"#687d68"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#2a2d2a",color:"#687d68",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#435643"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#435643"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#435643"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#435643"},'code[class*="language-"]::selection':{textShadow:"none",background:"#435643"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#435643"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#535f53"},prolog:{color:"#535f53"},doctype:{color:"#535f53"},cdata:{color:"#535f53"},punctuation:{color:"#535f53"},namespace:{Opacity:".7"},tag:{color:"#a2b34d"},operator:{color:"#a2b34d"},number:{color:"#a2b34d"},property:{color:"#687d68"},function:{color:"#687d68"},"tag-id":{color:"#f0fff0"},selector:{color:"#f0fff0"},"atrule-id":{color:"#f0fff0"},"code.language-javascript":{color:"#b3d6b3"},"attr-name":{color:"#b3d6b3"},"code.language-css":{color:"#e5fb79"},"code.language-scss":{color:"#e5fb79"},boolean:{color:"#e5fb79"},string:{color:"#e5fb79"},entity:{color:"#e5fb79",cursor:"help"},url:{color:"#e5fb79"},".language-css .token.string":{color:"#e5fb79"},".language-scss .token.string":{color:"#e5fb79"},".style .token.string":{color:"#e5fb79"},"attr-value":{color:"#e5fb79"},keyword:{color:"#e5fb79"},control:{color:"#e5fb79"},directive:{color:"#e5fb79"},unit:{color:"#e5fb79"},statement:{color:"#e5fb79"},regex:{color:"#e5fb79"},atrule:{color:"#e5fb79"},placeholder:{color:"#e5fb79"},variable:{color:"#e5fb79"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #f0fff0",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#b3d6b3"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #5c705c",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#2c302c"},".line-numbers .line-numbers-rows > span:before":{color:"#3b423b"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(162, 179, 77, 0.2) 70%, rgba(162, 179, 77, 0))"}}}(jw)),jw}var Gw={},$F;function nye(){return $F||($F=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#faf8f5",color:"#728fcb"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#faf8f5",color:"#728fcb",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#faf8f5"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"]::selection':{textShadow:"none",background:"#faf8f5"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#faf8f5"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#b6ad9a"},prolog:{color:"#b6ad9a"},doctype:{color:"#b6ad9a"},cdata:{color:"#b6ad9a"},punctuation:{color:"#b6ad9a"},namespace:{Opacity:".7"},tag:{color:"#063289"},operator:{color:"#063289"},number:{color:"#063289"},property:{color:"#b29762"},function:{color:"#b29762"},"tag-id":{color:"#2d2006"},selector:{color:"#2d2006"},"atrule-id":{color:"#2d2006"},"code.language-javascript":{color:"#896724"},"attr-name":{color:"#896724"},"code.language-css":{color:"#728fcb"},"code.language-scss":{color:"#728fcb"},boolean:{color:"#728fcb"},string:{color:"#728fcb"},entity:{color:"#728fcb",cursor:"help"},url:{color:"#728fcb"},".language-css .token.string":{color:"#728fcb"},".language-scss .token.string":{color:"#728fcb"},".style .token.string":{color:"#728fcb"},"attr-value":{color:"#728fcb"},keyword:{color:"#728fcb"},control:{color:"#728fcb"},directive:{color:"#728fcb"},unit:{color:"#728fcb"},statement:{color:"#728fcb"},regex:{color:"#728fcb"},atrule:{color:"#728fcb"},placeholder:{color:"#93abdc"},variable:{color:"#93abdc"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #2d2006",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#896724"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #896724",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#ece8de"},".line-numbers .line-numbers-rows > span:before":{color:"#cdc4b1"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(45, 32, 6, 0.2) 70%, rgba(45, 32, 6, 0))"}}}(Gw)),Gw}var Hw={},qF;function rye(){return qF||(qF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#1d262f",color:"#57718e"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#1d262f",color:"#57718e",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#004a9e"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"]::selection':{textShadow:"none",background:"#004a9e"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#004a9e"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#4a5f78"},prolog:{color:"#4a5f78"},doctype:{color:"#4a5f78"},cdata:{color:"#4a5f78"},punctuation:{color:"#4a5f78"},namespace:{Opacity:".7"},tag:{color:"#0aa370"},operator:{color:"#0aa370"},number:{color:"#0aa370"},property:{color:"#57718e"},function:{color:"#57718e"},"tag-id":{color:"#ebf4ff"},selector:{color:"#ebf4ff"},"atrule-id":{color:"#ebf4ff"},"code.language-javascript":{color:"#7eb6f6"},"attr-name":{color:"#7eb6f6"},"code.language-css":{color:"#47ebb4"},"code.language-scss":{color:"#47ebb4"},boolean:{color:"#47ebb4"},string:{color:"#47ebb4"},entity:{color:"#47ebb4",cursor:"help"},url:{color:"#47ebb4"},".language-css .token.string":{color:"#47ebb4"},".language-scss .token.string":{color:"#47ebb4"},".style .token.string":{color:"#47ebb4"},"attr-value":{color:"#47ebb4"},keyword:{color:"#47ebb4"},control:{color:"#47ebb4"},directive:{color:"#47ebb4"},unit:{color:"#47ebb4"},statement:{color:"#47ebb4"},regex:{color:"#47ebb4"},atrule:{color:"#47ebb4"},placeholder:{color:"#47ebb4"},variable:{color:"#47ebb4"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #ebf4ff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#7eb6f6"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #34659d",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#1f2932"},".line-numbers .line-numbers-rows > span:before":{color:"#2c3847"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(10, 163, 112, 0.2) 70%, rgba(10, 163, 112, 0))"}}}(Hw)),Hw}var $w={},VF;function aye(){return VF||(VF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#24242e",color:"#767693"},'pre[class*="language-"]':{fontFamily:'Consolas, Menlo, Monaco, "Andale Mono WT", "Andale Mono", "Lucida Console", "Lucida Sans Typewriter", "DejaVu Sans Mono", "Bitstream Vera Sans Mono", "Liberation Mono", "Nimbus Mono L", "Courier New", Courier, monospace',fontSize:"14px",lineHeight:"1.375",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",background:"#24242e",color:"#767693",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#5151e6"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"]::selection':{textShadow:"none",background:"#5151e6"},'code[class*="language-"] ::selection':{textShadow:"none",background:"#5151e6"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#5b5b76"},prolog:{color:"#5b5b76"},doctype:{color:"#5b5b76"},cdata:{color:"#5b5b76"},punctuation:{color:"#5b5b76"},namespace:{Opacity:".7"},tag:{color:"#dd672c"},operator:{color:"#dd672c"},number:{color:"#dd672c"},property:{color:"#767693"},function:{color:"#767693"},"tag-id":{color:"#ebebff"},selector:{color:"#ebebff"},"atrule-id":{color:"#ebebff"},"code.language-javascript":{color:"#aaaaca"},"attr-name":{color:"#aaaaca"},"code.language-css":{color:"#fe8c52"},"code.language-scss":{color:"#fe8c52"},boolean:{color:"#fe8c52"},string:{color:"#fe8c52"},entity:{color:"#fe8c52",cursor:"help"},url:{color:"#fe8c52"},".language-css .token.string":{color:"#fe8c52"},".language-scss .token.string":{color:"#fe8c52"},".style .token.string":{color:"#fe8c52"},"attr-value":{color:"#fe8c52"},keyword:{color:"#fe8c52"},control:{color:"#fe8c52"},directive:{color:"#fe8c52"},unit:{color:"#fe8c52"},statement:{color:"#fe8c52"},regex:{color:"#fe8c52"},atrule:{color:"#fe8c52"},placeholder:{color:"#fe8c52"},variable:{color:"#fe8c52"},deleted:{textDecoration:"line-through"},inserted:{borderBottom:"1px dotted #ebebff",textDecoration:"none"},italic:{fontStyle:"italic"},important:{fontWeight:"bold",color:"#aaaaca"},bold:{fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid #7676f4",OutlineOffset:".4em"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#262631"},".line-numbers .line-numbers-rows > span:before":{color:"#393949"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(221, 103, 44, 0.2) 70%, rgba(221, 103, 44, 0))"}}}($w)),$w}var qw={},WF;function oye(){return WF||(WF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:"1px solid #dddddd",backgroundColor:"white"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{background:"#b3d4fc"},'pre[class*="language-"] ::-moz-selection':{background:"#b3d4fc"},'code[class*="language-"]::-moz-selection':{background:"#b3d4fc"},'code[class*="language-"] ::-moz-selection':{background:"#b3d4fc"},'pre[class*="language-"]::selection':{background:"#b3d4fc"},'pre[class*="language-"] ::selection':{background:"#b3d4fc"},'code[class*="language-"]::selection':{background:"#b3d4fc"},'code[class*="language-"] ::selection':{background:"#b3d4fc"},':not(pre) > code[class*="language-"]':{padding:".2em",paddingTop:"1px",paddingBottom:"1px",background:"#f8f8f8",border:"1px solid #dddddd"},comment:{color:"#999988",fontStyle:"italic"},prolog:{color:"#999988",fontStyle:"italic"},doctype:{color:"#999988",fontStyle:"italic"},cdata:{color:"#999988",fontStyle:"italic"},namespace:{Opacity:".7"},string:{color:"#e3116c"},"attr-value":{color:"#e3116c"},punctuation:{color:"#393A34"},operator:{color:"#393A34"},entity:{color:"#36acaa"},url:{color:"#36acaa"},symbol:{color:"#36acaa"},number:{color:"#36acaa"},boolean:{color:"#36acaa"},variable:{color:"#36acaa"},constant:{color:"#36acaa"},property:{color:"#36acaa"},regex:{color:"#36acaa"},inserted:{color:"#36acaa"},atrule:{color:"#00a4db"},keyword:{color:"#00a4db"},"attr-name":{color:"#00a4db"},".language-autohotkey .token.selector":{color:"#00a4db"},function:{color:"#9a050f",fontWeight:"bold"},deleted:{color:"#9a050f"},".language-autohotkey .token.tag":{color:"#9a050f"},tag:{color:"#00009f"},selector:{color:"#00009f"},".language-autohotkey .token.keyword":{color:"#00009f"},important:{fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(qw)),qw}var Vw={},YF;function iye(){return YF||(YF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#ebdbb2",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#ebdbb2",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#1d2021"},'pre[class*="language-"]::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"] ::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"]::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"] ::-moz-selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"]::selection':{color:"#fbf1c7",background:"#7c6f64"},'pre[class*="language-"] ::selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"]::selection':{color:"#fbf1c7",background:"#7c6f64"},'code[class*="language-"] ::selection':{color:"#fbf1c7",background:"#7c6f64"},':not(pre) > code[class*="language-"]':{background:"#1d2021",padding:"0.1em",borderRadius:"0.3em"},comment:{color:"#a89984"},prolog:{color:"#a89984"},cdata:{color:"#a89984"},delimiter:{color:"#fb4934"},boolean:{color:"#fb4934"},keyword:{color:"#fb4934"},selector:{color:"#fb4934"},important:{color:"#fb4934"},atrule:{color:"#fb4934"},operator:{color:"#a89984"},punctuation:{color:"#a89984"},"attr-name":{color:"#a89984"},tag:{color:"#fabd2f"},"tag.punctuation":{color:"#fabd2f"},doctype:{color:"#fabd2f"},builtin:{color:"#fabd2f"},entity:{color:"#d3869b"},number:{color:"#d3869b"},symbol:{color:"#d3869b"},property:{color:"#fb4934"},constant:{color:"#fb4934"},variable:{color:"#fb4934"},string:{color:"#b8bb26"},char:{color:"#b8bb26"},"attr-value":{color:"#a89984"},"attr-value.punctuation":{color:"#a89984"},url:{color:"#b8bb26",textDecoration:"underline"},function:{color:"#fabd2f"},regex:{background:"#b8bb26"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#a89984"},deleted:{background:"#fb4934"}}}(Vw)),Vw}var Ww={},KF;function lye(){return KF||(KF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#3c3836",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#3c3836",fontFamily:'Consolas, Monaco, "Andale Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#f9f5d7"},'pre[class*="language-"]::-moz-selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"] ::-moz-selection':{color:"#282828",background:"#a89984"},'code[class*="language-"]::-moz-selection':{color:"#282828",background:"#a89984"},'code[class*="language-"] ::-moz-selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"]::selection':{color:"#282828",background:"#a89984"},'pre[class*="language-"] ::selection':{color:"#282828",background:"#a89984"},'code[class*="language-"]::selection':{color:"#282828",background:"#a89984"},'code[class*="language-"] ::selection':{color:"#282828",background:"#a89984"},':not(pre) > code[class*="language-"]':{background:"#f9f5d7",padding:"0.1em",borderRadius:"0.3em"},comment:{color:"#7c6f64"},prolog:{color:"#7c6f64"},cdata:{color:"#7c6f64"},delimiter:{color:"#9d0006"},boolean:{color:"#9d0006"},keyword:{color:"#9d0006"},selector:{color:"#9d0006"},important:{color:"#9d0006"},atrule:{color:"#9d0006"},operator:{color:"#7c6f64"},punctuation:{color:"#7c6f64"},"attr-name":{color:"#7c6f64"},tag:{color:"#b57614"},"tag.punctuation":{color:"#b57614"},doctype:{color:"#b57614"},builtin:{color:"#b57614"},entity:{color:"#8f3f71"},number:{color:"#8f3f71"},symbol:{color:"#8f3f71"},property:{color:"#9d0006"},constant:{color:"#9d0006"},variable:{color:"#9d0006"},string:{color:"#797403"},char:{color:"#797403"},"attr-value":{color:"#7c6f64"},"attr-value.punctuation":{color:"#7c6f64"},url:{color:"#797403",textDecoration:"underline"},function:{color:"#b57614"},regex:{background:"#797403"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#7c6f64"},deleted:{background:"#9d0006"}}}(Ww)),Ww}var Yw={},XF;function sye(){return XF||(XF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={"code[class*='language-']":{color:"#d6e7ff",background:"#030314",textShadow:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',fontSize:"1em",lineHeight:"1.5",letterSpacing:".2px",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",textAlign:"left",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},"pre[class*='language-']":{color:"#d6e7ff",background:"#030314",textShadow:"none",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',fontSize:"1em",lineHeight:"1.5",letterSpacing:".2px",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",textAlign:"left",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",border:"1px solid #2a4555",borderRadius:"5px",padding:"1.5em 1em",margin:"1em 0",overflow:"auto"},"pre[class*='language-']::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-'] ::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-']::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-'] ::-moz-selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-']::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"pre[class*='language-'] ::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-']::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},"code[class*='language-'] ::selection":{color:"inherit",background:"#1d3b54",textShadow:"none"},":not(pre) > code[class*='language-']":{color:"#f0f6f6",background:"#2a4555",padding:"0.2em 0.3em",borderRadius:"0.2em",boxDecorationBreak:"clone"},comment:{color:"#446e69"},prolog:{color:"#446e69"},doctype:{color:"#446e69"},cdata:{color:"#446e69"},punctuation:{color:"#d6b007"},property:{color:"#d6e7ff"},tag:{color:"#d6e7ff"},boolean:{color:"#d6e7ff"},number:{color:"#d6e7ff"},constant:{color:"#d6e7ff"},symbol:{color:"#d6e7ff"},deleted:{color:"#d6e7ff"},selector:{color:"#e60067"},"attr-name":{color:"#e60067"},builtin:{color:"#e60067"},inserted:{color:"#e60067"},string:{color:"#49c6ec"},char:{color:"#49c6ec"},operator:{color:"#ec8e01",background:"transparent"},entity:{color:"#ec8e01",background:"transparent"},url:{color:"#ec8e01",background:"transparent"},".language-css .token.string":{color:"#ec8e01",background:"transparent"},".style .token.string":{color:"#ec8e01",background:"transparent"},atrule:{color:"#0fe468"},"attr-value":{color:"#0fe468"},keyword:{color:"#0fe468"},function:{color:"#78f3e9"},"class-name":{color:"#78f3e9"},regex:{color:"#d6e7ff"},important:{color:"#d6e7ff"},variable:{color:"#d6e7ff"}}}(Yw)),Yw}var Kw={},ZF;function uye(){return ZF||(ZF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{fontFamily:'"Fira Mono", Menlo, Monaco, "Lucida Console", "Courier New", Courier, monospace',fontSize:"16px",lineHeight:"1.375",direction:"ltr",textAlign:"left",wordSpacing:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",background:"#322931",color:"#b9b5b8"},'pre[class*="language-"]':{fontFamily:'"Fira Mono", Menlo, Monaco, "Lucida Console", "Courier New", Courier, monospace',fontSize:"16px",lineHeight:"1.375",direction:"ltr",textAlign:"left",wordSpacing:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",background:"#322931",color:"#b9b5b8",padding:"1em",margin:".5em 0",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{padding:".1em",borderRadius:".3em"},comment:{color:"#797379"},prolog:{color:"#797379"},doctype:{color:"#797379"},cdata:{color:"#797379"},punctuation:{color:"#b9b5b8"},".namespace":{Opacity:".7"},null:{color:"#fd8b19"},operator:{color:"#fd8b19"},boolean:{color:"#fd8b19"},number:{color:"#fd8b19"},property:{color:"#fdcc59"},tag:{color:"#1290bf"},string:{color:"#149b93"},selector:{color:"#c85e7c"},"attr-name":{color:"#fd8b19"},entity:{color:"#149b93",cursor:"help"},url:{color:"#149b93"},".language-css .token.string":{color:"#149b93"},".style .token.string":{color:"#149b93"},"attr-value":{color:"#8fc13e"},keyword:{color:"#8fc13e"},control:{color:"#8fc13e"},directive:{color:"#8fc13e"},unit:{color:"#8fc13e"},statement:{color:"#149b93"},regex:{color:"#149b93"},atrule:{color:"#149b93"},placeholder:{color:"#1290bf"},variable:{color:"#1290bf"},important:{color:"#dd464c",fontWeight:"bold"},"pre > code.highlight":{Outline:".4em solid red",OutlineOffset:".4em"}}}(Kw)),Kw}var Xw={},QF;function cye(){return QF||(QF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Monaco, Consolas, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#263E52",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Monaco, Consolas, 'Andale Mono', 'Ubuntu Mono', monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#263E52",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#5c98cd"},prolog:{color:"#5c98cd"},doctype:{color:"#5c98cd"},cdata:{color:"#5c98cd"},punctuation:{color:"#f8f8f2"},".namespace":{Opacity:".7"},property:{color:"#F05E5D"},tag:{color:"#F05E5D"},constant:{color:"#F05E5D"},symbol:{color:"#F05E5D"},deleted:{color:"#F05E5D"},boolean:{color:"#BC94F9"},number:{color:"#BC94F9"},selector:{color:"#FCFCD6"},"attr-name":{color:"#FCFCD6"},string:{color:"#FCFCD6"},char:{color:"#FCFCD6"},builtin:{color:"#FCFCD6"},inserted:{color:"#FCFCD6"},operator:{color:"#f8f8f2"},entity:{color:"#f8f8f2",cursor:"help"},url:{color:"#f8f8f2"},".language-css .token.string":{color:"#f8f8f2"},".style .token.string":{color:"#f8f8f2"},variable:{color:"#f8f8f2"},atrule:{color:"#66D8EF"},"attr-value":{color:"#66D8EF"},function:{color:"#66D8EF"},"class-name":{color:"#66D8EF"},keyword:{color:"#6EB26E"},regex:{color:"#F05E5D"},important:{color:"#F05E5D",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(Xw)),Xw}var Zw={},JF;function dye(){return JF||(JF=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#eee",background:"#2f2f2f",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#eee",background:"#2f2f2f",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#363636"},'pre[class*="language-"]::-moz-selection':{background:"#363636"},'code[class*="language-"] ::-moz-selection':{background:"#363636"},'pre[class*="language-"] ::-moz-selection':{background:"#363636"},'code[class*="language-"]::selection':{background:"#363636"},'pre[class*="language-"]::selection':{background:"#363636"},'code[class*="language-"] ::selection':{background:"#363636"},'pre[class*="language-"] ::selection':{background:"#363636"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#fd9170"},".language-sass > code":{color:"#fd9170"},".language-scss > code":{color:"#fd9170"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#c792ea"},"attr-name":{color:"#ffcb6b"},"attr-value":{color:"#a5e844"},attribute:{color:"#a5e844"},boolean:{color:"#c792ea"},builtin:{color:"#ffcb6b"},cdata:{color:"#80cbc4"},char:{color:"#80cbc4"},class:{color:"#ffcb6b"},"class-name":{color:"#f2ff00"},comment:{color:"#616161"},constant:{color:"#c792ea"},deleted:{color:"#ff6666"},doctype:{color:"#616161"},entity:{color:"#ff6666"},function:{color:"#c792ea"},hexcode:{color:"#f2ff00"},id:{color:"#c792ea",fontWeight:"bold"},important:{color:"#c792ea",fontWeight:"bold"},inserted:{color:"#80cbc4"},keyword:{color:"#c792ea"},number:{color:"#fd9170"},operator:{color:"#89ddff"},prolog:{color:"#616161"},property:{color:"#80cbc4"},"pseudo-class":{color:"#a5e844"},"pseudo-element":{color:"#a5e844"},punctuation:{color:"#89ddff"},regex:{color:"#f2ff00"},selector:{color:"#ff6666"},string:{color:"#a5e844"},symbol:{color:"#c792ea"},tag:{color:"#ff6666"},unit:{color:"#fd9170"},url:{color:"#ff6666"},variable:{color:"#ff6666"}}}(Zw)),Zw}var Qw={},ez;function fye(){return ez||(ez=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#90a4ae",background:"#fafafa",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#90a4ae",background:"#fafafa",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"]::-moz-selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"] ::-moz-selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"] ::-moz-selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"]::selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"]::selection':{background:"#cceae7",color:"#263238"},'code[class*="language-"] ::selection':{background:"#cceae7",color:"#263238"},'pre[class*="language-"] ::selection':{background:"#cceae7",color:"#263238"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#f76d47"},".language-sass > code":{color:"#f76d47"},".language-scss > code":{color:"#f76d47"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#7c4dff"},"attr-name":{color:"#39adb5"},"attr-value":{color:"#f6a434"},attribute:{color:"#f6a434"},boolean:{color:"#7c4dff"},builtin:{color:"#39adb5"},cdata:{color:"#39adb5"},char:{color:"#39adb5"},class:{color:"#39adb5"},"class-name":{color:"#6182b8"},comment:{color:"#aabfc9"},constant:{color:"#7c4dff"},deleted:{color:"#e53935"},doctype:{color:"#aabfc9"},entity:{color:"#e53935"},function:{color:"#7c4dff"},hexcode:{color:"#f76d47"},id:{color:"#7c4dff",fontWeight:"bold"},important:{color:"#7c4dff",fontWeight:"bold"},inserted:{color:"#39adb5"},keyword:{color:"#7c4dff"},number:{color:"#f76d47"},operator:{color:"#39adb5"},prolog:{color:"#aabfc9"},property:{color:"#39adb5"},"pseudo-class":{color:"#f6a434"},"pseudo-element":{color:"#f6a434"},punctuation:{color:"#39adb5"},regex:{color:"#6182b8"},selector:{color:"#e53935"},string:{color:"#f6a434"},symbol:{color:"#7c4dff"},tag:{color:"#e53935"},unit:{color:"#f76d47"},url:{color:"#e53935"},variable:{color:"#e53935"}}}(Qw)),Qw}var Jw={},tz;function pye(){return tz||(tz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#c3cee3",background:"#263238",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",color:"#c3cee3",background:"#263238",fontFamily:"Roboto Mono, monospace",fontSize:"1em",lineHeight:"1.5em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",overflow:"auto",position:"relative",margin:"0.5em 0",padding:"1.25em 1em"},'code[class*="language-"]::-moz-selection':{background:"#363636"},'pre[class*="language-"]::-moz-selection':{background:"#363636"},'code[class*="language-"] ::-moz-selection':{background:"#363636"},'pre[class*="language-"] ::-moz-selection':{background:"#363636"},'code[class*="language-"]::selection':{background:"#363636"},'pre[class*="language-"]::selection':{background:"#363636"},'code[class*="language-"] ::selection':{background:"#363636"},'pre[class*="language-"] ::selection':{background:"#363636"},':not(pre) > code[class*="language-"]':{whiteSpace:"normal",borderRadius:"0.2em",padding:"0.1em"},".language-css > code":{color:"#fd9170"},".language-sass > code":{color:"#fd9170"},".language-scss > code":{color:"#fd9170"},'[class*="language-"] .namespace':{Opacity:"0.7"},atrule:{color:"#c792ea"},"attr-name":{color:"#ffcb6b"},"attr-value":{color:"#c3e88d"},attribute:{color:"#c3e88d"},boolean:{color:"#c792ea"},builtin:{color:"#ffcb6b"},cdata:{color:"#80cbc4"},char:{color:"#80cbc4"},class:{color:"#ffcb6b"},"class-name":{color:"#f2ff00"},color:{color:"#f2ff00"},comment:{color:"#546e7a"},constant:{color:"#c792ea"},deleted:{color:"#f07178"},doctype:{color:"#546e7a"},entity:{color:"#f07178"},function:{color:"#c792ea"},hexcode:{color:"#f2ff00"},id:{color:"#c792ea",fontWeight:"bold"},important:{color:"#c792ea",fontWeight:"bold"},inserted:{color:"#80cbc4"},keyword:{color:"#c792ea",fontStyle:"italic"},number:{color:"#fd9170"},operator:{color:"#89ddff"},prolog:{color:"#546e7a"},property:{color:"#80cbc4"},"pseudo-class":{color:"#c3e88d"},"pseudo-element":{color:"#c3e88d"},punctuation:{color:"#89ddff"},regex:{color:"#f2ff00"},selector:{color:"#f07178"},string:{color:"#c3e88d"},symbol:{color:"#c792ea"},tag:{color:"#f07178"},unit:{color:"#f07178"},url:{color:"#fd9170"},variable:{color:"#f07178"}}}(Jw)),Jw}var ex={},nz;function gye(){return nz||(nz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#d6deeb",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",fontSize:"1em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"white",fontFamily:'Consolas, Monaco, "Andale Mono", "Ubuntu Mono", monospace',textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",fontSize:"1em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",background:"#011627"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},':not(pre) > code[class*="language-"]':{color:"white",background:"#011627",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"rgb(99, 119, 119)",fontStyle:"italic"},prolog:{color:"rgb(99, 119, 119)",fontStyle:"italic"},cdata:{color:"rgb(99, 119, 119)",fontStyle:"italic"},punctuation:{color:"rgb(199, 146, 234)"},".namespace":{color:"rgb(178, 204, 214)"},deleted:{color:"rgba(239, 83, 80, 0.56)",fontStyle:"italic"},symbol:{color:"rgb(128, 203, 196)"},property:{color:"rgb(128, 203, 196)"},tag:{color:"rgb(127, 219, 202)"},operator:{color:"rgb(127, 219, 202)"},keyword:{color:"rgb(127, 219, 202)"},boolean:{color:"rgb(255, 88, 116)"},number:{color:"rgb(247, 140, 108)"},constant:{color:"rgb(130, 170, 255)"},function:{color:"rgb(130, 170, 255)"},builtin:{color:"rgb(130, 170, 255)"},char:{color:"rgb(130, 170, 255)"},selector:{color:"rgb(199, 146, 234)",fontStyle:"italic"},doctype:{color:"rgb(199, 146, 234)",fontStyle:"italic"},"attr-name":{color:"rgb(173, 219, 103)",fontStyle:"italic"},inserted:{color:"rgb(173, 219, 103)",fontStyle:"italic"},string:{color:"rgb(173, 219, 103)"},url:{color:"rgb(173, 219, 103)"},entity:{color:"rgb(173, 219, 103)"},".language-css .token.string":{color:"rgb(173, 219, 103)"},".style .token.string":{color:"rgb(173, 219, 103)"},"class-name":{color:"rgb(255, 203, 139)"},atrule:{color:"rgb(255, 203, 139)"},"attr-value":{color:"rgb(255, 203, 139)"},regex:{color:"rgb(214, 222, 235)"},important:{color:"rgb(214, 222, 235)",fontWeight:"bold"},variable:{color:"rgb(214, 222, 235)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(ex)),ex}var tx={},rz;function hye(){return rz||(rz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f8f8f2",background:"none",fontFamily:`"Fira Code", Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace`,textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f8f8f2",background:"#2E3440",fontFamily:`"Fira Code", Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace`,textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em"},':not(pre) > code[class*="language-"]':{background:"#2E3440",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#636f88"},prolog:{color:"#636f88"},doctype:{color:"#636f88"},cdata:{color:"#636f88"},punctuation:{color:"#81A1C1"},".namespace":{Opacity:".7"},property:{color:"#81A1C1"},tag:{color:"#81A1C1"},constant:{color:"#81A1C1"},symbol:{color:"#81A1C1"},deleted:{color:"#81A1C1"},number:{color:"#B48EAD"},boolean:{color:"#81A1C1"},selector:{color:"#A3BE8C"},"attr-name":{color:"#A3BE8C"},string:{color:"#A3BE8C"},char:{color:"#A3BE8C"},builtin:{color:"#A3BE8C"},inserted:{color:"#A3BE8C"},operator:{color:"#81A1C1"},entity:{color:"#81A1C1",cursor:"help"},url:{color:"#81A1C1"},".language-css .token.string":{color:"#81A1C1"},".style .token.string":{color:"#81A1C1"},variable:{color:"#81A1C1"},atrule:{color:"#88C0D0"},"attr-value":{color:"#88C0D0"},function:{color:"#88C0D0"},"class-name":{color:"#88C0D0"},keyword:{color:"#81A1C1"},regex:{color:"#EBCB8B"},important:{color:"#EBCB8B",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(tx)),tx}var nx={},az;function mye(){return az||(az=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{background:"hsl(220, 13%, 18%)",color:"hsl(220, 14%, 71%)",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},'code[class*="language-"]::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::-moz-selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"]::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'code[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},'pre[class*="language-"] *::selection':{background:"hsl(220, 13%, 28%)",color:"inherit",textShadow:"none"},':not(pre) > code[class*="language-"]':{padding:"0.2em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},prolog:{color:"hsl(220, 10%, 40%)"},cdata:{color:"hsl(220, 10%, 40%)"},doctype:{color:"hsl(220, 14%, 71%)"},punctuation:{color:"hsl(220, 14%, 71%)"},entity:{color:"hsl(220, 14%, 71%)",cursor:"help"},"attr-name":{color:"hsl(29, 54%, 61%)"},"class-name":{color:"hsl(29, 54%, 61%)"},boolean:{color:"hsl(29, 54%, 61%)"},constant:{color:"hsl(29, 54%, 61%)"},number:{color:"hsl(29, 54%, 61%)"},atrule:{color:"hsl(29, 54%, 61%)"},keyword:{color:"hsl(286, 60%, 67%)"},property:{color:"hsl(355, 65%, 65%)"},tag:{color:"hsl(355, 65%, 65%)"},symbol:{color:"hsl(355, 65%, 65%)"},deleted:{color:"hsl(355, 65%, 65%)"},important:{color:"hsl(355, 65%, 65%)"},selector:{color:"hsl(95, 38%, 62%)"},string:{color:"hsl(95, 38%, 62%)"},char:{color:"hsl(95, 38%, 62%)"},builtin:{color:"hsl(95, 38%, 62%)"},inserted:{color:"hsl(95, 38%, 62%)"},regex:{color:"hsl(95, 38%, 62%)"},"attr-value":{color:"hsl(95, 38%, 62%)"},"attr-value > .token.punctuation":{color:"hsl(95, 38%, 62%)"},variable:{color:"hsl(207, 82%, 66%)"},operator:{color:"hsl(207, 82%, 66%)"},function:{color:"hsl(207, 82%, 66%)"},url:{color:"hsl(187, 47%, 55%)"},"attr-value > .token.punctuation.attr-equals":{color:"hsl(220, 14%, 71%)"},"special-attr > .token.attr-value > .token.value.css":{color:"hsl(220, 14%, 71%)"},".language-css .token.selector":{color:"hsl(355, 65%, 65%)"},".language-css .token.property":{color:"hsl(220, 14%, 71%)"},".language-css .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.function":{color:"hsl(187, 47%, 55%)"},".language-css .token.url > .token.string.url":{color:"hsl(95, 38%, 62%)"},".language-css .token.important":{color:"hsl(286, 60%, 67%)"},".language-css .token.atrule .token.rule":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.operator":{color:"hsl(286, 60%, 67%)"},".language-javascript .token.template-string > .token.interpolation > .token.interpolation-punctuation.punctuation":{color:"hsl(5, 48%, 51%)"},".language-json .token.operator":{color:"hsl(220, 14%, 71%)"},".language-json .token.null.keyword":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.url":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.operator":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url-reference.url > .token.string":{color:"hsl(220, 14%, 71%)"},".language-markdown .token.url > .token.content":{color:"hsl(207, 82%, 66%)"},".language-markdown .token.url > .token.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.url-reference.url":{color:"hsl(187, 47%, 55%)"},".language-markdown .token.blockquote.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.hr.punctuation":{color:"hsl(220, 10%, 40%)",fontStyle:"italic"},".language-markdown .token.code-snippet":{color:"hsl(95, 38%, 62%)"},".language-markdown .token.bold .token.content":{color:"hsl(29, 54%, 61%)"},".language-markdown .token.italic .token.content":{color:"hsl(286, 60%, 67%)"},".language-markdown .token.strike .token.content":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.strike .token.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.list.punctuation":{color:"hsl(355, 65%, 65%)"},".language-markdown .token.title.important > .token.punctuation":{color:"hsl(355, 65%, 65%)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:"0.8"},"token.tab:not(:empty):before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.cr:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.lf:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"token.space:before":{color:"hsla(220, 14%, 71%, 0.15)",textShadow:"none"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item":{marginRight:"0.4em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 9%, 55%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{background:"hsl(220, 13%, 28%)",color:"hsl(220, 14%, 71%)"},".line-highlight.line-highlight":{background:"hsla(220, 100%, 80%, 0.04)"},".line-highlight.line-highlight:before":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},".line-highlight.line-highlight[data-end]:after":{background:"hsl(220, 13%, 26%)",color:"hsl(220, 14%, 71%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"hsla(220, 100%, 80%, 0.04)"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".command-line .command-line-prompt":{borderRightColor:"hsla(220, 14%, 71%, 0.15)"},".line-numbers .line-numbers-rows > span:before":{color:"hsl(220, 14%, 45%)"},".command-line .command-line-prompt > span:before":{color:"hsl(220, 14%, 45%)"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"hsl(355, 65%, 65%)"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"hsl(95, 38%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"hsl(207, 82%, 66%)"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"hsl(286, 60%, 67%)"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"hsl(286, 60%, 67%)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},".prism-previewer.prism-previewer:before":{borderColor:"hsl(224, 13%, 17%)"},".prism-previewer-gradient.prism-previewer-gradient div":{borderColor:"hsl(224, 13%, 17%)",borderRadius:"0.3em"},".prism-previewer-color.prism-previewer-color:before":{borderRadius:"0.3em"},".prism-previewer-easing.prism-previewer-easing:before":{borderRadius:"0.3em"},".prism-previewer.prism-previewer:after":{borderTopColor:"hsl(224, 13%, 17%)"},".prism-previewer-flipped.prism-previewer-flipped.after":{borderBottomColor:"hsl(224, 13%, 17%)"},".prism-previewer-angle.prism-previewer-angle:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-time.prism-previewer-time:before":{background:"hsl(219, 13%, 22%)"},".prism-previewer-easing.prism-previewer-easing":{background:"hsl(219, 13%, 22%)"},".prism-previewer-angle.prism-previewer-angle circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-time.prism-previewer-time circle":{stroke:"hsl(220, 14%, 71%)",strokeOpacity:"1"},".prism-previewer-easing.prism-previewer-easing circle":{stroke:"hsl(220, 14%, 71%)",fill:"transparent"},".prism-previewer-easing.prism-previewer-easing path":{stroke:"hsl(220, 14%, 71%)"},".prism-previewer-easing.prism-previewer-easing line":{stroke:"hsl(220, 14%, 71%)"}}}(nx)),nx}var rx={},oz;function bye(){return oz||(oz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{background:"hsl(230, 1%, 98%)",color:"hsl(230, 8%, 24%)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{background:"hsl(230, 1%, 98%)",color:"hsl(230, 8%, 24%)",fontFamily:'"Fira Code", "Fira Mono", Menlo, Consolas, "DejaVu Sans Mono", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:"0.5em 0",overflow:"auto",borderRadius:"0.3em"},'code[class*="language-"]::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"] *::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'pre[class*="language-"] *::-moz-selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"]::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'code[class*="language-"] *::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},'pre[class*="language-"] *::selection':{background:"hsl(230, 1%, 90%)",color:"inherit"},':not(pre) > code[class*="language-"]':{padding:"0.2em 0.3em",borderRadius:"0.3em",whiteSpace:"normal"},comment:{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},prolog:{color:"hsl(230, 4%, 64%)"},cdata:{color:"hsl(230, 4%, 64%)"},doctype:{color:"hsl(230, 8%, 24%)"},punctuation:{color:"hsl(230, 8%, 24%)"},entity:{color:"hsl(230, 8%, 24%)",cursor:"help"},"attr-name":{color:"hsl(35, 99%, 36%)"},"class-name":{color:"hsl(35, 99%, 36%)"},boolean:{color:"hsl(35, 99%, 36%)"},constant:{color:"hsl(35, 99%, 36%)"},number:{color:"hsl(35, 99%, 36%)"},atrule:{color:"hsl(35, 99%, 36%)"},keyword:{color:"hsl(301, 63%, 40%)"},property:{color:"hsl(5, 74%, 59%)"},tag:{color:"hsl(5, 74%, 59%)"},symbol:{color:"hsl(5, 74%, 59%)"},deleted:{color:"hsl(5, 74%, 59%)"},important:{color:"hsl(5, 74%, 59%)"},selector:{color:"hsl(119, 34%, 47%)"},string:{color:"hsl(119, 34%, 47%)"},char:{color:"hsl(119, 34%, 47%)"},builtin:{color:"hsl(119, 34%, 47%)"},inserted:{color:"hsl(119, 34%, 47%)"},regex:{color:"hsl(119, 34%, 47%)"},"attr-value":{color:"hsl(119, 34%, 47%)"},"attr-value > .token.punctuation":{color:"hsl(119, 34%, 47%)"},variable:{color:"hsl(221, 87%, 60%)"},operator:{color:"hsl(221, 87%, 60%)"},function:{color:"hsl(221, 87%, 60%)"},url:{color:"hsl(198, 99%, 37%)"},"attr-value > .token.punctuation.attr-equals":{color:"hsl(230, 8%, 24%)"},"special-attr > .token.attr-value > .token.value.css":{color:"hsl(230, 8%, 24%)"},".language-css .token.selector":{color:"hsl(5, 74%, 59%)"},".language-css .token.property":{color:"hsl(230, 8%, 24%)"},".language-css .token.function":{color:"hsl(198, 99%, 37%)"},".language-css .token.url > .token.function":{color:"hsl(198, 99%, 37%)"},".language-css .token.url > .token.string.url":{color:"hsl(119, 34%, 47%)"},".language-css .token.important":{color:"hsl(301, 63%, 40%)"},".language-css .token.atrule .token.rule":{color:"hsl(301, 63%, 40%)"},".language-javascript .token.operator":{color:"hsl(301, 63%, 40%)"},".language-javascript .token.template-string > .token.interpolation > .token.interpolation-punctuation.punctuation":{color:"hsl(344, 84%, 43%)"},".language-json .token.operator":{color:"hsl(230, 8%, 24%)"},".language-json .token.null.keyword":{color:"hsl(35, 99%, 36%)"},".language-markdown .token.url":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url > .token.operator":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url-reference.url > .token.string":{color:"hsl(230, 8%, 24%)"},".language-markdown .token.url > .token.content":{color:"hsl(221, 87%, 60%)"},".language-markdown .token.url > .token.url":{color:"hsl(198, 99%, 37%)"},".language-markdown .token.url-reference.url":{color:"hsl(198, 99%, 37%)"},".language-markdown .token.blockquote.punctuation":{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},".language-markdown .token.hr.punctuation":{color:"hsl(230, 4%, 64%)",fontStyle:"italic"},".language-markdown .token.code-snippet":{color:"hsl(119, 34%, 47%)"},".language-markdown .token.bold .token.content":{color:"hsl(35, 99%, 36%)"},".language-markdown .token.italic .token.content":{color:"hsl(301, 63%, 40%)"},".language-markdown .token.strike .token.content":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.strike .token.punctuation":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.list.punctuation":{color:"hsl(5, 74%, 59%)"},".language-markdown .token.title.important > .token.punctuation":{color:"hsl(5, 74%, 59%)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},namespace:{Opacity:"0.8"},"token.tab:not(:empty):before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.cr:before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.lf:before":{color:"hsla(230, 8%, 24%, 0.2)"},"token.space:before":{color:"hsla(230, 8%, 24%, 0.2)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item":{marginRight:"0.4em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 6%, 44%)",padding:"0.1em 0.4em",borderRadius:"0.3em"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > button:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > a:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:hover":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},"div.code-toolbar > .toolbar.toolbar > .toolbar-item > span:focus":{background:"hsl(230, 1%, 78%)",color:"hsl(230, 8%, 24%)"},".line-highlight.line-highlight":{background:"hsla(230, 8%, 24%, 0.05)"},".line-highlight.line-highlight:before":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 8%, 24%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},".line-highlight.line-highlight[data-end]:after":{background:"hsl(230, 1%, 90%)",color:"hsl(230, 8%, 24%)",padding:"0.1em 0.6em",borderRadius:"0.3em",boxShadow:"0 2px 0 0 rgba(0, 0, 0, 0.2)"},"pre[id].linkable-line-numbers.linkable-line-numbers span.line-numbers-rows > span:hover:before":{backgroundColor:"hsla(230, 8%, 24%, 0.05)"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"hsla(230, 8%, 24%, 0.2)"},".command-line .command-line-prompt":{borderRightColor:"hsla(230, 8%, 24%, 0.2)"},".line-numbers .line-numbers-rows > span:before":{color:"hsl(230, 1%, 62%)"},".command-line .command-line-prompt > span:before":{color:"hsl(230, 1%, 62%)"},".rainbow-braces .token.token.punctuation.brace-level-1":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-5":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-9":{color:"hsl(5, 74%, 59%)"},".rainbow-braces .token.token.punctuation.brace-level-2":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-6":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-10":{color:"hsl(119, 34%, 47%)"},".rainbow-braces .token.token.punctuation.brace-level-3":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-7":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-11":{color:"hsl(221, 87%, 60%)"},".rainbow-braces .token.token.punctuation.brace-level-4":{color:"hsl(301, 63%, 40%)"},".rainbow-braces .token.token.punctuation.brace-level-8":{color:"hsl(301, 63%, 40%)"},".rainbow-braces .token.token.punctuation.brace-level-12":{color:"hsl(301, 63%, 40%)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)":{backgroundColor:"hsla(353, 100%, 66%, 0.15)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix)::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre > code.diff-highlight .token.token.deleted:not(.prefix) *::selection":{backgroundColor:"hsla(353, 95%, 66%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)":{backgroundColor:"hsla(137, 100%, 55%, 0.15)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::-moz-selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre.diff-highlight > code .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix)::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},"pre > code.diff-highlight .token.token.inserted:not(.prefix) *::selection":{backgroundColor:"hsla(135, 73%, 55%, 0.25)"},".prism-previewer.prism-previewer:before":{borderColor:"hsl(0, 0, 95%)"},".prism-previewer-gradient.prism-previewer-gradient div":{borderColor:"hsl(0, 0, 95%)",borderRadius:"0.3em"},".prism-previewer-color.prism-previewer-color:before":{borderRadius:"0.3em"},".prism-previewer-easing.prism-previewer-easing:before":{borderRadius:"0.3em"},".prism-previewer.prism-previewer:after":{borderTopColor:"hsl(0, 0, 95%)"},".prism-previewer-flipped.prism-previewer-flipped.after":{borderBottomColor:"hsl(0, 0, 95%)"},".prism-previewer-angle.prism-previewer-angle:before":{background:"hsl(0, 0%, 100%)"},".prism-previewer-time.prism-previewer-time:before":{background:"hsl(0, 0%, 100%)"},".prism-previewer-easing.prism-previewer-easing":{background:"hsl(0, 0%, 100%)"},".prism-previewer-angle.prism-previewer-angle circle":{stroke:"hsl(230, 8%, 24%)",strokeOpacity:"1"},".prism-previewer-time.prism-previewer-time circle":{stroke:"hsl(230, 8%, 24%)",strokeOpacity:"1"},".prism-previewer-easing.prism-previewer-easing circle":{stroke:"hsl(230, 8%, 24%)",fill:"transparent"},".prism-previewer-easing.prism-previewer-easing path":{stroke:"hsl(230, 8%, 24%)"},".prism-previewer-easing.prism-previewer-easing line":{stroke:"hsl(230, 8%, 24%)"}}}(rx)),rx}var ax={},iz;function yye(){return iz||(iz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"15px",lineHeight:"1.5",color:"#dccf8f",textShadow:"0"},'pre[class*="language-"]':{MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordBreak:"break-all",wordWrap:"break-word",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"15px",lineHeight:"1.5",color:"#DCCF8F",textShadow:"0",borderRadius:"5px",border:"1px solid #000",background:"#181914 url('data:image/jpeg;base64,/9j/4AAQSkZJRgABAgAAZABkAAD/7AARRHVja3kAAQAEAAAAMAAA/+4ADkFkb2JlAGTAAAAAAf/bAIQACQYGBgcGCQcHCQ0IBwgNDwsJCQsPEQ4ODw4OERENDg4ODg0RERQUFhQUERoaHBwaGiYmJiYmKysrKysrKysrKwEJCAgJCgkMCgoMDwwODA8TDg4ODhMVDg4PDg4VGhMRERERExoXGhYWFhoXHR0aGh0dJCQjJCQrKysrKysrKysr/8AAEQgAjACMAwEiAAIRAQMRAf/EAF4AAQEBAAAAAAAAAAAAAAAAAAABBwEBAQAAAAAAAAAAAAAAAAAAAAIQAAEDAwIHAQEAAAAAAAAAAADwAREhYaExkUFRcYGxwdHh8REBAAAAAAAAAAAAAAAAAAAAAP/aAAwDAQACEQMRAD8AyGFEjHaBS2fDDs2zkhKmBKktb7km+ZwwCnXPkLVmCTMItj6AXFxRS465/BTnkAJvkLkJe+7AKKoi2AtRS2zuAWsCb5GOlBN8gKfmuGHZ8MFqIth3ALmFoFwbwKWyAlTAp17uKqBvgBD8sM4fTjhvAhkzhaRkBMKBrfs7jGPIpzy7gFrAqnC0C0gB0EWwBDW2cBVQwm+QtPpa3wBO3sVvszCnLAhkzgL5/RLf13cLQd8/AGlu0Cb5HTx9KuAEieGJEdcehS3eRTp2ATdt3CpIm+QtZwAhROXFeb7swp/ahaM3kBE/jSIUBc/AWrgBN8uNFAl+b7sAXFxFn2YLUU5Ns7gFX8C4ib+hN8gFWXwK3bZglxEJm+gKdciLPsFV/TClsgJUwKJ5FVA7tvIFrfZhVfGJDcsCKaYgAqv6YRbE+RWOWBtu7+AL3yRalXLyKqAIIfk+zARbDgFyEsncYwJvlgFRW+GEWntIi2P0BooyFxcNr8Ep3+ANLbMO+QyhvbiqdgC0kVvgUUiLYgBS2QtPbiVI1/sgOmG9uO+Y8DW+7jS2zAOnj6O2BndwuIAUtkdRN8gFoK3wwXMQyZwHVbClsuNLd4E3yAUR6FVDBR+BafQGt93LVMxJTv8ABts4CVLhcfYWsCb5kC9/BHdU8CLYFY5bMAd+eX9MGthhpbA1vu4B7+RKkaW2Yq4AQtVBBFsAJU/AuIXBhN8gGWnstefhiZyWvLAEnbYS1uzSFP6Jvn4Baxx70JKkQojLib5AVTey1jjgkKJGO0AKWyOm7N7cSpgSpAdPH0Tfd/gp1z5C1ZgKqN9J2wFxcUUuAFLZAm+QC0Fb4YUVRFsAOvj4KW2dwtYE3yAWk/wS/PLMKfmuGHZ8MAXF/Ja32Yi5haAKWz4Ydm2cSpgU693Atb7km+Zwwh+WGcPpxw3gAkzCLY+iYUDW/Z3Adc/gpzyFrAqnALkJe+7DoItgAtRS2zuKqGE3yAx0oJvkdvYrfZmALURbDuL5/RLf13cAuDeBS2RpbtAm+QFVA3wR+3fUtFHoBDJnC0jIXH0HWsgMY8inPLuOkd9chp4z20ALQLSA8cI9jYAIa2zjzjBd8gRafS1vgiUho/kAKcsCGTOGWvoOpkAtB3z8Hm8x2Ff5ADp4+lXAlIvcmwH/2Q==') repeat left top",padding:"12px",overflow:"auto"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{borderRadius:"5px",border:"1px solid #000",color:"#DCCF8F",background:"#181914 url('data:image/jpeg;base64,/9j/4AAQSkZJRgABAgAAZABkAAD/7AARRHVja3kAAQAEAAAAMAAA/+4ADkFkb2JlAGTAAAAAAf/bAIQACQYGBgcGCQcHCQ0IBwgNDwsJCQsPEQ4ODw4OERENDg4ODg0RERQUFhQUERoaHBwaGiYmJiYmKysrKysrKysrKwEJCAgJCgkMCgoMDwwODA8TDg4ODhMVDg4PDg4VGhMRERERExoXGhYWFhoXHR0aGh0dJCQjJCQrKysrKysrKysr/8AAEQgAjACMAwEiAAIRAQMRAf/EAF4AAQEBAAAAAAAAAAAAAAAAAAABBwEBAQAAAAAAAAAAAAAAAAAAAAIQAAEDAwIHAQEAAAAAAAAAAADwAREhYaExkUFRcYGxwdHh8REBAAAAAAAAAAAAAAAAAAAAAP/aAAwDAQACEQMRAD8AyGFEjHaBS2fDDs2zkhKmBKktb7km+ZwwCnXPkLVmCTMItj6AXFxRS465/BTnkAJvkLkJe+7AKKoi2AtRS2zuAWsCb5GOlBN8gKfmuGHZ8MFqIth3ALmFoFwbwKWyAlTAp17uKqBvgBD8sM4fTjhvAhkzhaRkBMKBrfs7jGPIpzy7gFrAqnC0C0gB0EWwBDW2cBVQwm+QtPpa3wBO3sVvszCnLAhkzgL5/RLf13cLQd8/AGlu0Cb5HTx9KuAEieGJEdcehS3eRTp2ATdt3CpIm+QtZwAhROXFeb7swp/ahaM3kBE/jSIUBc/AWrgBN8uNFAl+b7sAXFxFn2YLUU5Ns7gFX8C4ib+hN8gFWXwK3bZglxEJm+gKdciLPsFV/TClsgJUwKJ5FVA7tvIFrfZhVfGJDcsCKaYgAqv6YRbE+RWOWBtu7+AL3yRalXLyKqAIIfk+zARbDgFyEsncYwJvlgFRW+GEWntIi2P0BooyFxcNr8Ep3+ANLbMO+QyhvbiqdgC0kVvgUUiLYgBS2QtPbiVI1/sgOmG9uO+Y8DW+7jS2zAOnj6O2BndwuIAUtkdRN8gFoK3wwXMQyZwHVbClsuNLd4E3yAUR6FVDBR+BafQGt93LVMxJTv8ABts4CVLhcfYWsCb5kC9/BHdU8CLYFY5bMAd+eX9MGthhpbA1vu4B7+RKkaW2Yq4AQtVBBFsAJU/AuIXBhN8gGWnstefhiZyWvLAEnbYS1uzSFP6Jvn4Baxx70JKkQojLib5AVTey1jjgkKJGO0AKWyOm7N7cSpgSpAdPH0Tfd/gp1z5C1ZgKqN9J2wFxcUUuAFLZAm+QC0Fb4YUVRFsAOvj4KW2dwtYE3yAWk/wS/PLMKfmuGHZ8MAXF/Ja32Yi5haAKWz4Ydm2cSpgU693Atb7km+Zwwh+WGcPpxw3gAkzCLY+iYUDW/Z3Adc/gpzyFrAqnALkJe+7DoItgAtRS2zuKqGE3yAx0oJvkdvYrfZmALURbDuL5/RLf13cAuDeBS2RpbtAm+QFVA3wR+3fUtFHoBDJnC0jIXH0HWsgMY8inPLuOkd9chp4z20ALQLSA8cI9jYAIa2zjzjBd8gRafS1vgiUho/kAKcsCGTOGWvoOpkAtB3z8Hm8x2Ff5ADp4+lXAlIvcmwH/2Q==') repeat left top",padding:"2px 6px"},namespace:{Opacity:".7"},comment:{color:"#586e75",fontStyle:"italic"},prolog:{color:"#586e75",fontStyle:"italic"},doctype:{color:"#586e75",fontStyle:"italic"},cdata:{color:"#586e75",fontStyle:"italic"},number:{color:"#b89859"},string:{color:"#468966"},char:{color:"#468966"},builtin:{color:"#468966"},inserted:{color:"#468966"},"attr-name":{color:"#b89859"},operator:{color:"#dccf8f"},entity:{color:"#dccf8f",cursor:"help"},url:{color:"#dccf8f"},".language-css .token.string":{color:"#dccf8f"},".style .token.string":{color:"#dccf8f"},selector:{color:"#859900"},regex:{color:"#859900"},atrule:{color:"#cb4b16"},keyword:{color:"#cb4b16"},"attr-value":{color:"#468966"},function:{color:"#b58900"},variable:{color:"#b58900"},placeholder:{color:"#b58900"},property:{color:"#b89859"},tag:{color:"#ffb03b"},boolean:{color:"#b89859"},constant:{color:"#b89859"},symbol:{color:"#b89859"},important:{color:"#dc322f"},statement:{color:"#dc322f"},deleted:{color:"#dc322f"},punctuation:{color:"#dccf8f"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(ax)),ax}var ox={},lz;function vye(){return lz||(lz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={"code[class*='language-']":{color:"#9efeff",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",fontFamily:"'Operator Mono', 'Fira Code', Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontWeight:"400",fontSize:"17px",lineHeight:"25px",letterSpacing:"0.5px",textShadow:"0 1px #222245"},"pre[class*='language-']":{color:"#9efeff",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",fontFamily:"'Operator Mono', 'Fira Code', Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontWeight:"400",fontSize:"17px",lineHeight:"25px",letterSpacing:"0.5px",textShadow:"0 1px #222245",padding:"2em",margin:"0.5em 0",overflow:"auto",background:"#1e1e3f"},"pre[class*='language-']::-moz-selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-'] ::-moz-selection":{color:"inherit",background:"#a599e9"},"code[class*='language-']::-moz-selection":{color:"inherit",background:"#a599e9"},"code[class*='language-'] ::-moz-selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-']::selection":{color:"inherit",background:"#a599e9"},"pre[class*='language-'] ::selection":{color:"inherit",background:"#a599e9"},"code[class*='language-']::selection":{color:"inherit",background:"#a599e9"},"code[class*='language-'] ::selection":{color:"inherit",background:"#a599e9"},":not(pre) > code[class*='language-']":{background:"#1e1e3f",padding:"0.1em",borderRadius:"0.3em"},"":{fontWeight:"400"},comment:{color:"#b362ff"},prolog:{color:"#b362ff"},cdata:{color:"#b362ff"},delimiter:{color:"#ff9d00"},keyword:{color:"#ff9d00"},selector:{color:"#ff9d00"},important:{color:"#ff9d00"},atrule:{color:"#ff9d00"},operator:{color:"rgb(255, 180, 84)",background:"none"},"attr-name":{color:"rgb(255, 180, 84)"},punctuation:{color:"#ffffff"},boolean:{color:"rgb(255, 98, 140)"},tag:{color:"rgb(255, 157, 0)"},"tag.punctuation":{color:"rgb(255, 157, 0)"},doctype:{color:"rgb(255, 157, 0)"},builtin:{color:"rgb(255, 157, 0)"},entity:{color:"#6897bb",background:"none"},symbol:{color:"#6897bb"},number:{color:"#ff628c"},property:{color:"#ff628c"},constant:{color:"#ff628c"},variable:{color:"#ff628c"},string:{color:"#a5ff90"},char:{color:"#a5ff90"},"attr-value":{color:"#a5c261"},"attr-value.punctuation":{color:"#a5c261"},"attr-value.punctuation:first-child":{color:"#a9b7c6"},url:{color:"#287bde",textDecoration:"underline",background:"none"},function:{color:"rgb(250, 208, 0)"},regex:{background:"#364135"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{background:"#00ff00"},deleted:{background:"#ff000d"},"code.language-css .token.property":{color:"#a9b7c6"},"code.language-css .token.property + .token.punctuation":{color:"#a9b7c6"},"code.language-css .token.id":{color:"#ffc66d"},"code.language-css .token.selector > .token.class":{color:"#ffc66d"},"code.language-css .token.selector > .token.attribute":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-class":{color:"#ffc66d"},"code.language-css .token.selector > .token.pseudo-element":{color:"#ffc66d"},"class-name":{color:"#fb94ff"},".language-css .token.string":{background:"none"},".style .token.string":{background:"none"},".line-highlight.line-highlight":{marginTop:"36px",background:"linear-gradient(to right, rgba(179, 98, 255, 0.17), transparent)"},".line-highlight.line-highlight:before":{content:"''"},".line-highlight.line-highlight[data-end]:after":{content:"''"}}}(ox)),ox}var ix={},sz;function Sye(){return sz||(sz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#839496",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#839496",textShadow:"0 1px rgba(0, 0, 0, 0.3)",fontFamily:"Inconsolata, Monaco, Consolas, 'Courier New', Courier, monospace",direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",borderRadius:"0.3em",background:"#002b36"},':not(pre) > code[class*="language-"]':{background:"#002b36",padding:".1em",borderRadius:".3em"},comment:{color:"#586e75"},prolog:{color:"#586e75"},doctype:{color:"#586e75"},cdata:{color:"#586e75"},punctuation:{color:"#93a1a1"},".namespace":{Opacity:".7"},property:{color:"#268bd2"},keyword:{color:"#268bd2"},tag:{color:"#268bd2"},"class-name":{color:"#FFFFB6",textDecoration:"underline"},boolean:{color:"#b58900"},constant:{color:"#b58900"},symbol:{color:"#dc322f"},deleted:{color:"#dc322f"},number:{color:"#859900"},selector:{color:"#859900"},"attr-name":{color:"#859900"},string:{color:"#859900"},char:{color:"#859900"},builtin:{color:"#859900"},inserted:{color:"#859900"},variable:{color:"#268bd2"},operator:{color:"#EDEDED"},function:{color:"#268bd2"},regex:{color:"#E9C062"},important:{color:"#fd971f",fontWeight:"bold"},entity:{color:"#FFFFB6",cursor:"help"},url:{color:"#96CBFE"},".language-css .token.string":{color:"#87C38A"},".style .token.string":{color:"#87C38A"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},atrule:{color:"#F9EE98"},"attr-value":{color:"#F9EE98"}}}(ix)),ix}var lx={},uz;function Eye(){return uz||(uz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3",background:"none",fontFamily:"Consolas, Monaco, 'Andale Mono', 'Ubuntu Mono', monospace",fontSize:"1em",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",backgroundColor:"transparent !important",backgroundImage:"linear-gradient(to bottom, #2a2139 75%, #34294f)"},':not(pre) > code[class*="language-"]':{backgroundColor:"transparent !important",backgroundImage:"linear-gradient(to bottom, #2a2139 75%, #34294f)",padding:".1em",borderRadius:".3em",whiteSpace:"normal"},comment:{color:"#8e8e8e"},"block-comment":{color:"#8e8e8e"},prolog:{color:"#8e8e8e"},doctype:{color:"#8e8e8e"},cdata:{color:"#8e8e8e"},punctuation:{color:"#ccc"},tag:{color:"#e2777a"},"attr-name":{color:"#e2777a"},namespace:{color:"#e2777a"},number:{color:"#e2777a"},unit:{color:"#e2777a"},hexcode:{color:"#e2777a"},deleted:{color:"#e2777a"},property:{color:"#72f1b8",textShadow:"0 0 2px #100c0f, 0 0 10px #257c5575, 0 0 35px #21272475"},selector:{color:"#72f1b8",textShadow:"0 0 2px #100c0f, 0 0 10px #257c5575, 0 0 35px #21272475"},"function-name":{color:"#6196cc"},boolean:{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},"selector.id":{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},function:{color:"#fdfdfd",textShadow:"0 0 2px #001716, 0 0 3px #03edf975, 0 0 5px #03edf975, 0 0 8px #03edf975"},"class-name":{color:"#fff5f6",textShadow:"0 0 2px #000, 0 0 10px #fc1f2c75, 0 0 5px #fc1f2c75, 0 0 25px #fc1f2c75"},constant:{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3"},symbol:{color:"#f92aad",textShadow:"0 0 2px #100c0f, 0 0 5px #dc078e33, 0 0 10px #fff3"},important:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575",fontWeight:"bold"},atrule:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},keyword:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},"selector.class":{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},builtin:{color:"#f4eee4",textShadow:"0 0 2px #393a33, 0 0 8px #f39f0575, 0 0 2px #f39f0575"},string:{color:"#f87c32"},char:{color:"#f87c32"},"attr-value":{color:"#f87c32"},regex:{color:"#f87c32"},variable:{color:"#f87c32"},operator:{color:"#67cdcc"},entity:{color:"#67cdcc",cursor:"help"},url:{color:"#67cdcc"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},inserted:{color:"green"}}}(lx)),lx}var sx={},cz;function wye(){return cz||(cz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]':{color:"#393A34",fontFamily:'"Consolas", "Bitstream Vera Sans Mono", "Courier New", Courier, monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",fontSize:".9em",lineHeight:"1.2em",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",border:"1px solid #dddddd",backgroundColor:"white"},'pre > code[class*="language-"]':{fontSize:"1em"},'pre[class*="language-"]::-moz-selection':{background:"#C1DEF1"},'pre[class*="language-"] ::-moz-selection':{background:"#C1DEF1"},'code[class*="language-"]::-moz-selection':{background:"#C1DEF1"},'code[class*="language-"] ::-moz-selection':{background:"#C1DEF1"},'pre[class*="language-"]::selection':{background:"#C1DEF1"},'pre[class*="language-"] ::selection':{background:"#C1DEF1"},'code[class*="language-"]::selection':{background:"#C1DEF1"},'code[class*="language-"] ::selection':{background:"#C1DEF1"},':not(pre) > code[class*="language-"]':{padding:".2em",paddingTop:"1px",paddingBottom:"1px",background:"#f8f8f8",border:"1px solid #dddddd"},comment:{color:"#008000",fontStyle:"italic"},prolog:{color:"#008000",fontStyle:"italic"},doctype:{color:"#008000",fontStyle:"italic"},cdata:{color:"#008000",fontStyle:"italic"},namespace:{Opacity:".7"},string:{color:"#A31515"},punctuation:{color:"#393A34"},operator:{color:"#393A34"},url:{color:"#36acaa"},symbol:{color:"#36acaa"},number:{color:"#36acaa"},boolean:{color:"#36acaa"},variable:{color:"#36acaa"},constant:{color:"#36acaa"},inserted:{color:"#36acaa"},atrule:{color:"#0000ff"},keyword:{color:"#0000ff"},"attr-value":{color:"#0000ff"},".language-autohotkey .token.selector":{color:"#0000ff"},".language-json .token.boolean":{color:"#0000ff"},".language-json .token.number":{color:"#0000ff"},'code[class*="language-css"]':{color:"#0000ff"},function:{color:"#393A34"},deleted:{color:"#9a050f"},".language-autohotkey .token.tag":{color:"#9a050f"},selector:{color:"#800000"},".language-autohotkey .token.keyword":{color:"#00009f"},important:{color:"#e90",fontWeight:"bold"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"},"class-name":{color:"#2B91AF"},".language-json .token.property":{color:"#2B91AF"},tag:{color:"#800000"},"attr-name":{color:"#ff0000"},property:{color:"#ff0000"},regex:{color:"#ff0000"},entity:{color:"#ff0000"},"directive.tag.tag":{background:"#ffff00",color:"#393A34"},".line-numbers.line-numbers .line-numbers-rows":{borderRightColor:"#a5a5a5"},".line-numbers .line-numbers-rows > span:before":{color:"#2B91AF"},".line-highlight.line-highlight":{background:"linear-gradient(to right, rgba(193, 222, 241, 0.2) 70%, rgba(221, 222, 241, 0))"}}}(sx)),sx}var ux={},dz;function xye(){return dz||(dz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'pre[class*="language-"]':{color:"#d4d4d4",fontSize:"13px",textShadow:"none",fontFamily:'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",padding:"1em",margin:".5em 0",overflow:"auto",background:"#1e1e1e"},'code[class*="language-"]':{color:"#d4d4d4",fontSize:"13px",textShadow:"none",fontFamily:'Menlo, Monaco, Consolas, "Andale Mono", "Ubuntu Mono", "Courier New", monospace',direction:"ltr",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",lineHeight:"1.5",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none"},'pre[class*="language-"]::selection':{textShadow:"none",background:"#264F78"},'code[class*="language-"]::selection':{textShadow:"none",background:"#264F78"},'pre[class*="language-"] *::selection':{textShadow:"none",background:"#264F78"},'code[class*="language-"] *::selection':{textShadow:"none",background:"#264F78"},':not(pre) > code[class*="language-"]':{padding:".1em .3em",borderRadius:".3em",color:"#db4c69",background:"#1e1e1e"},".namespace":{Opacity:".7"},"doctype.doctype-tag":{color:"#569CD6"},"doctype.name":{color:"#9cdcfe"},comment:{color:"#6a9955"},prolog:{color:"#6a9955"},punctuation:{color:"#d4d4d4"},".language-html .language-css .token.punctuation":{color:"#d4d4d4"},".language-html .language-javascript .token.punctuation":{color:"#d4d4d4"},property:{color:"#9cdcfe"},tag:{color:"#569cd6"},boolean:{color:"#569cd6"},number:{color:"#b5cea8"},constant:{color:"#9cdcfe"},symbol:{color:"#b5cea8"},inserted:{color:"#b5cea8"},unit:{color:"#b5cea8"},selector:{color:"#d7ba7d"},"attr-name":{color:"#9cdcfe"},string:{color:"#ce9178"},char:{color:"#ce9178"},builtin:{color:"#ce9178"},deleted:{color:"#ce9178"},".language-css .token.string.url":{textDecoration:"underline"},operator:{color:"#d4d4d4"},entity:{color:"#569cd6"},"operator.arrow":{color:"#569CD6"},atrule:{color:"#ce9178"},"atrule.rule":{color:"#c586c0"},"atrule.url":{color:"#9cdcfe"},"atrule.url.function":{color:"#dcdcaa"},"atrule.url.punctuation":{color:"#d4d4d4"},keyword:{color:"#569CD6"},"keyword.module":{color:"#c586c0"},"keyword.control-flow":{color:"#c586c0"},function:{color:"#dcdcaa"},"function.maybe-class-name":{color:"#dcdcaa"},regex:{color:"#d16969"},important:{color:"#569cd6"},italic:{fontStyle:"italic"},"class-name":{color:"#4ec9b0"},"maybe-class-name":{color:"#4ec9b0"},console:{color:"#9cdcfe"},parameter:{color:"#9cdcfe"},interpolation:{color:"#9cdcfe"},"punctuation.interpolation-punctuation":{color:"#569cd6"},variable:{color:"#9cdcfe"},"imports.maybe-class-name":{color:"#9cdcfe"},"exports.maybe-class-name":{color:"#9cdcfe"},escape:{color:"#d7ba7d"},"tag.punctuation":{color:"#808080"},cdata:{color:"#808080"},"attr-value":{color:"#ce9178"},"attr-value.punctuation":{color:"#ce9178"},"attr-value.punctuation.attr-equals":{color:"#d4d4d4"},namespace:{color:"#4ec9b0"},'pre[class*="language-javascript"]':{color:"#9cdcfe"},'code[class*="language-javascript"]':{color:"#9cdcfe"},'pre[class*="language-jsx"]':{color:"#9cdcfe"},'code[class*="language-jsx"]':{color:"#9cdcfe"},'pre[class*="language-typescript"]':{color:"#9cdcfe"},'code[class*="language-typescript"]':{color:"#9cdcfe"},'pre[class*="language-tsx"]':{color:"#9cdcfe"},'code[class*="language-tsx"]':{color:"#9cdcfe"},'pre[class*="language-css"]':{color:"#ce9178"},'code[class*="language-css"]':{color:"#ce9178"},'pre[class*="language-html"]':{color:"#d4d4d4"},'code[class*="language-html"]':{color:"#d4d4d4"},".language-regex .token.anchor":{color:"#dcdcaa"},".language-html .token.punctuation":{color:"#808080"},'pre[class*="language-"] > code[class*="language-"]':{position:"relative",zIndex:"1"},".line-highlight.line-highlight":{background:"#f7ebc6",boxShadow:"inset 5px 0 0 #f7d87c",zIndex:"0"}}}(ux)),ux}var cx={},fz;function kye(){return fz||(fz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordWrap:"normal",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"14px",color:"#76d9e6",textShadow:"none"},'pre[class*="language-"]':{MozTabSize:"2",OTabSize:"2",tabSize:"2",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",whiteSpace:"pre-wrap",wordWrap:"normal",fontFamily:'Menlo, Monaco, "Courier New", monospace',fontSize:"14px",color:"#76d9e6",textShadow:"none",background:"#2a2a2a",padding:"15px",borderRadius:"4px",border:"1px solid #e1e1e8",overflow:"auto",position:"relative"},'pre > code[class*="language-"]':{fontSize:"1em"},':not(pre) > code[class*="language-"]':{background:"#2a2a2a",padding:"0.15em 0.2em 0.05em",borderRadius:".3em",border:"0.13em solid #7a6652",boxShadow:"1px 1px 0.3em -0.1em #000 inset"},'pre[class*="language-"] code':{whiteSpace:"pre",display:"block"},namespace:{Opacity:".7"},comment:{color:"#6f705e"},prolog:{color:"#6f705e"},doctype:{color:"#6f705e"},cdata:{color:"#6f705e"},operator:{color:"#a77afe"},boolean:{color:"#a77afe"},number:{color:"#a77afe"},"attr-name":{color:"#e6d06c"},string:{color:"#e6d06c"},entity:{color:"#e6d06c",cursor:"help"},url:{color:"#e6d06c"},".language-css .token.string":{color:"#e6d06c"},".style .token.string":{color:"#e6d06c"},selector:{color:"#a6e22d"},inserted:{color:"#a6e22d"},atrule:{color:"#ef3b7d"},"attr-value":{color:"#ef3b7d"},keyword:{color:"#ef3b7d"},important:{color:"#ef3b7d",fontWeight:"bold"},deleted:{color:"#ef3b7d"},regex:{color:"#76d9e6"},statement:{color:"#76d9e6",fontWeight:"bold"},placeholder:{color:"#fff"},variable:{color:"#fff"},bold:{fontWeight:"bold"},punctuation:{color:"#bebec5"},italic:{fontStyle:"italic"},"code.language-markup":{color:"#f9f9f9"},"code.language-markup .token.tag":{color:"#ef3b7d"},"code.language-markup .token.attr-name":{color:"#a6e22d"},"code.language-markup .token.attr-value":{color:"#e6d06c"},"code.language-markup .token.style":{color:"#76d9e6"},"code.language-markup .token.script":{color:"#76d9e6"},"code.language-markup .token.script .token.keyword":{color:"#76d9e6"},".line-highlight.line-highlight":{padding:"0",background:"rgba(255, 255, 255, 0.08)"},".line-highlight.line-highlight:before":{padding:"0.2em 0.5em",backgroundColor:"rgba(255, 255, 255, 0.4)",color:"black",height:"1em",lineHeight:"1em",boxShadow:"0 1px 1px rgba(255, 255, 255, 0.7)"},".line-highlight.line-highlight[data-end]:after":{padding:"0.2em 0.5em",backgroundColor:"rgba(255, 255, 255, 0.4)",color:"black",height:"1em",lineHeight:"1em",boxShadow:"0 1px 1px rgba(255, 255, 255, 0.7)"}}}(cx)),cx}var dx={},pz;function Aye(){return pz||(pz=1,function(e){Object.defineProperty(e,"__esModule",{value:!0}),e.default=void 0,e.default={'code[class*="language-"]':{color:"#22da17",fontFamily:"monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",lineHeight:"25px",fontSize:"18px",margin:"5px 0"},'pre[class*="language-"]':{color:"white",fontFamily:"monospace",textAlign:"left",whiteSpace:"pre",wordSpacing:"normal",wordBreak:"normal",wordWrap:"normal",MozTabSize:"4",OTabSize:"4",tabSize:"4",WebkitHyphens:"none",MozHyphens:"none",msHyphens:"none",hyphens:"none",lineHeight:"25px",fontSize:"18px",margin:"0.5em 0",background:"#0a143c",padding:"1em",overflow:"auto"},'pre[class*="language-"] *':{fontFamily:"monospace"},':not(pre) > code[class*="language-"]':{color:"white",background:"#0a143c",padding:"0.1em",borderRadius:"0.3em",whiteSpace:"normal"},'pre[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::-moz-selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'pre[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"]::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},'code[class*="language-"] ::selection':{textShadow:"none",background:"rgba(29, 59, 83, 0.99)"},comment:{color:"rgb(99, 119, 119)",fontStyle:"italic"},prolog:{color:"rgb(99, 119, 119)",fontStyle:"italic"},cdata:{color:"rgb(99, 119, 119)",fontStyle:"italic"},punctuation:{color:"rgb(199, 146, 234)"},".namespace":{color:"rgb(178, 204, 214)"},deleted:{color:"rgba(239, 83, 80, 0.56)",fontStyle:"italic"},symbol:{color:"rgb(128, 203, 196)"},property:{color:"rgb(128, 203, 196)"},tag:{color:"rgb(127, 219, 202)"},operator:{color:"rgb(127, 219, 202)"},keyword:{color:"rgb(127, 219, 202)"},boolean:{color:"rgb(255, 88, 116)"},number:{color:"rgb(247, 140, 108)"},constant:{color:"rgb(34 183 199)"},function:{color:"rgb(34 183 199)"},builtin:{color:"rgb(34 183 199)"},char:{color:"rgb(34 183 199)"},selector:{color:"rgb(199, 146, 234)",fontStyle:"italic"},doctype:{color:"rgb(199, 146, 234)",fontStyle:"italic"},"attr-name":{color:"rgb(173, 219, 103)",fontStyle:"italic"},inserted:{color:"rgb(173, 219, 103)",fontStyle:"italic"},string:{color:"rgb(173, 219, 103)"},url:{color:"rgb(173, 219, 103)"},entity:{color:"rgb(173, 219, 103)"},".language-css .token.string":{color:"rgb(173, 219, 103)"},".style .token.string":{color:"rgb(173, 219, 103)"},"class-name":{color:"rgb(255, 203, 139)"},atrule:{color:"rgb(255, 203, 139)"},"attr-value":{color:"rgb(255, 203, 139)"},regex:{color:"rgb(214, 222, 235)"},important:{color:"rgb(214, 222, 235)",fontWeight:"bold"},variable:{color:"rgb(214, 222, 235)"},bold:{fontWeight:"bold"},italic:{fontStyle:"italic"}}}(dx)),dx}var gz;function Tye(){return gz||(gz=1,function(e){var t=Mbe();Object.defineProperty(e,"__esModule",{value:!0}),Object.defineProperty(e,"a11yDark",{enumerable:!0,get:function(){return p.default}}),Object.defineProperty(e,"atomDark",{enumerable:!0,get:function(){return g.default}}),Object.defineProperty(e,"base16AteliersulphurpoolLight",{enumerable:!0,get:function(){return b.default}}),Object.defineProperty(e,"cb",{enumerable:!0,get:function(){return m.default}}),Object.defineProperty(e,"coldarkCold",{enumerable:!0,get:function(){return S.default}}),Object.defineProperty(e,"coldarkDark",{enumerable:!0,get:function(){return v.default}}),Object.defineProperty(e,"coy",{enumerable:!0,get:function(){return n.default}}),Object.defineProperty(e,"coyWithoutShadows",{enumerable:!0,get:function(){return A.default}}),Object.defineProperty(e,"darcula",{enumerable:!0,get:function(){return R.default}}),Object.defineProperty(e,"dark",{enumerable:!0,get:function(){return r.default}}),Object.defineProperty(e,"dracula",{enumerable:!0,get:function(){return x.default}}),Object.defineProperty(e,"duotoneDark",{enumerable:!0,get:function(){return T.default}}),Object.defineProperty(e,"duotoneEarth",{enumerable:!0,get:function(){return C.default}}),Object.defineProperty(e,"duotoneForest",{enumerable:!0,get:function(){return N.default}}),Object.defineProperty(e,"duotoneLight",{enumerable:!0,get:function(){return _.default}}),Object.defineProperty(e,"duotoneSea",{enumerable:!0,get:function(){return O.default}}),Object.defineProperty(e,"duotoneSpace",{enumerable:!0,get:function(){return z.default}}),Object.defineProperty(e,"funky",{enumerable:!0,get:function(){return a.default}}),Object.defineProperty(e,"ghcolors",{enumerable:!0,get:function(){return I.default}}),Object.defineProperty(e,"gruvboxDark",{enumerable:!0,get:function(){return M.default}}),Object.defineProperty(e,"gruvboxLight",{enumerable:!0,get:function(){return H.default}}),Object.defineProperty(e,"holiTheme",{enumerable:!0,get:function(){return q.default}}),Object.defineProperty(e,"hopscotch",{enumerable:!0,get:function(){return P.default}}),Object.defineProperty(e,"lucario",{enumerable:!0,get:function(){return W.default}}),Object.defineProperty(e,"materialDark",{enumerable:!0,get:function(){return Z.default}}),Object.defineProperty(e,"materialLight",{enumerable:!0,get:function(){return j.default}}),Object.defineProperty(e,"materialOceanic",{enumerable:!0,get:function(){return G.default}}),Object.defineProperty(e,"nightOwl",{enumerable:!0,get:function(){return B.default}}),Object.defineProperty(e,"nord",{enumerable:!0,get:function(){return X.default}}),Object.defineProperty(e,"okaidia",{enumerable:!0,get:function(){return i.default}}),Object.defineProperty(e,"oneDark",{enumerable:!0,get:function(){return D.default}}),Object.defineProperty(e,"oneLight",{enumerable:!0,get:function(){return V.default}}),Object.defineProperty(e,"pojoaque",{enumerable:!0,get:function(){return U.default}}),Object.defineProperty(e,"prism",{enumerable:!0,get:function(){return f.default}}),Object.defineProperty(e,"shadesOfPurple",{enumerable:!0,get:function(){return L.default}}),Object.defineProperty(e,"solarizedDarkAtom",{enumerable:!0,get:function(){return Y.default}}),Object.defineProperty(e,"solarizedlight",{enumerable:!0,get:function(){return l.default}}),Object.defineProperty(e,"synthwave84",{enumerable:!0,get:function(){return Q.default}}),Object.defineProperty(e,"tomorrow",{enumerable:!0,get:function(){return u.default}}),Object.defineProperty(e,"twilight",{enumerable:!0,get:function(){return c.default}}),Object.defineProperty(e,"vs",{enumerable:!0,get:function(){return se.default}}),Object.defineProperty(e,"vscDarkPlus",{enumerable:!0,get:function(){return re.default}}),Object.defineProperty(e,"xonokai",{enumerable:!0,get:function(){return le.default}}),Object.defineProperty(e,"zTouch",{enumerable:!0,get:function(){return Ae.default}});var n=t(Fbe()),r=t(zbe()),a=t(Pbe()),i=t(Bbe()),l=t(Ube()),u=t(jbe()),c=t(Gbe()),f=t(Hbe()),p=t($be()),g=t(qbe()),b=t(Vbe()),m=t(Wbe()),S=t(Ybe()),v=t(Kbe()),A=t(Xbe()),R=t(Zbe()),x=t(Qbe()),T=t(Jbe()),C=t(eye()),N=t(tye()),_=t(nye()),O=t(rye()),z=t(aye()),I=t(oye()),M=t(iye()),H=t(lye()),q=t(sye()),P=t(uye()),W=t(cye()),Z=t(dye()),j=t(fye()),G=t(pye()),B=t(gye()),X=t(hye()),D=t(mye()),V=t(bye()),U=t(yye()),L=t(vye()),Y=t(Sye()),Q=t(Eye()),se=t(wye()),re=t(xye()),le=t(kye()),Ae=t(Aye())}(Sw)),Sw}var hz=Tye();const _ye=({message:e})=>{const t=k.useCallback(async()=>{if(e.content)try{await navigator.clipboard.writeText(e.content)}catch(n){console.error("Failed to copy:",n)}},[e]);return w.jsxs("div",{className:`max-w-[80%] rounded-lg px-4 py-2 ${e.role==="user"?"bg-primary text-primary-foreground":e.isError?"bg-red-100 text-red-600 dark:bg-red-950 dark:text-red-400":"bg-muted"}`,children:[w.jsxs("pre",{className:"relative break-words whitespace-pre-wrap",children:[w.jsx(Mle,{className:"dark:prose-invert max-w-none text-base text-sm",remarkPlugins:[Wue,oce],rehypePlugins:[Yue],skipHtml:!1,components:{code:Cye},children:e.content}),e.role==="assistant"&&e.content.length>0&&w.jsx(Lt,{onClick:t,className:"absolute right-0 bottom-0 size-6 rounded-md opacity-20 transition-opacity hover:opacity-100",tooltip:"Copy to clipboard",variant:"default",size:"icon",children:w.jsx(Cq,{})})]}),e.content.length===0&&w.jsx(Hq,{className:"animate-spin duration-2000"})]})},Rye=e=>!(e.children||[]).filter(n=>n.type==="text").map(n=>n.value).join("").includes(`
`),Cye=({className:e,children:t,node:n,...r})=>{const{theme:a}=l0(),i=e==null?void 0:e.match(/language-(\w+)/),l=i?i[1]:void 0;return(n?Rye(n):!1)?w.jsx("code",{className:Me(e,"mx-1 rounded-xs bg-black/10 px-1 dark:bg-gray-100/20"),...r,children:t}):w.jsx(J5,{style:a==="dark"?hz.oneDark:hz.oneLight,PreTag:"div",language:l,...r,children:String(t).replace(/\n$/,"")})};function Nye(){const[e,t]=k.useState(()=>We.getState().retrievalHistory||[]),[n,r]=k.useState(""),[a,i]=k.useState(!1),l=k.useRef(null),u=k.useCallback(()=>{var g;(g=l.current)==null||g.scrollIntoView({behavior:"smooth"})},[]),c=k.useCallback(async g=>{if(g.preventDefault(),!n.trim()||a)return;const b={content:n,role:"user"},m={content:"",role:"assistant"},S=[...e];t([...S,b,m]),r(""),i(!0);const v=(x,T)=>{m.content+=x,t(C=>{const N=[...C],_=N[N.length-1];return _.role==="assistant"&&(_.content=m.content,_.isError=T),N})},A=We.getState(),R={...A.querySettings,query:b.content,conversation_history:S.filter(x=>x.isError!==!0).map(x=>({role:x.role,content:x.content}))};try{if(A.querySettings.stream){let x="";await gq(R,v,T=>{x+=T}),x&&(m.content&&(x=m.content+`
`+x),v(x,!0))}else{const x=await pq(R);v(x.response)}}catch(x){v(`Error: Failed to get response
${Nr(x)}`,!0)}finally{i(!1),We.getState().setRetrievalHistory([...S,b,m])}},[n,a,e,t]),f=I0(e,100);k.useEffect(()=>u(),[f,u]);const p=k.useCallback(()=>{t([]),We.getState().setRetrievalHistory([])},[t]);return w.jsxs("div",{className:"flex size-full gap-2 px-2 pb-12",children:[w.jsxs("div",{className:"flex grow flex-col gap-4",children:[w.jsx("div",{className:"relative grow",children:w.jsx("div",{className:"bg-primary-foreground/60 absolute inset-0 flex flex-col overflow-auto rounded-lg border p-2",children:w.jsxs("div",{className:"flex min-h-0 flex-1 flex-col gap-2",children:[e.length===0?w.jsx("div",{className:"text-muted-foreground flex h-full items-center justify-center text-lg",children:"Start a retrieval by typing your query below"}):e.map((g,b)=>w.jsx("div",{className:`flex ${g.role==="user"?"justify-end":"justify-start"}`,children:w.jsx(_ye,{message:g})},b)),w.jsx("div",{ref:l,className:"pb-1"})]})})}),w.jsxs("form",{onSubmit:c,className:"flex shrink-0 items-center gap-2",children:[w.jsxs(Lt,{type:"button",variant:"outline",onClick:p,disabled:a,size:"sm",children:[w.jsx(uP,{}),"Clear"]}),w.jsx(Eo,{className:"flex-1",value:n,onChange:g=>r(g.target.value),placeholder:"Type your query...",disabled:a}),w.jsxs(Lt,{type:"submit",variant:"default",disabled:a,size:"sm",children:[w.jsx(o8,{}),"Send"]})]})]}),w.jsx(kre,{})]})}function Oye(){return w.jsx("iframe",{src:Rz+"/docs",className:"size-full"})}function Dye(){const e=Pn.use.message(),t=We.use.enableHealthCheck(),[n]=k.useState(()=>We.getState().currentTab),[r,a]=k.useState(!1);k.useEffect(()=>{if(!t)return;Pn.getState().check();const l=setInterval(async()=>{await Pn.getState().check()},T9*1e3);return()=>clearInterval(l)},[t]);const i=k.useCallback(l=>We.getState().setCurrentTab(l),[]);return k.useEffect(()=>{if(e&&(e.includes(oP)||e.includes(iP))){a(!0);return}a(!1)},[e,a]),w.jsx(N9,{children:w.jsxs("main",{className:"flex h-screen w-screen overflow-x-hidden",children:[w.jsxs(LY,{defaultValue:n,className:"!m-0 flex grow flex-col !p-0",onValueChange:i,children:[w.jsx(FY,{}),w.jsxs("div",{className:"relative grow",children:[w.jsx(Vs,{value:"documents",className:"absolute top-0 right-0 bottom-0 left-0",children:w.jsx(Ane,{})}),w.jsx(Vs,{value:"knowledge-graph",className:"absolute top-0 right-0 bottom-0 left-0",children:w.jsx(Kee,{})}),w.jsx(Vs,{value:"retrieval",className:"absolute top-0 right-0 bottom-0 left-0",children:w.jsx(Nye,{})}),w.jsx(Vs,{value:"api",className:"absolute top-0 right-0 bottom-0 left-0",children:w.jsx(Oye,{})})]})]}),t&&w.jsx(mY,{}),e!==null&&!r&&w.jsx(y8,{}),r&&w.jsx(nY,{}),w.jsx(tY,{})]})})}xH.createRoot(document.getElementById("root")).render(w.jsx(k.StrictMode,{children:w.jsx(Dye,{})}));
